-- sql
-- $Source: gm_brand-ca.sql
-- $Revision: 1
-- $Author: Jim Busser, GNUmed project
-- ---------------------------
-- Description:
-- script for importing Health Canada DPD data
-- … into GNUmed ref.branded_drug
-- … renamed as 'install-data-pack.sql' within GNUmed data packs
-- … configurational name = variants of 'Drugs, brand, <Country>'
-- … zip archive name = variants of 'drugs_brand_COUNTRY.zip
-- Caveats:
-- 1. The data in this pack will have been acquired directly from Health Canada
-- 2. It best avoids duplication in brand information when the praxis branded drugs info
--    was obtained only from earlier Canadian data packs or from FreeDiams Canadian db.
-- 3. The data pack will register new drugs as though they were from source FreeDiams. This is in 
--    order to leverage interoperability with FreeDiams' HCDPD-derived Canadian db source.
-- ---------------------------
-- References / links:
-- GNUmed git repository, data packs and project
--   git://gitorious.org/gnumed/gnumed.git
--   http://wiki.gnumed.de/bin/view/Gnumed/GmManualReferenceData
--   http://www.gnumed.de/downloads/data/data-packs.conf
--   http://wiki.gnumed.de
-- Health Canada DPD
--   file listing:
--     http://www.hc-sc.gc.ca/dhp-mps/prodpharma/databasdon/dpd_bdpp_data_extract-eng.php
--   data specifications:
--     http://www.hc-sc.gc.ca/dhp-mps/alt_formats/hpfb-dgpsa/txt/prodpharma/dpdreadme_bdpplisezmoi-eng.txt
-- ----------------------

-- uncomment the following to run from psql (instead of from GNUmed GUI)
-- set default_transaction_read_only to off;

-----------------------------------------------------------------------------
-- ************************************************************
-- set ON_ERROR_STOP 1
-- ************************************************************
-- ---------------------------------------------------------------------------
\set ON_ERROR_STOP 1

-----------------------------------------------------------------------------
-- ************************************************************
-- create staging table
-- ************************************************************
-- -----------------------------------------------------------------------------
-- ---------------------------------------------
\unset ON_ERROR_STOP
DROP TABLE staging.branded_drug CASCADE;
DROP TABLE staging.consumable_substance CASCADE;
DROP TABLE staging.vaccine CASCADE;
DROP TABLE staging.ingred CASCADE;
DROP TABLE staging.ingred2ind CASCADE;
\set ON_ERROR_STOP 1

begin;

CREATE TABLE staging.branded_drug
(
  description text NOT NULL,
  preparation text NOT NULL,
  atc_code text,
  is_fake boolean NOT NULL DEFAULT false,
  fk_data_source integer,
  external_code text,
  external_code_type text,
  drug_code integer
);

CREATE TABLE staging.consumable_substance
(
  description text,
  atc_code text,
  amount numeric,
  unit text,
  drug_code integer
);

CREATE TABLE staging.ingred (
    drug_code integer,
    ingred_code integer,
    description varchar(240),
    supplied varchar(1),
    strength numeric,
    strength_unit varchar(40),
    strength_type varchar(40),
    dosage_value varchar(20),
    base varchar(1),
    dosage_unit varchar(40),
    notes varchar(2000)
);

CREATE TABLE staging.vaccine
(
	is_live boolean,
	external_code varchar,
	route varchar
);

CREATE TABLE staging.ingred2ind (
	ingred_code integer,
	fk_indication integer
);

-- -----------------------------------------------------------------------------
-- *********************
-- import staging data
-- *********************
-- -----------------------------------------------------------------------------
--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = staging, pg_catalog;

--
-- Data for Name: branded_drug; Type: TABLE DATA; Schema: staging; Owner: gm-dbo
--

INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tapazole 5mg Tablet', 'tablet', 'H03BB02', false, 0, '00015741', 'FreeDiams::CA_HCDPD::DIN', 9);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aventyl', 'capsule', 'N06AA10', false, 0, '00015229', 'FreeDiams::CA_HCDPD::DIN', 15);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aventyl', 'capsule', 'N06AA10', false, 0, '00015237', 'FreeDiams::CA_HCDPD::DIN', 16);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neo-Bex Injectable', 'solution', 'A11EX', false, 0, '00147680', 'FreeDiams::CA_HCDPD::DIN', 31);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gentiane Violet Liq Top', 'liquid', 'D01AE02', false, 0, '00050857', 'FreeDiams::CA_HCDPD::DIN', 44);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minerale Legere Huile', 'liquid', 'D02AC', false, 0, '00050520', 'FreeDiams::CA_HCDPD::DIN', 57);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylene Bleu Liq 1%', 'liquid', 'V04CG05', false, 0, '00050466', 'FreeDiams::CA_HCDPD::DIN', 68);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylene Bleu Liq 2%', 'liquid', 'V03AB17', false, 0, '00050474', 'FreeDiams::CA_HCDPD::DIN', 69);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bacteriostatic Sodium Chloride Injection', 'solution', 'B05CB01', false, 0, '00037818', 'FreeDiams::CA_HCDPD::DIN', 115);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bacteriostatic Water For Injection', 'liquid', 'V07AB', false, 0, '00038202', 'FreeDiams::CA_HCDPD::DIN', 117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Entrophen 325mg Tablets', 'tablet (delayed-release)', 'N02BA01', false, 0, '00010332', 'FreeDiams::CA_HCDPD::DIN', 157);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Propyl-Thyracil', 'tablet', 'H03BA02', false, 0, '00010200', 'FreeDiams::CA_HCDPD::DIN', 158);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Propyl-Thyracil', 'tablet', 'H03BA02', false, 0, '00010219', 'FreeDiams::CA_HCDPD::DIN', 159);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Papaverine Hydrochloride Injection Usp', 'liquid', 'A03AD01', false, 0, '00009881', 'FreeDiams::CA_HCDPD::DIN', 160);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bionet Lozenge', 'lozenge', 'R02AA20', false, 0, '00116785', 'FreeDiams::CA_HCDPD::DIN', 186);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diovol Plus Suspension', 'suspension', 'A02AF02', false, 0, '00116815', 'FreeDiams::CA_HCDPD::DIN', 187);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diovol Plus Tablets', 'tablet', 'A02AF02', false, 0, '00116882', 'FreeDiams::CA_HCDPD::DIN', 188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gravol Adult Suppositories 100mg', 'suppository', 'R06AA02', false, 0, '00013609', 'FreeDiams::CA_HCDPD::DIN', 193);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gravol Im', 'solution', 'R06AA02', false, 0, '00013579', 'FreeDiams::CA_HCDPD::DIN', 197);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ovol Drops 40mg', 'drops', 'A03AX13', false, 0, '00013617', 'FreeDiams::CA_HCDPD::DIN', 198);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buminate 5%', 'solution', 'B05AA01', false, 0, '00118311', 'FreeDiams::CA_HCDPD::DIN', 207);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buminate 25%', 'solution', 'B05AA01', false, 0, '00118303', 'FreeDiams::CA_HCDPD::DIN', 208);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine Viscous 2%', 'liquid', 'N01BB02', false, 0, '00001686', 'FreeDiams::CA_HCDPD::DIN', 209);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine Topical 4%', 'spray', 'N01BB02', false, 0, '00049816', 'FreeDiams::CA_HCDPD::DIN', 210);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine Ointment 5%', 'ointment', 'D04AB01', false, 0, '00001961', 'FreeDiams::CA_HCDPD::DIN', 211);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine Jelly 2%', 'jelly', 'N01BB02', false, 0, '00001694', 'FreeDiams::CA_HCDPD::DIN', 212);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentothal Sodium Inj 1gm Sterile', 'powder for solution', 'N01AF03', false, 0, '00038407', 'FreeDiams::CA_HCDPD::DIN', 224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quelicin Chloride Inj 20mg/Ml', 'solution', 'M03AB01', false, 0, '00038172', 'FreeDiams::CA_HCDPD::DIN', 227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride Irrigation 9mg/Ml', 'solution', 'B05CB01', false, 0, '00037834', 'FreeDiams::CA_HCDPD::DIN', 228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Water For Irrigation', 'liquid', 'V07AB', false, 0, '00038229', 'FreeDiams::CA_HCDPD::DIN', 229);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germex 11.5%', 'liquid', 'V07AV', false, 0, '00141569', 'FreeDiams::CA_HCDPD::DIN', 234);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cosmegen', 'powder for solution', 'L01DA01', false, 0, '00213071', 'FreeDiams::CA_HCDPD::DIN', 250);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isopto Atropine  1%', 'liquid', 'S01FA01', false, 0, '00035017', 'FreeDiams::CA_HCDPD::DIN', 254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isopto Carbachol 3%', 'liquid', 'S01EB02', false, 0, '00000663', 'FreeDiams::CA_HCDPD::DIN', 255);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isopto Homatropine 2%', 'liquid', 'S01FA05', false, 0, '00000779', 'FreeDiams::CA_HCDPD::DIN', 257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isopto Homatropine 5%', 'liquid', 'S01FA05', false, 0, '00000787', 'FreeDiams::CA_HCDPD::DIN', 258);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maxitrol', 'suspension', 'S01CA01', false, 0, '00042676', 'FreeDiams::CA_HCDPD::DIN', 259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mydriacyl 0.5%', 'liquid', 'S01FA06', false, 0, '00000981', 'FreeDiams::CA_HCDPD::DIN', 260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cuprimine', 'capsule', 'M01CC01', false, 0, '00016055', 'FreeDiams::CA_HCDPD::DIN', 287);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Quinine Cap 300mg', 'capsule', 'P01BC01', false, 0, '00021016', 'FreeDiams::CA_HCDPD::DIN', 290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pen-Vk 500 Tab', 'tablet', 'J01CE02', false, 0, '00021202', 'FreeDiams::CA_HCDPD::DIN', 295);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atarax Syrup 2mg/Ml', 'syrup', 'N05BB01', false, 0, '00024694', 'FreeDiams::CA_HCDPD::DIN', 316);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Celestone Soluspan', 'suspension', 'H02AB01', false, 0, '00028096', 'FreeDiams::CA_HCDPD::DIN', 354);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Sulamyd 10%', 'drops', 'S01AB04', false, 0, '00028053', 'FreeDiams::CA_HCDPD::DIN', 371);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenobarb', 'tablet', 'N03AA02', false, 0, '00178799', 'FreeDiams::CA_HCDPD::DIN', 405);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenobarb', 'tablet', 'N03AA02', false, 0, '00178802', 'FreeDiams::CA_HCDPD::DIN', 406);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenobarb', 'tablet', 'N03AA02', false, 0, '00178810', 'FreeDiams::CA_HCDPD::DIN', 407);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenobarb', 'tablet', 'N03AA02', false, 0, '00178829', 'FreeDiams::CA_HCDPD::DIN', 408);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Emo Cort Lotion 1%', 'lotion', 'D07AA02', false, 0, '00192600', 'FreeDiams::CA_HCDPD::DIN', 410);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Emo Cort Cream 1%', 'cream', 'D07AA02', false, 0, '00192597', 'FreeDiams::CA_HCDPD::DIN', 411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cafergot Tab', 'tablet', 'N02CA52', false, 0, '00176095', 'FreeDiams::CA_HCDPD::DIN', 413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dihydroergotamine (Dhe), 1mg/Ml', 'liquid', 'N02CA01', false, 0, '00027243', 'FreeDiams::CA_HCDPD::DIN', 415);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lincocin', 'solution', 'J01FF02', false, 0, '00030732', 'FreeDiams::CA_HCDPD::DIN', 425);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Provera 5mg Tablets', 'tablet', 'G03DA02', false, 0, '00030937', 'FreeDiams::CA_HCDPD::DIN', 430);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bacitracin Usp', 'powder for solution', 'J01XX10', false, 0, '00030708', 'FreeDiams::CA_HCDPD::DIN', 431);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cortef Tablets 10mg', 'tablet', 'H02AB09', false, 0, '00030910', 'FreeDiams::CA_HCDPD::DIN', 432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cortef Tablets 20 Mg', 'tablet', 'H02AB09', false, 0, '00030929', 'FreeDiams::CA_HCDPD::DIN', 433);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Depo-Provera Sterile Aqueous Suspension 50 Mg/Ml', 'suspension', 'G03AC06', false, 0, '00030848', 'FreeDiams::CA_HCDPD::DIN', 441);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Entrophen Ect 650mg', 'tablet (enteric-coated)', 'N02BA01', false, 0, '00010340', 'FreeDiams::CA_HCDPD::DIN', 468);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin A Cap 25000iu', 'capsule', 'A11CA01', false, 0, '00021067', 'FreeDiams::CA_HCDPD::DIN', 502);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin A Cap 50000iu', 'capsule', 'A11CA01', false, 0, '00021075', 'FreeDiams::CA_HCDPD::DIN', 503);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Prednisone 5mg', 'tablet', 'H02AB07', false, 0, '00021695', 'FreeDiams::CA_HCDPD::DIN', 507);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isopto Carbachol 1.5%', 'liquid', 'S01EB02', false, 0, '00000655', 'FreeDiams::CA_HCDPD::DIN', 575);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Dimenate 50mg', 'tablet', 'R06AA02', false, 0, '00021423', 'FreeDiams::CA_HCDPD::DIN', 577);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Folacid 5mg', 'tablet', 'B03BB01', false, 0, '00021466', 'FreeDiams::CA_HCDPD::DIN', 578);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pheniram 4mg', 'tablet', 'R06AB04', false, 0, '00021288', 'FreeDiams::CA_HCDPD::DIN', 579);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine 0.5%', 'liquid', 'N01BB02', false, 0, '00001724', 'FreeDiams::CA_HCDPD::DIN', 584);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine 1%', 'liquid', 'N01BB02', false, 0, '00001732', 'FreeDiams::CA_HCDPD::DIN', 585);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine 2%', 'liquid', 'N01BB02', false, 0, '00036641', 'FreeDiams::CA_HCDPD::DIN', 587);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine 1% W Epinephrine 1:100000', 'solution', 'N01BB52', false, 0, '00001791', 'FreeDiams::CA_HCDPD::DIN', 589);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine 1% W Epinephrine 1:200000', 'liquid', 'N01BB52', false, 0, '00001805', 'FreeDiams::CA_HCDPD::DIN', 590);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine 1.5% W Epinephrine 1:200000', 'liquid', 'N01BB52', false, 0, '00001813', 'FreeDiams::CA_HCDPD::DIN', 591);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine 2% W Epinephrine 1:100000', 'liquid', 'N01BB52', false, 0, '00001821', 'FreeDiams::CA_HCDPD::DIN', 592);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dentsply 2% Lidocaine With Epinephrine 1:50,000', 'solution', 'N01BB52', false, 0, '00275808', 'FreeDiams::CA_HCDPD::DIN', 593);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dilantin-125 Suspension', 'suspension', 'N03AB02', false, 0, '00023450', 'FreeDiams::CA_HCDPD::DIN', 613);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Edecrin', 'powder for solution', 'C03CC01', false, 0, '00268313', 'FreeDiams::CA_HCDPD::DIN', 615);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Locacorten Vioform', 'cream', 'D07CB05', false, 0, '00074462', 'FreeDiams::CA_HCDPD::DIN', 631);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Octocaine Hcl 2% Epinephrine 1:50000', 'liquid', 'N01BB52', false, 0, '00151874', 'FreeDiams::CA_HCDPD::DIN', 635);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Octocaine Hcl 2% Epinephrine 1:100000', 'liquid', 'N01BB52', false, 0, '00151866', 'FreeDiams::CA_HCDPD::DIN', 636);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Quinine 200mg', 'capsule', 'P01BC01', false, 0, '00021008', 'FreeDiams::CA_HCDPD::DIN', 651);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Botulism Antitoxin (Equine) Type E', 'solution', 'J06AA04', false, 0, '00075116', 'FreeDiams::CA_HCDPD::DIN', 663);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bcg Vaccine (Freeze-Dried)', 'powder for solution', 'J07AN01', false, 0, '00075124', 'FreeDiams::CA_HCDPD::DIN', 673);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Provera 100mg Tablets', 'tablet', 'G03DA02', false, 0, '00030945', 'FreeDiams::CA_HCDPD::DIN', 675);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Chloroquine', 'tablet', 'P01BA01', false, 0, '00021261', 'FreeDiams::CA_HCDPD::DIN', 682);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydergine Tablets, 1mg', 'tablet', 'C04AE01', false, 0, '00176176', 'FreeDiams::CA_HCDPD::DIN', 690);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ergodryl Cap', 'capsule', 'N02CA52', false, 0, '00156086', 'FreeDiams::CA_HCDPD::DIN', 696);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Garamycin Ophthalmic Ointment 0.3%', 'ointment', 'S01AA11', false, 0, '00028339', 'FreeDiams::CA_HCDPD::DIN', 703);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fleet Enema Mineral Oil', 'enema', 'A06AA01', false, 0, '00107875', 'FreeDiams::CA_HCDPD::DIN', 721);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vibramycin Cap 100mg', 'capsule', 'J01AA02', false, 0, '00024368', 'FreeDiams::CA_HCDPD::DIN', 722);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Librax', 'capsule', 'A03CA02', false, 0, '00115630', 'FreeDiams::CA_HCDPD::DIN', 728);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zarontin Syr 250mg/5ml', 'syrup', 'N03AD01', false, 0, '00023485', 'FreeDiams::CA_HCDPD::DIN', 731);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prednisone Tab 5mg', 'tablet', 'H02AB07', false, 0, '00156876', 'FreeDiams::CA_HCDPD::DIN', 733);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tetracycline Cap 250mg', 'capsule', 'J01AA07', false, 0, '00156744', 'FreeDiams::CA_HCDPD::DIN', 735);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Urologic G Half Strength For Irrigation', 'solution', 'B05CB10', false, 0, '00039365', 'FreeDiams::CA_HCDPD::DIN', 744);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elliott''S Solution A', 'solution', 'B05CB10', false, 0, '00039411', 'FreeDiams::CA_HCDPD::DIN', 745);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Celontin Cap 300mg', 'capsule', 'N03AD03', false, 0, '00022802', 'FreeDiams::CA_HCDPD::DIN', 763);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dilantin-30 Suspension', 'suspension', 'N03AB02', false, 0, '00023442', 'FreeDiams::CA_HCDPD::DIN', 769);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zarontin Cap 250mg', 'capsule', 'N03AD01', false, 0, '00022799', 'FreeDiams::CA_HCDPD::DIN', 771);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Thyroid Tab 30mg', 'tablet', 'H03AA05', false, 0, '00023949', 'FreeDiams::CA_HCDPD::DIN', 772);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Thyroid Tab 60mg', 'tablet', 'H03AA05', false, 0, '00023957', 'FreeDiams::CA_HCDPD::DIN', 773);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Thyroid Tab 125mg', 'tablet', 'H03AA05', false, 0, '00023965', 'FreeDiams::CA_HCDPD::DIN', 774);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tegretol 200mg', 'tablet', 'N03AF01', false, 0, '00010405', 'FreeDiams::CA_HCDPD::DIN', 777);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Hydrochlorothiazide', 'tablet', 'C03AA03', false, 0, '00021474', 'FreeDiams::CA_HCDPD::DIN', 778);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mydriacyl Liq 1%', 'liquid', 'S01FA06', false, 0, '00001007', 'FreeDiams::CA_HCDPD::DIN', 780);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Navane Capsules 10mg', 'capsule', 'N05AF04', false, 0, '00024457', 'FreeDiams::CA_HCDPD::DIN', 783);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Navane Cap 5mg', 'capsule', 'N05AF04', false, 0, '00024449', 'FreeDiams::CA_HCDPD::DIN', 784);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Navane Cap 2mg', 'capsule', 'N05AF04', false, 0, '00024430', 'FreeDiams::CA_HCDPD::DIN', 785);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Depo-Medrol 80 Mg/Ml', 'suspension', 'H02AB04', false, 0, '00030767', 'FreeDiams::CA_HCDPD::DIN', 789);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ephedrine Sulfate Injection', 'solution', 'R03CA02', false, 0, '00038121', 'FreeDiams::CA_HCDPD::DIN', 790);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isopto Tears 0.5%', 'drops', 'S01XA20', false, 0, '00000809', 'FreeDiams::CA_HCDPD::DIN', 793);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isopto Tears 1.0%', 'drops', 'S01XA20', false, 0, '00000817', 'FreeDiams::CA_HCDPD::DIN', 794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ritalin 10mg', 'tablet', 'N06BA04', false, 0, '00005606', 'FreeDiams::CA_HCDPD::DIN', 800);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ritalin 20mg', 'tablet', 'N06BA04', false, 0, '00005614', 'FreeDiams::CA_HCDPD::DIN', 801);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vioform Hydrocortisone', 'cream', 'D07CA01', false, 0, '00074500', 'FreeDiams::CA_HCDPD::DIN', 810);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Hydrochlorothiazide', 'tablet', 'C03AA03', false, 0, '00021482', 'FreeDiams::CA_HCDPD::DIN', 812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valisone G Cream', 'cream', 'D07CC01', false, 0, '00177016', 'FreeDiams::CA_HCDPD::DIN', 816);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride Inj 9mg/Ml', 'solution', 'B05XA03', false, 0, '00037796', 'FreeDiams::CA_HCDPD::DIN', 817);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Locacorten Vioform Eardrops', 'drops', 'S02CA02', false, 0, '00074454', 'FreeDiams::CA_HCDPD::DIN', 868);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germiphene Concentrate 13.0%', 'liquid', 'D08AJ01', false, 0, '00109991', 'FreeDiams::CA_HCDPD::DIN', 869);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fiorinal C1/4 Cap', 'capsule', 'N02BA71', false, 0, '00176192', 'FreeDiams::CA_HCDPD::DIN', 872);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fiorinal C1/2', 'capsule', 'N02AA79', false, 0, '00176206', 'FreeDiams::CA_HCDPD::DIN', 873);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dalacin C 150 Mg', 'capsule', 'J01FF01', false, 0, '00030570', 'FreeDiams::CA_HCDPD::DIN', 874);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('222 Tablet', 'tablet', 'N02BA51', false, 0, '00108162', 'FreeDiams::CA_HCDPD::DIN', 876);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Slow K', 'tablet (extended-release)', 'A12BA01', false, 0, '00074225', 'FreeDiams::CA_HCDPD::DIN', 889);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minitran - Patch Trd 18mg/6.7 Sq Cm', 'patch', 'C01DA02', false, 0, '02162806', 'FreeDiams::CA_HCDPD::DIN', 891);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Conray 60', 'solution', 'V08AA04', false, 0, '00131237', 'FreeDiams::CA_HCDPD::DIN', 899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Rythro Estolate Sus 125mg/', 'suspension', 'J01FA01', false, 0, '00021172', 'FreeDiams::CA_HCDPD::DIN', 901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fungizone Intravenous Injection 50mg', 'powder for solution', 'J02AA01', false, 0, '00029149', 'FreeDiams::CA_HCDPD::DIN', 933);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Albalon', 'drops', 'S01GA01', false, 0, '00001147', 'FreeDiams::CA_HCDPD::DIN', 934);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lomotil', 'tablet', 'A07DA01', false, 0, '00036323', 'FreeDiams::CA_HCDPD::DIN', 937);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Matulane', 'capsule', 'L01XB01', false, 0, '00012750', 'FreeDiams::CA_HCDPD::DIN', 938);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adrenalin Chloride Sol 1:1000 Amp', 'solution', 'C01CA24', false, 0, '00155357', 'FreeDiams::CA_HCDPD::DIN', 940);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Codeine Phosphate Sirop De', 'syrup', 'R05DA04', false, 0, '00050024', 'FreeDiams::CA_HCDPD::DIN', 943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinequan Cap 10mg', 'capsule', 'N06AA12', false, 0, '00024325', 'FreeDiams::CA_HCDPD::DIN', 944);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinequan Cap 25mg', 'capsule', 'N06AA12', false, 0, '00024333', 'FreeDiams::CA_HCDPD::DIN', 945);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinequan Cap 50mg', 'capsule', 'N06AA12', false, 0, '00024341', 'FreeDiams::CA_HCDPD::DIN', 946);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coactifed', 'tablet', 'R05DA20', false, 0, '00068608', 'FreeDiams::CA_HCDPD::DIN', 955);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coactifed', 'syrup', 'R05FA02', false, 0, '00068756', 'FreeDiams::CA_HCDPD::DIN', 956);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coactifed', 'syrup', 'R05DA20', false, 0, '00068594', 'FreeDiams::CA_HCDPD::DIN', 957);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Myleran', 'tablet', 'L01AB01', false, 0, '00004618', 'FreeDiams::CA_HCDPD::DIN', 959);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Purinethol', 'tablet', 'L01BB02', false, 0, '00004723', 'FreeDiams::CA_HCDPD::DIN', 960);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hibitane Disinfectant', 'liquid', 'V07AV', false, 0, '00053236', 'FreeDiams::CA_HCDPD::DIN', 1016);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetylsalicylic Acid, Caffeine And 8mg Codeine Phosphate', 'tablet', 'N02BA51', false, 0, '00095494', 'FreeDiams::CA_HCDPD::DIN', 1025);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pramine Tab 50mg', 'tablet', 'N06AA02', false, 0, '00021520', 'FreeDiams::CA_HCDPD::DIN', 1030);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pramine Tab 10mg', 'tablet', 'N06AA02', false, 0, '00021504', 'FreeDiams::CA_HCDPD::DIN', 1031);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asa 325mg', 'tablet', 'N02BA01', false, 0, '00530336', 'FreeDiams::CA_HCDPD::DIN', 4272);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pramine Tab 25mg', 'tablet', 'N06AA02', false, 0, '00021512', 'FreeDiams::CA_HCDPD::DIN', 1032);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Nidazol Tab 250mg', 'tablet', 'J01XD01', false, 0, '00021555', 'FreeDiams::CA_HCDPD::DIN', 1033);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dilantin - 30mg', 'capsule', 'N03AB02', false, 0, '00022772', 'FreeDiams::CA_HCDPD::DIN', 1036);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dilantin - 100mg', 'capsule', 'N03AB02', false, 0, '00022780', 'FreeDiams::CA_HCDPD::DIN', 1037);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cora Caine', 'paste', 'A01AD11', false, 0, '00070254', 'FreeDiams::CA_HCDPD::DIN', 1062);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sintrom', 'tablet', 'B01AA07', false, 0, '00010391', 'FreeDiams::CA_HCDPD::DIN', 1084);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dilantin Infatabs', 'tablet', 'N03AB02', false, 0, '00023698', 'FreeDiams::CA_HCDPD::DIN', 1086);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neo Laryngobis', 'suppository', 'R07AX', false, 0, '00065927', 'FreeDiams::CA_HCDPD::DIN', 1090);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cerumol', 'drops', 'S02DC', false, 0, '00221570', 'FreeDiams::CA_HCDPD::DIN', 1103);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daraprim', 'tablet', 'P01BD01', false, 0, '00004774', 'FreeDiams::CA_HCDPD::DIN', 1116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sintrom', 'tablet', 'B01AA07', false, 0, '00010383', 'FreeDiams::CA_HCDPD::DIN', 1118);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Ampicillin Cap 500mg', 'capsule', 'J01CA01', false, 0, '00020885', 'FreeDiams::CA_HCDPD::DIN', 1124);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Ampicillin Cap 250mg', 'capsule', 'J01CA01', false, 0, '00020877', 'FreeDiams::CA_HCDPD::DIN', 1125);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solu-Medrol', 'kit', 'H02AB04', false, 0, '00036137', 'FreeDiams::CA_HCDPD::DIN', 1130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solu-Medrol', 'kit', 'H02AB04', false, 0, '00030678', 'FreeDiams::CA_HCDPD::DIN', 1132);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Depo-Medrol 40 Mg/Ml', 'suspension', 'H02AB04', false, 0, '00030759', 'FreeDiams::CA_HCDPD::DIN', 1134);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valisone Scalp Lotion 0.1%', 'lotion', 'D07AC01', false, 0, '00027944', 'FreeDiams::CA_HCDPD::DIN', 1147);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asa Tablets Usp 325 Mg', 'tablet', 'N02BA01', false, 0, '00036145', 'FreeDiams::CA_HCDPD::DIN', 1171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alcaine Dps 0.5%', 'drops', 'S01HA04', false, 0, '00035076', 'FreeDiams::CA_HCDPD::DIN', 1172);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mannitol 25%', 'solution', 'B05BC01', false, 0, '00038024', 'FreeDiams::CA_HCDPD::DIN', 1181);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Keflex', 'powder for suspension', 'J01DB01', false, 0, '00015547', 'FreeDiams::CA_HCDPD::DIN', 1184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imuran', 'tablet', 'L04AX01', false, 0, '00004596', 'FreeDiams::CA_HCDPD::DIN', 1192);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Leukeran', 'tablet', 'L01AA02', false, 0, '00004626', 'FreeDiams::CA_HCDPD::DIN', 1193);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alkeran', 'tablet', 'L01AA03', false, 0, '00004715', 'FreeDiams::CA_HCDPD::DIN', 1195);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Conray 30', 'solution', 'V08AA04', false, 0, '00223107', 'FreeDiams::CA_HCDPD::DIN', 1201);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Keflex', 'powder for suspension', 'J01DB01', false, 0, '00035645', 'FreeDiams::CA_HCDPD::DIN', 1212);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ketalar', 'solution', 'N01AX03', false, 0, '00224391', 'FreeDiams::CA_HCDPD::DIN', 1214);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ketalar', 'solution', 'N01AX03', false, 0, '00224405', 'FreeDiams::CA_HCDPD::DIN', 1215);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vasofrinic', 'tablet', 'R01BA52', false, 0, '00225843', 'FreeDiams::CA_HCDPD::DIN', 1224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dalacin C Flavoured Granules', 'powder for solution', 'J01FF01', false, 0, '00225851', 'FreeDiams::CA_HCDPD::DIN', 1225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fiorinal Cap', 'capsule', 'N02BA71', false, 0, '00226327', 'FreeDiams::CA_HCDPD::DIN', 1233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sarapin', 'solution', 'M02AX10', false, 0, '00226882', 'FreeDiams::CA_HCDPD::DIN', 1235);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride Irrigation 9mg/Ml', 'solution', 'B05CB01', false, 0, '00037826', 'FreeDiams::CA_HCDPD::DIN', 1239);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Endomethasone Ivory', 'powder', 'A01AC52', false, 0, '00229679', 'FreeDiams::CA_HCDPD::DIN', 1251);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitrostat Slt 0.6mg', 'tablet', 'C01DA02', false, 0, '00037621', 'FreeDiams::CA_HCDPD::DIN', 1253);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitrostat Slt 0.3mg', 'tablet', 'C01DA02', false, 0, '00037613', 'FreeDiams::CA_HCDPD::DIN', 1254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gravol Liquid 15mg/5cc', 'syrup', 'R06AA02', false, 0, '00230197', 'FreeDiams::CA_HCDPD::DIN', 1256);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Triptyn Tab 50mg', 'tablet', 'N06AA09', false, 0, '00037427', 'FreeDiams::CA_HCDPD::DIN', 1263);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Triptyn Tab 25mg', 'tablet', 'N06AA09', false, 0, '00037419', 'FreeDiams::CA_HCDPD::DIN', 1264);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Triptyn Tab 10mg', 'tablet', 'N06AA09', false, 0, '00037400', 'FreeDiams::CA_HCDPD::DIN', 1265);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Ampicillin Pws 500mg/5ml', 'powder for solution', 'J01CA01', false, 0, '00231207', 'FreeDiams::CA_HCDPD::DIN', 1270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Delatestryl Inj 200mg/Ml', 'liquid', 'G03BA03', false, 0, '00029246', 'FreeDiams::CA_HCDPD::DIN', 1275);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Magnolax', 'emulsion', 'A06AA51', false, 0, '00202045', 'FreeDiams::CA_HCDPD::DIN', 1281);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valisone G Ointment', 'ointment', 'D07CC01', false, 0, '00232351', 'FreeDiams::CA_HCDPD::DIN', 1285);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Prednisone Tab 50mg', 'tablet', 'H02AB07', false, 0, '00232378', 'FreeDiams::CA_HCDPD::DIN', 1286);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micronor Tablets 28-Day', 'tablet', 'G03AC01', false, 0, '00037605', 'FreeDiams::CA_HCDPD::DIN', 1290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Chlorpromazine', 'tablet', 'N05AA01', false, 0, '00232807', 'FreeDiams::CA_HCDPD::DIN', 1293);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Chlorpromazine', 'tablet', 'N05AA01', false, 0, '00232823', 'FreeDiams::CA_HCDPD::DIN', 1294);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Chlorpromazine', 'tablet', 'N05AA01', false, 0, '00232831', 'FreeDiams::CA_HCDPD::DIN', 1295);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Phenytoin Cap 100mg', 'capsule', 'N03AB02', false, 0, '00037435', 'FreeDiams::CA_HCDPD::DIN', 1299);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Trifluzine - Tab 2mg', 'tablet', 'N05AB06', false, 0, '00021865', 'FreeDiams::CA_HCDPD::DIN', 1303);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Trifluzine - Tab 5mg', 'tablet', 'N05AB06', false, 0, '00021873', 'FreeDiams::CA_HCDPD::DIN', 1304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Trifluzine - Tab 10mg', 'tablet', 'N05AB06', false, 0, '00021881', 'FreeDiams::CA_HCDPD::DIN', 1305);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benoxyl', 'lotion', 'D10AE01', false, 0, '00236063', 'FreeDiams::CA_HCDPD::DIN', 1317);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbolith Cap 300mg', 'capsule', 'N05AN01', false, 0, '00236683', 'FreeDiams::CA_HCDPD::DIN', 1327);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zeasorb', 'powder', 'D08AE55', false, 0, '00237213', 'FreeDiams::CA_HCDPD::DIN', 1338);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benoxyl', 'lotion', 'D10AE01', false, 0, '00187585', 'FreeDiams::CA_HCDPD::DIN', 1339);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neo-Medrol Acne Lotion', 'lotion', 'D10AA02', false, 0, '00195057', 'FreeDiams::CA_HCDPD::DIN', 1394);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medrol 16 Mg', 'tablet', 'H02AB04', false, 0, '00036129', 'FreeDiams::CA_HCDPD::DIN', 1396);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medrol 4 Mg', 'tablet', 'H02AB04', false, 0, '00030988', 'FreeDiams::CA_HCDPD::DIN', 1397);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Depo-Testosterone Inj 100mg/Ml', 'solution', 'G03BA03', false, 0, '00030783', 'FreeDiams::CA_HCDPD::DIN', 1398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norlutate', 'tablet', 'G03DC02', false, 0, '00023760', 'FreeDiams::CA_HCDPD::DIN', 1401);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aldactone 25 Mg', 'tablet', 'C03DA01', false, 0, '00028606', 'FreeDiams::CA_HCDPD::DIN', 1403);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aldactazide 25', 'tablet', 'C03EA01', false, 0, '00180408', 'FreeDiams::CA_HCDPD::DIN', 1404);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Keflex', 'tablet', 'J01DB01', false, 0, '00244392', 'FreeDiams::CA_HCDPD::DIN', 1434);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hibitane Skin Cleanser', 'solution', 'D08AC02', false, 0, '00245097', 'FreeDiams::CA_HCDPD::DIN', 1436);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dalmane', 'capsule', 'N05CD01', false, 0, '00012718', 'FreeDiams::CA_HCDPD::DIN', 1466);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fml 0.1%', 'drops', 'S01BA07', false, 0, '00247855', 'FreeDiams::CA_HCDPD::DIN', 1470);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Etibi Tab 100mg', 'tablet', 'J04AK02', false, 0, '00247960', 'FreeDiams::CA_HCDPD::DIN', 1471);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Etibi Tab 400mg', 'tablet', 'J04AK02', false, 0, '00247979', 'FreeDiams::CA_HCDPD::DIN', 1472);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acne Aid Soap 6.3%', 'soap bar', 'D10AX30', false, 0, '00187607', 'FreeDiams::CA_HCDPD::DIN', 1494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polytar Shampoo 1.0%', 'shampoo', 'D05AA', false, 0, '00249866', 'FreeDiams::CA_HCDPD::DIN', 1495);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vasofrinic Sirop', 'syrup', 'R01BA52', false, 0, '00249971', 'FreeDiams::CA_HCDPD::DIN', 1497);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vasofrinic Plus Sirop', 'syrup', 'R05FA02', false, 0, '00249998', 'FreeDiams::CA_HCDPD::DIN', 1498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adrenalin Chloride Sol 1:1000', 'solution', 'R01AA14', false, 0, '00155365', 'FreeDiams::CA_HCDPD::DIN', 1508);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medrol Acne Lotion', 'lotion', 'D10AA02', false, 0, '00252395', 'FreeDiams::CA_HCDPD::DIN', 1527);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyclogyl Oph Dps 1%', 'drops', 'S01FA04', false, 0, '00252506', 'FreeDiams::CA_HCDPD::DIN', 1530);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lactate 1-2-3 Injection', 'solution', 'B05BB02', false, 0, '00039306', 'FreeDiams::CA_HCDPD::DIN', 1548);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dulcolax Ect 5mg', 'tablet (enteric-coated)', 'A06AB02', false, 0, '00254142', 'FreeDiams::CA_HCDPD::DIN', 1553);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dulcolax', 'suppository', 'A06AB02', false, 0, '00003867', 'FreeDiams::CA_HCDPD::DIN', 1554);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dulcolax Sup 10mg', 'suppository', 'A06AB02', false, 0, '00003875', 'FreeDiams::CA_HCDPD::DIN', 1555);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Blenoxane Pws 15unit', 'powder for solution', 'L01DC01', false, 0, '00258482', 'FreeDiams::CA_HCDPD::DIN', 1589);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ponstan', 'capsule', 'M01AG01', false, 0, '00155225', 'FreeDiams::CA_HCDPD::DIN', 1598);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Catapres Tab 0.1mg', 'tablet', 'C02AC01', false, 0, '00259527', 'FreeDiams::CA_HCDPD::DIN', 1601);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Depo-Medrol With Lidocaine', 'solution', 'H02BX01', false, 0, '00260428', 'FreeDiams::CA_HCDPD::DIN', 1619);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dalacin C Phosphate', 'solution', 'J01FF01', false, 0, '00260436', 'FreeDiams::CA_HCDPD::DIN', 1620);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Plasmalyte 148 In Water', 'solution', 'B05BB01', false, 0, '00260576', 'FreeDiams::CA_HCDPD::DIN', 1622);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Plasmalyte 148 In 5% Dextrose Inj', 'solution', 'B05BB02', false, 0, '00260592', 'FreeDiams::CA_HCDPD::DIN', 1623);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bisacolax', 'suppository', 'A06AB02', false, 0, '00261327', 'FreeDiams::CA_HCDPD::DIN', 1627);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lactated Ringers Inj Usp', 'solution', 'B05BB01', false, 0, '00061085', 'FreeDiams::CA_HCDPD::DIN', 1628);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Rythro Estolate Sus', 'liquid', 'J01FA01', false, 0, '00262595', 'FreeDiams::CA_HCDPD::DIN', 1642);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Panoxyl 10 Gel', 'gel', 'D10AE01', false, 0, '00263699', 'FreeDiams::CA_HCDPD::DIN', 1647);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Panoxyl 5 Gel', 'gel', 'D10AE01', false, 0, '00263702', 'FreeDiams::CA_HCDPD::DIN', 1648);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cotazym', 'capsule', 'A09AA02', false, 0, '00263818', 'FreeDiams::CA_HCDPD::DIN', 1649);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('C.E.S. Tablets', 'tablet', 'G03CA57', false, 0, '00265470', 'FreeDiams::CA_HCDPD::DIN', 1657);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('C.E.S. Tablets', 'tablet', 'G03CA57', false, 0, '00265489', 'FreeDiams::CA_HCDPD::DIN', 1658);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tardan Shp', 'shampoo', 'D05AA', false, 0, '00266493', 'FreeDiams::CA_HCDPD::DIN', 1667);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adasept Liq 0.5%', 'liquid', 'D08AE04', false, 0, '00266507', 'FreeDiams::CA_HCDPD::DIN', 1668);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lactated Ringers Inj W 5% Dextrose', 'solution', 'B05BB02', false, 0, '00061131', 'FreeDiams::CA_HCDPD::DIN', 1673);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levate', 'tablet', 'N06AA09', false, 0, '00271152', 'FreeDiams::CA_HCDPD::DIN', 1690);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allerdryl Cap 50mg', 'capsule', 'R06AA02', false, 0, '00271411', 'FreeDiams::CA_HCDPD::DIN', 1694);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenazo 100mg', 'tablet', 'G04BX06', false, 0, '00271489', 'FreeDiams::CA_HCDPD::DIN', 1695);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Dipam Tab 2mg', 'tablet', 'N05BA01', false, 0, '00272434', 'FreeDiams::CA_HCDPD::DIN', 1718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Dipam Tab 5mg', 'tablet', 'N05BA01', false, 0, '00272442', 'FreeDiams::CA_HCDPD::DIN', 1719);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Dipam Tab 10mg', 'tablet', 'N05BA01', false, 0, '00272450', 'FreeDiams::CA_HCDPD::DIN', 1720);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Urozide', 'tablet', 'C03AA03', false, 0, '00263893', 'FreeDiams::CA_HCDPD::DIN', 1723);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tham Solution 36mg/Ml', 'solution', 'B05XX02', false, 0, '00244287', 'FreeDiams::CA_HCDPD::DIN', 1731);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextran 6% In 5% Dextrose Injection', 'solution', 'B05AA55', false, 0, '00224219', 'FreeDiams::CA_HCDPD::DIN', 1732);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextran 6% In 0.9% Sodium Chloride Injection', 'solution', 'B05AA55', false, 0, '00225436', 'FreeDiams::CA_HCDPD::DIN', 1733);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Water For Injection Sterile Usp', 'liquid', 'V07AB', false, 0, '00038245', 'FreeDiams::CA_HCDPD::DIN', 1734);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride Injection 5%', 'solution', 'B05XA03', false, 0, '00037850', 'FreeDiams::CA_HCDPD::DIN', 1735);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride Injection 0.45%', 'solution', 'B05XA03', false, 0, '00037788', 'FreeDiams::CA_HCDPD::DIN', 1736);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Normosol R With Dextrose 5% Injection', 'solution', 'B05BB02', false, 0, '00039640', 'FreeDiams::CA_HCDPD::DIN', 1737);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Normosol R', 'solution', 'B05BB01', false, 0, '00039500', 'FreeDiams::CA_HCDPD::DIN', 1738);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Normosol M With Dextrose 5%', 'solution', 'B05BB02', false, 0, '00039489', 'FreeDiams::CA_HCDPD::DIN', 1739);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mannitol 20%', 'solution', 'B05BC01', false, 0, '00038016', 'FreeDiams::CA_HCDPD::DIN', 1740);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lmd 10% In 0.9% Sodium Chloride', 'solution', 'B05AA55', false, 0, '00224227', 'FreeDiams::CA_HCDPD::DIN', 1743);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lmd 10% In Dextrose 5%', 'solution', 'B05AA55', false, 0, '00224235', 'FreeDiams::CA_HCDPD::DIN', 1744);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lactated Ringer''S Injection', 'solution', 'B05BB01', false, 0, '00039470', 'FreeDiams::CA_HCDPD::DIN', 1745);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 50% Injection Usp', 'solution', 'B05BA03', false, 0, '00037974', 'FreeDiams::CA_HCDPD::DIN', 1746);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 5% In 0.9% Sodium Chloride', 'solution', 'B05BB02', false, 0, '00038946', 'FreeDiams::CA_HCDPD::DIN', 1747);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 10% Injection Usp', 'solution', 'B05BA03', false, 0, '00037958', 'FreeDiams::CA_HCDPD::DIN', 1748);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 5% In Lactated Ringers', 'solution', 'B05BB02', false, 0, '00039551', 'FreeDiams::CA_HCDPD::DIN', 1749);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 5% In 0.45% Sodium Chloride', 'solution', 'B05BB02', false, 0, '00038903', 'FreeDiams::CA_HCDPD::DIN', 1750);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 5% In 0.225% Sodium Chloride', 'solution', 'B05BB02', false, 0, '00038873', 'FreeDiams::CA_HCDPD::DIN', 1751);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cortisone Acetate Tab 25mg', 'tablet', 'H02AB10', false, 0, '00280437', 'FreeDiams::CA_HCDPD::DIN', 1802);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lanvis', 'tablet', 'L01BB03', false, 0, '00282081', 'FreeDiams::CA_HCDPD::DIN', 1812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tebrazid Tab 500mg', 'tablet', 'J04AK01', false, 0, '00283991', 'FreeDiams::CA_HCDPD::DIN', 1828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Urozide', 'tablet', 'C03AA03', false, 0, '00263907', 'FreeDiams::CA_HCDPD::DIN', 1829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine 2% W Epinephrine 1:200000', 'liquid', 'N01BB52', false, 0, '00284106', 'FreeDiams::CA_HCDPD::DIN', 1830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride 146mg/Ml Injection', 'solution', 'B05XA03', false, 0, '00262005', 'FreeDiams::CA_HCDPD::DIN', 1848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Protylol Cap 10mg', 'capsule', 'A03AA07', false, 0, '00287709', 'FreeDiams::CA_HCDPD::DIN', 1857);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Impril', 'tablet', 'N06AA02', false, 0, '00236756', 'FreeDiams::CA_HCDPD::DIN', 1877);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levate', 'tablet', 'N06AA09', false, 0, '00293911', 'FreeDiams::CA_HCDPD::DIN', 1878);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benuryl', 'tablet', 'M04AB01', false, 0, '00294926', 'FreeDiams::CA_HCDPD::DIN', 1883);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Impril', 'tablet', 'N06AA02', false, 0, '00236721', 'FreeDiams::CA_HCDPD::DIN', 1884);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Impril', 'tablet', 'N06AA02', false, 0, '00236748', 'FreeDiams::CA_HCDPD::DIN', 1885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetazolam', 'tablet', 'S01EC01', false, 0, '00295019', 'FreeDiams::CA_HCDPD::DIN', 1886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexasone 0.5mg', 'tablet', 'H02AB02', false, 0, '00295094', 'FreeDiams::CA_HCDPD::DIN', 1887);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Travasol Inj 10%', 'solution', 'B05BA10', false, 0, '00285528', 'FreeDiams::CA_HCDPD::DIN', 1888);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ovol 80mg Tab Chewable', 'tablet', 'A03AX13', false, 0, '00292990', 'FreeDiams::CA_HCDPD::DIN', 1889);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allopurinol', 'tablet', 'M04AA01', false, 0, '00294322', 'FreeDiams::CA_HCDPD::DIN', 1892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexasone 0.75mg', 'tablet', 'H02AB02', false, 0, '00285471', 'FreeDiams::CA_HCDPD::DIN', 1899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Bicarbonate Inj 8.4%', 'solution', 'B05XA02', false, 0, '00261998', 'FreeDiams::CA_HCDPD::DIN', 1905);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenol Saline Inj', 'liquid', 'V07AB', false, 0, '00298409', 'FreeDiams::CA_HCDPD::DIN', 1911);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glycerinated Phenol Saline', 'liquid', 'V07AB', false, 0, '00298417', 'FreeDiams::CA_HCDPD::DIN', 1912);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract Non Pollens', 'liquid', 'V01AA20', false, 0, '00299979', 'FreeDiams::CA_HCDPD::DIN', 1913);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract Pollens', 'liquid', 'V01AA20', false, 0, '00299987', 'FreeDiams::CA_HCDPD::DIN', 1914);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Loestrin 1.5/30 21day Pack', 'tablet', 'G03AA05', false, 0, '00297143', 'FreeDiams::CA_HCDPD::DIN', 1922);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Formaline Desinfectant', 'solution', 'V07AV', false, 0, '00292303', 'FreeDiams::CA_HCDPD::DIN', 1926);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levate', 'tablet', 'N06AA09', false, 0, '00306320', 'FreeDiams::CA_HCDPD::DIN', 1929);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Colchicine', 'tablet', 'M04AC01', false, 0, '00287873', 'FreeDiams::CA_HCDPD::DIN', 1931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Colchicine', 'tablet', 'M04AC01', false, 0, '00206032', 'FreeDiams::CA_HCDPD::DIN', 1934);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pred Mild 0.12%', 'drops', 'S01BA04', false, 0, '00299405', 'FreeDiams::CA_HCDPD::DIN', 1936);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pred Forte 1%', 'drops', 'S01BA04', false, 0, '00301175', 'FreeDiams::CA_HCDPD::DIN', 1937);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Catapres Tab 0.2mg', 'tablet', 'C02AC01', false, 0, '00291889', 'FreeDiams::CA_HCDPD::DIN', 1943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cortrosyn Inj 0.25mg', 'powder for solution', 'H01AA02', false, 0, '00022381', 'FreeDiams::CA_HCDPD::DIN', 1954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Blephamide Oph Ont', 'ointment', 'S01CA02', false, 0, '00307246', 'FreeDiams::CA_HCDPD::DIN', 1971);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estragyn', 'tablet', 'G03CA07', false, 0, '00287725', 'FreeDiams::CA_HCDPD::DIN', 1978);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Theo-Bronc', 'syrup', 'R03DA54', false, 0, '00317225', 'FreeDiams::CA_HCDPD::DIN', 1980);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sting Stop 0.1%', 'liquid', 'D08AJ01', false, 0, '00311243', 'FreeDiams::CA_HCDPD::DIN', 1984);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diazepam 5 Tab', 'tablet', 'N05BA01', false, 0, '00313580', 'FreeDiams::CA_HCDPD::DIN', 2037);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anafranil', 'tablet', 'N06AA04', false, 0, '00324019', 'FreeDiams::CA_HCDPD::DIN', 2039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Drixoral Cold & Sinus', 'tablet (extended-release)', 'R01BA52', false, 0, '00298433', 'FreeDiams::CA_HCDPD::DIN', 2048);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinequan Cap 100mg', 'capsule', 'N06AA12', false, 0, '00326925', 'FreeDiams::CA_HCDPD::DIN', 2049);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Orap', 'tablet', 'N05AG02', false, 0, '00313815', 'FreeDiams::CA_HCDPD::DIN', 2058);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Orap', 'tablet', 'N05AG02', false, 0, '00313823', 'FreeDiams::CA_HCDPD::DIN', 2059);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atasol Forte Tab 500mg', 'tablet', 'N02BE01', false, 0, '00013668', 'FreeDiams::CA_HCDPD::DIN', 2064);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atasol Tab 325mg', 'tablet', 'N02BE01', false, 0, '00293482', 'FreeDiams::CA_HCDPD::DIN', 2065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diprosone Cream 0.05%', 'cream', 'D07AC01', false, 0, '00323071', 'FreeDiams::CA_HCDPD::DIN', 2071);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adasept Acne Gel', 'lotion', 'D02AF', false, 0, '00326577', 'FreeDiams::CA_HCDPD::DIN', 2072);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tubersol', 'solution', 'V04CF01', false, 0, '00317268', 'FreeDiams::CA_HCDPD::DIN', 2087);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Chlorpropamide Tab 250mg', 'tablet', 'A10BB02', false, 0, '00312711', 'FreeDiams::CA_HCDPD::DIN', 2091);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tolbutamide', 'tablet', 'A10BB03', false, 0, '00312762', 'FreeDiams::CA_HCDPD::DIN', 2092);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitrofurantoin', 'tablet', 'J01XE01', false, 0, '00312738', 'FreeDiams::CA_HCDPD::DIN', 2093);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitrofurantoin', 'tablet', 'J01XE01', false, 0, '00319511', 'FreeDiams::CA_HCDPD::DIN', 2094);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Urologic G For Irrigation', 'solution', 'B05CB10', false, 0, '00039373', 'FreeDiams::CA_HCDPD::DIN', 2122);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Senokot S Tab', 'tablet', 'A06AB56', false, 0, '00026123', 'FreeDiams::CA_HCDPD::DIN', 2133);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Efudex Crm 5%', 'cream', 'L01BC02', false, 0, '00330582', 'FreeDiams::CA_HCDPD::DIN', 2138);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinemet 250/25', 'tablet', 'N04BA02', false, 0, '00328219', 'FreeDiams::CA_HCDPD::DIN', 2142);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aldactone 100 Mg', 'tablet', 'C03DA01', false, 0, '00285455', 'FreeDiams::CA_HCDPD::DIN', 2145);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flamazine Crm 1%', 'cream', 'D06BA01', false, 0, '00323098', 'FreeDiams::CA_HCDPD::DIN', 2146);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creo-Rectal Adulte', 'suppository', 'R05CA10', false, 0, '00299561', 'FreeDiams::CA_HCDPD::DIN', 2148);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creo-Rectal Nourrisson', 'suppository', 'R05CA10', false, 0, '00299588', 'FreeDiams::CA_HCDPD::DIN', 2149);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creo-Rectal Enfant', 'suppository', 'R05CA10', false, 0, '00299596', 'FreeDiams::CA_HCDPD::DIN', 2150);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bicnu', 'powder for solution', 'L01AD01', false, 0, '00297763', 'FreeDiams::CA_HCDPD::DIN', 2153);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anafranil', 'tablet', 'N06AA04', false, 0, '00330566', 'FreeDiams::CA_HCDPD::DIN', 2164);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydrochlorothiazide Tab 25mg', 'tablet', 'C03AA03', false, 0, '00341975', 'FreeDiams::CA_HCDPD::DIN', 2170);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sting Stop 0.1%', 'liquid', 'D08AJ01', false, 0, '00319589', 'FreeDiams::CA_HCDPD::DIN', 2171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atasol 8 Tab', 'tablet', 'N02BE51', false, 0, '00293490', 'FreeDiams::CA_HCDPD::DIN', 2178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atasol 15 Tab', 'tablet', 'N02BE51', false, 0, '00293504', 'FreeDiams::CA_HCDPD::DIN', 2179);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atasol 30 Tab', 'tablet', 'N02AA59', false, 0, '00293512', 'FreeDiams::CA_HCDPD::DIN', 2180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Medopa Tab 250mg', 'tablet', 'C02AB02', false, 0, '00337471', 'FreeDiams::CA_HCDPD::DIN', 2188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nettoyeur Liquide U974', 'liquid', 'V07AV', false, 0, '00343471', 'FreeDiams::CA_HCDPD::DIN', 2196);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Targel', 'gel', 'D05AA', false, 0, '00344508', 'FreeDiams::CA_HCDPD::DIN', 2197);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Premise Disinfectant', 'liquid', 'V07AV', false, 0, '00344540', 'FreeDiams::CA_HCDPD::DIN', 2199);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trifluoperazine', 'tablet', 'N05AB06', false, 0, '00312746', 'FreeDiams::CA_HCDPD::DIN', 2209);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trifluoperazine', 'tablet', 'N05AB06', false, 0, '00312754', 'FreeDiams::CA_HCDPD::DIN', 2210);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imipramine', 'tablet', 'N06AA02', false, 0, '00312797', 'FreeDiams::CA_HCDPD::DIN', 2211);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imipramine', 'tablet', 'N06AA02', false, 0, '00326852', 'FreeDiams::CA_HCDPD::DIN', 2212);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elavil', 'tablet', 'N06AA09', false, 0, '00335053', 'FreeDiams::CA_HCDPD::DIN', 2213);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elavil', 'tablet', 'N06AA09', false, 0, '00335061', 'FreeDiams::CA_HCDPD::DIN', 2214);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elavil', 'tablet', 'N06AA09', false, 0, '00335088', 'FreeDiams::CA_HCDPD::DIN', 2215);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solu-Cortef 100 Mg Act-O-Vial', 'powder for solution', 'H02AB09', false, 0, '00030600', 'FreeDiams::CA_HCDPD::DIN', 2219);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solu-Cortef 250 Mg Act-O-Vial', 'powder for solution', 'H02AB09', false, 0, '00030619', 'FreeDiams::CA_HCDPD::DIN', 2220);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solu-Cortef 500 Mg Act-O-Vial', 'powder for solution', 'H02AB09', false, 0, '00030627', 'FreeDiams::CA_HCDPD::DIN', 2221);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solu-Cortef 1 Gm Act-O-Vial', 'powder for solution', 'H02AB09', false, 0, '00030635', 'FreeDiams::CA_HCDPD::DIN', 2222);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prostin F2 Alpha', 'solution', 'G02AD01', false, 0, '00318736', 'FreeDiams::CA_HCDPD::DIN', 2224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Halothane', 'solution', 'N01AB01', false, 0, '00346314', 'FreeDiams::CA_HCDPD::DIN', 2226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Medopa Tab 125mg', 'tablet', 'C02AB02', false, 0, '00337463', 'FreeDiams::CA_HCDPD::DIN', 2232);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cloxin Cap 250mg', 'capsule', 'J01CF02', false, 0, '00337765', 'FreeDiams::CA_HCDPD::DIN', 2233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cloxin Cap 500mg', 'capsule', 'J01CF02', false, 0, '00337773', 'FreeDiams::CA_HCDPD::DIN', 2234);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Medopa Tab 500mg', 'tablet', 'C02AB02', false, 0, '00337498', 'FreeDiams::CA_HCDPD::DIN', 2251);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minestrin 1/20 28', 'tablet', 'G03AA05', false, 0, '00343838', 'FreeDiams::CA_HCDPD::DIN', 2254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minestrin 1/20 21', 'tablet', 'G03AA05', false, 0, '00315966', 'FreeDiams::CA_HCDPD::DIN', 2255);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Secol', 'liquid', 'D02AC', false, 0, '00351385', 'FreeDiams::CA_HCDPD::DIN', 2256);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('White Petroleum Jelly', 'ointment', 'D02AC', false, 0, '00263249', 'FreeDiams::CA_HCDPD::DIN', 2259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('A3', 'liquid', 'V07AV', false, 0, '00354716', 'FreeDiams::CA_HCDPD::DIN', 2265);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diprosone Ointment 0.05%', 'ointment', 'D07AC01', false, 0, '00344923', 'FreeDiams::CA_HCDPD::DIN', 2272);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Folic Acid Tab 25mg', 'tablet', 'B03BB01', false, 0, '00356557', 'FreeDiams::CA_HCDPD::DIN', 2283);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dualquat Saniterge', 'liquid', 'V07AV', false, 0, '00343595', 'FreeDiams::CA_HCDPD::DIN', 2298);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trifluoperazine', 'tablet', 'N05AB06', false, 0, '00326836', 'FreeDiams::CA_HCDPD::DIN', 2300);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fassil San-Det', 'liquid', 'V07AV', false, 0, '00351717', 'FreeDiams::CA_HCDPD::DIN', 2305);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trifluoperazine', 'tablet', 'N05AB06', false, 0, '00345539', 'FreeDiams::CA_HCDPD::DIN', 2308);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentothal Sodium Pws 5gm', 'powder for solution', 'N01AF03', false, 0, '00038415', 'FreeDiams::CA_HCDPD::DIN', 2315);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Odans Liquor Carbonis Detergens', 'liquid', 'D05AA', false, 0, '00358495', 'FreeDiams::CA_HCDPD::DIN', 2317);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Semide Tab 20mg', 'tablet', 'C03CA01', false, 0, '00337730', 'FreeDiams::CA_HCDPD::DIN', 2333);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Magnesium Sulfate Inj 50%', 'solution', 'B05XA05', false, 0, '00328162', 'FreeDiams::CA_HCDPD::DIN', 2334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Perphenazine', 'tablet', 'N05AB03', false, 0, '00335096', 'FreeDiams::CA_HCDPD::DIN', 2365);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Perphenazine', 'tablet', 'N05AB03', false, 0, '00335118', 'FreeDiams::CA_HCDPD::DIN', 2366);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Perphenazine', 'tablet', 'N05AB03', false, 0, '00335126', 'FreeDiams::CA_HCDPD::DIN', 2367);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Perphenazine', 'tablet', 'N05AB03', false, 0, '00335134', 'FreeDiams::CA_HCDPD::DIN', 2368);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isopto Carpine Liq 4%', 'liquid', 'S01EB01', false, 0, '00000884', 'FreeDiams::CA_HCDPD::DIN', 2374);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isopto Carpine Liq 2%', 'liquid', 'S01EB01', false, 0, '00000868', 'FreeDiams::CA_HCDPD::DIN', 2375);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isopto Carpine Liq 1%', 'liquid', 'S01EB01', false, 0, '00000841', 'FreeDiams::CA_HCDPD::DIN', 2376);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Loestrin 1.5/30 28day Pack', 'tablet', 'G03AA05', false, 0, '00353027', 'FreeDiams::CA_HCDPD::DIN', 2386);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bactocide', 'liquid', 'V07AV', false, 0, '00345067', 'FreeDiams::CA_HCDPD::DIN', 2389);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atropine Sulfate Inj 0.1mg/Ml', 'solution', 'A03BA01', false, 0, '00328154', 'FreeDiams::CA_HCDPD::DIN', 2390);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isotamine B 300', 'tablet', 'J04AC51', false, 0, '00236799', 'FreeDiams::CA_HCDPD::DIN', 2396);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isotamine-100', 'tablet', 'J04AC01', false, 0, '00261270', 'FreeDiams::CA_HCDPD::DIN', 2400);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isotamine-300', 'tablet', 'J04AC01', false, 0, '00272655', 'FreeDiams::CA_HCDPD::DIN', 2401);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fectol 3130 Liq 4.2%', 'liquid', 'V07AV', false, 0, '00371556', 'FreeDiams::CA_HCDPD::DIN', 2404);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fectol 3105 Liq 3.13%', 'liquid', 'V07AV', false, 0, '00371564', 'FreeDiams::CA_HCDPD::DIN', 2405);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fectol 3120 Liq', 'liquid', 'V07AV', false, 0, '00371572', 'FreeDiams::CA_HCDPD::DIN', 2406);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novasen Ect 650mg', 'tablet (enteric-coated)', 'N02BA01', false, 0, '00229296', 'FreeDiams::CA_HCDPD::DIN', 2410);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maxitrol Ont', 'ointment', 'S01CA01', false, 0, '00358177', 'FreeDiams::CA_HCDPD::DIN', 2423);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amitriptyline 10tab', 'tablet', 'N06AA09', false, 0, '00370991', 'FreeDiams::CA_HCDPD::DIN', 2426);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amitriptyline 25tab', 'tablet', 'N06AA09', false, 0, '00371009', 'FreeDiams::CA_HCDPD::DIN', 2427);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ostro San', 'liquid', 'V07AV', false, 0, '00373176', 'FreeDiams::CA_HCDPD::DIN', 2430);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imipramine', 'tablet', 'N06AA02', false, 0, '00360201', 'FreeDiams::CA_HCDPD::DIN', 2444);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Semide Tab 40mg', 'tablet', 'C03CA01', false, 0, '00337749', 'FreeDiams::CA_HCDPD::DIN', 2447);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlorthalidone', 'tablet', 'C03BA04', false, 0, '00360279', 'FreeDiams::CA_HCDPD::DIN', 2467);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Chlorthalidone Tab 100mg', 'tablet', 'C03BA04', false, 0, '00360287', 'FreeDiams::CA_HCDPD::DIN', 2468);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methyldopa', 'tablet', 'C02AB02', false, 0, '00360252', 'FreeDiams::CA_HCDPD::DIN', 2470);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methyldopa', 'tablet', 'C02AB02', false, 0, '00360260', 'FreeDiams::CA_HCDPD::DIN', 2471);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Furosemide Tab 40mg', 'tablet', 'C03CA01', false, 0, '00362166', 'FreeDiams::CA_HCDPD::DIN', 2472);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buscopan Tab 10mg', 'tablet', 'A04AD01', false, 0, '00363812', 'FreeDiams::CA_HCDPD::DIN', 2481);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buscopan Inj 20mg/Ml', 'liquid', 'A04AD01', false, 0, '00363839', 'FreeDiams::CA_HCDPD::DIN', 2483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Power Quat', 'liquid', 'V07AV', false, 0, '00375004', 'FreeDiams::CA_HCDPD::DIN', 2486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quat O Germ', 'liquid', 'V07AV', false, 0, '00375012', 'FreeDiams::CA_HCDPD::DIN', 2487);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benoxyl', 'lotion', 'D10AE01', false, 0, '00370568', 'FreeDiams::CA_HCDPD::DIN', 2488);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Panoxyl 20 Gel', 'gel', 'D10AE01', false, 0, '00373036', 'FreeDiams::CA_HCDPD::DIN', 2490);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aseptone 5 Detergent', 'liquid', 'V07AV', false, 0, '00368415', 'FreeDiams::CA_HCDPD::DIN', 2493);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aseptone 1 Solution', 'solution', 'V07AV', false, 0, '00364495', 'FreeDiams::CA_HCDPD::DIN', 2494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aseptone 2 Detergent', 'liquid', 'V07AV', false, 0, '00364487', 'FreeDiams::CA_HCDPD::DIN', 2495);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lignospan Forte', 'liquid', 'N01BB52', false, 0, '00375799', 'FreeDiams::CA_HCDPD::DIN', 2506);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quelicin Chloride 100mg/Ml', 'solution', 'M03AB01', false, 0, '00296163', 'FreeDiams::CA_HCDPD::DIN', 2526);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Chloride For Injection Concentrate', 'solution', 'B05XA01', false, 0, '00037869', 'FreeDiams::CA_HCDPD::DIN', 2527);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceenu', 'capsule', 'L01AD02', false, 0, '00360414', 'FreeDiams::CA_HCDPD::DIN', 2529);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceenu', 'capsule', 'L01AD02', false, 0, '00360422', 'FreeDiams::CA_HCDPD::DIN', 2530);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceenu', 'capsule', 'L01AD02', false, 0, '00360430', 'FreeDiams::CA_HCDPD::DIN', 2531);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Episec Lot', 'lotion', 'D02AC', false, 0, '00382302', 'FreeDiams::CA_HCDPD::DIN', 2536);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lignospan Standard', 'liquid', 'N01BB52', false, 0, '00375780', 'FreeDiams::CA_HCDPD::DIN', 2541);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trl 02 Tri San Liq', 'liquid', 'V07AV', false, 0, '00386456', 'FreeDiams::CA_HCDPD::DIN', 2545);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allerdryl Cap 25mg', 'capsule', 'R06AA02', false, 0, '00370517', 'FreeDiams::CA_HCDPD::DIN', 2552);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isotamine Powder', 'powder', 'J04AC01', false, 0, '00261289', 'FreeDiams::CA_HCDPD::DIN', 2553);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rivotril 0.5tab', 'tablet', 'N03AE01', false, 0, '00382825', 'FreeDiams::CA_HCDPD::DIN', 2568);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rivotril 2tab', 'tablet', 'N03AE01', false, 0, '00382841', 'FreeDiams::CA_HCDPD::DIN', 2569);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lipiodol Ultra Fluide 38%', 'liquid', 'V08AD01', false, 0, '00386685', 'FreeDiams::CA_HCDPD::DIN', 2570);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 3.3% In 0.3% Sodium Chloride', 'solution', 'B05BB02', false, 0, '00038881', 'FreeDiams::CA_HCDPD::DIN', 2575);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fectol 3125', 'liquid', 'V07AV', false, 0, '00390577', 'FreeDiams::CA_HCDPD::DIN', 2589);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Sulfisoxazole Tab 500mg', 'tablet', 'J01EB05', false, 0, '00363774', 'FreeDiams::CA_HCDPD::DIN', 2591);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maxidex Sus 0.1%', 'drops', 'S01BA01', false, 0, '00042560', 'FreeDiams::CA_HCDPD::DIN', 2620);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Formulex Cap 10mg', 'capsule', 'A03AA07', false, 0, '00361933', 'FreeDiams::CA_HCDPD::DIN', 2623);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naphcon Forte Liq 0.1%', 'drops', 'S01GA01', false, 0, '00390283', 'FreeDiams::CA_HCDPD::DIN', 2634);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Racestyptine Sol', 'liquid', 'A01AD', false, 0, '00379638', 'FreeDiams::CA_HCDPD::DIN', 2645);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Diazepam Tab 5mg', 'tablet', 'N05BA01', false, 0, '00362158', 'FreeDiams::CA_HCDPD::DIN', 2657);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Chlorpropamide Tab 100mg', 'tablet', 'A10BB02', false, 0, '00399302', 'FreeDiams::CA_HCDPD::DIN', 2658);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosept 3131', 'liquid', 'V07AV', false, 0, '00403032', 'FreeDiams::CA_HCDPD::DIN', 2679);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tears Naturale', 'solution', 'S01XA20', false, 0, '00390291', 'FreeDiams::CA_HCDPD::DIN', 2682);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prostin E2 Tablets', 'tablet', 'G02AD02', false, 0, '00400688', 'FreeDiams::CA_HCDPD::DIN', 2684);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Dimenhydrinate Tab 50mg', 'tablet', 'R06AA02', false, 0, '00363766', 'FreeDiams::CA_HCDPD::DIN', 2701);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prefrin Liq 0.12%', 'liquid', 'S01GA05', false, 0, '00395161', 'FreeDiams::CA_HCDPD::DIN', 2716);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prolopa Cap 100-25', 'capsule', 'N04BA02', false, 0, '00386464', 'FreeDiams::CA_HCDPD::DIN', 2723);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prolopa Cap 200-50', 'capsule', 'N04BA02', false, 0, '00386472', 'FreeDiams::CA_HCDPD::DIN', 2724);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophene 325tab', 'tablet', 'N02BE01', false, 0, '00382752', 'FreeDiams::CA_HCDPD::DIN', 2727);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophene 500tab', 'tablet', 'N02BE01', false, 0, '00386626', 'FreeDiams::CA_HCDPD::DIN', 2728);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lopresor 50mg', 'tablet', 'C07AB02', false, 0, '00397423', 'FreeDiams::CA_HCDPD::DIN', 2738);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lopresor 100mg', 'tablet', 'C07AB02', false, 0, '00397431', 'FreeDiams::CA_HCDPD::DIN', 2739);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isocaine Hcl Inj 3%', 'solution', 'N01BB03', false, 0, '00364304', 'FreeDiams::CA_HCDPD::DIN', 2743);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isocaine Hcl Inj 2%', 'solution', 'N01BB53', false, 0, '00393711', 'FreeDiams::CA_HCDPD::DIN', 2744);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlorine', 'liquid', 'V07AV', false, 0, '00399892', 'FreeDiams::CA_HCDPD::DIN', 2747);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Guanethidine Sulfate Tab 10mg', 'tablet', 'C02CC02', false, 0, '00396745', 'FreeDiams::CA_HCDPD::DIN', 2748);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Guanethidine Sulfate Tab 25mg', 'tablet', 'C02CC02', false, 0, '00396753', 'FreeDiams::CA_HCDPD::DIN', 2749);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Primidone', 'tablet', 'N03AA03', false, 0, '00396761', 'FreeDiams::CA_HCDPD::DIN', 2750);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Primidone', 'tablet', 'N03AA03', false, 0, '00399310', 'FreeDiams::CA_HCDPD::DIN', 2751);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn 5%', 'solution', 'B05BA01', false, 0, '00404160', 'FreeDiams::CA_HCDPD::DIN', 2776);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinequan Cap 75mg', 'capsule', 'N06AA12', false, 0, '00400750', 'FreeDiams::CA_HCDPD::DIN', 2780);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chloromycetin Succinate Injection 1gm', 'powder for solution', 'J01BA01', false, 0, '00312363', 'FreeDiams::CA_HCDPD::DIN', 2789);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cytosar 100 Mg', 'powder for solution', 'L01BC01', false, 0, '00386715', 'FreeDiams::CA_HCDPD::DIN', 2792);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Furosemide Tab 20mg', 'tablet', 'C03CA01', false, 0, '00396788', 'FreeDiams::CA_HCDPD::DIN', 2798);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Detergent Sanitizer Oakite', 'liquid', 'V07AV', false, 0, '00416355', 'FreeDiams::CA_HCDPD::DIN', 2802);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Keflex', 'tablet', 'J01DB01', false, 0, '00403628', 'FreeDiams::CA_HCDPD::DIN', 2809);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Asa', 'tablet', 'N02BA01', false, 0, '00040851', 'FreeDiams::CA_HCDPD::DIN', 2811);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pen Vk Syr 500000/5ml', 'powder for solution', 'J01CE02', false, 0, '00391603', 'FreeDiams::CA_HCDPD::DIN', 2814);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prilocaine Hcl 4% Epineph 1:200000inj', 'liquid', 'N01BB54', false, 0, '00393746', 'FreeDiams::CA_HCDPD::DIN', 2828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Furosemide 40mg', 'tablet', 'C03CA01', false, 0, '00397792', 'FreeDiams::CA_HCDPD::DIN', 2851);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Fluphenazine Tab 1mg', 'tablet', 'N05AB02', false, 0, '00405345', 'FreeDiams::CA_HCDPD::DIN', 2858);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Fluphenazine Tab 2.5mg', 'tablet', 'N05AB02', false, 0, '00405353', 'FreeDiams::CA_HCDPD::DIN', 2859);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Fluphenazine Tab 5mg', 'tablet', 'N05AB02', false, 0, '00405361', 'FreeDiams::CA_HCDPD::DIN', 2860);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Fluphenazine Tab 2mg', 'tablet', 'N05AB02', false, 0, '00410632', 'FreeDiams::CA_HCDPD::DIN', 2861);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rofact 300mg', 'capsule', 'J04AB02', false, 0, '00343617', 'FreeDiams::CA_HCDPD::DIN', 2863);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isotamine Syr Pediatric 50mg/5ml', 'syrup', 'J04AC01', false, 0, '00265500', 'FreeDiams::CA_HCDPD::DIN', 2865);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rofact 150mg', 'capsule', 'J04AB02', false, 0, '00393444', 'FreeDiams::CA_HCDPD::DIN', 2866);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germidet', 'liquid', 'V07AV', false, 0, '00398144', 'FreeDiams::CA_HCDPD::DIN', 2868);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diprosone Lotion 0.05%', 'lotion', 'D07AC01', false, 0, '00417246', 'FreeDiams::CA_HCDPD::DIN', 2870);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Sulfamethoxazole Tab 500mg', 'tablet', 'J01EC01', false, 0, '00421480', 'FreeDiams::CA_HCDPD::DIN', 2888);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Dimenhydrinate', 'suppository', 'R06AA02', false, 0, '00392545', 'FreeDiams::CA_HCDPD::DIN', 2890);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Dimenhydrinate', 'suppository', 'R06AA02', false, 0, '00392553', 'FreeDiams::CA_HCDPD::DIN', 2891);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germicidal Detergent No 1492', 'liquid', 'V07AV', false, 0, '00405671', 'FreeDiams::CA_HCDPD::DIN', 2901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 5% Injection Usp', 'solution', 'B05BA03', false, 0, '00037915', 'FreeDiams::CA_HCDPD::DIN', 2902);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Sulfasalazine Tab 500mg', 'tablet', 'A07EC01', false, 0, '00410640', 'FreeDiams::CA_HCDPD::DIN', 2908);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methyldopa', 'tablet', 'C02AB02', false, 0, '00426830', 'FreeDiams::CA_HCDPD::DIN', 2909);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo Ac And C 8mg Tab', 'tablet', 'N02BA51', false, 0, '00426865', 'FreeDiams::CA_HCDPD::DIN', 2918);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aseptone Quat Detergent', 'liquid', 'V07AV', false, 0, '00435996', 'FreeDiams::CA_HCDPD::DIN', 2932);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine 2% Jelly', 'jelly', 'N01BB02', false, 0, '00385484', 'FreeDiams::CA_HCDPD::DIN', 2935);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cysto-Conray Ii', 'solution', 'V08AA04', false, 0, '00397466', 'FreeDiams::CA_HCDPD::DIN', 2949);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mikroklene', 'liquid', 'V07AV', false, 0, '00435430', 'FreeDiams::CA_HCDPD::DIN', 2954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prefrin A Liq', 'liquid', 'S01GA55', false, 0, '00400408', 'FreeDiams::CA_HCDPD::DIN', 2963);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Yf-Vax (Yellow Fever Vaccine)', 'powder for solution', 'J07BL01', false, 0, '00428833', 'FreeDiams::CA_HCDPD::DIN', 2964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Entrophen Ect 975mg', 'tablet (enteric-coated)', 'N02BA01', false, 0, '00419508', 'FreeDiams::CA_HCDPD::DIN', 2966);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pneumovax 23', 'solution', 'J07AL02', false, 0, '00431648', 'FreeDiams::CA_HCDPD::DIN', 2969);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cresophene Liq', 'liquid', 'A01AC52', false, 0, '00379689', 'FreeDiams::CA_HCDPD::DIN', 2977);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Linctus Codeine Blanc', 'liquid', 'R05DA04', false, 0, '00380571', 'FreeDiams::CA_HCDPD::DIN', 2982);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polytar Mild Shampoo', 'shampoo', 'D05AA', false, 0, '00419133', 'FreeDiams::CA_HCDPD::DIN', 2984);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Folic Acid Tab 5mg', 'tablet', 'B03BB01', false, 0, '00426849', 'FreeDiams::CA_HCDPD::DIN', 3002);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Benztropine Mesylate Tab 2mg', 'tablet', 'N04AC01', false, 0, '00426857', 'FreeDiams::CA_HCDPD::DIN', 3003);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride Injection Usp', 'solution', 'B05XA03', false, 0, '00392499', 'FreeDiams::CA_HCDPD::DIN', 3009);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metronidazole Tab 250mg', 'tablet', 'J01XD01', false, 0, '00420409', 'FreeDiams::CA_HCDPD::DIN', 3010);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dehydrated Alcohol Injection Usp', 'liquid', 'V03AZ01', false, 0, '00394394', 'FreeDiams::CA_HCDPD::DIN', 3011);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Formula 19 Germ Liq Cleaner', 'liquid', 'V07AV', false, 0, '00439193', 'FreeDiams::CA_HCDPD::DIN', 3015);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mikro Quat', 'liquid', 'V07AV', false, 0, '00333441', 'FreeDiams::CA_HCDPD::DIN', 3026);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Albalon A', 'liquid', 'S01GA51', false, 0, '00433519', 'FreeDiams::CA_HCDPD::DIN', 3028);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Noroma 25 Liq 5.625%', 'spray', 'V07AV', false, 0, '00388246', 'FreeDiams::CA_HCDPD::DIN', 3039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Noroma 5 Liq 1%', 'spray', 'V07AV', false, 0, '00388254', 'FreeDiams::CA_HCDPD::DIN', 3040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sulfate Inj 15mg/Ml Usp', 'liquid', 'N02AA01', false, 0, '00392561', 'FreeDiams::CA_HCDPD::DIN', 3042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sulfate Inj 10mg/Ml Usp', 'liquid', 'N02AA01', false, 0, '00392588', 'FreeDiams::CA_HCDPD::DIN', 3043);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Winpred Tab 1mg', 'tablet', 'H02AB07', false, 0, '00271373', 'FreeDiams::CA_HCDPD::DIN', 3076);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diazepam 10tab 10mg', 'tablet', 'N05BA01', false, 0, '00434388', 'FreeDiams::CA_HCDPD::DIN', 3084);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diazepam 2tab 2mg', 'tablet', 'N05BA01', false, 0, '00434396', 'FreeDiams::CA_HCDPD::DIN', 3085);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Magnesium Sulfate Inj 20% Usp', 'liquid', 'B05XA05', false, 0, '00392618', 'FreeDiams::CA_HCDPD::DIN', 3088);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Visken Tab 5mg', 'tablet', 'C07AA03', false, 0, '00417270', 'FreeDiams::CA_HCDPD::DIN', 3089);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Visken Tab 15mg', 'tablet', 'C07AA03', false, 0, '00417289', 'FreeDiams::CA_HCDPD::DIN', 3090);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Visken Tab 10mg', 'tablet', 'C07AA03', false, 0, '00443174', 'FreeDiams::CA_HCDPD::DIN', 3091);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hg7 Hos Germicide', 'liquid', 'V07AV', false, 0, '00388300', 'FreeDiams::CA_HCDPD::DIN', 3093);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bactigras', 'dressing', 'D09AA12', false, 0, '00433497', 'FreeDiams::CA_HCDPD::DIN', 3111);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Depakene Cap 250mg', 'capsule', 'N03AG01', false, 0, '00443840', 'FreeDiams::CA_HCDPD::DIN', 3112);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 3.3% Sod Chlor .3% Pot Chlor .15%', 'solution', 'B05BB02', false, 0, '00438014', 'FreeDiams::CA_HCDPD::DIN', 3132);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 3.3% Sod Chlor .3% Pot Chlor .3%', 'liquid', 'B05BB02', false, 0, '00438022', 'FreeDiams::CA_HCDPD::DIN', 3133);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amitriptyline 50 Tab 50mg', 'tablet', 'N06AA09', false, 0, '00456349', 'FreeDiams::CA_HCDPD::DIN', 3141);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Depakene Syr 50mg/Ml', 'syrup', 'N03AG01', false, 0, '00443832', 'FreeDiams::CA_HCDPD::DIN', 3156);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asa Tab 325mg', 'tablet', 'N02BA01', false, 0, '00230324', 'FreeDiams::CA_HCDPD::DIN', 3158);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Devrom Chew Tab 200mg', 'tablet', 'A07BB', false, 0, '00452696', 'FreeDiams::CA_HCDPD::DIN', 3166);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ees-400', 'powder for suspension', 'J01FA01', false, 0, '00453617', 'FreeDiams::CA_HCDPD::DIN', 3172);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valium 5 Tab', 'tablet', 'N05BA01', false, 0, '00013285', 'FreeDiams::CA_HCDPD::DIN', 3178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lioresal Tab 10mg', 'tablet', 'M03BX01', false, 0, '00455881', 'FreeDiams::CA_HCDPD::DIN', 3182);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Timoptic', 'solution', 'S01ED01', false, 0, '00451207', 'FreeDiams::CA_HCDPD::DIN', 3186);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cotazym 65b', 'capsule', 'A09AA02', false, 0, '00456233', 'FreeDiams::CA_HCDPD::DIN', 3189);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lithane', 'capsule', 'N05AN01', false, 0, '00406775', 'FreeDiams::CA_HCDPD::DIN', 3192);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alloprin', 'tablet', 'M04AA01', false, 0, '00449687', 'FreeDiams::CA_HCDPD::DIN', 3194);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxyderm Lot 20%', 'lotion', 'D10AE01', false, 0, '00374318', 'FreeDiams::CA_HCDPD::DIN', 3198);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Formule C34', 'liquid', 'P02CB01', false, 0, '00438898', 'FreeDiams::CA_HCDPD::DIN', 3228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novamoxin Cap 500mg', 'capsule', 'J01CA04', false, 0, '00406716', 'FreeDiams::CA_HCDPD::DIN', 3263);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novamoxin Cap 250mg', 'capsule', 'J01CA04', false, 0, '00406724', 'FreeDiams::CA_HCDPD::DIN', 3264);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nytol Tablet 25mg', 'tablet', 'R06AA02', false, 0, '00450839', 'FreeDiams::CA_HCDPD::DIN', 3266);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zap Liquid', 'liquid', 'D04AB30', false, 0, '00443786', 'FreeDiams::CA_HCDPD::DIN', 3276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Diazepam Tab 2mg', 'tablet', 'N05BA01', false, 0, '00405329', 'FreeDiams::CA_HCDPD::DIN', 3290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Diazepam Tab 10mg', 'tablet', 'N05BA01', false, 0, '00405337', 'FreeDiams::CA_HCDPD::DIN', 3291);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxyderm Lotion 5%', 'lotion', 'D10AE01', false, 0, '00374326', 'FreeDiams::CA_HCDPD::DIN', 3292);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxyderm Lotion 10%', 'lotion', 'D10AE01', false, 0, '00432938', 'FreeDiams::CA_HCDPD::DIN', 3293);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chem Shop Power Plus', 'liquid', 'V07AV', false, 0, '00470988', 'FreeDiams::CA_HCDPD::DIN', 3307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Urozide', 'tablet', 'C03AA03', false, 0, '00405620', 'FreeDiams::CA_HCDPD::DIN', 3311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mydfrin Liq 2.5%', 'liquid', 'S01FB01', false, 0, '00465763', 'FreeDiams::CA_HCDPD::DIN', 3319);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterex Shp', 'shampoo', 'D05AA', false, 0, '00444448', 'FreeDiams::CA_HCDPD::DIN', 3320);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenazo 200mg', 'tablet', 'G04BX06', false, 0, '00454583', 'FreeDiams::CA_HCDPD::DIN', 3329);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinemet 100/10', 'tablet', 'N04BA02', false, 0, '00355658', 'FreeDiams::CA_HCDPD::DIN', 3331);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novamoxin Sus 250mg/5ml', 'granules for suspension', 'J01CA04', false, 0, '00452130', 'FreeDiams::CA_HCDPD::DIN', 3344);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novamoxin Sus 125mg/5ml', 'granules for suspension', 'J01CA04', false, 0, '00452149', 'FreeDiams::CA_HCDPD::DIN', 3345);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lysodren', 'tablet', 'L01XX23', false, 0, '00463221', 'FreeDiams::CA_HCDPD::DIN', 3348);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novasen Tab 325mg', 'tablet (enteric-coated)', 'N02BA01', false, 0, '00216666', 'FreeDiams::CA_HCDPD::DIN', 3369);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Hydrocort Crm 1%', 'cream', 'D07AA02', false, 0, '00461903', 'FreeDiams::CA_HCDPD::DIN', 3370);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Demulen 30 (28 Day Pack)', 'tablet', 'G03AA01', false, 0, '00471526', 'FreeDiams::CA_HCDPD::DIN', 3374);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Penicilline V 300 Tab', 'tablet', 'J01CE02', false, 0, '00468029', 'FreeDiams::CA_HCDPD::DIN', 3375);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('L-Arginine Hydrochloride Injection', 'liquid', 'V04CD', false, 0, '00399736', 'FreeDiams::CA_HCDPD::DIN', 3378);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Water Inj', 'liquid', 'V07AB', false, 0, '00402257', 'FreeDiams::CA_HCDPD::DIN', 3383);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Chloride Inj', 'solution', 'B05XA01', false, 0, '00402206', 'FreeDiams::CA_HCDPD::DIN', 3394);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride Inj 23.4%', 'solution', 'B05XA03', false, 0, '00402230', 'FreeDiams::CA_HCDPD::DIN', 3395);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride Bacteriostatic Inj', 'liquid', 'B05XA03', false, 0, '00402249', 'FreeDiams::CA_HCDPD::DIN', 3396);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimenhydrinate Inj 50mg Usp', 'liquid', 'A04AD', false, 0, '00392537', 'FreeDiams::CA_HCDPD::DIN', 3397);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pollinex R', 'liquid', 'V01AA02', false, 0, '00464988', 'FreeDiams::CA_HCDPD::DIN', 3409);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levate', 'tablet', 'N06AA09', false, 0, '00405612', 'FreeDiams::CA_HCDPD::DIN', 3413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbolith Cap 150mg', 'capsule', 'N05AN01', false, 0, '00461733', 'FreeDiams::CA_HCDPD::DIN', 3414);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balminil Dm', 'syrup', 'R05DA09', false, 0, '00436895', 'FreeDiams::CA_HCDPD::DIN', 3422);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sulfinpyrazone', 'tablet', 'M04AB02', false, 0, '00441767', 'FreeDiams::CA_HCDPD::DIN', 3425);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rocaltrol Cap 0.5mcg', 'capsule', 'A11CC04', false, 0, '00481815', 'FreeDiams::CA_HCDPD::DIN', 3429);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rocaltrol Cap 0.25mcg', 'capsule', 'A11CC04', false, 0, '00481823', 'FreeDiams::CA_HCDPD::DIN', 3430);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydrea Cap 500mg', 'capsule', 'L01XX05', false, 0, '00465283', 'FreeDiams::CA_HCDPD::DIN', 3453);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pulmophylline Elx', 'elixir', 'R03DA04', false, 0, '00466409', 'FreeDiams::CA_HCDPD::DIN', 3455);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trl 13 Iodophor Disinfectant', 'liquid', 'V07AV', false, 0, '00481637', 'FreeDiams::CA_HCDPD::DIN', 3456);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Oxazepam Tab 10mg', 'tablet', 'N05BA04', false, 0, '00402680', 'FreeDiams::CA_HCDPD::DIN', 3463);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Oxazepam Tab 30mg', 'tablet', 'N05BA04', false, 0, '00402737', 'FreeDiams::CA_HCDPD::DIN', 3464);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Oxazepam Tab 15mg', 'tablet', 'N05BA04', false, 0, '00402745', 'FreeDiams::CA_HCDPD::DIN', 3465);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn 10%', 'solution', 'B05BA01', false, 0, '00454907', 'FreeDiams::CA_HCDPD::DIN', 3468);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citrus Disinfectant', 'liquid', 'V07AV', false, 0, '00482528', 'FreeDiams::CA_HCDPD::DIN', 3470);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pine Disinfectant', 'liquid', 'V07AV', false, 0, '00482536', 'FreeDiams::CA_HCDPD::DIN', 3471);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Patent Blue Sodium Inj', 'solution', 'V04CX', false, 0, '00405396', 'FreeDiams::CA_HCDPD::DIN', 3486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nauseatol', 'tablet (chewable)', 'R06AA02', false, 0, '00399779', 'FreeDiams::CA_HCDPD::DIN', 3491);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proctofoam Hc', 'aerosol', 'C05AA01', false, 0, '00363014', 'FreeDiams::CA_HCDPD::DIN', 3492);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fortaplex Inj', 'liquid', 'A11EA', false, 0, '00463434', 'FreeDiams::CA_HCDPD::DIN', 3497);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riboflavin Inj 50mg/Ml', 'solution', 'A11HA04', false, 0, '00463442', 'FreeDiams::CA_HCDPD::DIN', 3498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Niacin Inj 100mg/Ml', 'solution', 'C04AC01', false, 0, '00463450', 'FreeDiams::CA_HCDPD::DIN', 3499);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cobex Inj 1000mcg/Ml', 'solution', 'B03BA01', false, 0, '00465356', 'FreeDiams::CA_HCDPD::DIN', 3500);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pyridoxine Hcl Inj 100mg/Ml', 'liquid', 'A11HA02', false, 0, '00463469', 'FreeDiams::CA_HCDPD::DIN', 3501);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydro Cobex Inj 1000mcg/Ml', 'liquid', 'B03BA03', false, 0, '00463477', 'FreeDiams::CA_HCDPD::DIN', 3502);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Thiamine Hcl Inj 100mg/Ml', 'liquid', 'A11DA01', false, 0, '00463493', 'FreeDiams::CA_HCDPD::DIN', 3503);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Chloride 20 Meq In 5% Dextrose With 0.45% Sodium Chloride', 'solution', 'B05BB02', false, 0, '00466670', 'FreeDiams::CA_HCDPD::DIN', 3534);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Chloride 20 Meq In 5% Dextrose With 0.225% Sodium Chloride', 'solution', 'B05BB02', false, 0, '00466689', 'FreeDiams::CA_HCDPD::DIN', 3535);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Chloride 20 Meq In 5% Dextrose', 'solution', 'B05BB02', false, 0, '00466697', 'FreeDiams::CA_HCDPD::DIN', 3536);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Chloride 40 Meq In 3.3% Dextrose With 0.3% Sodium Chloride', 'solution', 'B05BB02', false, 0, '00472077', 'FreeDiams::CA_HCDPD::DIN', 3537);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Chloride 20 Meq In 3.3% Dextrose With 0.3% Sodium Chloride', 'solution', 'B05BB02', false, 0, '00472085', 'FreeDiams::CA_HCDPD::DIN', 3538);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Formule L2', 'liquid', 'N02BA51', false, 0, '00469203', 'FreeDiams::CA_HCDPD::DIN', 3546);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Supeudol 20', 'suppository', 'N02AA05', false, 0, '00392472', 'FreeDiams::CA_HCDPD::DIN', 3550);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Supeudol 10', 'suppository', 'N02AA05', false, 0, '00392480', 'FreeDiams::CA_HCDPD::DIN', 3551);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atropine Sulfate Injection Usp', 'solution', 'A03BA01', false, 0, '00392693', 'FreeDiams::CA_HCDPD::DIN', 3553);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atropine Sulfate Injection Usp', 'solution', 'A03BA01', false, 0, '00392782', 'FreeDiams::CA_HCDPD::DIN', 3554);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dicyclomine Hydrochloride Injection Usp', 'solution', 'A03AA07', false, 0, '00392812', 'FreeDiams::CA_HCDPD::DIN', 3555);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dicyclomine Hydrochloride Usp', 'capsule', 'A03AA07', false, 0, '00392820', 'FreeDiams::CA_HCDPD::DIN', 3556);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M-M-R* Ii', 'powder for solution', 'J07BD52', false, 0, '00466085', 'FreeDiams::CA_HCDPD::DIN', 3569);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 70% Injection Usp', 'solution', 'B05BA03', false, 0, '00244988', 'FreeDiams::CA_HCDPD::DIN', 3585);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bac Stop', 'liquid', 'V07AV', false, 0, '00493236', 'FreeDiams::CA_HCDPD::DIN', 3592);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enviro 40liq', 'liquid', 'V07AV', false, 0, '00415219', 'FreeDiams::CA_HCDPD::DIN', 3594);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimenhydrinate Inj 10mg', 'liquid', 'R06AA02', false, 0, '00392731', 'FreeDiams::CA_HCDPD::DIN', 3595);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ko 10', 'liquid', 'V07AV', false, 0, '00472255', 'FreeDiams::CA_HCDPD::DIN', 3619);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doc Germicide', 'liquid', 'V07AV', false, 0, '00487422', 'FreeDiams::CA_HCDPD::DIN', 3629);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Demulen 30 (21 Day Pack)', 'tablet', 'G03AA01', false, 0, '00469327', 'FreeDiams::CA_HCDPD::DIN', 3633);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxpam', 'tablet', 'N05BA04', false, 0, '00414247', 'FreeDiams::CA_HCDPD::DIN', 3656);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxpam', 'tablet', 'N05BA04', false, 0, '00414255', 'FreeDiams::CA_HCDPD::DIN', 3657);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxpam', 'tablet', 'N05BA04', false, 0, '00414263', 'FreeDiams::CA_HCDPD::DIN', 3658);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexasone 4mg', 'tablet', 'H02AB02', false, 0, '00489158', 'FreeDiams::CA_HCDPD::DIN', 3661);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Sulfatrim Pediatric', 'tablet', 'J01EE01', false, 0, '00445266', 'FreeDiams::CA_HCDPD::DIN', 3677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Sulfatrim Tab', 'tablet', 'J01EE01', false, 0, '00445274', 'FreeDiams::CA_HCDPD::DIN', 3678);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Sulfatrim Ds Tab', 'tablet', 'J01EE01', false, 0, '00445282', 'FreeDiams::CA_HCDPD::DIN', 3679);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ees-200', 'powder for suspension', 'J01FA01', false, 0, '00000299', 'FreeDiams::CA_HCDPD::DIN', 3698);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Drixtab Tab', 'tablet', 'R01BA52', false, 0, '00411892', 'FreeDiams::CA_HCDPD::DIN', 3717);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diprogen Ointment', 'ointment', 'D07CC01', false, 0, '00417254', 'FreeDiams::CA_HCDPD::DIN', 3718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diprogen Cream', 'cream', 'D07CC01', false, 0, '00417262', 'FreeDiams::CA_HCDPD::DIN', 3719);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diazepam Injection Usp', 'solution', 'N05BA01', false, 0, '00399728', 'FreeDiams::CA_HCDPD::DIN', 3721);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synacthen Depot', 'liquid', 'H01AA02', false, 0, '00253952', 'FreeDiams::CA_HCDPD::DIN', 3725);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceclor', 'capsule', 'J01DC04', false, 0, '00465186', 'FreeDiams::CA_HCDPD::DIN', 3728);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceclor', 'capsule', 'J01DC04', false, 0, '00465194', 'FreeDiams::CA_HCDPD::DIN', 3729);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceclor', 'powder for suspension', 'J01DC04', false, 0, '00465208', 'FreeDiams::CA_HCDPD::DIN', 3730);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceclor', 'powder for suspension', 'J01DC04', false, 0, '00465216', 'FreeDiams::CA_HCDPD::DIN', 3731);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fectol 3122', 'liquid', 'V07AV', false, 0, '00470767', 'FreeDiams::CA_HCDPD::DIN', 3732);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naphcon A', 'liquid', 'S01GA51', false, 0, '00481408', 'FreeDiams::CA_HCDPD::DIN', 3743);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 20% Injection Usp', 'solution', 'B05BA03', false, 0, '00037966', 'FreeDiams::CA_HCDPD::DIN', 3747);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S. Syrup 1.0 Mg/Ml', 'syrup', 'N02AA01', false, 0, '00486582', 'FreeDiams::CA_HCDPD::DIN', 3752);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estragyn', 'tablet', 'G03CA07', false, 0, '00473618', 'FreeDiams::CA_HCDPD::DIN', 3756);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rapido', 'aerosol', 'V07AV', false, 0, '00501115', 'FreeDiams::CA_HCDPD::DIN', 3766);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rimso-50', 'solution', 'G04BX13', false, 0, '00493392', 'FreeDiams::CA_HCDPD::DIN', 3769);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dormiphen Extra-Fort Capsule', 'capsule', 'R06AA02', false, 0, '00489867', 'FreeDiams::CA_HCDPD::DIN', 3775);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Folic Acid Tab 5mg', 'tablet', 'B03BB01', false, 0, '00498777', 'FreeDiams::CA_HCDPD::DIN', 3778);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluorescite Inj 10%', 'solution', 'V04CX', false, 0, '00505005', 'FreeDiams::CA_HCDPD::DIN', 3781);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cloxin For Oral Solution 1', 'powder for solution', 'J01CF02', false, 0, '00337757', 'FreeDiams::CA_HCDPD::DIN', 3794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germex', 'liquid', 'V07AV', false, 0, '00503851', 'FreeDiams::CA_HCDPD::DIN', 3797);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Scandonest 3% Plain Inj', 'liquid', 'N01BB03', false, 0, '00479934', 'FreeDiams::CA_HCDPD::DIN', 3804);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Scandonest 2% Special Inj', 'liquid', 'N01BB53', false, 0, '00479942', 'FreeDiams::CA_HCDPD::DIN', 3805);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxazepam 10 Tab 10mg', 'tablet', 'N05BA04', false, 0, '00497754', 'FreeDiams::CA_HCDPD::DIN', 3806);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxazepam 15 Tab 15mg', 'tablet', 'N05BA04', false, 0, '00497762', 'FreeDiams::CA_HCDPD::DIN', 3807);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxazepam 30 Tab 30mg', 'tablet', 'N05BA04', false, 0, '00497770', 'FreeDiams::CA_HCDPD::DIN', 3808);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Furosemide 20 Tab', 'tablet', 'C03CA01', false, 0, '00496723', 'FreeDiams::CA_HCDPD::DIN', 3809);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Propranolol Tab 40mg', 'tablet', 'C07AA05', false, 0, '00402753', 'FreeDiams::CA_HCDPD::DIN', 3810);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Propranolol Tab 80mg', 'tablet', 'C07AA05', false, 0, '00402761', 'FreeDiams::CA_HCDPD::DIN', 3811);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Propranolol Tab 10mg', 'tablet', 'C07AA05', false, 0, '00402788', 'FreeDiams::CA_HCDPD::DIN', 3812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 40% Injection Usp', 'solution', 'B05BA03', false, 0, '00470953', 'FreeDiams::CA_HCDPD::DIN', 3819);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 50% Inj W Electrolytes Pf Abbovac', 'solution', 'B05BB02', false, 0, '00494704', 'FreeDiams::CA_HCDPD::DIN', 3820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Water For Irrigation', 'liquid', 'V07AB', false, 0, '00498785', 'FreeDiams::CA_HCDPD::DIN', 3822);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sorbitol Mannitol Irrigation', 'solution', 'B05CX10', false, 0, '00498807', 'FreeDiams::CA_HCDPD::DIN', 3823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advance Sanitizer', 'liquid', 'V07AV', false, 0, '00501786', 'FreeDiams::CA_HCDPD::DIN', 3824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advance Quat', 'liquid', 'V07AV', false, 0, '00470910', 'FreeDiams::CA_HCDPD::DIN', 3826);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bactol (Disinfectant And Sanitizer)/Bactol (Desinfectant Et Assainisseur)', 'solution', 'V07AV', false, 0, '00470880', 'FreeDiams::CA_HCDPD::DIN', 3828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pine Guard Disinfectant', 'liquid', 'V07AV', false, 0, '00487899', 'FreeDiams::CA_HCDPD::DIN', 3829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Colinon', 'liquid', 'V07AV', false, 0, '00464996', 'FreeDiams::CA_HCDPD::DIN', 3836);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Bicarbonate Inj 7.5%', 'solution', 'B05XA02', false, 0, '00038083', 'FreeDiams::CA_HCDPD::DIN', 3837);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alloprin', 'tablet', 'M04AA01', false, 0, '00454354', 'FreeDiams::CA_HCDPD::DIN', 3843);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glycine 1.5% Irrigation', 'solution', 'B05CX03', false, 0, '00498793', 'FreeDiams::CA_HCDPD::DIN', 3865);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ac Pine', 'liquid', 'V07AV', false, 0, '00508888', 'FreeDiams::CA_HCDPD::DIN', 3879);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cortate Ont 1%', 'ointment', 'D07AA02', false, 0, '00502197', 'FreeDiams::CA_HCDPD::DIN', 3880);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cortate Crm 1%', 'cream', 'D07AA02', false, 0, '00502200', 'FreeDiams::CA_HCDPD::DIN', 3881);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epipen', 'solution', 'C01CA24', false, 0, '00509558', 'FreeDiams::CA_HCDPD::DIN', 3883);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amphotone Plus', 'liquid', 'V07AV', false, 0, '00505617', 'FreeDiams::CA_HCDPD::DIN', 3884);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cotazym Ecs 8', 'capsule', 'A09AA02', false, 0, '00502790', 'FreeDiams::CA_HCDPD::DIN', 3891);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Miostat Ophthalmic Liq 0.01%', 'solution', 'S01EB02', false, 0, '00042544', 'FreeDiams::CA_HCDPD::DIN', 3906);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Haloperidol Tab 0.5mg', 'tablet', 'N05AD01', false, 0, '00396796', 'FreeDiams::CA_HCDPD::DIN', 3918);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Haloperidol Tab 1mg', 'tablet', 'N05AD01', false, 0, '00396818', 'FreeDiams::CA_HCDPD::DIN', 3919);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Carbamazepine Tab 200mg', 'tablet', 'N03AF01', false, 0, '00402699', 'FreeDiams::CA_HCDPD::DIN', 3920);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Niacinamide Inj 100mg/Ml', 'liquid', 'A11HA01', false, 0, '00504483', 'FreeDiams::CA_HCDPD::DIN', 3921);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Magnesium Sulfate Inj 50%', 'liquid', 'B05XA05', false, 0, '00504513', 'FreeDiams::CA_HCDPD::DIN', 3922);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('D4055 Liq Degreaser Cleaner', 'liquid', 'V07AV', false, 0, '00513032', 'FreeDiams::CA_HCDPD::DIN', 3924);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Conray 43', 'solution', 'V08AA04', false, 0, '00477095', 'FreeDiams::CA_HCDPD::DIN', 3930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gravol Filmkote Tab 15mg', 'tablet', 'R06AA02', false, 0, '00511196', 'FreeDiams::CA_HCDPD::DIN', 3943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gravol Filmkote Tab 50mg', 'tablet', 'R06AA02', false, 0, '00013803', 'FreeDiams::CA_HCDPD::DIN', 3944);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Lexin Cap 250mg', 'capsule', 'J01DB01', false, 0, '00342084', 'FreeDiams::CA_HCDPD::DIN', 3945);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Lexin Cap 500mg', 'capsule', 'J01DB01', false, 0, '00342114', 'FreeDiams::CA_HCDPD::DIN', 3946);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Niacin Pwr 800mg/1.25ml', 'powder', 'C04AC01', false, 0, '00520888', 'FreeDiams::CA_HCDPD::DIN', 3965);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Choledyl Elixir 100mg/5ml', 'elixir', 'R03DA02', false, 0, '00476366', 'FreeDiams::CA_HCDPD::DIN', 3966);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mogadon Tab 5mg', 'tablet', 'N05CD02', false, 0, '00511528', 'FreeDiams::CA_HCDPD::DIN', 3991);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mogadon Tab 10mg', 'tablet', 'N05CD02', false, 0, '00511536', 'FreeDiams::CA_HCDPD::DIN', 3992);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Supeudol 10', 'tablet', 'N02AA05', false, 0, '00443948', 'FreeDiams::CA_HCDPD::DIN', 3996);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('S J Liniment', 'lotion', 'M02AC', false, 0, '00449741', 'FreeDiams::CA_HCDPD::DIN', 3998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biodine', 'liquid', 'V07AV', false, 0, '00523720', 'FreeDiams::CA_HCDPD::DIN', 4000);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinemet 100/25', 'tablet', 'N04BA02', false, 0, '00513997', 'FreeDiams::CA_HCDPD::DIN', 4008);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Loniten 10mg', 'tablet', 'C02DC01', false, 0, '00514500', 'FreeDiams::CA_HCDPD::DIN', 4010);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Loniten 2.5mg', 'tablet', 'C02DC01', false, 0, '00514497', 'FreeDiams::CA_HCDPD::DIN', 4011);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Targel Sa', 'liquid', 'D05AA', false, 0, '00510335', 'FreeDiams::CA_HCDPD::DIN', 4037);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Voltaren Tab 50mg', 'tablet (delayed-release)', 'M01AB05', false, 0, '00514012', 'FreeDiams::CA_HCDPD::DIN', 4043);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dixarit Tab 0.025mg', 'tablet', 'N02CX02', false, 0, '00519251', 'FreeDiams::CA_HCDPD::DIN', 4045);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Propranolol Tab 120mg', 'tablet', 'C07AA05', false, 0, '00504335', 'FreeDiams::CA_HCDPD::DIN', 4071);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride Injection 0.9%', 'solution', 'B05XA03', false, 0, '00037842', 'FreeDiams::CA_HCDPD::DIN', 4092);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Td Adsorbed', 'suspension', 'J07AM51', false, 0, '00514462', 'FreeDiams::CA_HCDPD::DIN', 4109);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nalcrom', 'capsule', 'A07EB01', false, 0, '00500895', 'FreeDiams::CA_HCDPD::DIN', 4114);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vasofrinic Dh', 'syrup', 'R05DA20', false, 0, '00472549', 'FreeDiams::CA_HCDPD::DIN', 4124);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Methacin Cap 25mg', 'capsule', 'M01AB01', false, 0, '00337420', 'FreeDiams::CA_HCDPD::DIN', 4129);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Methacin Cap 50mg', 'capsule', 'M01AB01', false, 0, '00337439', 'FreeDiams::CA_HCDPD::DIN', 4130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Panoxyl 5 Bar', 'soap bar', 'D10AE01', false, 0, '00483184', 'FreeDiams::CA_HCDPD::DIN', 4131);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mega-C-Sodium Inj 250mg/Ml', 'solution', 'A11GA01', false, 0, '00525189', 'FreeDiams::CA_HCDPD::DIN', 4133);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lectopam Tab 3mg', 'tablet', 'N05BA08', false, 0, '00518123', 'FreeDiams::CA_HCDPD::DIN', 4157);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lectopam Tab 6mg', 'tablet', 'N05BA08', false, 0, '00518131', 'FreeDiams::CA_HCDPD::DIN', 4158);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Garamycin Otic Drops 0.3%', 'drops', 'S02AA14', false, 0, '00512184', 'FreeDiams::CA_HCDPD::DIN', 4181);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Garamycin Ophthalmic Drops 0.3%', 'drops', 'S01AA11', false, 0, '00512192', 'FreeDiams::CA_HCDPD::DIN', 4182);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germarc', 'liquid', 'V07AV', false, 0, '00522880', 'FreeDiams::CA_HCDPD::DIN', 4190);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibac B', 'powder', 'V07AV', false, 0, '00524123', 'FreeDiams::CA_HCDPD::DIN', 4191);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trl 35', 'liquid', 'V07AV', false, 0, '00523739', 'FreeDiams::CA_HCDPD::DIN', 4199);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trl 135 Mul T Quat', 'liquid', 'V07AV', false, 0, '00523747', 'FreeDiams::CA_HCDPD::DIN', 4200);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trl 132 Mul T Phenol', 'liquid', 'V07AV', false, 0, '00523755', 'FreeDiams::CA_HCDPD::DIN', 4201);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dentsply 4% Prilocaine And Epinephrine Injection 1:200,000', 'solution', 'N01BB54', false, 0, '00519227', 'FreeDiams::CA_HCDPD::DIN', 4202);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('4% Citanest Plain Dental', 'solution', 'N01BB04', false, 0, '00519235', 'FreeDiams::CA_HCDPD::DIN', 4203);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extracts Inj', 'liquid', 'V01AA20', false, 0, '00514713', 'FreeDiams::CA_HCDPD::DIN', 4212);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dynakil Sq Liquid Germicidal Detergent', 'liquid', 'V07AV', false, 0, '00514810', 'FreeDiams::CA_HCDPD::DIN', 4218);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stieva-A Cream', 'cream', 'D10AD01', false, 0, '00518182', 'FreeDiams::CA_HCDPD::DIN', 4220);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandomigran Ds', 'tablet', 'N02CX01', false, 0, '00511552', 'FreeDiams::CA_HCDPD::DIN', 4222);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Protylol Tab 20mg', 'tablet', 'A03AA07', false, 0, '00513059', 'FreeDiams::CA_HCDPD::DIN', 4223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminophylline Injection 25mg/Ml', 'solution', 'R03DA05', false, 0, '00497193', 'FreeDiams::CA_HCDPD::DIN', 4226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminophylline Injection 50mg/Ml', 'solution', 'R03DA05', false, 0, '00497207', 'FreeDiams::CA_HCDPD::DIN', 4227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atropine Sulfate Inj 0.4mg/Ml', 'solution', 'A03BA01', false, 0, '00497231', 'FreeDiams::CA_HCDPD::DIN', 4228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atropine Sulfate Inj 0.6mg/Ml', 'solution', 'A03BA01', false, 0, '00497258', 'FreeDiams::CA_HCDPD::DIN', 4229);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Calcium Chloride Inj 100mg/Ml', 'solution', 'B05XA07', false, 0, '00294748', 'FreeDiams::CA_HCDPD::DIN', 4230);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Codeine Phosphate Inj 30mg/Ml', 'solution', 'R05DA04', false, 0, '00497282', 'FreeDiams::CA_HCDPD::DIN', 4232);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Codeine Phosphate Inj 60mg/Ml', 'solution', 'R05DA04', false, 0, '00497290', 'FreeDiams::CA_HCDPD::DIN', 4233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Meperidine Hcl Injection 25mg/Ml', 'solution', 'N02AB02', false, 0, '00497444', 'FreeDiams::CA_HCDPD::DIN', 4234);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Meperidine Hcl Injection 50mg/Ml', 'solution', 'N02AB02', false, 0, '00497452', 'FreeDiams::CA_HCDPD::DIN', 4235);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Meperidine Hcl Injection 75mg/Ml', 'solution', 'N02AB02', false, 0, '00497460', 'FreeDiams::CA_HCDPD::DIN', 4236);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Meperidine Hcl Injection 100mg/Ml', 'solution', 'N02AB02', false, 0, '00497479', 'FreeDiams::CA_HCDPD::DIN', 4237);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Flupam Cap 15mg', 'capsule', 'N05CD01', false, 0, '00496545', 'FreeDiams::CA_HCDPD::DIN', 4239);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Flupam Cap 30mg', 'capsule', 'N05CD01', false, 0, '00496553', 'FreeDiams::CA_HCDPD::DIN', 4240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Trazodone Hcl Tab 50mg', 'tablet', 'N06AX05', false, 0, '01937227', 'FreeDiams::CA_HCDPD::DIN', 4241);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pulmorphan', 'syrup', 'R05FA02', false, 0, '00513741', 'FreeDiams::CA_HCDPD::DIN', 4252);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Calmex Tab 25mg', 'tablet', 'R06AA02', false, 0, '00479764', 'FreeDiams::CA_HCDPD::DIN', 4253);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pranol Tab 10mg', 'tablet', 'C07AA05', false, 0, '00496480', 'FreeDiams::CA_HCDPD::DIN', 4254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pranol Tab 40mg', 'tablet', 'C07AA05', false, 0, '00496499', 'FreeDiams::CA_HCDPD::DIN', 4255);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pranol Tab 80mg', 'tablet', 'C07AA05', false, 0, '00496502', 'FreeDiams::CA_HCDPD::DIN', 4256);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Choledyl Expectorant Elixir', 'elixir', 'R03DA54', false, 0, '00476374', 'FreeDiams::CA_HCDPD::DIN', 4258);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pyridium 200mg', 'tablet', 'G04BX06', false, 0, '00476722', 'FreeDiams::CA_HCDPD::DIN', 4260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Bisacodyl', 'suppository', 'A06AB02', false, 0, '00404802', 'FreeDiams::CA_HCDPD::DIN', 4262);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenobarbital Sodium Injection 120mg/Ml', 'solution', 'N03AA02', false, 0, '00497495', 'FreeDiams::CA_HCDPD::DIN', 4266);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pyridoxine Hydrochloride Injection 100mg/Ml', 'solution', 'A11HA02', false, 0, '00497517', 'FreeDiams::CA_HCDPD::DIN', 4267);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin B12 Inj 100mcg/Ml', 'solution', 'B03BA01', false, 0, '00497533', 'FreeDiams::CA_HCDPD::DIN', 4268);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin B12 Inj 1000mcg/Ml', 'solution', 'B03BA01', false, 0, '00038830', 'FreeDiams::CA_HCDPD::DIN', 4269);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin K1 Inj 2mg/Ml', 'solution', 'B02BA01', false, 0, '00497541', 'FreeDiams::CA_HCDPD::DIN', 4270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin K1 Inj 10mg/Ml', 'solution', 'B02BA01', false, 0, '00497568', 'FreeDiams::CA_HCDPD::DIN', 4271);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyloprim', 'tablet', 'M04AA01', false, 0, '00402818', 'FreeDiams::CA_HCDPD::DIN', 4276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Chlordiazepoxide', 'capsule', 'N05BA02', false, 0, '00522724', 'FreeDiams::CA_HCDPD::DIN', 4277);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Chlordiazepoxide', 'capsule', 'N05BA02', false, 0, '00522988', 'FreeDiams::CA_HCDPD::DIN', 4278);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Chlordiazepoxide', 'capsule', 'N05BA02', false, 0, '00522996', 'FreeDiams::CA_HCDPD::DIN', 4279);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Hydro Tab 50mg', 'tablet', 'C03AA03', false, 0, '00312800', 'FreeDiams::CA_HCDPD::DIN', 4280);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Hydro Tab 25mg', 'tablet', 'C03AA03', false, 0, '00326844', 'FreeDiams::CA_HCDPD::DIN', 4281);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atropine Sulfate Inj 0.3mg/Ml', 'solution', 'A03BA01', false, 0, '00497223', 'FreeDiams::CA_HCDPD::DIN', 4291);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ergonovine Maleate Injection', 'solution', 'G02AB03', false, 0, '00497312', 'FreeDiams::CA_HCDPD::DIN', 4292);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxytocin Injection 10unit/Ml', 'solution', 'H01BB02', false, 0, '00497398', 'FreeDiams::CA_HCDPD::DIN', 4293);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Meperidine Hcl Injection 10mg/Ml', 'solution', 'N02AB02', false, 0, '00497436', 'FreeDiams::CA_HCDPD::DIN', 4294);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S. Syrup 5mg/Ml', 'syrup', 'N02AA01', false, 0, '00514217', 'FreeDiams::CA_HCDPD::DIN', 4297);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyloprim', 'tablet', 'M04AA01', false, 0, '00402796', 'FreeDiams::CA_HCDPD::DIN', 4302);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyloprim', 'tablet', 'M04AA01', false, 0, '00479799', 'FreeDiams::CA_HCDPD::DIN', 4303);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Purol Tab 300mg', 'tablet', 'M04AA01', false, 0, '00363693', 'FreeDiams::CA_HCDPD::DIN', 4304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Purol Tab 100mg', 'tablet', 'M04AA01', false, 0, '00364282', 'FreeDiams::CA_HCDPD::DIN', 4305);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nardil', 'tablet', 'N06AF03', false, 0, '00476552', 'FreeDiams::CA_HCDPD::DIN', 4309);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anafranil', 'tablet', 'N06AA04', false, 0, '00402591', 'FreeDiams::CA_HCDPD::DIN', 4382);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pyridium 100mg', 'tablet', 'G04BX06', false, 0, '00476714', 'FreeDiams::CA_HCDPD::DIN', 4388);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anusol-Hc Ointment', 'ointment', 'C05AA01', false, 0, '00505773', 'FreeDiams::CA_HCDPD::DIN', 4389);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anugesic-Hc Ointment', 'ointment', 'C05AA51', false, 0, '00505781', 'FreeDiams::CA_HCDPD::DIN', 4390);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Panoxyl 10 Bar 10%', 'soap bar', 'D10AE01', false, 0, '00527661', 'FreeDiams::CA_HCDPD::DIN', 4408);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylonor Gel', 'gel', 'A01AD11', false, 0, '00479896', 'FreeDiams::CA_HCDPD::DIN', 4410);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Furosemide Inj Usp', 'liquid', 'C03CA01', false, 0, '00527033', 'FreeDiams::CA_HCDPD::DIN', 4431);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin B12', 'liquid', 'B03BA01', false, 0, '00521515', 'FreeDiams::CA_HCDPD::DIN', 4432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atropine Sulfate Inj 1mg/Ml', 'solution', 'A03BA01', false, 0, '00497266', 'FreeDiams::CA_HCDPD::DIN', 4440);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dehydrated Alcohol Injection', 'liquid', 'V03AX', false, 0, '00537640', 'FreeDiams::CA_HCDPD::DIN', 4442);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prolopa Cap 50-12.5', 'capsule', 'N04BA02', false, 0, '00522597', 'FreeDiams::CA_HCDPD::DIN', 4459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Erythro-S', 'tablet', 'J01FA01', false, 0, '00545678', 'FreeDiams::CA_HCDPD::DIN', 4465);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bismutal Adults', 'suppository', 'R05CA10', false, 0, '00535168', 'FreeDiams::CA_HCDPD::DIN', 4468);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Calmylin', 'liquid', 'R05FA02', false, 0, '00535230', 'FreeDiams::CA_HCDPD::DIN', 4469);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xanax Tab 0.25mg', 'tablet', 'N05BA12', false, 0, '00548359', 'FreeDiams::CA_HCDPD::DIN', 4471);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xanax Tab 0.5mg', 'tablet', 'N05BA12', false, 0, '00548367', 'FreeDiams::CA_HCDPD::DIN', 4472);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocard Inj', 'liquid', 'C01BB01', false, 0, '00001937', 'FreeDiams::CA_HCDPD::DIN', 4478);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Q8 Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '00537160', 'FreeDiams::CA_HCDPD::DIN', 4494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenobarbital Sodium Injection 30mg/Ml', 'solution', 'N03AA02', false, 0, '00497487', 'FreeDiams::CA_HCDPD::DIN', 4515);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quinidine Sulfate Injection 190mg/Ml', 'solution', 'C01BA01', false, 0, '00497525', 'FreeDiams::CA_HCDPD::DIN', 4516);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ectosone Mild Cream 0.05%', 'cream', 'D07AC01', false, 0, '00535427', 'FreeDiams::CA_HCDPD::DIN', 4521);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ectosone Regular Cream 0.1%', 'cream', 'D07AC01', false, 0, '00535435', 'FreeDiams::CA_HCDPD::DIN', 4522);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Triamterene/Hctz', 'tablet', 'C03EA01', false, 0, '00532657', 'FreeDiams::CA_HCDPD::DIN', 4523);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mandelamine', 'tablet', 'J01XX05', false, 0, '00499013', 'FreeDiams::CA_HCDPD::DIN', 4538);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dan-Gard', 'shampoo', 'D11AX12', false, 0, '00507415', 'FreeDiams::CA_HCDPD::DIN', 4544);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Som Pam', 'capsule', 'N05CD01', false, 0, '00414220', 'FreeDiams::CA_HCDPD::DIN', 4545);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Som Pam', 'capsule', 'N05CD01', false, 0, '00414239', 'FreeDiams::CA_HCDPD::DIN', 4546);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alloprin', 'tablet', 'M04AA01', false, 0, '00514209', 'FreeDiams::CA_HCDPD::DIN', 4547);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn 7%', 'solution', 'B05BA01', false, 0, '00523232', 'FreeDiams::CA_HCDPD::DIN', 4560);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tobrex 0.3% Ophthalmic Sol', 'liquid', 'S01AA12', false, 0, '00513962', 'FreeDiams::CA_HCDPD::DIN', 4571);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mazepine', 'tablet', 'N03AF01', false, 0, '00504742', 'FreeDiams::CA_HCDPD::DIN', 4582);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Uremol Hc', 'cream', 'D07XA01', false, 0, '00503134', 'FreeDiams::CA_HCDPD::DIN', 4583);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bronchophan Forte Dm Syr', 'syrup', 'R05DA09', false, 0, '00522791', 'FreeDiams::CA_HCDPD::DIN', 4590);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maxidex Ont 0.1%', 'ointment', 'S01BA01', false, 0, '00042579', 'FreeDiams::CA_HCDPD::DIN', 4591);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Trimel Ds Tab', 'tablet', 'J01EE01', false, 0, '00510645', 'FreeDiams::CA_HCDPD::DIN', 4610);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Trimel Tab', 'tablet', 'J01EE01', false, 0, '00510637', 'FreeDiams::CA_HCDPD::DIN', 4611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fp 787', 'liquid', 'V07AV', false, 0, '00470899', 'FreeDiams::CA_HCDPD::DIN', 4612);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Calmydone', 'syrup', 'R05DA20', false, 0, '00550477', 'FreeDiams::CA_HCDPD::DIN', 4615);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Capoten Tab 25mg', 'tablet', 'C09AA01', false, 0, '00546283', 'FreeDiams::CA_HCDPD::DIN', 4619);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anugesic-Hc Suppositories', 'suppository', 'C05AA51', false, 0, '00476242', 'FreeDiams::CA_HCDPD::DIN', 4629);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anusol-Hc Suppositories', 'suppository', 'C05AA01', false, 0, '00476285', 'FreeDiams::CA_HCDPD::DIN', 4630);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Travasol Inj Without Electrolytes 10%', 'solution', 'B05BA01', false, 0, '00388769', 'FreeDiams::CA_HCDPD::DIN', 4661);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Throat Lozenges', 'lozenge', 'R02AA06', false, 0, '00549665', 'FreeDiams::CA_HCDPD::DIN', 4665);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Throat Lozenges 1.5mg', 'lozenge', 'R02AA06', false, 0, '00549673', 'FreeDiams::CA_HCDPD::DIN', 4666);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anthranol Cream 0.1%', 'cream', 'D05AC01', false, 0, '00537594', 'FreeDiams::CA_HCDPD::DIN', 4677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anthranol Cream 0.2%', 'cream', 'D05AC01', false, 0, '00537608', 'FreeDiams::CA_HCDPD::DIN', 4678);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dalmane', 'capsule', 'N05CD01', false, 0, '00012696', 'FreeDiams::CA_HCDPD::DIN', 4697);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Septra Injection', 'solution', 'J01EE01', false, 0, '00550086', 'FreeDiams::CA_HCDPD::DIN', 4703);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Dicyclomine', 'capsule', 'A03AA07', false, 0, '00557102', 'FreeDiams::CA_HCDPD::DIN', 4710);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allopurinol Tab 100mg', 'tablet', 'M04AA01', false, 0, '00555681', 'FreeDiams::CA_HCDPD::DIN', 4724);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allopurinol Tab 300mg', 'tablet', 'M04AA01', false, 0, '00555703', 'FreeDiams::CA_HCDPD::DIN', 4725);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Flurazepam Hcl Cap 15mg', 'capsule', 'N05CD01', false, 0, '00521698', 'FreeDiams::CA_HCDPD::DIN', 4728);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Flurazepam Hcl Cap 30mg', 'capsule', 'N05CD01', false, 0, '00521701', 'FreeDiams::CA_HCDPD::DIN', 4729);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isdn', 'tablet', 'C01DA08', false, 0, '00441686', 'FreeDiams::CA_HCDPD::DIN', 4730);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isdn', 'tablet', 'C01DA08', false, 0, '00441694', 'FreeDiams::CA_HCDPD::DIN', 4731);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Prednisone Tab 5mg', 'tablet', 'H02AB07', false, 0, '00312770', 'FreeDiams::CA_HCDPD::DIN', 4732);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Acetaminophen Tab 325mg', 'tablet', 'N02BE01', false, 0, '00544981', 'FreeDiams::CA_HCDPD::DIN', 4733);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Acetaminophen Tab 500mg', 'tablet', 'N02BE01', false, 0, '00545007', 'FreeDiams::CA_HCDPD::DIN', 4734);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Prednisone Tab 50mg', 'tablet', 'H02AB07', false, 0, '00550957', 'FreeDiams::CA_HCDPD::DIN', 4736);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Slo-Pot', 'tablet (extended-release)', 'A12BA01', false, 0, '00554308', 'FreeDiams::CA_HCDPD::DIN', 4739);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vermox Tablets 100 Mg', 'tablet', 'P02CA01', false, 0, '00556734', 'FreeDiams::CA_HCDPD::DIN', 4743);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Calcium Inj', 'liquid', 'A12AA20', false, 0, '00532762', 'FreeDiams::CA_HCDPD::DIN', 4761);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Scopolamine Hydrobromide Injection 0.4mg/Ml', 'solution', 'A04AD01', false, 0, '00541869', 'FreeDiams::CA_HCDPD::DIN', 4787);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Scopolamine Hydrobromide Injection 0.6mg/Ml', 'solution', 'A04AD01', false, 0, '00541877', 'FreeDiams::CA_HCDPD::DIN', 4788);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sanit C 16 26.5%', 'liquid', 'V07AV', false, 0, '00536806', 'FreeDiams::CA_HCDPD::DIN', 4791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diluent Sterile', 'liquid', 'V07AB', false, 0, '00316288', 'FreeDiams::CA_HCDPD::DIN', 4792);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novoxapam Tab 15mg', 'tablet', 'N05BA04', false, 0, '00496529', 'FreeDiams::CA_HCDPD::DIN', 4794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novoxapam Tab 30mg', 'tablet', 'N05BA04', false, 0, '00496537', 'FreeDiams::CA_HCDPD::DIN', 4795);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novoxapam Tab 10mg', 'tablet', 'N05BA04', false, 0, '00500852', 'FreeDiams::CA_HCDPD::DIN', 4796);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prostin Vr Sterile Solution', 'solution', 'C01EA01', false, 0, '00559253', 'FreeDiams::CA_HCDPD::DIN', 4802);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Codeine Phosphate Injection Usp', 'liquid', 'R05DA04', false, 0, '00544884', 'FreeDiams::CA_HCDPD::DIN', 4806);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chemprocide 7.5%', 'liquid', 'V07AV', false, 0, '00568236', 'FreeDiams::CA_HCDPD::DIN', 4830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Purol Tab 200 Mg', 'tablet', 'M04AA01', false, 0, '00565342', 'FreeDiams::CA_HCDPD::DIN', 4835);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lozide Tab 2.5mg', 'tablet', 'C03BA11', false, 0, '00564966', 'FreeDiams::CA_HCDPD::DIN', 4857);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clearasil Daily Clear Acne Treatment Cream Bp Plus', 'cream', 'D10AE01', false, 0, '00442968', 'FreeDiams::CA_HCDPD::DIN', 4861);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alvogyl', 'paste', 'A01AD11', false, 0, '00555509', 'FreeDiams::CA_HCDPD::DIN', 4875);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Relief 325mg Tablets', 'tablet', 'N02BE01', false, 0, '00374148', 'FreeDiams::CA_HCDPD::DIN', 4883);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Tablets Usp 500 Mg', 'tablet', 'N02BE01', false, 0, '00567663', 'FreeDiams::CA_HCDPD::DIN', 4884);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Secaris', 'gel', 'R01AX10', false, 0, '00551805', 'FreeDiams::CA_HCDPD::DIN', 4885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lubricating Nasal Mist', 'metered-dose (aerosol)', 'R01AX10', false, 0, '00551813', 'FreeDiams::CA_HCDPD::DIN', 4886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('R-2-L Bactericide Deodorizer', 'solution', 'V07AV', false, 0, '00558826', 'FreeDiams::CA_HCDPD::DIN', 4889);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Oxtriphylline Tab 100mg', 'tablet', 'R03DA02', false, 0, '00441724', 'FreeDiams::CA_HCDPD::DIN', 4894);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Oxtriphylline Tab 200mg', 'tablet', 'R03DA02', false, 0, '00441732', 'FreeDiams::CA_HCDPD::DIN', 4895);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enteric Coated Asa Tablets 325mg', 'tablet (enteric-coated)', 'N02BA01', false, 0, '00510696', 'FreeDiams::CA_HCDPD::DIN', 4896);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enteric Coated Asa Tablets 650mg', 'tablet (enteric-coated)', 'N02BA01', false, 0, '00472476', 'FreeDiams::CA_HCDPD::DIN', 4897);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Oxtriphylline Tab 300mg', 'tablet', 'R03DA02', false, 0, '00511692', 'FreeDiams::CA_HCDPD::DIN', 4898);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetazolamide', 'tablet', 'S01EC01', false, 0, '00545015', 'FreeDiams::CA_HCDPD::DIN', 4899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Bisacodyl Tab 5mg', 'tablet', 'A06AB02', false, 0, '00545023', 'FreeDiams::CA_HCDPD::DIN', 4900);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trihexyphenidyl', 'tablet', 'N04AA01', false, 0, '00545058', 'FreeDiams::CA_HCDPD::DIN', 4901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metronidazole', 'tablet', 'P01AB01', false, 0, '00545066', 'FreeDiams::CA_HCDPD::DIN', 4902);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trihexyphenidyl', 'tablet', 'N04AA01', false, 0, '00545074', 'FreeDiams::CA_HCDPD::DIN', 4903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Furosemide Inj 10mg/Ml', 'solution', 'C03CA01', false, 0, '00565040', 'FreeDiams::CA_HCDPD::DIN', 4910);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bss Plus', 'kit', 'V07AB', false, 0, '00568082', 'FreeDiams::CA_HCDPD::DIN', 4913);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Dipyridamole-Sc Tab 25mg', 'tablet', 'B01AC07', false, 0, '00571237', 'FreeDiams::CA_HCDPD::DIN', 4915);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Dipyridamole-Sc Tab 50mg', 'tablet', 'B01AC07', false, 0, '00571245', 'FreeDiams::CA_HCDPD::DIN', 4916);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyndet', 'liquid', 'V07AV', false, 0, '00561290', 'FreeDiams::CA_HCDPD::DIN', 4938);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cesamet', 'capsule', 'A04AD11', false, 0, '00548375', 'FreeDiams::CA_HCDPD::DIN', 4941);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zovirax', 'ointment', 'D06BB03', false, 0, '00569771', 'FreeDiams::CA_HCDPD::DIN', 4959);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Naproxen Tab 250mg', 'tablet', 'M01AE02', false, 0, '00522651', 'FreeDiams::CA_HCDPD::DIN', 4980);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Naproxen Tab 125mg', 'tablet', 'M01AE02', false, 0, '00522678', 'FreeDiams::CA_HCDPD::DIN', 4981);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Gesic Tab 325mg', 'tablet', 'N02BE01', false, 0, '00389218', 'FreeDiams::CA_HCDPD::DIN', 5035);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Naproxen', 'tablet', 'M01AE02', false, 0, '00565350', 'FreeDiams::CA_HCDPD::DIN', 5036);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benzalkonium Chloride Antisept Towel', 'pad', 'D08AJ01', false, 0, '00555983', 'FreeDiams::CA_HCDPD::DIN', 5046);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Colchicine Tab 0.6mg', 'tablet', 'M04AC01', false, 0, '00572349', 'FreeDiams::CA_HCDPD::DIN', 5069);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Lexin 250 Oral Susp 250mg/5ml', 'powder for solution', 'J01DB01', false, 0, '00342092', 'FreeDiams::CA_HCDPD::DIN', 5072);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Lexin 125 Oral Susp 125mg/5ml', 'powder for solution', 'J01DB01', false, 0, '00342106', 'FreeDiams::CA_HCDPD::DIN', 5073);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Theophylline Elixir', 'elixir', 'R03DA04', false, 0, '00575151', 'FreeDiams::CA_HCDPD::DIN', 5078);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quato', 'liquid', 'V07AV', false, 0, '00514276', 'FreeDiams::CA_HCDPD::DIN', 5088);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Promethazine Hydrochloride Injection Usp', 'liquid', 'R06AD02', false, 0, '00567434', 'FreeDiams::CA_HCDPD::DIN', 5089);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lopresor Sr 200 Mg', 'tablet (extended-release)', 'C07AB02', false, 0, '00534560', 'FreeDiams::CA_HCDPD::DIN', 5091);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ortho 1/35 Tablets (21 Day)', 'tablet', 'G03AA05', false, 0, '00372846', 'FreeDiams::CA_HCDPD::DIN', 5103);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ortho 0.5/35 Tablets (21 Day)', 'tablet', 'G03AA05', false, 0, '00317047', 'FreeDiams::CA_HCDPD::DIN', 5104);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ortho 1/35 Tablets (28 Day)', 'tablet', 'G03AA05', false, 0, '00372838', 'FreeDiams::CA_HCDPD::DIN', 5105);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ortho 0.5/35 Tablets (28 Day)', 'tablet', 'G03AA05', false, 0, '00340731', 'FreeDiams::CA_HCDPD::DIN', 5106);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbamazepine 200 Tab 200mg', 'tablet', 'N03AF01', false, 0, '00578460', 'FreeDiams::CA_HCDPD::DIN', 5107);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flurazepam 15', 'capsule', 'N05CD01', false, 0, '00578479', 'FreeDiams::CA_HCDPD::DIN', 5108);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flurazepam 30', 'capsule', 'N05CD01', false, 0, '00578487', 'FreeDiams::CA_HCDPD::DIN', 5109);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Total Germicidal Cleaner And Polish 1%', 'liquid', 'V07AV', false, 0, '00574988', 'FreeDiams::CA_HCDPD::DIN', 5120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tears Plus 1.4%', 'solution', 'S01XA20', false, 0, '00579408', 'FreeDiams::CA_HCDPD::DIN', 5121);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accutane Roche', 'capsule', 'D10BA01', false, 0, '00582344', 'FreeDiams::CA_HCDPD::DIN', 5128);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accutane Roche', 'capsule', 'D10BA01', false, 0, '00582352', 'FreeDiams::CA_HCDPD::DIN', 5129);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Consept Plus', 'liquid', 'V07AV', false, 0, '00590452', 'FreeDiams::CA_HCDPD::DIN', 5132);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cimetine Tab 200mg', 'tablet', 'A02BA01', false, 0, '00582409', 'FreeDiams::CA_HCDPD::DIN', 5151);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cimetine Tab 300mg', 'tablet', 'A02BA01', false, 0, '00582417', 'FreeDiams::CA_HCDPD::DIN', 5152);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Viskazide 10/25tab', 'tablet', 'C07CA03', false, 0, '00568627', 'FreeDiams::CA_HCDPD::DIN', 5156);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Viskazide 10/50tab', 'tablet', 'C07CA03', false, 0, '00568635', 'FreeDiams::CA_HCDPD::DIN', 5157);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stieva-A Cream', 'cream', 'D10AD01', false, 0, '00578576', 'FreeDiams::CA_HCDPD::DIN', 5168);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naproxen 250 Tab 250mg', 'tablet', 'M01AE02', false, 0, '00590762', 'FreeDiams::CA_HCDPD::DIN', 5175);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Sorbide Tab 10mg', 'tablet', 'C01DA08', false, 0, '00458686', 'FreeDiams::CA_HCDPD::DIN', 5179);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Sorbide Tab 30mg', 'tablet', 'C01DA08', false, 0, '00458694', 'FreeDiams::CA_HCDPD::DIN', 5180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Lexin Tab 250mg', 'tablet', 'J01DB01', false, 0, '00583413', 'FreeDiams::CA_HCDPD::DIN', 5181);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Lexin Tab 500mg', 'tablet', 'J01DB01', false, 0, '00583421', 'FreeDiams::CA_HCDPD::DIN', 5182);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Naproxen', 'tablet', 'M01AE02', false, 0, '00589861', 'FreeDiams::CA_HCDPD::DIN', 5183);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Gesic Forte Tab 500mg', 'tablet', 'N02BE01', false, 0, '00482323', 'FreeDiams::CA_HCDPD::DIN', 5184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Nytol Tab 50mg', 'tablet', 'R06AA02', false, 0, '00583332', 'FreeDiams::CA_HCDPD::DIN', 5187);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Cimetidine Tab 200mg', 'tablet', 'A02BA01', false, 0, '00584215', 'FreeDiams::CA_HCDPD::DIN', 5195);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Cimetidine Tab 300mg', 'tablet', 'A02BA01', false, 0, '00487872', 'FreeDiams::CA_HCDPD::DIN', 5196);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Haloperidol Liq 2mg/Ml', 'liquid', 'N05AD01', false, 0, '00587702', 'FreeDiams::CA_HCDPD::DIN', 5197);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva Oxazepam', 'tablet', 'N05BA04', false, 0, '00568406', 'FreeDiams::CA_HCDPD::DIN', 5213);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva Oxazepam', 'tablet', 'N05BA04', false, 0, '00568414', 'FreeDiams::CA_HCDPD::DIN', 5214);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gaseous Nitrogen 99.0%', 'gas', 'V03AN04', false, 0, '00591645', 'FreeDiams::CA_HCDPD::DIN', 5221);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Naproxen Tab 500mg', 'tablet', 'M01AE02', false, 0, '00592277', 'FreeDiams::CA_HCDPD::DIN', 5222);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ptm Disinfectant Cream Cleanser', 'liquid', 'V07AV', false, 0, '00581372', 'FreeDiams::CA_HCDPD::DIN', 5240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol Regular Strength Tab 325mg', 'tablet', 'N02BE01', false, 0, '00559393', 'FreeDiams::CA_HCDPD::DIN', 5254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol Extra Strength Tab 500mg', 'tablet', 'N02BE01', false, 0, '00559407', 'FreeDiams::CA_HCDPD::DIN', 5255);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amsa Pd Inj 50mg/Ml', 'liquid', 'L01XX01', false, 0, '00582212', 'FreeDiams::CA_HCDPD::DIN', 5262);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stieva-A Solution', 'solution', 'D10AD01', false, 0, '00578568', 'FreeDiams::CA_HCDPD::DIN', 5278);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Uremol Hc', 'lotion', 'D07XA01', false, 0, '00560022', 'FreeDiams::CA_HCDPD::DIN', 5280);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diprosalic', 'ointment', 'D07XC01', false, 0, '00578436', 'FreeDiams::CA_HCDPD::DIN', 5287);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sanitrol 10%', 'liquid', 'V07AV', false, 0, '00599697', 'FreeDiams::CA_HCDPD::DIN', 5289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tetracycline', 'capsule', 'J01AA07', false, 0, '00580929', 'FreeDiams::CA_HCDPD::DIN', 5293);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pediazole', 'powder for suspension', 'J01RA02', false, 0, '00583405', 'FreeDiams::CA_HCDPD::DIN', 5294);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ees 600 Tablets 600mg', 'tablet', 'J01FA01', false, 0, '00583782', 'FreeDiams::CA_HCDPD::DIN', 5296);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Propranolol Tablets 10mg', 'tablet', 'C07AA05', false, 0, '00582255', 'FreeDiams::CA_HCDPD::DIN', 5307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Propranolol Tablets 40mg', 'tablet', 'C07AA05', false, 0, '00582263', 'FreeDiams::CA_HCDPD::DIN', 5308);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Propranolol Tablets 80mg', 'tablet', 'C07AA05', false, 0, '00582271', 'FreeDiams::CA_HCDPD::DIN', 5309);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Propranolol Tablets 120mg', 'tablet', 'C07AA05', false, 0, '00582298', 'FreeDiams::CA_HCDPD::DIN', 5310);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Conjugated Estrogens C.S.D.', 'tablet', 'G03CA57', false, 0, '00587281', 'FreeDiams::CA_HCDPD::DIN', 5311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Conjugated Estrogens C.S.D.', 'tablet', 'G03CA57', false, 0, '00587303', 'FreeDiams::CA_HCDPD::DIN', 5312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Canthacur-Ps', 'liquid', 'D11AF', false, 0, '00589500', 'FreeDiams::CA_HCDPD::DIN', 5314);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Garasone Ophthalmic Ointment', 'ointment', 'S01CA05', false, 0, '00586706', 'FreeDiams::CA_HCDPD::DIN', 5315);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aldactazide 50', 'tablet', 'C03EA01', false, 0, '00594377', 'FreeDiams::CA_HCDPD::DIN', 5316);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humulin R Inj', 'liquid', 'A10AB01', false, 0, '00586714', 'FreeDiams::CA_HCDPD::DIN', 5325);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humulin N Inj 100unit/Ml', 'suspension', 'A10AC01', false, 0, '00587737', 'FreeDiams::CA_HCDPD::DIN', 5326);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('0.4% Lidocaine Hydrochloride And 5% Dextrose Injection Usp', 'solution', 'C01BB01', false, 0, '00478288', 'FreeDiams::CA_HCDPD::DIN', 5339);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidocaine 0.2% In 5% Dextrose Inj', 'solution', 'C01BB01', false, 0, '00478296', 'FreeDiams::CA_HCDPD::DIN', 5340);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Extra Strength Tab 500mg', 'tablet', 'N02BE01', false, 0, '00589233', 'FreeDiams::CA_HCDPD::DIN', 5345);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minipress', 'tablet', 'C02CA01', false, 0, '00560979', 'FreeDiams::CA_HCDPD::DIN', 5357);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minipress', 'tablet', 'C02CA01', false, 0, '00560952', 'FreeDiams::CA_HCDPD::DIN', 5358);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minipress', 'tablet', 'C02CA01', false, 0, '00560960', 'FreeDiams::CA_HCDPD::DIN', 5359);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cimetine Tab 400mg', 'tablet', 'A02BA01', false, 0, '00603678', 'FreeDiams::CA_HCDPD::DIN', 5361);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cimetine Tab 600mg', 'tablet', 'A02BA01', false, 0, '00603686', 'FreeDiams::CA_HCDPD::DIN', 5362);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dormex Extra Fort', 'capsule', 'R06AA02', false, 0, '00509345', 'FreeDiams::CA_HCDPD::DIN', 5363);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Nylidrin Tab 6mg', 'tablet', 'C04AA02', false, 0, '00590975', 'FreeDiams::CA_HCDPD::DIN', 5367);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Histantil Tab 25mg', 'tablet', 'R06AD02', false, 0, '00575178', 'FreeDiams::CA_HCDPD::DIN', 5368);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Histantil Tab 50mg', 'tablet', 'R06AD02', false, 0, '00575186', 'FreeDiams::CA_HCDPD::DIN', 5369);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ac And C Tab 1/8gr', 'tablet', 'N02BA51', false, 0, '00589470', 'FreeDiams::CA_HCDPD::DIN', 5371);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen W Codeine Tab', 'tablet', 'N02BE51', false, 0, '00589489', 'FreeDiams::CA_HCDPD::DIN', 5372);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rocco', 'solution', 'V07AV', false, 0, '00601977', 'FreeDiams::CA_HCDPD::DIN', 5377);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tobramycin For Injection, Usp', 'powder for solution', 'J01GB01', false, 0, '00533688', 'FreeDiams::CA_HCDPD::DIN', 5402);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Emo Cort Lotion 2.5%', 'lotion', 'D07AA02', false, 0, '00595802', 'FreeDiams::CA_HCDPD::DIN', 5413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diphenhydramine Hydrochloride Injection Usp', 'liquid', 'R06AA02', false, 0, '00596612', 'FreeDiams::CA_HCDPD::DIN', 5430);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pulmorphan Pediatrique', 'syrup', 'R05DA20', false, 0, '00590282', 'FreeDiams::CA_HCDPD::DIN', 5431);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Ibuprofen Tab 400mg', 'tablet', 'M01AE01', false, 0, '00506052', 'FreeDiams::CA_HCDPD::DIN', 5432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Ibuprofen Tab 300mg', 'tablet', 'M01AE01', false, 0, '00441651', 'FreeDiams::CA_HCDPD::DIN', 5433);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Cimetidine Tab 400mg', 'tablet', 'A02BA01', false, 0, '00600059', 'FreeDiams::CA_HCDPD::DIN', 5434);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Cimetidine Tab 600mg', 'tablet', 'A02BA01', false, 0, '00600067', 'FreeDiams::CA_HCDPD::DIN', 5435);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tiamol Cream 0.05%', 'cream', 'D07AC08', false, 0, '00598933', 'FreeDiams::CA_HCDPD::DIN', 5439);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nerisone Oily Cream', 'cream', 'D07AC06', false, 0, '00587818', 'FreeDiams::CA_HCDPD::DIN', 5442);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nerisone Cream', 'cream', 'D07AC06', false, 0, '00587826', 'FreeDiams::CA_HCDPD::DIN', 5443);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nerisone Ointment', 'ointment', 'D07AC06', false, 0, '00587834', 'FreeDiams::CA_HCDPD::DIN', 5444);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stieva-A Gel', 'gel', 'D10AD01', false, 0, '00587966', 'FreeDiams::CA_HCDPD::DIN', 5471);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Emo Cort Cream 2.5%', 'cream', 'D07AA02', false, 0, '00595799', 'FreeDiams::CA_HCDPD::DIN', 5472);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dalmacol', 'liquid', 'R05DA20', false, 0, '00507407', 'FreeDiams::CA_HCDPD::DIN', 5475);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen 500 Mg Tablets Usp Extra Strength', 'tablet', 'N02BE01', false, 0, '00549703', 'FreeDiams::CA_HCDPD::DIN', 5476);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antiseptic Hand Soap', 'liquid', 'D08AE54', false, 0, '00564311', 'FreeDiams::CA_HCDPD::DIN', 5480);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ortho 7/7/7 Tablets (21 Day)', 'tablet', 'G03AB04', false, 0, '00602957', 'FreeDiams::CA_HCDPD::DIN', 5482);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ortho 7/7/7 Tablets (28 Day)', 'tablet', 'G03AB04', false, 0, '00602965', 'FreeDiams::CA_HCDPD::DIN', 5483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sirop Cocillana Codeine', 'syrup', 'R05FA02', false, 0, '00593168', 'FreeDiams::CA_HCDPD::DIN', 5504);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Naproxen Tab 375mg', 'tablet', 'M01AE02', false, 0, '00600806', 'FreeDiams::CA_HCDPD::DIN', 5508);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diclectin', 'tablet (delayed-release)', 'R06AA59', false, 0, '00609129', 'FreeDiams::CA_HCDPD::DIN', 5509);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coly-Mycin M Parenteral', 'powder for solution', 'J01XB01', false, 0, '00476420', 'FreeDiams::CA_HCDPD::DIN', 5524);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tpn Electrolytes', 'solution', 'B05XA30', false, 0, '00590215', 'FreeDiams::CA_HCDPD::DIN', 5535);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Preattached Lta Kit', 'solution', 'N01BB02', false, 0, '00295531', 'FreeDiams::CA_HCDPD::DIN', 5536);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Histatrol', 'solution', 'V04CL', false, 0, '00609692', 'FreeDiams::CA_HCDPD::DIN', 5537);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Histatrol', 'solution', 'V04CL', false, 0, '00609706', 'FreeDiams::CA_HCDPD::DIN', 5538);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quat 774', 'liquid', 'V07AV', false, 0, '00613436', 'FreeDiams::CA_HCDPD::DIN', 5544);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Emergency Oxygen Supply 99.5%', 'gas', 'V03AN01', false, 0, '00575046', 'FreeDiams::CA_HCDPD::DIN', 5545);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hexabrix 320', 'solution', 'V08AB03', false, 0, '00603740', 'FreeDiams::CA_HCDPD::DIN', 5554);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Herbal Multi-Tar Plus Shampoo', 'shampoo', 'D05AA', false, 0, '00379727', 'FreeDiams::CA_HCDPD::DIN', 5557);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diprosalic', 'lotion', 'D07XC01', false, 0, '00578428', 'FreeDiams::CA_HCDPD::DIN', 5561);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva Oxazepam', 'tablet', 'N05BA04', false, 0, '00568392', 'FreeDiams::CA_HCDPD::DIN', 5563);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydrophil Ont', 'ointment', 'D02AE51', false, 0, '00566810', 'FreeDiams::CA_HCDPD::DIN', 5569);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Tablets 325 Mg', 'tablet', 'N02BE01', false, 0, '00605751', 'FreeDiams::CA_HCDPD::DIN', 5570);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Acetaminophen Tablets 500 Mg', 'tablet', 'N02BE01', false, 0, '00605778', 'FreeDiams::CA_HCDPD::DIN', 5571);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Travel Tabs 50 Mg', 'tablet', 'R06AA02', false, 0, '00605786', 'FreeDiams::CA_HCDPD::DIN', 5572);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cortifoam', 'aerosol', 'A07EA02', false, 0, '00579335', 'FreeDiams::CA_HCDPD::DIN', 5575);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dynakil Plus Liquid Germicidal Deodorizing Detergent', 'liquid', 'V07AV', false, 0, '00608025', 'FreeDiams::CA_HCDPD::DIN', 5578);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germicidal Multi-Purpose Cleaner 9%', 'liquid', 'V07AV', false, 0, '00611441', 'FreeDiams::CA_HCDPD::DIN', 5579);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Tab 325mg', 'tablet', 'N02BE01', false, 0, '00589241', 'FreeDiams::CA_HCDPD::DIN', 5584);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amfo', 'liquid', 'V07AV', false, 0, '00615803', 'FreeDiams::CA_HCDPD::DIN', 5590);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Ampi Capsules 250mg', 'capsule', 'J01CA01', false, 0, '00603279', 'FreeDiams::CA_HCDPD::DIN', 5595);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Ampi Capsules 500mg', 'capsule', 'J01CA01', false, 0, '00603295', 'FreeDiams::CA_HCDPD::DIN', 5596);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eryc Delayed-Release Capsules', 'capsule (enteric-coated)', 'J01FA01', false, 0, '00607142', 'FreeDiams::CA_HCDPD::DIN', 5599);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Rythro Ethylsuccinate Pws', 'powder for solution', 'J01FA01', false, 0, '00605859', 'FreeDiams::CA_HCDPD::DIN', 5603);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multi 1000', 'solution', 'A11BA', false, 0, '00586315', 'FreeDiams::CA_HCDPD::DIN', 5613);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Magnesium Sulfate Injection 50% Usp', 'liquid', 'B05XA05', false, 0, '00602264', 'FreeDiams::CA_HCDPD::DIN', 5614);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Restoril', 'capsule', 'N05CD07', false, 0, '00604453', 'FreeDiams::CA_HCDPD::DIN', 5616);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Restoril', 'capsule', 'N05CD07', false, 0, '00604461', 'FreeDiams::CA_HCDPD::DIN', 5618);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterex Crm Plus', 'cream', 'D07XA01', false, 0, '00449768', 'FreeDiams::CA_HCDPD::DIN', 5634);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterex Lot Plus', 'lotion', 'D07XA01', false, 0, '00456403', 'FreeDiams::CA_HCDPD::DIN', 5635);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fucidin Cream 2%', 'cream', 'D06AX01', false, 0, '00586668', 'FreeDiams::CA_HCDPD::DIN', 5637);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fucidin Ointment 2%', 'ointment', 'D06AX01', false, 0, '00586676', 'FreeDiams::CA_HCDPD::DIN', 5638);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mustargen', 'powder for solution', 'L01AA05', false, 0, '00016063', 'FreeDiams::CA_HCDPD::DIN', 5644);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Spironolactone', 'tablet', 'C03DA01', false, 0, '00613215', 'FreeDiams::CA_HCDPD::DIN', 5646);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Spironolactone', 'tablet', 'C03DA01', false, 0, '00613223', 'FreeDiams::CA_HCDPD::DIN', 5647);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anthraforte 2 Ointment 2%', 'ointment', 'D05AC01', false, 0, '00566748', 'FreeDiams::CA_HCDPD::DIN', 5667);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anthraforte 1 Ointment 1%', 'ointment', 'D05AC01', false, 0, '00566756', 'FreeDiams::CA_HCDPD::DIN', 5668);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Triazide Tab', 'tablet', 'C03EA01', false, 0, '00441775', 'FreeDiams::CA_HCDPD::DIN', 5672);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Cloxi Cap 500mg', 'capsule', 'J01CF02', false, 0, '00618284', 'FreeDiams::CA_HCDPD::DIN', 5673);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Cloxi Cap 250mg', 'capsule', 'J01CF02', false, 0, '00618292', 'FreeDiams::CA_HCDPD::DIN', 5674);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epival Ect 125mg', 'tablet (enteric-coated)', 'N03AG01', false, 0, '00596418', 'FreeDiams::CA_HCDPD::DIN', 5676);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epival Ect 250mg', 'tablet (enteric-coated)', 'N03AG01', false, 0, '00596426', 'FreeDiams::CA_HCDPD::DIN', 5677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epival Ect 500mg', 'tablet (enteric-coated)', 'N03AG01', false, 0, '00596434', 'FreeDiams::CA_HCDPD::DIN', 5678);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen 100%', 'gas', 'V03AN01', false, 0, '00572810', 'FreeDiams::CA_HCDPD::DIN', 5682);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitrogen 100%', 'gas', 'V03AN04', false, 0, '00572829', 'FreeDiams::CA_HCDPD::DIN', 5683);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medical Air 100%', 'gas', 'V03AN05', false, 0, '00572837', 'FreeDiams::CA_HCDPD::DIN', 5684);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitrous Oxide 100%', 'gas', 'N01AX13', false, 0, '00572845', 'FreeDiams::CA_HCDPD::DIN', 5685);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen Carbon Dioxide Mixture', 'gas', 'V03AN', false, 0, '00572853', 'FreeDiams::CA_HCDPD::DIN', 5686);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbon Dioxide 100%', 'gas', 'V03AN02', false, 0, '00572861', 'FreeDiams::CA_HCDPD::DIN', 5687);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Helium 100%', 'gas', 'V03AN03', false, 0, '00572888', 'FreeDiams::CA_HCDPD::DIN', 5688);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Helium Oxygen Mixture', 'gas', 'V03AN', false, 0, '00572896', 'FreeDiams::CA_HCDPD::DIN', 5689);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flexo Qb 470', 'liquid', 'V07AV', false, 0, '00578940', 'FreeDiams::CA_HCDPD::DIN', 5699);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminophylline Inj 50mg/Ml', 'solution', 'R03DA05', false, 0, '00582654', 'FreeDiams::CA_HCDPD::DIN', 5704);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminophylline Inj 25mg/Ml', 'solution', 'R03DA05', false, 0, '00582662', 'FreeDiams::CA_HCDPD::DIN', 5705);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tobrex Ophthalmic Ont 3mg/Gm', 'ointment', 'S01AA12', false, 0, '00614254', 'FreeDiams::CA_HCDPD::DIN', 5707);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('4 Trace Elements Injection, Usp', 'solution', 'B05XA31', false, 0, '00569046', 'FreeDiams::CA_HCDPD::DIN', 5708);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Levazine 3/15 Tab', 'tablet', 'N06CA01', false, 0, '00577774', 'FreeDiams::CA_HCDPD::DIN', 5717);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Isoniazid 100mg/Tab', 'tablet', 'J04AC01', false, 0, '00577790', 'FreeDiams::CA_HCDPD::DIN', 5718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Isoniazid 300mg/Tab', 'tablet', 'J04AC01', false, 0, '00577804', 'FreeDiams::CA_HCDPD::DIN', 5719);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Isoniazid Syrup 50mg/5ml', 'syrup', 'J04AC01', false, 0, '00577812', 'FreeDiams::CA_HCDPD::DIN', 5720);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Promethazine Syr 10mg/5ml', 'syrup', 'R06AD02', false, 0, '00583979', 'FreeDiams::CA_HCDPD::DIN', 5721);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Metronidazole 250mg/Tab', 'tablet', 'J01XD01', false, 0, '00584339', 'FreeDiams::CA_HCDPD::DIN', 5722);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Benztropine 2mg/Tab', 'tablet', 'N04AC01', false, 0, '00587265', 'FreeDiams::CA_HCDPD::DIN', 5724);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Procyclidine Elx 2.5mg/5ml', 'elixir', 'N04AA04', false, 0, '00587362', 'FreeDiams::CA_HCDPD::DIN', 5725);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Levazine 2/25 Tab', 'tablet', 'N06CA01', false, 0, '00590495', 'FreeDiams::CA_HCDPD::DIN', 5726);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Levazine 4/25 Tab', 'tablet', 'N06CA01', false, 0, '00590509', 'FreeDiams::CA_HCDPD::DIN', 5727);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Sulfasalazine 500mg/Tab Usp', 'tablet', 'A07EC01', false, 0, '00598461', 'FreeDiams::CA_HCDPD::DIN', 5728);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trifluoperazine', 'tablet', 'N05AB06', false, 0, '00595942', 'FreeDiams::CA_HCDPD::DIN', 5732);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Microban Hospital Spray', 'spray', 'V07AV', false, 0, '00614971', 'FreeDiams::CA_HCDPD::DIN', 5740);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lopid Cap 300mg', 'capsule', 'C10AB04', false, 0, '00599026', 'FreeDiams::CA_HCDPD::DIN', 5759);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Podofilm Liq 250mg/Ml', 'liquid', 'D06BB04', false, 0, '00598208', 'FreeDiams::CA_HCDPD::DIN', 5764);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Oxycodan', 'tablet', 'N02BA51', false, 0, '00608157', 'FreeDiams::CA_HCDPD::DIN', 5777);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Oxycocet', 'tablet', 'N02BE51', false, 0, '00608165', 'FreeDiams::CA_HCDPD::DIN', 5778);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Tecnal', 'tablet', 'N02BA71', false, 0, '00608211', 'FreeDiams::CA_HCDPD::DIN', 5779);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Emtec-30', 'tablet', 'N02AA59', false, 0, '00608882', 'FreeDiams::CA_HCDPD::DIN', 5780);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandimmune Iv 50mg/Ml', 'liquid', 'L04AD01', false, 0, '00593257', 'FreeDiams::CA_HCDPD::DIN', 5790);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lansoyl Gel 78%', 'gel', 'A06AA01', false, 0, '00608734', 'FreeDiams::CA_HCDPD::DIN', 5792);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rince Bouche Antiseptique', 'mouthwash/gargle', 'R02AA06', false, 0, '00609900', 'FreeDiams::CA_HCDPD::DIN', 5812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nesacaine Ce 2% Inj 20mg/Ml', 'solution', 'N01BA04', false, 0, '00613304', 'FreeDiams::CA_HCDPD::DIN', 5813);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Metoprolol Tab 50mg', 'tablet', 'C07AB02', false, 0, '00618632', 'FreeDiams::CA_HCDPD::DIN', 5818);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Metoprolol Tab 100mg', 'tablet', 'C07AB02', false, 0, '00618640', 'FreeDiams::CA_HCDPD::DIN', 5819);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Methazide 15', 'tablet', 'C02LB01', false, 0, '00441708', 'FreeDiams::CA_HCDPD::DIN', 5820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Methazide 25', 'tablet', 'C02LB01', false, 0, '00441716', 'FreeDiams::CA_HCDPD::DIN', 5821);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Amoxi Cap 250mg', 'capsule', 'J01CA04', false, 0, '00628115', 'FreeDiams::CA_HCDPD::DIN', 5822);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Amoxi Cap 500mg', 'capsule', 'J01CA04', false, 0, '00628123', 'FreeDiams::CA_HCDPD::DIN', 5823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Amoxi Pwr For Susp 125mg/5ml', 'powder for suspension', 'J01CA04', false, 0, '00628131', 'FreeDiams::CA_HCDPD::DIN', 5824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Amoxi Pwr For Susp 250mg/5ml', 'powder for suspension', 'J01CA04', false, 0, '00628158', 'FreeDiams::CA_HCDPD::DIN', 5825);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Prednisone Tab 1mg Usp', 'tablet', 'H02AB07', false, 0, '00598194', 'FreeDiams::CA_HCDPD::DIN', 5826);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Ampi Liq 125mg/5ml', 'liquid', 'J01CA01', false, 0, '00603260', 'FreeDiams::CA_HCDPD::DIN', 5827);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Ampi Liq 250mg/5ml', 'liquid', 'J01CA01', false, 0, '00603287', 'FreeDiams::CA_HCDPD::DIN', 5828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S.- 10', 'suppository', 'N02AA01', false, 0, '00624268', 'FreeDiams::CA_HCDPD::DIN', 5846);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S.- 20', 'suppository', 'N02AA01', false, 0, '00624276', 'FreeDiams::CA_HCDPD::DIN', 5847);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lemon Tree Liq 4.5%', 'liquid', 'V07AV', false, 0, '00628891', 'FreeDiams::CA_HCDPD::DIN', 5849);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mega C Acid Inj 500mg/Ml', 'liquid', 'A11GA01', false, 0, '00623849', 'FreeDiams::CA_HCDPD::DIN', 5851);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydroxy Cobal Inj 1000mcg/Ml', 'liquid', 'B03BA03', false, 0, '00623857', 'FreeDiams::CA_HCDPD::DIN', 5852);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Spironolactone/Hctz', 'tablet', 'C03EA01', false, 0, '00613231', 'FreeDiams::CA_HCDPD::DIN', 5858);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Peridol Tab 5mg', 'tablet', 'N05AD01', false, 0, '00363650', 'FreeDiams::CA_HCDPD::DIN', 5859);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Naproxen', 'tablet', 'M01AE02', false, 0, '00627097', 'FreeDiams::CA_HCDPD::DIN', 5860);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Dopazide 15 Tab', 'tablet', 'C02LB01', false, 0, '00584967', 'FreeDiams::CA_HCDPD::DIN', 5862);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bacitin Ont 500unit/Gm', 'ointment', 'D06AX05', false, 0, '00584908', 'FreeDiams::CA_HCDPD::DIN', 5863);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Sulfasalazine-E.C. Tab 500mg', 'tablet (enteric-coated)', 'A07EC01', false, 0, '00598488', 'FreeDiams::CA_HCDPD::DIN', 5864);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen 500 Mg Compound Tablets With Codeine', 'tablet', 'N02BE51', false, 0, '00617059', 'FreeDiams::CA_HCDPD::DIN', 5876);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Dimenhydrinate Tab 50mg', 'tablet', 'R06AA02', false, 0, '00586331', 'FreeDiams::CA_HCDPD::DIN', 5885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn 8.5%', 'solution', 'B05BA01', false, 0, '00613320', 'FreeDiams::CA_HCDPD::DIN', 5890);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn 8.5% Injection With Electrolytes', 'solution', 'B05BA10', false, 0, '00613339', 'FreeDiams::CA_HCDPD::DIN', 5891);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Dipyridamole-Sc Tab 75mg', 'tablet', 'B01AC07', false, 0, '00601845', 'FreeDiams::CA_HCDPD::DIN', 5893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Td Polio Adsorbed', 'suspension', 'J07CA01', false, 0, '00615358', 'FreeDiams::CA_HCDPD::DIN', 5907);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Ibuprofen Tab 600mg', 'tablet', 'M01AE01', false, 0, '00585114', 'FreeDiams::CA_HCDPD::DIN', 5917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Indomethacin Cap 25mg', 'capsule', 'M01AB01', false, 0, '00611158', 'FreeDiams::CA_HCDPD::DIN', 5918);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Indomethacin Cap 50mg', 'capsule', 'M01AB01', false, 0, '00611166', 'FreeDiams::CA_HCDPD::DIN', 5919);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dilaudid Hp', 'liquid', 'N02AA03', false, 0, '00622133', 'FreeDiams::CA_HCDPD::DIN', 5936);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dilaudid', 'liquid', 'N02AA03', false, 0, '00627100', 'FreeDiams::CA_HCDPD::DIN', 5937);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dilaudid', 'tablet', 'N02AA03', false, 0, '00125083', 'FreeDiams::CA_HCDPD::DIN', 5939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dilaudid', 'tablet', 'N02AA03', false, 0, '00125121', 'FreeDiams::CA_HCDPD::DIN', 5940);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Plegisol', 'solution', 'B05BB01', false, 0, '00625663', 'FreeDiams::CA_HCDPD::DIN', 5950);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ak Fluor Inj 10%', 'solution', 'V04CX', false, 0, '00622869', 'FreeDiams::CA_HCDPD::DIN', 5951);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vepesid', 'capsule', 'L01CB01', false, 0, '00616192', 'FreeDiams::CA_HCDPD::DIN', 5963);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epipen Jr', 'solution', 'C01CA24', false, 0, '00578657', 'FreeDiams::CA_HCDPD::DIN', 5970);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-600k Srt 600mg', 'tablet (extended-release)', 'A12BA01', false, 0, '00613274', 'FreeDiams::CA_HCDPD::DIN', 5975);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solution Saline Sterile Aux Phosphates', 'solution', 'V04CX', false, 0, '00616958', 'FreeDiams::CA_HCDPD::DIN', 5984);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vumon', 'liquid', 'L01CB02', false, 0, '00588989', 'FreeDiams::CA_HCDPD::DIN', 5995);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ak Pentolate Oph Soln 1%', 'liquid', 'S01FA04', false, 0, '00626627', 'FreeDiams::CA_HCDPD::DIN', 5997);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ak Pentolate Oph Soln 0.5%', 'liquid', 'S01FA04', false, 0, '00626635', 'FreeDiams::CA_HCDPD::DIN', 5998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euflex', 'tablet', 'L02BB01', false, 0, '00637726', 'FreeDiams::CA_HCDPD::DIN', 6035);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Protrin Df Tab', 'tablet', 'J01EE01', false, 0, '00512524', 'FreeDiams::CA_HCDPD::DIN', 6037);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro Chlorax', 'capsule', 'A03CA02', false, 0, '00636223', 'FreeDiams::CA_HCDPD::DIN', 6039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Indocid P.D.A.', 'powder for solution', 'C01EB03', false, 0, '00597805', 'FreeDiams::CA_HCDPD::DIN', 6040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tegretol Chewtabs 100mg', 'tablet', 'N03AF01', false, 0, '00369810', 'FreeDiams::CA_HCDPD::DIN', 6049);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pilopine Hs 4%', 'gel', 'S01EB01', false, 0, '00575240', 'FreeDiams::CA_HCDPD::DIN', 6053);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tropicacyl Oph Soln 1%', 'drops', 'S01FA06', false, 0, '00622885', 'FreeDiams::CA_HCDPD::DIN', 6054);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ak Sulf Liq 10%', 'liquid', 'S01AB04', false, 0, '00622966', 'FreeDiams::CA_HCDPD::DIN', 6055);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tropicacyl Oph Soln 0.5%', 'solution', 'S01FA06', false, 0, '00627704', 'FreeDiams::CA_HCDPD::DIN', 6056);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenyltrope  Oph Soln', 'solution', 'S01FA56', false, 0, '00629693', 'FreeDiams::CA_HCDPD::DIN', 6057);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ritalin-Sr Tab 20mg', 'tablet (extended-release)', 'N06BA04', false, 0, '00632775', 'FreeDiams::CA_HCDPD::DIN', 6067);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Procan Sr', 'tablet (extended-release)', 'C01BA02', false, 0, '00638676', 'FreeDiams::CA_HCDPD::DIN', 6086);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Procan Sr', 'tablet (extended-release)', 'C01BA02', false, 0, '00638684', 'FreeDiams::CA_HCDPD::DIN', 6087);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Procan Sr', 'tablet (extended-release)', 'C01BA02', false, 0, '00638692', 'FreeDiams::CA_HCDPD::DIN', 6088);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenobarb Elixir', 'elixir', 'N03AA02', false, 0, '00645575', 'FreeDiams::CA_HCDPD::DIN', 6095);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Clopate Cap 3.75mg', 'capsule', 'N05BA05', false, 0, '00628190', 'FreeDiams::CA_HCDPD::DIN', 6096);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Clopate Cap 7.5mg', 'capsule', 'N05BA05', false, 0, '00628204', 'FreeDiams::CA_HCDPD::DIN', 6097);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Clopate Cap 15mg', 'capsule', 'N05BA05', false, 0, '00628212', 'FreeDiams::CA_HCDPD::DIN', 6098);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ak Taine Liq 0.5%', 'liquid', 'S01HA04', false, 0, '00622974', 'FreeDiams::CA_HCDPD::DIN', 6105);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atasol Drops Usp 80mg/Ml', 'drops', 'N02BE01', false, 0, '00631353', 'FreeDiams::CA_HCDPD::DIN', 6112);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S.- 30', 'suppository', 'N02AA01', false, 0, '00636681', 'FreeDiams::CA_HCDPD::DIN', 6122);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Statex Suppositories 20mg', 'suppository', 'N02AA01', false, 0, '00596965', 'FreeDiams::CA_HCDPD::DIN', 6129);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pyrazinamide Tab Usp 500mg', 'tablet', 'J04AK01', false, 0, '00618810', 'FreeDiams::CA_HCDPD::DIN', 6130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Statex Drops 20mg/Ml', 'drops', 'N02AA01', false, 0, '00621935', 'FreeDiams::CA_HCDPD::DIN', 6131);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Statex     -Suppositories 10mg', 'suppository', 'N02AA01', false, 0, '00632201', 'FreeDiams::CA_HCDPD::DIN', 6132);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Statex Syrup 5mg/Ml', 'syrup', 'N02AA01', false, 0, '00591475', 'FreeDiams::CA_HCDPD::DIN', 6133);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Statex Syrup 1mg/Ml', 'syrup', 'N02AA01', false, 0, '00591467', 'FreeDiams::CA_HCDPD::DIN', 6134);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Lorazem Tab 1mg', 'tablet', 'N05BA06', false, 0, '00637742', 'FreeDiams::CA_HCDPD::DIN', 6135);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Lorazem Tab 2mg', 'tablet', 'N05BA06', false, 0, '00637750', 'FreeDiams::CA_HCDPD::DIN', 6136);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ibuprofen Tab 400mg', 'tablet', 'M01AE01', false, 0, '00636533', 'FreeDiams::CA_HCDPD::DIN', 6161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Dopazide-25 Tab', 'tablet', 'C02LB01', false, 0, '00584975', 'FreeDiams::CA_HCDPD::DIN', 6163);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zanosar Sterile Powder', 'powder for solution', 'L01AD04', false, 0, '00622141', 'FreeDiams::CA_HCDPD::DIN', 6166);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ansaid Tablets 50 Mg', 'tablet', 'M01AE09', false, 0, '00647942', 'FreeDiams::CA_HCDPD::DIN', 6167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elixir De Theophylline', 'elixir', 'R03DA04', false, 0, '00627410', 'FreeDiams::CA_HCDPD::DIN', 6170);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doloral 1', 'syrup', 'N02AA01', false, 0, '00614491', 'FreeDiams::CA_HCDPD::DIN', 6171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S. 20 Concentrate 20mg/Ml', 'syrup', 'N02AA01', false, 0, '00632481', 'FreeDiams::CA_HCDPD::DIN', 6182);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S. 10 Syrup 10mg/Ml', 'syrup', 'N02AA01', false, 0, '00632503', 'FreeDiams::CA_HCDPD::DIN', 6183);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Colchicine Tab 1mg', 'tablet', 'M04AC01', false, 0, '00621374', 'FreeDiams::CA_HCDPD::DIN', 6196);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quaternal 1.5%', 'liquid', 'V07AV', false, 0, '00626465', 'FreeDiams::CA_HCDPD::DIN', 6203);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stieva-A Gel', 'gel', 'D10AD01', false, 0, '00641863', 'FreeDiams::CA_HCDPD::DIN', 6204);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doak Oil 2%', 'liquid', 'D05AA', false, 0, '00579955', 'FreeDiams::CA_HCDPD::DIN', 6207);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('1 Stroke Environ', 'liquid', 'V07AV', false, 0, '00611433', 'FreeDiams::CA_HCDPD::DIN', 6212);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Chloride 40 Meq In 5% Dextrose And 0.45% Sodium Chloride', 'solution', 'B05BB02', false, 0, '00603244', 'FreeDiams::CA_HCDPD::DIN', 6228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Betagan 0.5% Ophthalmic Sol', 'liquid', 'S01ED03', false, 0, '00637661', 'FreeDiams::CA_HCDPD::DIN', 6230);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Center-Al', 'liquid', 'V01AA20', false, 0, '00648922', 'FreeDiams::CA_HCDPD::DIN', 6237);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lioresal D.S. Tab 20mg', 'tablet', 'M03BX01', false, 0, '00636576', 'FreeDiams::CA_HCDPD::DIN', 6244);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potaba Tab 0.5gm', 'tablet', 'V03AX', false, 0, '00550175', 'FreeDiams::CA_HCDPD::DIN', 6245);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potaba Cap 0.5gm', 'capsule', 'V03AX', false, 0, '00611271', 'FreeDiams::CA_HCDPD::DIN', 6246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Selax Cap 100mg', 'capsule', 'A06AA02', false, 0, '00514888', 'FreeDiams::CA_HCDPD::DIN', 6258);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextroject 25%', 'solution', 'B05BA03', false, 0, '00623563', 'FreeDiams::CA_HCDPD::DIN', 6260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Saliject 570mg/Ml', 'liquid', 'C05BB', false, 0, '00623571', 'FreeDiams::CA_HCDPD::DIN', 6261);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('B-12 1000 Inj 1000mcg/Ml', 'liquid', 'B03BA01', false, 0, '00626112', 'FreeDiams::CA_HCDPD::DIN', 6262);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Q6543 Nettoyeur Desinfectant', 'liquid', 'V07AV', false, 0, '00648884', 'FreeDiams::CA_HCDPD::DIN', 6263);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cimetidine Tab 600mg', 'tablet', 'A02BA01', false, 0, '00618705', 'FreeDiams::CA_HCDPD::DIN', 6265);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naproxen 500 Tab 500mg', 'tablet', 'M01AE02', false, 0, '00618721', 'FreeDiams::CA_HCDPD::DIN', 6266);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('F-1984', 'solution', 'V07AV', false, 0, '00644366', 'FreeDiams::CA_HCDPD::DIN', 6268);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proglycem', 'capsule', 'V03AH01', false, 0, '00503347', 'FreeDiams::CA_HCDPD::DIN', 6269);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ansaid Tablets 100 Mg', 'tablet', 'M01AE09', false, 0, '00600792', 'FreeDiams::CA_HCDPD::DIN', 6276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Chlorax Cap', 'capsule', 'A03CA02', false, 0, '00618454', 'FreeDiams::CA_HCDPD::DIN', 6283);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lorazepam Tab 0.5mg', 'tablet', 'N05BA06', false, 0, '00655740', 'FreeDiams::CA_HCDPD::DIN', 6295);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lorazepam Tab 1mg', 'tablet', 'N05BA06', false, 0, '00655759', 'FreeDiams::CA_HCDPD::DIN', 6296);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lorazepam Tab 2mg', 'tablet', 'N05BA06', false, 0, '00655767', 'FreeDiams::CA_HCDPD::DIN', 6297);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lopresor Sr 100mg', 'tablet (extended-release)', 'C07AB02', false, 0, '00658855', 'FreeDiams::CA_HCDPD::DIN', 6311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Charac-50', 'suspension', 'A07BA01', false, 0, '00637955', 'FreeDiams::CA_HCDPD::DIN', 6317);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Profen Tab 200mg', 'tablet', 'M01AE01', false, 0, '00629324', 'FreeDiams::CA_HCDPD::DIN', 6320);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Profen Tab 300mg', 'tablet', 'M01AE01', false, 0, '00629332', 'FreeDiams::CA_HCDPD::DIN', 6321);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Profen Tab 400mg', 'tablet', 'M01AE01', false, 0, '00629340', 'FreeDiams::CA_HCDPD::DIN', 6322);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Profen Tab 600mg', 'tablet', 'M01AE01', false, 0, '00629359', 'FreeDiams::CA_HCDPD::DIN', 6323);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Rythro Ethylsuccinate Pwr 400mg/5ml', 'powder', 'J01FA01', false, 0, '00652318', 'FreeDiams::CA_HCDPD::DIN', 6324);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buro Sol Antiseptic Powder', 'powder', 'D08AJ58', false, 0, '00579947', 'FreeDiams::CA_HCDPD::DIN', 6345);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Lenoltec No 3', 'tablet', 'N02AA59', false, 0, '00653276', 'FreeDiams::CA_HCDPD::DIN', 6346);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ak Fluor Inj 25%', 'liquid', 'V04CX', false, 0, '00622877', 'FreeDiams::CA_HCDPD::DIN', 6359);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balanced Salt Solution', 'solution', 'B05CB10', false, 0, '00622893', 'FreeDiams::CA_HCDPD::DIN', 6360);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ak Dilate Oph Soln 2.5%', 'drops', 'S01FB01', false, 0, '00622915', 'FreeDiams::CA_HCDPD::DIN', 6361);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ak Chlor Liq 0.5%', 'liquid', 'S01AA01', false, 0, '00622958', 'FreeDiams::CA_HCDPD::DIN', 6363);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ak Dex Oph Otic Soln 0.1%', 'solution', 'S03BA01', false, 0, '00627763', 'FreeDiams::CA_HCDPD::DIN', 6364);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ak Cide Oph Soln', 'solution', 'S01CA02', false, 0, '00630640', 'FreeDiams::CA_HCDPD::DIN', 6365);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bss Sterile Irrigating Solution', 'solution', 'V07AB', false, 0, '00512990', 'FreeDiams::CA_HCDPD::DIN', 6366);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Golytely Gi Lavage Solution', 'powder for solution', 'A06AD10', false, 0, '00652512', 'FreeDiams::CA_HCDPD::DIN', 6370);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Voltaren Sr Tab 100mg', 'tablet (extended-release)', 'M01AB05', false, 0, '00590827', 'FreeDiams::CA_HCDPD::DIN', 6379);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Triazide', 'tablet', 'C03EA01', false, 0, '00519367', 'FreeDiams::CA_HCDPD::DIN', 6390);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Serophene Tab 50mg', 'tablet', 'G03GB02', false, 0, '00640158', 'FreeDiams::CA_HCDPD::DIN', 6391);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Procyclidine Tab 5mg', 'tablet', 'N04AA04', false, 0, '00587354', 'FreeDiams::CA_HCDPD::DIN', 6392);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Charcodote Susp 200mg/Ml', 'suspension', 'A07BA01', false, 0, '00632333', 'FreeDiams::CA_HCDPD::DIN', 6393);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Procyclidine Tab 2.5mg Usp', 'tablet', 'N04AA04', false, 0, '00649392', 'FreeDiams::CA_HCDPD::DIN', 6394);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Chloride 40 Meq In 5% Dextrose', 'solution', 'B05BB02', false, 0, '00606820', 'FreeDiams::CA_HCDPD::DIN', 6400);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Winpred Tab 5mg', 'tablet', 'H02AB07', false, 0, '00271381', 'FreeDiams::CA_HCDPD::DIN', 6402);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Codeine', 'tablet', 'R05DA04', false, 0, '00593435', 'FreeDiams::CA_HCDPD::DIN', 6415);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Codeine', 'tablet', 'R05DA04', false, 0, '00593451', 'FreeDiams::CA_HCDPD::DIN', 6416);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Hemcort Hc', 'ointment', 'C05AA01', false, 0, '00607789', 'FreeDiams::CA_HCDPD::DIN', 6417);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Hemcort Hc', 'suppository', 'C05AA01', false, 0, '00607797', 'FreeDiams::CA_HCDPD::DIN', 6418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Tecnal C 1/2', 'capsule', 'N02AA79', false, 0, '00608181', 'FreeDiams::CA_HCDPD::DIN', 6419);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Pen Vk Tab 500000unit Usp', 'tablet', 'J01CE02', false, 0, '00642215', 'FreeDiams::CA_HCDPD::DIN', 6421);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Pen Vk Pws 200000unit/5ml Usp', 'powder for solution', 'J01CE02', false, 0, '00642223', 'FreeDiams::CA_HCDPD::DIN', 6422);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Pen Vk Pws 500000unit/5ml', 'powder for solution', 'J01CE02', false, 0, '00642231', 'FreeDiams::CA_HCDPD::DIN', 6423);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Cloxi For Oral Soln 125mg/5ml', 'powder for solution', 'J01CF02', false, 0, '00644633', 'FreeDiams::CA_HCDPD::DIN', 6424);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doak Oil Forte 10%', 'liquid', 'D05AA', false, 0, '00579971', 'FreeDiams::CA_HCDPD::DIN', 6435);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tersa-Tar Mild Shp 1%', 'shampoo', 'D05AA', false, 0, '00632295', 'FreeDiams::CA_HCDPD::DIN', 6436);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tersa Tar Shp 3%', 'shampoo', 'D05AA', false, 0, '00632309', 'FreeDiams::CA_HCDPD::DIN', 6437);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fectolime Liq 4.8%', 'liquid', 'V07AV', false, 0, '00664065', 'FreeDiams::CA_HCDPD::DIN', 6450);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Voltaren Sup 50mg', 'suppository', 'M01AB05', false, 0, '00632724', 'FreeDiams::CA_HCDPD::DIN', 6461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Voltaren Sup 100mg', 'suppository', 'M01AB05', false, 0, '00632732', 'FreeDiams::CA_HCDPD::DIN', 6462);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tegretol Chewtabs 200mg', 'tablet', 'N03AF01', false, 0, '00665088', 'FreeDiams::CA_HCDPD::DIN', 6463);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Airx 15 Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '00638919', 'FreeDiams::CA_HCDPD::DIN', 6464);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Airx 44 Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '00638927', 'FreeDiams::CA_HCDPD::DIN', 6465);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Airx 78 Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '00638935', 'FreeDiams::CA_HCDPD::DIN', 6466);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Airx 15 Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '00638773', 'FreeDiams::CA_HCDPD::DIN', 6469);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Selexid Tab 185mg', 'tablet', 'J01CA08', false, 0, '00657212', 'FreeDiams::CA_HCDPD::DIN', 6471);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Tecnal C1/4', 'capsule', 'N02BA71', false, 0, '00608203', 'FreeDiams::CA_HCDPD::DIN', 6479);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Tecnal', 'capsule', 'N02BA71', false, 0, '00608238', 'FreeDiams::CA_HCDPD::DIN', 6480);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro Amox-500 Cap 500mg', 'capsule', 'J01CA04', false, 0, '00644315', 'FreeDiams::CA_HCDPD::DIN', 6510);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Amox-250 Orl Sus 250mg/5ml', 'powder for solution', 'J01CA04', false, 0, '00644331', 'FreeDiams::CA_HCDPD::DIN', 6511);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoprolol-50 Tab 50mg', 'tablet', 'C07AB02', false, 0, '00648019', 'FreeDiams::CA_HCDPD::DIN', 6512);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoprolol-100 Tab 100mg', 'tablet', 'C07AB02', false, 0, '00648027', 'FreeDiams::CA_HCDPD::DIN', 6513);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Gesic-C8', 'tablet', 'N02BE51', false, 0, '00615528', 'FreeDiams::CA_HCDPD::DIN', 6516);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vit E 610 Xd 4%', 'liquid', 'V07AV', false, 0, '00679526', 'FreeDiams::CA_HCDPD::DIN', 6523);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naproxen-375 Tab 375mg', 'tablet', 'M01AE02', false, 0, '00655686', 'FreeDiams::CA_HCDPD::DIN', 6524);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diprolene', 'ointment', 'D07AC01', false, 0, '00629367', 'FreeDiams::CA_HCDPD::DIN', 6529);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quato 15 Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '00639109', 'FreeDiams::CA_HCDPD::DIN', 6535);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tersaseptic Liq 0.5%', 'kit', 'D08AE04', false, 0, '00632317', 'FreeDiams::CA_HCDPD::DIN', 6538);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Morphine', 'syrup', 'N02AA01', false, 0, '00607762', 'FreeDiams::CA_HCDPD::DIN', 6539);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Morphine', 'syrup', 'N02AA01', false, 0, '00607770', 'FreeDiams::CA_HCDPD::DIN', 6540);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isdn', 'tablet', 'C01DA08', false, 0, '00670944', 'FreeDiams::CA_HCDPD::DIN', 6550);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Indo 25 Cap 25mg', 'capsule', 'M01AB01', false, 0, '00646261', 'FreeDiams::CA_HCDPD::DIN', 6558);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Indo 50 Cap 50mg', 'capsule', 'M01AB01', false, 0, '00646288', 'FreeDiams::CA_HCDPD::DIN', 6559);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexamethasone Sodium Phosphate Inj Usp 4mg/Ml', 'solution', 'H02AB02', false, 0, '00664227', 'FreeDiams::CA_HCDPD::DIN', 6593);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Metoprolol', 'tablet', 'C07AB02', false, 0, '00648035', 'FreeDiams::CA_HCDPD::DIN', 6611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Metoprolol', 'tablet', 'C07AB02', false, 0, '00648043', 'FreeDiams::CA_HCDPD::DIN', 6612);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Colyte', 'powder for solution', 'A06AD65', false, 0, '00677442', 'FreeDiams::CA_HCDPD::DIN', 6616);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stieva-A Cream', 'cream', 'D10AD01', false, 0, '00657204', 'FreeDiams::CA_HCDPD::DIN', 6619);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ectosone Scalp Lotion 0.1%', 'lotion', 'D07AC01', false, 0, '00653217', 'FreeDiams::CA_HCDPD::DIN', 6620);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antimicrobial 0.3% Triclosan / Antimicrobien 0.3% Triclosan', 'lotion', 'D08AE04', false, 0, '00674915', 'FreeDiams::CA_HCDPD::DIN', 6621);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Lock Flush Solution Inj 10unit/Ml', 'solution', 'V07AC', false, 0, '00640468', 'FreeDiams::CA_HCDPD::DIN', 6627);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Lorazepam Tab 0.5mg', 'tablet', 'N05BA06', false, 0, '00655643', 'FreeDiams::CA_HCDPD::DIN', 6656);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Lorazepam Tab 1.0mg', 'tablet', 'N05BA06', false, 0, '00655651', 'FreeDiams::CA_HCDPD::DIN', 6657);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Lorazepam Tab 2mg', 'tablet', 'N05BA06', false, 0, '00655678', 'FreeDiams::CA_HCDPD::DIN', 6658);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Magnat-C', 'liquid', 'V07AV', false, 0, '00679615', 'FreeDiams::CA_HCDPD::DIN', 6666);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Magnat-T', 'liquid', 'V07AV', false, 0, '00679607', 'FreeDiams::CA_HCDPD::DIN', 6667);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antiseptic Lotion Soap', 'soap bar', 'D08AE55', false, 0, '00664529', 'FreeDiams::CA_HCDPD::DIN', 6675);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Propranolol Tab 20mg', 'tablet', 'C07AA05', false, 0, '00663719', 'FreeDiams::CA_HCDPD::DIN', 6685);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Erythro-Es', 'tablet', 'J01FA01', false, 0, '00637416', 'FreeDiams::CA_HCDPD::DIN', 6686);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Erythro-Base Tab 250mg', 'tablet', 'J01FA01', false, 0, '00682020', 'FreeDiams::CA_HCDPD::DIN', 6687);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Erythro-S', 'tablet', 'J01FA01', false, 0, '00688568', 'FreeDiams::CA_HCDPD::DIN', 6688);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Hp 25 - 25mg/Ml', 'solution', 'N02AA01', false, 0, '00676411', 'FreeDiams::CA_HCDPD::DIN', 6690);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Emo Cort Sol 2.5% Usp', 'solution', 'D07AA02', false, 0, '00641154', 'FreeDiams::CA_HCDPD::DIN', 6695);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buro-Sol Otic Solution', 'solution', 'S02AA30', false, 0, '00674222', 'FreeDiams::CA_HCDPD::DIN', 6696);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Piroxicam Cap 10mg', 'capsule', 'M01AC01', false, 0, '00642886', 'FreeDiams::CA_HCDPD::DIN', 6714);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Piroxicam Cap 20mg', 'capsule', 'M01AC01', false, 0, '00642894', 'FreeDiams::CA_HCDPD::DIN', 6715);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Persantine Inj 5mg/Ml', 'solution', 'B01AC07', false, 0, '00637734', 'FreeDiams::CA_HCDPD::DIN', 6720);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluoracaine Oph Soln', 'solution', 'S01JA51', false, 0, '00629707', 'FreeDiams::CA_HCDPD::DIN', 6721);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluorets Stp 1mg', 'strip', 'S01JA01', false, 0, '00687812', 'FreeDiams::CA_HCDPD::DIN', 6722);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neosporin Irrigating Solution', 'solution', 'B05CA10', false, 0, '00666157', 'FreeDiams::CA_HCDPD::DIN', 6727);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S. 10 Tablets 10mg', 'tablet', 'N02AA01', false, 0, '00690198', 'FreeDiams::CA_HCDPD::DIN', 6733);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S.-20 Tab 20mg', 'tablet', 'N02AA01', false, 0, '00690201', 'FreeDiams::CA_HCDPD::DIN', 6734);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S.-40 Tab 40mg', 'tablet', 'N02AA01', false, 0, '00690228', 'FreeDiams::CA_HCDPD::DIN', 6735);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S.-50 Concentrate Liq 50mg/Ml', 'syrup', 'N02AA01', false, 0, '00690236', 'FreeDiams::CA_HCDPD::DIN', 6736);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S.-60 Tab 60mg', 'tablet', 'N02AA01', false, 0, '00690244', 'FreeDiams::CA_HCDPD::DIN', 6737);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ibuprofen-600 Tab 600mg', 'tablet', 'M01AE01', false, 0, '00658804', 'FreeDiams::CA_HCDPD::DIN', 6749);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Flurazepam Cap 15mg', 'capsule', 'N05CD01', false, 0, '00667102', 'FreeDiams::CA_HCDPD::DIN', 6751);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Isoniazid Tab 50mg', 'tablet', 'J04AC01', false, 0, '00577782', 'FreeDiams::CA_HCDPD::DIN', 6752);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Statex Tablet 25mg', 'tablet', 'N02AA01', false, 0, '00594636', 'FreeDiams::CA_HCDPD::DIN', 6753);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Statex Tab 10mg', 'tablet', 'N02AA01', false, 0, '00594644', 'FreeDiams::CA_HCDPD::DIN', 6754);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Statex Tab 5mg', 'tablet', 'N02AA01', false, 0, '00594652', 'FreeDiams::CA_HCDPD::DIN', 6755);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Docusate-Calcium Cap 240mg Usp', 'capsule', 'A06AA02', false, 0, '00664553', 'FreeDiams::CA_HCDPD::DIN', 6756);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Statex Tablets 50mg', 'tablet', 'N02AA01', false, 0, '00675962', 'FreeDiams::CA_HCDPD::DIN', 6757);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Lenoltec No 1', 'tablet', 'N02BE51', false, 0, '00653233', 'FreeDiams::CA_HCDPD::DIN', 6763);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Lenoltec No 2', 'tablet', 'N02BE51', false, 0, '00653241', 'FreeDiams::CA_HCDPD::DIN', 6764);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kwat', 'liquid', 'V07AV', false, 0, '00696986', 'FreeDiams::CA_HCDPD::DIN', 7322);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dopamine Hydrochloride And 5% Dextrose Injection Usp', 'solution', 'C01CA04', false, 0, '00619698', 'FreeDiams::CA_HCDPD::DIN', 6768);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dopamine Hydrochloride And 5% Dextrose Injection Usp', 'solution', 'C01CA04', false, 0, '00619701', 'FreeDiams::CA_HCDPD::DIN', 6769);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentothal Inj 500mg/Syr', 'powder for solution', 'N01AF03', false, 0, '00038393', 'FreeDiams::CA_HCDPD::DIN', 6770);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentothal Ready To Mix Syringe 250mg', 'powder for solution', 'N01AF03', false, 0, '00372536', 'FreeDiams::CA_HCDPD::DIN', 6771);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ak Con Oph Soln 0.1%', 'solution', 'S01GA01', false, 0, '00626570', 'FreeDiams::CA_HCDPD::DIN', 6772);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ak Vernacon Oph Soln', 'solution', 'S01GA55', false, 0, '00626643', 'FreeDiams::CA_HCDPD::DIN', 6773);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bicarbonate Concentrate D17000', 'solution', 'B05ZA', false, 0, '00691623', 'FreeDiams::CA_HCDPD::DIN', 6775);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('G-10', 'liquid', 'V07AV', false, 0, '00695564', 'FreeDiams::CA_HCDPD::DIN', 6784);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vibra-Tabs', 'tablet', 'J01AA02', false, 0, '00578452', 'FreeDiams::CA_HCDPD::DIN', 6795);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triple D Liq 4.5%', 'liquid', 'V07AV', false, 0, '00610461', 'FreeDiams::CA_HCDPD::DIN', 6799);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pirocam Cap 20mg', 'capsule', 'M01AC01', false, 0, '00695696', 'FreeDiams::CA_HCDPD::DIN', 6812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pirocam Cap 10mg', 'capsule', 'M01AC01', false, 0, '00695718', 'FreeDiams::CA_HCDPD::DIN', 6813);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Carbamazepine', 'tablet', 'N03AF01', false, 0, '00667110', 'FreeDiams::CA_HCDPD::DIN', 6819);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ectosone Mild Lotion 0.05%', 'lotion', 'D07AC01', false, 0, '00653209', 'FreeDiams::CA_HCDPD::DIN', 6822);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Lenoltec No 4', 'tablet', 'N02AA59', false, 0, '00621463', 'FreeDiams::CA_HCDPD::DIN', 6824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen 99.0%', 'gas', 'V03AN01', false, 0, '00591629', 'FreeDiams::CA_HCDPD::DIN', 6826);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Furosemide Tab 80mg', 'tablet', 'C03CA01', false, 0, '00707570', 'FreeDiams::CA_HCDPD::DIN', 6827);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cough Syrup', 'syrup', 'R05FA02', false, 0, '00690074', 'FreeDiams::CA_HCDPD::DIN', 6844);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sebcur-T', 'shampoo', 'D05AA', false, 0, '00666114', 'FreeDiams::CA_HCDPD::DIN', 6848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Liqui-Med Analgesic Gas', 'gas', 'N01AX63', false, 0, '00693596', 'FreeDiams::CA_HCDPD::DIN', 6850);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sulfate Injection 1mg/Ml', 'solution', 'N02AA01', false, 0, '00636908', 'FreeDiams::CA_HCDPD::DIN', 6871);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Meperidine Hydrochloride Injection 10mg/Ml Usp', 'solution', 'N02AB02', false, 0, '00640409', 'FreeDiams::CA_HCDPD::DIN', 6872);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dilaudid', 'tablet', 'N02AA03', false, 0, '00705438', 'FreeDiams::CA_HCDPD::DIN', 6889);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Spironolactone/Hctz', 'tablet', 'C03EA01', false, 0, '00657182', 'FreeDiams::CA_HCDPD::DIN', 6892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Gesic C15', 'tablet', 'N02BE51', false, 0, '00687200', 'FreeDiams::CA_HCDPD::DIN', 6893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Gesic C30', 'tablet', 'N02AA59', false, 0, '00687219', 'FreeDiams::CA_HCDPD::DIN', 6894);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Morphine', 'syrup', 'N02AA01', false, 0, '00690791', 'FreeDiams::CA_HCDPD::DIN', 6903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flexo Csg 1000', 'liquid', 'V07AV', false, 0, '00692336', 'FreeDiams::CA_HCDPD::DIN', 7022);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potaba Pwr 2gm/Pck', 'powder', 'V03AX', false, 0, '00611298', 'FreeDiams::CA_HCDPD::DIN', 7024);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cortisporin', 'ointment', 'D07CA01', false, 0, '00666246', 'FreeDiams::CA_HCDPD::DIN', 7030);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sarna Hc', 'lotion', 'D07AA02', false, 0, '00578541', 'FreeDiams::CA_HCDPD::DIN', 7035);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kemsol Csg 1000', 'liquid', 'V07AV', false, 0, '00693065', 'FreeDiams::CA_HCDPD::DIN', 7041);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Prednisolone', 'suspension', 'S01BA04', false, 0, '00700401', 'FreeDiams::CA_HCDPD::DIN', 7042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zovirax Tab 200mg', 'tablet', 'J05AB01', false, 0, '00634506', 'FreeDiams::CA_HCDPD::DIN', 7063);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Larose Csg 1000', 'liquid', 'V07AV', false, 0, '00693073', 'FreeDiams::CA_HCDPD::DIN', 7071);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('G-700', 'liquid', 'V07AV', false, 0, '00695572', 'FreeDiams::CA_HCDPD::DIN', 7079);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Sinus Pain And Congestion Daytime', 'tablet', 'N02BE51', false, 0, '00663980', 'FreeDiams::CA_HCDPD::DIN', 7081);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Coristex-Dh', 'syrup', 'R05DA20', false, 0, '00694827', 'FreeDiams::CA_HCDPD::DIN', 7082);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dakin''S Solution 0.5% Modified', 'solution', 'D08AX07', false, 0, '00658529', 'FreeDiams::CA_HCDPD::DIN', 7083);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rogaine Topical Solution', 'solution', 'D11AX01', false, 0, '00708925', 'FreeDiams::CA_HCDPD::DIN', 7084);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pepcid Tab 20mg', 'tablet', 'A02BA03', false, 0, '00710121', 'FreeDiams::CA_HCDPD::DIN', 7087);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pepcid Tab 40mg', 'tablet', 'A02BA03', false, 0, '00710113', 'FreeDiams::CA_HCDPD::DIN', 7088);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ensuite', 'gel', 'D08AE20', false, 0, '00708224', 'FreeDiams::CA_HCDPD::DIN', 7121);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Florafree Gel 0.3%', 'gel', 'D08AE04', false, 0, '00708232', 'FreeDiams::CA_HCDPD::DIN', 7122);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Morphine', 'syrup', 'N02AA01', false, 0, '00690783', 'FreeDiams::CA_HCDPD::DIN', 7123);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prevex Crm 67%', 'cream', 'D02AC', false, 0, '00635189', 'FreeDiams::CA_HCDPD::DIN', 7127);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Peridol Tab 0.5mg', 'tablet', 'N05AD01', false, 0, '00363685', 'FreeDiams::CA_HCDPD::DIN', 7128);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Peridol Tab 1mg', 'tablet', 'N05AD01', false, 0, '00363677', 'FreeDiams::CA_HCDPD::DIN', 7129);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Peridol Tab 2mg', 'tablet', 'N05AD01', false, 0, '00363669', 'FreeDiams::CA_HCDPD::DIN', 7130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Peridol Tab 10mg', 'tablet', 'N05AD01', false, 0, '00713449', 'FreeDiams::CA_HCDPD::DIN', 7131);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sulfate Injection 5mg/Ml Usp', 'solution', 'N02AA01', false, 0, '00649619', 'FreeDiams::CA_HCDPD::DIN', 7136);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Greer Csg 1000', 'liquid', 'V07AV', false, 0, '00693057', 'FreeDiams::CA_HCDPD::DIN', 7139);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Procainamide Cap 500mg', 'capsule', 'C01BA02', false, 0, '00713341', 'FreeDiams::CA_HCDPD::DIN', 7149);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Procainamide Cap 375mg', 'capsule', 'C01BA02', false, 0, '00713333', 'FreeDiams::CA_HCDPD::DIN', 7150);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Procainamide Cap 250mg', 'capsule', 'C01BA02', false, 0, '00713325', 'FreeDiams::CA_HCDPD::DIN', 7151);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eurax Cream 10%', 'cream', 'P03AX', false, 0, '00623377', 'FreeDiams::CA_HCDPD::DIN', 7152);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nupercainal Antiseptic Crm', 'cream', 'D04AB02', false, 0, '00623407', 'FreeDiams::CA_HCDPD::DIN', 7153);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn Rf Injection', 'solution', 'B05BA01', false, 0, '00640131', 'FreeDiams::CA_HCDPD::DIN', 7163);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Colestid Granules', 'granules', 'C10AC02', false, 0, '00642975', 'FreeDiams::CA_HCDPD::DIN', 7199);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Collyre Bleu Laiter', 'drops', 'S01GA01', false, 0, '00674354', 'FreeDiams::CA_HCDPD::DIN', 7203);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tryptan Cap 500mg', 'capsule', 'N06AX02', false, 0, '00718149', 'FreeDiams::CA_HCDPD::DIN', 7263);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tryptan Tab 1000mg', 'tablet', 'N06AX02', false, 0, '00654531', 'FreeDiams::CA_HCDPD::DIN', 7264);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hycort Retention Enema 100mg/60ml', 'enema', 'A07EA02', false, 0, '00230316', 'FreeDiams::CA_HCDPD::DIN', 7265);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Charactol-50', 'suspension', 'A07BA01', false, 0, '00649236', 'FreeDiams::CA_HCDPD::DIN', 7267);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nupercainal Anesthetic Ont 1%', 'ointment', 'C05AD04', false, 0, '00623385', 'FreeDiams::CA_HCDPD::DIN', 7287);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pamprin Extra Strength Caplets', 'tablet', 'N02BE51', false, 0, '00718130', 'FreeDiams::CA_HCDPD::DIN', 7288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('One Alpha Caps 0.25mcg', 'capsule', 'A11CC03', false, 0, '00474517', 'FreeDiams::CA_HCDPD::DIN', 7292);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('One Alpha Caps 1mcg', 'capsule', 'A11CC03', false, 0, '00474525', 'FreeDiams::CA_HCDPD::DIN', 7293);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ascorbic Acid Inj 500mg/Ml', 'solution', 'A11GA01', false, 0, '00729280', 'FreeDiams::CA_HCDPD::DIN', 7309);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cimetine Tab 800mg', 'tablet', 'A02BA01', false, 0, '00663727', 'FreeDiams::CA_HCDPD::DIN', 7312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Trimel Oral Sus', 'suspension', 'J01EE01', false, 0, '00726540', 'FreeDiams::CA_HCDPD::DIN', 7313);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Lorazem Tab 0.5mg', 'tablet', 'N05BA06', false, 0, '00711101', 'FreeDiams::CA_HCDPD::DIN', 7314);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lemon Quat', 'liquid', 'V07AV', false, 0, '00732052', 'FreeDiams::CA_HCDPD::DIN', 7320);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Betaloc Iv Inj 1 Mg/Ml', 'solution', 'C07AB02', false, 0, '00719846', 'FreeDiams::CA_HCDPD::DIN', 7325);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Surgi Bac Hand Wash 0.5%', 'liquid', 'D08AE04', false, 0, '00723029', 'FreeDiams::CA_HCDPD::DIN', 7341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pranol Tab 20mg', 'tablet', 'C07AA05', false, 0, '00740675', 'FreeDiams::CA_HCDPD::DIN', 7349);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artritol Cap 325mg Usp', 'capsule', 'N02BE01', false, 0, '00649708', 'FreeDiams::CA_HCDPD::DIN', 7352);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckley''S Dm', 'liquid', 'R05DA09', false, 0, '00729655', 'FreeDiams::CA_HCDPD::DIN', 7354);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lopresor Inj 1.0mg/Ml', 'liquid', 'C07AB02', false, 0, '00590819', 'FreeDiams::CA_HCDPD::DIN', 7357);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetylsalicylic Acid Tab 325mg', 'tablet', 'N02BA01', false, 0, '00718831', 'FreeDiams::CA_HCDPD::DIN', 7362);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Tab 325mg', 'tablet', 'N02BE01', false, 0, '00718858', 'FreeDiams::CA_HCDPD::DIN', 7363);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Tab 500mg Ext Strength', 'tablet', 'N02BE01', false, 0, '00718866', 'FreeDiams::CA_HCDPD::DIN', 7364);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Docusate Sodium Cap 100mg', 'capsule', 'A06AA02', false, 0, '00703494', 'FreeDiams::CA_HCDPD::DIN', 7365);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Docusate Sodium', 'syrup', 'A06AA02', false, 0, '00703508', 'FreeDiams::CA_HCDPD::DIN', 7366);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lupron', 'liquid', 'L02AE02', false, 0, '00727695', 'FreeDiams::CA_HCDPD::DIN', 7367);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Hydroxyzine Cap 50mg', 'capsule', 'N05BB01', false, 0, '00646016', 'FreeDiams::CA_HCDPD::DIN', 7391);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Hydroxyzine Cap 25mg', 'capsule', 'N05BB01', false, 0, '00646024', 'FreeDiams::CA_HCDPD::DIN', 7392);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Hydroxyzine Cap 10mg', 'capsule', 'N05BB01', false, 0, '00646059', 'FreeDiams::CA_HCDPD::DIN', 7393);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Androcur', 'tablet', 'G03HA01', false, 0, '00704431', 'FreeDiams::CA_HCDPD::DIN', 7394);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Garasone Ophthalmic And Otic Solution', 'solution', 'S03CA06', false, 0, '00682217', 'FreeDiams::CA_HCDPD::DIN', 7418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Hp 50 - 50mg/Ml Usp', 'solution', 'N02AA01', false, 0, '00617288', 'FreeDiams::CA_HCDPD::DIN', 7421);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metronidazole 5mg/Ml', 'solution', 'J01XD01', false, 0, '00649074', 'FreeDiams::CA_HCDPD::DIN', 7425);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ranitidine Tablet 150mg', 'tablet', 'A02BA02', false, 0, '00733059', 'FreeDiams::CA_HCDPD::DIN', 7426);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ranitidine Tablet 300mg', 'tablet', 'A02BA02', false, 0, '00733067', 'FreeDiams::CA_HCDPD::DIN', 7427);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen 325 Mg With 15 Mg Caffeine And 8 Mg Codeine Phosphate', 'tablet', 'N02BE51', false, 0, '00706221', 'FreeDiams::CA_HCDPD::DIN', 7434);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Hydroxyzin Cap 10mg', 'capsule', 'N05BB01', false, 0, '00738824', 'FreeDiams::CA_HCDPD::DIN', 7442);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Hydroxyzin Cap 25mg', 'capsule', 'N05BB01', false, 0, '00738832', 'FreeDiams::CA_HCDPD::DIN', 7443);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Hydroxyzin Cap 50mg', 'capsule', 'N05BB01', false, 0, '00738840', 'FreeDiams::CA_HCDPD::DIN', 7444);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Siligaz Cap 160mg', 'capsule', 'A03AX13', false, 0, '00637211', 'FreeDiams::CA_HCDPD::DIN', 7455);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bisacolax', 'tablet (enteric-coated)', 'A06AB02', false, 0, '00714488', 'FreeDiams::CA_HCDPD::DIN', 7456);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('K-20 Liquid Lemon', 'liquid', 'V07AV', false, 0, '00725870', 'FreeDiams::CA_HCDPD::DIN', 7457);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eyestream', 'liquid', 'V07AB', false, 0, '00707937', 'FreeDiams::CA_HCDPD::DIN', 7474);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Provera 10mg Tablets', 'tablet', 'G03DA02', false, 0, '00729973', 'FreeDiams::CA_HCDPD::DIN', 7480);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medi-Scrub Liq 0.6%', 'liquid', 'D08AE05', false, 0, '00694983', 'FreeDiams::CA_HCDPD::DIN', 7506);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Urispas Tab 200mg', 'tablet', 'G04BD02', false, 0, '00728179', 'FreeDiams::CA_HCDPD::DIN', 7520);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fml Forte Sus 0.25%', 'suspension', 'S01BA07', false, 0, '00707511', 'FreeDiams::CA_HCDPD::DIN', 7626);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Doxy Cap 100mg', 'capsule', 'J01AA02', false, 0, '00740713', 'FreeDiams::CA_HCDPD::DIN', 7627);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lemon Odour Germicidal Cleaner 2.5%', 'liquid', 'V07AV', false, 0, '00719595', 'FreeDiams::CA_HCDPD::DIN', 7632);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estragyn Vaginal Cream', 'cream', 'G03CA07', false, 0, '00727369', 'FreeDiams::CA_HCDPD::DIN', 7645);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rocephin Pws Inj 0.25gm/Vial', 'powder for solution', 'J01DD04', false, 0, '00657387', 'FreeDiams::CA_HCDPD::DIN', 8037);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Leo Inj 25000unit/Ml', 'liquid', 'B01AB01', false, 0, '00453781', 'FreeDiams::CA_HCDPD::DIN', 8041);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Leo 100unit/Ml', 'liquid', 'B01AB01', false, 0, '00727520', 'FreeDiams::CA_HCDPD::DIN', 8042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Leo Inj 10000unit/Ml', 'liquid', 'B01AB01', false, 0, '00579718', 'FreeDiams::CA_HCDPD::DIN', 8043);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Air X 78 Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '00638811', 'FreeDiams::CA_HCDPD::DIN', 8044);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Air X 44 Disinfectant', 'liquid', 'V07AV', false, 0, '00638838', 'FreeDiams::CA_HCDPD::DIN', 8045);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Air X 15 Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '00638846', 'FreeDiams::CA_HCDPD::DIN', 8046);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Primaxin 500', 'powder for solution', 'J01DH51', false, 0, '00717282', 'FreeDiams::CA_HCDPD::DIN', 8054);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydroxyzine-10', 'capsule', 'N05BB01', false, 0, '00739618', 'FreeDiams::CA_HCDPD::DIN', 8057);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydroxyzine-25', 'capsule', 'N05BB01', false, 0, '00739626', 'FreeDiams::CA_HCDPD::DIN', 8058);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydroxyzine-50', 'capsule', 'N05BB01', false, 0, '00739634', 'FreeDiams::CA_HCDPD::DIN', 8059);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Benztropine Tab 1mg Usp', 'tablet', 'N04AC01', false, 0, '00706531', 'FreeDiams::CA_HCDPD::DIN', 8060);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trimipramine', 'tablet', 'N06AA06', false, 0, '00740799', 'FreeDiams::CA_HCDPD::DIN', 8065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trimipramine', 'tablet', 'N06AA06', false, 0, '00740802', 'FreeDiams::CA_HCDPD::DIN', 8066);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trimipramine', 'tablet', 'N06AA06', false, 0, '00740810', 'FreeDiams::CA_HCDPD::DIN', 8067);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rocephin Pws 1gm/Vial', 'powder for solution', 'J01DD04', false, 0, '00657417', 'FreeDiams::CA_HCDPD::DIN', 8074);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vasotec', 'tablet', 'C09AA02', false, 0, '00670901', 'FreeDiams::CA_HCDPD::DIN', 8102);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vasotec', 'tablet', 'C09AA02', false, 0, '00670928', 'FreeDiams::CA_HCDPD::DIN', 8103);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trimipramine', 'tablet', 'N06AA06', false, 0, '00740829', 'FreeDiams::CA_HCDPD::DIN', 8106);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vasotec', 'tablet', 'C09AA02', false, 0, '00708879', 'FreeDiams::CA_HCDPD::DIN', 8111);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Selax Syr 20mg/5ml Usp', 'syrup', 'A06AA02', false, 0, '00695033', 'FreeDiams::CA_HCDPD::DIN', 8116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydroxyzine Hydrochloride Injection Usp', 'liquid', 'N05BB01', false, 0, '00742813', 'FreeDiams::CA_HCDPD::DIN', 8118);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phosphate De Potassium Monobasic Inj 176mg/Ml', 'liquid', 'B05XA06', false, 0, '00711306', 'FreeDiams::CA_HCDPD::DIN', 8119);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Meperidine Hydrochloride Injection Usp', 'solution', 'N02AB02', false, 0, '00725757', 'FreeDiams::CA_HCDPD::DIN', 8120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Meperidine Hydrochloride Injection Usp', 'solution', 'N02AB02', false, 0, '00725765', 'FreeDiams::CA_HCDPD::DIN', 8121);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triquilar 28', 'tablet', 'G03AB03', false, 0, '00707503', 'FreeDiams::CA_HCDPD::DIN', 8123);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triquilar 21', 'tablet', 'G03AB03', false, 0, '00707600', 'FreeDiams::CA_HCDPD::DIN', 8124);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anthrascalp Lotion 0.4%', 'lotion', 'D05AC01', false, 0, '00695351', 'FreeDiams::CA_HCDPD::DIN', 8125);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Opcon-A', 'drops', 'S01GA51', false, 0, '00750794', 'FreeDiams::CA_HCDPD::DIN', 8155);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra 1 Etap', 'liquid', 'V07AV', false, 0, '00738344', 'FreeDiams::CA_HCDPD::DIN', 8159);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Basic 12 Liquid 10.8%', 'liquid', 'V07AV', false, 0, '00617016', 'FreeDiams::CA_HCDPD::DIN', 8161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balanced Salt Solution', 'solution', 'B05CB10', false, 0, '00708127', 'FreeDiams::CA_HCDPD::DIN', 8169);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Haloperidol Tab 2mg', 'tablet', 'N05AD01', false, 0, '00396826', 'FreeDiams::CA_HCDPD::DIN', 8170);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Haloperidol Tab 5mg', 'tablet', 'N05AD01', false, 0, '00396834', 'FreeDiams::CA_HCDPD::DIN', 8171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Haloperidol Tab 10mg', 'tablet', 'N05AD01', false, 0, '00463698', 'FreeDiams::CA_HCDPD::DIN', 8172);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estraderm-100', 'patch (extended release)', 'G03CA03', false, 0, '00756792', 'FreeDiams::CA_HCDPD::DIN', 8175);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lung Diffusion Test Mix No Ne Co', 'gas', 'V03AN', false, 0, '00588075', 'FreeDiams::CA_HCDPD::DIN', 8185);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humatrope Inj 1mg/Ml', 'powder for solution', 'H01AC01', false, 0, '00745626', 'FreeDiams::CA_HCDPD::DIN', 8187);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diprolene', 'cream', 'D07AC01', false, 0, '00688622', 'FreeDiams::CA_HCDPD::DIN', 8190);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Liposyn Ii 20%', 'emulsion', 'B05BA02', false, 0, '00720968', 'FreeDiams::CA_HCDPD::DIN', 8197);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Liposyn Ii 10%', 'emulsion', 'B05BA02', false, 0, '00720976', 'FreeDiams::CA_HCDPD::DIN', 8198);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elavil', 'tablet', 'N06AA09', false, 0, '00754129', 'FreeDiams::CA_HCDPD::DIN', 8199);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Viroptic', 'solution', 'S01AD02', false, 0, '00687456', 'FreeDiams::CA_HCDPD::DIN', 8203);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lindane Shp 1%', 'shampoo', 'P03AB02', false, 0, '00703605', 'FreeDiams::CA_HCDPD::DIN', 8213);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Perphenazine Tab 2mg', 'tablet', 'N05AB03', false, 0, '00726184', 'FreeDiams::CA_HCDPD::DIN', 8214);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Perphenazine Tab 4mg', 'tablet', 'N05AB03', false, 0, '00726192', 'FreeDiams::CA_HCDPD::DIN', 8215);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Perphenazine Tab 16mg', 'tablet', 'N05AB03', false, 0, '00726206', 'FreeDiams::CA_HCDPD::DIN', 8216);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Trihexyphenidyl', 'tablet', 'N04AA01', false, 0, '00726265', 'FreeDiams::CA_HCDPD::DIN', 8217);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Trihexyphenidyl', 'tablet', 'N04AA01', false, 0, '00726273', 'FreeDiams::CA_HCDPD::DIN', 8218);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Perphenazine Tab 8mg', 'tablet', 'N05AB03', false, 0, '00726281', 'FreeDiams::CA_HCDPD::DIN', 8219);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flarex Oph Susp 0.1%', 'suspension', 'S01BA07', false, 0, '00756784', 'FreeDiams::CA_HCDPD::DIN', 8229);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Tylenol Cold Chewable Tablets', 'tablet', 'N02BE51', false, 0, '00743224', 'FreeDiams::CA_HCDPD::DIN', 8247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Regular Strength Tylenol Cold Nighttime Caplet', 'tablet', 'N02BE51', false, 0, '00574007', 'FreeDiams::CA_HCDPD::DIN', 8249);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Cold Daytime', 'tablet', 'N02BE51', false, 0, '00743267', 'FreeDiams::CA_HCDPD::DIN', 8250);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Cold Nighttime Caplet', 'tablet', 'N02BE51', false, 0, '00743275', 'FreeDiams::CA_HCDPD::DIN', 8251);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Regular Strength Tylenol Cold Daytime', 'tablet', 'N02BE51', false, 0, '00743283', 'FreeDiams::CA_HCDPD::DIN', 8252);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lindane Lot 1%', 'lotion', 'P03AB02', false, 0, '00703591', 'FreeDiams::CA_HCDPD::DIN', 8259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tromboject 3% Inj 30mg/Ml', 'solution', 'C05BB04', false, 0, '00511226', 'FreeDiams::CA_HCDPD::DIN', 8274);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tromboject 1% Inj 10mg/Ml', 'solution', 'C05BB04', false, 0, '00511234', 'FreeDiams::CA_HCDPD::DIN', 8275);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Albumin Human Diluent', 'liquid', 'V07AB', false, 0, '00674621', 'FreeDiams::CA_HCDPD::DIN', 8276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tussodan Dm Syrup', 'syrup', 'R05DA20', false, 0, '00720208', 'FreeDiams::CA_HCDPD::DIN', 8324);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermaflex Hc 1% Lotion', 'lotion', 'D07XA01', false, 0, '00681997', 'FreeDiams::CA_HCDPD::DIN', 8338);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Primaxin 250', 'powder for solution', 'J01DH51', false, 0, '00717274', 'FreeDiams::CA_HCDPD::DIN', 8348);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Bicarbonate Inj 4.2% Infant Usp', 'solution', 'B05XA02', false, 0, '00261971', 'FreeDiams::CA_HCDPD::DIN', 8350);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidocaine Hydrochloride Inj 2% Usp', 'solution', 'C01BB01', false, 0, '00436208', 'FreeDiams::CA_HCDPD::DIN', 8351);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epinephrine Inj 0.1mg/Ml Usp', 'solution', 'C01CA24', false, 0, '00710814', 'FreeDiams::CA_HCDPD::DIN', 8352);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germ-Cid-800', 'liquid', 'V07AV', false, 0, '00716340', 'FreeDiams::CA_HCDPD::DIN', 8354);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tegretol Cr Tab 200mg', 'tablet (extended-release)', 'N03AF01', false, 0, '00773611', 'FreeDiams::CA_HCDPD::DIN', 8373);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tegretol Cr Tab 400mg', 'tablet (extended-release)', 'N03AF01', false, 0, '00755583', 'FreeDiams::CA_HCDPD::DIN', 8374);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nifedipine', 'capsule', 'C08CA05', false, 0, '00755907', 'FreeDiams::CA_HCDPD::DIN', 8376);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estraderm-25', 'patch (extended release)', 'G03CA03', false, 0, '00756849', 'FreeDiams::CA_HCDPD::DIN', 8386);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol Extra-Strength Caplets 500mg', 'tablet', 'N02BE01', false, 0, '00723908', 'FreeDiams::CA_HCDPD::DIN', 8387);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bioderm Ointment', 'ointment', 'D06AX05', false, 0, '00621366', 'FreeDiams::CA_HCDPD::DIN', 8398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('G-1250', 'liquid', 'V07AV', false, 0, '00695580', 'FreeDiams::CA_HCDPD::DIN', 8435);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimension Iv', 'liquid', 'V07AV', false, 0, '00764671', 'FreeDiams::CA_HCDPD::DIN', 8461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rythmol Tab 150mg', 'tablet', 'C01BC03', false, 0, '00603708', 'FreeDiams::CA_HCDPD::DIN', 8464);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rythmol Tab 300mg', 'tablet', 'C01BC03', false, 0, '00603716', 'FreeDiams::CA_HCDPD::DIN', 8465);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('K-Exit Poudre', 'powder for solution', 'V03AE01', false, 0, '00765252', 'FreeDiams::CA_HCDPD::DIN', 8468);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Hylazin Tab 25mg', 'tablet', 'C02DB02', false, 0, '00759473', 'FreeDiams::CA_HCDPD::DIN', 8475);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Hylazin Tab 50mg', 'tablet', 'C02DB02', false, 0, '00759481', 'FreeDiams::CA_HCDPD::DIN', 8476);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Peridol Tab 20mg', 'tablet', 'N05AD01', false, 0, '00768820', 'FreeDiams::CA_HCDPD::DIN', 8477);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Parquat', 'liquid', 'V07AV', false, 0, '00594261', 'FreeDiams::CA_HCDPD::DIN', 8478);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ranitidine - 150', 'tablet', 'A02BA02', false, 0, '00740748', 'FreeDiams::CA_HCDPD::DIN', 8482);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ranitidine - 300', 'tablet', 'A02BA02', false, 0, '00740756', 'FreeDiams::CA_HCDPD::DIN', 8483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Meperidine Hydrochloride Injection Usp', 'solution', 'N02AB02', false, 0, '00725749', 'FreeDiams::CA_HCDPD::DIN', 8487);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlorpromazine Hydrochloride Injection', 'liquid', 'N05AA01', false, 0, '00743518', 'FreeDiams::CA_HCDPD::DIN', 8488);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zochlor Disinfectant Tab 55%', 'tablet', 'V07AV', false, 0, '00764914', 'FreeDiams::CA_HCDPD::DIN', 8505);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Original Eye Drops', 'drops', 'S01GA01', false, 0, '00764647', 'FreeDiams::CA_HCDPD::DIN', 8526);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neosporin Ointment', 'ointment', 'D06AX04', false, 0, '00666122', 'FreeDiams::CA_HCDPD::DIN', 8528);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Haloperidol Soln 2mg/Ml', 'solution', 'N05AD01', false, 0, '00759503', 'FreeDiams::CA_HCDPD::DIN', 8558);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Imipramine Tab 25mg', 'tablet', 'N06AA02', false, 0, '00726303', 'FreeDiams::CA_HCDPD::DIN', 8560);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Imipramine Tab 50mg', 'tablet', 'N06AA02', false, 0, '00726311', 'FreeDiams::CA_HCDPD::DIN', 8561);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Imipramine Tab 10mg', 'tablet', 'N06AA02', false, 0, '00726397', 'FreeDiams::CA_HCDPD::DIN', 8562);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lubricating Nasal Mist', 'metered-dose (aerosol)', 'R01AX10', false, 0, '00732230', 'FreeDiams::CA_HCDPD::DIN', 8563);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Trifluoperazine Hcl Syrup 11.8mg/Ml', 'syrup', 'N05AB06', false, 0, '00751871', 'FreeDiams::CA_HCDPD::DIN', 8564);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Perphenazine Concentrate Liq 3.2mg/Ml', 'liquid', 'N05AB03', false, 0, '00751898', 'FreeDiams::CA_HCDPD::DIN', 8565);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Hydroxyzine Syr 10mg/5ml', 'syrup', 'N05BB01', false, 0, '00741817', 'FreeDiams::CA_HCDPD::DIN', 8566);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaderm Crm 0.1%', 'cream', 'D07AB09', false, 0, '00716960', 'FreeDiams::CA_HCDPD::DIN', 8573);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methocarbamol Inj 100mg/Ml', 'liquid', 'M03BA03', false, 0, '00731110', 'FreeDiams::CA_HCDPD::DIN', 8576);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate 2102', 'solution', 'B05ZA', false, 0, '00774804', 'FreeDiams::CA_HCDPD::DIN', 8585);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate 2120', 'solution', 'B05ZA', false, 0, '00774960', 'FreeDiams::CA_HCDPD::DIN', 8586);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('800 Sodium Bicarbonate Powder', 'powder for solution', 'B05ZA', false, 0, '00774995', 'FreeDiams::CA_HCDPD::DIN', 8587);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cimetidine Tab 800mg', 'tablet', 'A02BA01', false, 0, '00749494', 'FreeDiams::CA_HCDPD::DIN', 8588);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Timol Tablets 5mg', 'tablet', 'C07AA06', false, 0, '00755842', 'FreeDiams::CA_HCDPD::DIN', 8589);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Timol Tablets 10mg', 'tablet', 'C07AA06', false, 0, '00755850', 'FreeDiams::CA_HCDPD::DIN', 8590);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Timol Tablets 20mg', 'tablet', 'C07AA06', false, 0, '00755869', 'FreeDiams::CA_HCDPD::DIN', 8591);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Sulin Tab 150mg', 'tablet', 'M01AB02', false, 0, '00778354', 'FreeDiams::CA_HCDPD::DIN', 8592);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Sulin Tab 200mg', 'tablet', 'M01AB02', false, 0, '00778362', 'FreeDiams::CA_HCDPD::DIN', 8593);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Hydro Tab 100mg', 'tablet', 'C03AA03', false, 0, '00644552', 'FreeDiams::CA_HCDPD::DIN', 8594);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S. Sr Tablets 30mg', 'tablet (extended-release)', 'N02AA01', false, 0, '00776181', 'FreeDiams::CA_HCDPD::DIN', 8595);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S. Sr Tablets 60mg', 'tablet (extended-release)', 'N02AA01', false, 0, '00776203', 'FreeDiams::CA_HCDPD::DIN', 8596);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol Regular Strength Caplets 325mg', 'tablet', 'N02BE01', false, 0, '00723894', 'FreeDiams::CA_HCDPD::DIN', 8597);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Panoxyl Clear Acne Cleansing Gel', 'gel', 'D02AF', false, 0, '00754927', 'FreeDiams::CA_HCDPD::DIN', 8599);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentothal Inj 25mg/Ml', 'powder for solution', 'N01AF03', false, 0, '00695017', 'FreeDiams::CA_HCDPD::DIN', 8600);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lactated Ringer''S Irrigation', 'solution', 'B05CB10', false, 0, '00758566', 'FreeDiams::CA_HCDPD::DIN', 8601);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Metoprolol (Type L) Tab 100mg', 'tablet', 'C07AB02', false, 0, '00751170', 'FreeDiams::CA_HCDPD::DIN', 8602);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Metoprolol (Type L) Tab 50mg', 'tablet', 'C07AB02', false, 0, '00749354', 'FreeDiams::CA_HCDPD::DIN', 8603);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vasopressin Inj 20unit/Ml Usp', 'liquid', 'H01BA01', false, 0, '00693820', 'FreeDiams::CA_HCDPD::DIN', 8604);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Air X 44 Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '00638862', 'FreeDiams::CA_HCDPD::DIN', 8606);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Codeine', 'syrup', 'R05DA04', false, 0, '00779474', 'FreeDiams::CA_HCDPD::DIN', 8616);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Axid', 'capsule', 'A02BA04', false, 0, '00778338', 'FreeDiams::CA_HCDPD::DIN', 8915);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Axid', 'capsule', 'A02BA04', false, 0, '00778346', 'FreeDiams::CA_HCDPD::DIN', 8916);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Statex Syrup 10mg/Ml', 'syrup', 'N02AA01', false, 0, '00647217', 'FreeDiams::CA_HCDPD::DIN', 8917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Sodium Polysterene Sulfonate', 'powder', 'V03AE01', false, 0, '00755338', 'FreeDiams::CA_HCDPD::DIN', 8918);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Timop Oph Soln 0.25%', 'liquid', 'S01ED01', false, 0, '00755826', 'FreeDiams::CA_HCDPD::DIN', 8958);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Timop Liq 0.5%', 'liquid', 'S01ED01', false, 0, '00755834', 'FreeDiams::CA_HCDPD::DIN', 8959);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nix Creme Rinse', 'cream', 'P03AC04', false, 0, '00771368', 'FreeDiams::CA_HCDPD::DIN', 8964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Betaderm Crm 0.05%', 'cream', 'D07AC01', false, 0, '00716618', 'FreeDiams::CA_HCDPD::DIN', 8972);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Betaderm Ont 0.1%', 'ointment', 'D07AC01', false, 0, '00716650', 'FreeDiams::CA_HCDPD::DIN', 8973);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Docusate', 'capsule', 'A06AA02', false, 0, '00716731', 'FreeDiams::CA_HCDPD::DIN', 8974);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluoderm Crm 0.025%', 'cream', 'D07AC04', false, 0, '00716790', 'FreeDiams::CA_HCDPD::DIN', 8975);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nyaderm Crm 100000unit/Gm', 'cream', 'D01AA01', false, 0, '00716871', 'FreeDiams::CA_HCDPD::DIN', 8977);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nyaderm Ont 100000unit/Gm', 'ointment', 'D01AA01', false, 0, '00716898', 'FreeDiams::CA_HCDPD::DIN', 8978);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stieva-A Cream', 'cream', 'D10AD01', false, 0, '00662348', 'FreeDiams::CA_HCDPD::DIN', 8989);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Bisacodyl Sup 10mg', 'suppository', 'A06AB02', false, 0, '00754595', 'FreeDiams::CA_HCDPD::DIN', 9011);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Hydroxyzine Cap 10mg', 'capsule', 'N05BB01', false, 0, '00741884', 'FreeDiams::CA_HCDPD::DIN', 9126);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate 2125', 'solution', 'B05ZA', false, 0, '00770213', 'FreeDiams::CA_HCDPD::DIN', 9129);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate 2135', 'solution', 'B05ZA', false, 0, '00771244', 'FreeDiams::CA_HCDPD::DIN', 9130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate 2139', 'solution', 'B05ZA', false, 0, '00771279', 'FreeDiams::CA_HCDPD::DIN', 9131);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Della-San Liq 12%', 'solution', 'V07AV', false, 0, '00724939', 'FreeDiams::CA_HCDPD::DIN', 9158);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pce', 'tablet', 'J01FA01', false, 0, '00769991', 'FreeDiams::CA_HCDPD::DIN', 9162);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epinephrine Inj 1mg/Ml Usp', 'solution', 'C01CA24', false, 0, '00721891', 'FreeDiams::CA_HCDPD::DIN', 9164);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pindol Tab 5mg', 'tablet', 'C07AA03', false, 0, '00755877', 'FreeDiams::CA_HCDPD::DIN', 9167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pindol Tab 10mg', 'tablet', 'C07AA03', false, 0, '00755885', 'FreeDiams::CA_HCDPD::DIN', 9168);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pindol Tab 15mg', 'tablet', 'C07AA03', false, 0, '00755893', 'FreeDiams::CA_HCDPD::DIN', 9169);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cephalex Tab 500mg', 'tablet', 'J01DB01', false, 0, '00768715', 'FreeDiams::CA_HCDPD::DIN', 9170);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cephalex Tab 250mg', 'tablet', 'J01DB01', false, 0, '00768723', 'FreeDiams::CA_HCDPD::DIN', 9171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Diltiaz Tab 30mg', 'tablet', 'C08DB01', false, 0, '00771376', 'FreeDiams::CA_HCDPD::DIN', 9172);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Diltiaz Tab 60mg', 'tablet', 'C08DB01', false, 0, '00771384', 'FreeDiams::CA_HCDPD::DIN', 9173);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Atenol Tab 50mg', 'tablet', 'C07AB03', false, 0, '00773689', 'FreeDiams::CA_HCDPD::DIN', 9174);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Atenol Tab 100mg', 'tablet', 'C07AB03', false, 0, '00773697', 'FreeDiams::CA_HCDPD::DIN', 9175);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Nadol Tab 80mg', 'tablet', 'C07AA12', false, 0, '00782467', 'FreeDiams::CA_HCDPD::DIN', 9176);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Nadol Tab 160mg', 'tablet', 'C07AA12', false, 0, '00782475', 'FreeDiams::CA_HCDPD::DIN', 9177);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Nadol Tab 40mg', 'tablet', 'C07AA12', false, 0, '00782505', 'FreeDiams::CA_HCDPD::DIN', 9178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('D-Fend 2%', 'solution', 'V07AV', false, 0, '00653047', 'FreeDiams::CA_HCDPD::DIN', 9221);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Menomune-A/C/Y/W-135', 'powder for solution', 'J07AH04', false, 0, '00588490', 'FreeDiams::CA_HCDPD::DIN', 9222);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cadisan-10', 'liquid', 'V07AV', false, 0, '00703664', 'FreeDiams::CA_HCDPD::DIN', 9223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cadisan 1.6', 'liquid', 'V07AV', false, 0, '00703672', 'FreeDiams::CA_HCDPD::DIN', 9224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Sulindac', 'tablet', 'M01AB02', false, 0, '00745588', 'FreeDiams::CA_HCDPD::DIN', 9238);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Sulindac', 'tablet', 'M01AB02', false, 0, '00745596', 'FreeDiams::CA_HCDPD::DIN', 9239);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Semide Tab 80mg', 'tablet', 'C03CA01', false, 0, '00765953', 'FreeDiams::CA_HCDPD::DIN', 9240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Naproxen Sodium', 'tablet', 'M01AE02', false, 0, '00778389', 'FreeDiams::CA_HCDPD::DIN', 9241);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Carbamazepine', 'tablet', 'N03AF01', false, 0, '00782718', 'FreeDiams::CA_HCDPD::DIN', 9242);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mevacor', 'tablet', 'C10AA02', false, 0, '00795860', 'FreeDiams::CA_HCDPD::DIN', 9253);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lopid 600mg', 'tablet', 'C10AB04', false, 0, '00659606', 'FreeDiams::CA_HCDPD::DIN', 9259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isoptin Sr', 'tablet (extended-release)', 'C08DA01', false, 0, '00742554', 'FreeDiams::CA_HCDPD::DIN', 9264);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Betaderm Crm 0.1%', 'cream', 'D07AC01', false, 0, '00716626', 'FreeDiams::CA_HCDPD::DIN', 9268);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Betaderm Lotion 0.1%', 'lotion', 'D07AC01', false, 0, '00716634', 'FreeDiams::CA_HCDPD::DIN', 9269);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Betaderm Ont 0.05%', 'ointment', 'D07AC01', false, 0, '00716642', 'FreeDiams::CA_HCDPD::DIN', 9270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cortoderm Ont 1%', 'ointment', 'D07AA02', false, 0, '00716693', 'FreeDiams::CA_HCDPD::DIN', 9272);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluoderm Crm 0.01%', 'cream', 'D07AC04', false, 0, '00716782', 'FreeDiams::CA_HCDPD::DIN', 9273);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hyderm Crm 1%', 'cream', 'D07AA02', false, 0, '00716839', 'FreeDiams::CA_HCDPD::DIN', 9275);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lyderm Cream 0.05%', 'cream', 'D07AC08', false, 0, '00716863', 'FreeDiams::CA_HCDPD::DIN', 9276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nyaderm Vag Crm 25000unit/Gm', 'cream', 'G01AA01', false, 0, '00716901', 'FreeDiams::CA_HCDPD::DIN', 9277);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaderm Crm 0.025%', 'cream', 'D07AB09', false, 0, '00716952', 'FreeDiams::CA_HCDPD::DIN', 9278);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaderm Ont 0.1%', 'ointment', 'D07AB09', false, 0, '00716987', 'FreeDiams::CA_HCDPD::DIN', 9280);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aqua San', 'liquid', 'V07AV', false, 0, '00579769', 'FreeDiams::CA_HCDPD::DIN', 9323);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin E Inj 100unit/Ml', 'liquid', 'A11HA03', false, 0, '00781193', 'FreeDiams::CA_HCDPD::DIN', 9325);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentrax Tar Shampoo 4.3%', 'shampoo', 'D05AA', false, 0, '00740314', 'FreeDiams::CA_HCDPD::DIN', 9334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pramegel 1%', 'gel', 'D04AB07', false, 0, '00740284', 'FreeDiams::CA_HCDPD::DIN', 9335);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Amitriptyline Tablets 25mg', 'tablet', 'N06AA09', false, 0, '00654515', 'FreeDiams::CA_HCDPD::DIN', 9346);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Hydroxyzine Cap 50mg', 'capsule', 'N05BB01', false, 0, '00741906', 'FreeDiams::CA_HCDPD::DIN', 9347);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Hydroxyzine Cap 25mg', 'capsule', 'N05BB01', false, 0, '00741892', 'FreeDiams::CA_HCDPD::DIN', 9348);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lorazepam Tab 0.5mg', 'tablet', 'N05BA06', false, 0, '00728187', 'FreeDiams::CA_HCDPD::DIN', 9349);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Trifluoperazine Tab 10mg', 'tablet', 'N05AB06', false, 0, '00726249', 'FreeDiams::CA_HCDPD::DIN', 9350);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Peglyte Powder', 'powder for solution', 'A06AD10', false, 0, '00777838', 'FreeDiams::CA_HCDPD::DIN', 9351);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Oxazepam Tab 30mg', 'tablet', 'N05BA04', false, 0, '00726389', 'FreeDiams::CA_HCDPD::DIN', 9353);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cantharone Plus', 'liquid', 'D11AF', false, 0, '00772011', 'FreeDiams::CA_HCDPD::DIN', 9361);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hexabrix 200', 'solution', 'V08AB03', false, 0, '00788805', 'FreeDiams::CA_HCDPD::DIN', 9362);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Erythrocin I.V.', 'powder for solution', 'J01FA01', false, 0, '00682268', 'FreeDiams::CA_HCDPD::DIN', 9396);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Erythrocin I.V.', 'powder for solution', 'J01FA01', false, 0, '00682276', 'FreeDiams::CA_HCDPD::DIN', 9397);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenytoin Sodium Injection Usp', 'liquid', 'N03AB02', false, 0, '00780626', 'FreeDiams::CA_HCDPD::DIN', 9398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hepalean-Lok 100 Usp', 'solution', 'B01AB01', false, 0, '00740578', 'FreeDiams::CA_HCDPD::DIN', 9400);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Impril', 'tablet', 'N06AA02', false, 0, '00405604', 'FreeDiams::CA_HCDPD::DIN', 9411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Health Care Antiseptic Lotion Soap', 'lotion', 'D08AE05', false, 0, '00784044', 'FreeDiams::CA_HCDPD::DIN', 9415);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Trifluoperazine Hcl Syr 1.18mg/Ml', 'syrup', 'N05AB06', false, 0, '00776505', 'FreeDiams::CA_HCDPD::DIN', 9416);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Amitriptyline Tablets 10mg', 'tablet', 'N06AA09', false, 0, '00654523', 'FreeDiams::CA_HCDPD::DIN', 9417);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Amitriptyline Tablets 50mg', 'tablet', 'N06AA09', false, 0, '00654507', 'FreeDiams::CA_HCDPD::DIN', 9418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Trifluoperazine Tab 5mg', 'tablet', 'N05AB06', false, 0, '00726230', 'FreeDiams::CA_HCDPD::DIN', 9420);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Trifluoperazine Tab 2mg', 'tablet', 'N05AB06', false, 0, '00726222', 'FreeDiams::CA_HCDPD::DIN', 9421);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lorazepam Tab 1mg', 'tablet', 'N05BA06', false, 0, '00728195', 'FreeDiams::CA_HCDPD::DIN', 9423);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lorazepam Tab 2mg', 'tablet', 'N05BA06', false, 0, '00728209', 'FreeDiams::CA_HCDPD::DIN', 9424);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Acetate', 'liquid', 'B05XA17', false, 0, '00780650', 'FreeDiams::CA_HCDPD::DIN', 9429);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Codeine Tab 15mg', 'tablet', 'R05DA04', false, 0, '00779458', 'FreeDiams::CA_HCDPD::DIN', 9439);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluoderm Ont 0.025%', 'ointment', 'D07AC04', false, 0, '00716812', 'FreeDiams::CA_HCDPD::DIN', 9447);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Viaderm Kc Crm', 'cream', 'D07CB01', false, 0, '00717002', 'FreeDiams::CA_HCDPD::DIN', 9448);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Viaderm Kc Ont', 'ointment', 'D07CB01', false, 0, '00717029', 'FreeDiams::CA_HCDPD::DIN', 9449);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hepalean 1000 Usp', 'solution', 'B01AB01', false, 0, '00740519', 'FreeDiams::CA_HCDPD::DIN', 9470);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hepalean 10,000 Usp', 'solution', 'B01AB01', false, 0, '00740497', 'FreeDiams::CA_HCDPD::DIN', 9471);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('P & W Liquid Antiseptic 0.13%', 'liquid', 'D08AJ01', false, 0, '00788333', 'FreeDiams::CA_HCDPD::DIN', 9483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dilaudid', 'tablet', 'N02AA03', false, 0, '00786543', 'FreeDiams::CA_HCDPD::DIN', 9509);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hytrin Tab 5mg', 'tablet', 'G04CA03', false, 0, '00818666', 'FreeDiams::CA_HCDPD::DIN', 9542);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm Sans Sucre Liq 15mg/5ml', 'liquid', 'R05DA09', false, 0, '00511013', 'FreeDiams::CA_HCDPD::DIN', 9543);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Oxazepam Tab 10mg', 'tablet', 'N05BA04', false, 0, '00726362', 'FreeDiams::CA_HCDPD::DIN', 9562);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Oxazepam Tab 15mg', 'tablet', 'N05BA04', false, 0, '00726370', 'FreeDiams::CA_HCDPD::DIN', 9563);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Prochlorperazine Tab 10mg', 'tablet', 'N05AB04', false, 0, '00753637', 'FreeDiams::CA_HCDPD::DIN', 9564);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Prochlorperazine Tab 5mg', 'tablet', 'N05AB04', false, 0, '00753661', 'FreeDiams::CA_HCDPD::DIN', 9565);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gastrocalm Liq', 'liquid', 'A02AF02', false, 0, '00649643', 'FreeDiams::CA_HCDPD::DIN', 9572);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Triazo', 'tablet', 'N05CD05', false, 0, '00808563', 'FreeDiams::CA_HCDPD::DIN', 9574);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Triazo', 'tablet', 'N05CD05', false, 0, '00808571', 'FreeDiams::CA_HCDPD::DIN', 9575);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gravol Suppositories For Children 25mg', 'suppository', 'R06AA02', false, 0, '00783595', 'FreeDiams::CA_HCDPD::DIN', 9585);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('White Petroleum Jelly Usp Ointment', 'ointment', 'D02AC', false, 0, '00741515', 'FreeDiams::CA_HCDPD::DIN', 9587);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('K-Dur', 'tablet (extended-release)', 'A12BA01', false, 0, '00713376', 'FreeDiams::CA_HCDPD::DIN', 9588);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vancocin', 'capsule', 'A07AA09', false, 0, '00788716', 'FreeDiams::CA_HCDPD::DIN', 9593);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vancocin', 'capsule', 'A07AA09', false, 0, '00800430', 'FreeDiams::CA_HCDPD::DIN', 9594);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Sodium Polystyrene Sulfonate', 'suspension', 'V03AE01', false, 0, '00769541', 'FreeDiams::CA_HCDPD::DIN', 9611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Sodium Polystyrene Sulfonate', 'suspension', 'V03AE01', false, 0, '00769533', 'FreeDiams::CA_HCDPD::DIN', 9612);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Dexamethasone Sod Phosphate Inj 4mg/Ml', 'solution', 'H02AB02', false, 0, '00751863', 'FreeDiams::CA_HCDPD::DIN', 9613);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Estradiol Valerate Inj 10mg/Ml', 'liquid', 'G03CA03', false, 0, '00741930', 'FreeDiams::CA_HCDPD::DIN', 9615);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Dexamethasone Sod Phosphate Dps 1mg/Ml', 'drops', 'S03BA01', false, 0, '00785261', 'FreeDiams::CA_HCDPD::DIN', 9616);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Gentamicin Sulfate Oph Dps 0.3%', 'liquid', 'S01AA11', false, 0, '00776521', 'FreeDiams::CA_HCDPD::DIN', 9617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hytrin Tab 1mg', 'tablet', 'G04CA03', false, 0, '00818658', 'FreeDiams::CA_HCDPD::DIN', 9618);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hytrin Tab 2mg', 'tablet', 'G04CA03', false, 0, '00818682', 'FreeDiams::CA_HCDPD::DIN', 9619);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('A-Quat Liq', 'liquid', 'V07AV', false, 0, '00799408', 'FreeDiams::CA_HCDPD::DIN', 9621);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triatec-30 Tab', 'tablet', 'N02AA59', false, 0, '00789828', 'FreeDiams::CA_HCDPD::DIN', 9626);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Tab 500mg Usp', 'tablet', 'N02BE01', false, 0, '00789798', 'FreeDiams::CA_HCDPD::DIN', 9627);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Tab 325mg Usp', 'tablet', 'N02BE01', false, 0, '00789801', 'FreeDiams::CA_HCDPD::DIN', 9628);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Prochlorperazine Suppositoires 10mg', 'suppository', 'N05AB04', false, 0, '00753688', 'FreeDiams::CA_HCDPD::DIN', 9629);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Peglyte Solution', 'liquid', 'A06AD10', false, 0, '00777846', 'FreeDiams::CA_HCDPD::DIN', 9631);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Albutein 25% Soln Usp', 'solution', 'B05AA01', false, 0, '00779571', 'FreeDiams::CA_HCDPD::DIN', 9700);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prozac Capsules 20mg', 'capsule', 'N06AB03', false, 0, '00636622', 'FreeDiams::CA_HCDPD::DIN', 9703);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Veramil Tab 80mg', 'tablet', 'C08DA01', false, 0, '00812331', 'FreeDiams::CA_HCDPD::DIN', 9731);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Veramil Tab 120mg', 'tablet', 'C08DA01', false, 0, '00812358', 'FreeDiams::CA_HCDPD::DIN', 9732);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Albutein 5% Soln Usp', 'solution', 'B05AA01', false, 0, '00779563', 'FreeDiams::CA_HCDPD::DIN', 9740);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robaximol Inj 100mg/Ml', 'liquid', 'M03BA03', false, 0, '00783978', 'FreeDiams::CA_HCDPD::DIN', 9776);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Docusate Sodium Capsule 100mg Usp', 'capsule', 'A06AA02', false, 0, '00794406', 'FreeDiams::CA_HCDPD::DIN', 9782);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humulin 30/70 (Insulin Human Biosynth Inj)', 'suspension', 'A10AD01', false, 0, '00795879', 'FreeDiams::CA_HCDPD::DIN', 9788);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Lock Flush Solution Injection Usp', 'solution', 'B01AB01', false, 0, '00725323', 'FreeDiams::CA_HCDPD::DIN', 9790);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Lock Flush Solution Injection Usp', 'solution', 'B01AB01', false, 0, '00725315', 'FreeDiams::CA_HCDPD::DIN', 9791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine 1.5% W Epinephrine 1:200000 Test Dose', 'liquid', 'N01BB52', false, 0, '00753149', 'FreeDiams::CA_HCDPD::DIN', 9802);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quattro Liq', 'liquid', 'V07AV', false, 0, '02089718', 'FreeDiams::CA_HCDPD::DIN', 15972);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Docusate Sodium Syrup 4mg/Ml', 'syrup', 'A06AA02', false, 0, '00779105', 'FreeDiams::CA_HCDPD::DIN', 9812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doxycin Cap 100mg', 'capsule', 'J01AA02', false, 0, '00817120', 'FreeDiams::CA_HCDPD::DIN', 9814);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ak-Rose Liq 1%', 'liquid', 'S01JA02', false, 0, '00832170', 'FreeDiams::CA_HCDPD::DIN', 9819);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Refresh Lacri-Lube', 'ointment', 'S01XA20', false, 0, '00210889', 'FreeDiams::CA_HCDPD::DIN', 9820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epquat Disinfectant Sanitizer Fungicide Deodorizer', 'liquid', 'V07AV', false, 0, '00799394', 'FreeDiams::CA_HCDPD::DIN', 9822);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Losec Capsules 20mg', 'capsule (delayed release)', 'A02BC01', false, 0, '00846503', 'FreeDiams::CA_HCDPD::DIN', 9823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexidin 20 Sol 20mg', 'liquid', 'D08AC02', false, 0, '00832030', 'FreeDiams::CA_HCDPD::DIN', 9824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride Liq Irigation 900mg/100ml Usp', 'liquid', 'B05CB01', false, 0, '00786160', 'FreeDiams::CA_HCDPD::DIN', 9825);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potass Chlorid 20meq In 0.9% Sod Chloride Inj', 'liquid', 'B05BB01', false, 0, '00786209', 'FreeDiams::CA_HCDPD::DIN', 9826);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potass Chlorid 40meq In 0.9% Sod Chlorid Inj', 'liquid', 'B05BB01', false, 0, '00786217', 'FreeDiams::CA_HCDPD::DIN', 9827);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glycine 1.5% Irrigation Usp Sol', 'liquid', 'B05CX03', false, 0, '00799955', 'FreeDiams::CA_HCDPD::DIN', 9828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cystosol W 3% Hexitols', 'liquid', 'B05CX10', false, 0, '00799963', 'FreeDiams::CA_HCDPD::DIN', 9829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lactated Ringer''S Irrigation Sol', 'liquid', 'B05CB10', false, 0, '00799971', 'FreeDiams::CA_HCDPD::DIN', 9830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Water For Irrigation', 'liquid', 'V07AB', false, 0, '00799998', 'FreeDiams::CA_HCDPD::DIN', 9831);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multiple Electrolyte Additive Liq Formula 1', 'liquid', 'B05BB01', false, 0, '00809551', 'FreeDiams::CA_HCDPD::DIN', 9833);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12186', 'solution', 'B05ZA', false, 0, '00860425', 'FreeDiams::CA_HCDPD::DIN', 9845);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12203', 'solution', 'B05ZA', false, 0, '00860468', 'FreeDiams::CA_HCDPD::DIN', 9848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12201', 'solution', 'B05ZA', false, 0, '00860565', 'FreeDiams::CA_HCDPD::DIN', 9852);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12188', 'solution', 'B05ZA', false, 0, '00860611', 'FreeDiams::CA_HCDPD::DIN', 9854);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Transderm-Nitro 0.2', 'patch (extended release)', 'C01DA02', false, 0, '00584223', 'FreeDiams::CA_HCDPD::DIN', 9858);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ddavp Spray', 'metered-dose (aerosol)', 'H01BA02', false, 0, '00836362', 'FreeDiams::CA_HCDPD::DIN', 9861);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Metoprolol', 'tablet', 'C07AB02', false, 0, '00842648', 'FreeDiams::CA_HCDPD::DIN', 9886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Metoprolol', 'tablet', 'C07AB02', false, 0, '00842656', 'FreeDiams::CA_HCDPD::DIN', 9887);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diclofenac Ec', 'tablet (enteric-coated)', 'M01AB05', false, 0, '00808539', 'FreeDiams::CA_HCDPD::DIN', 9888);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diclofenac Ec', 'tablet (enteric-coated)', 'M01AB05', false, 0, '00808547', 'FreeDiams::CA_HCDPD::DIN', 9889);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Ranitidine', 'tablet', 'A02BA02', false, 0, '00828556', 'FreeDiams::CA_HCDPD::DIN', 9890);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Ranitidine', 'tablet', 'A02BA02', false, 0, '00828564', 'FreeDiams::CA_HCDPD::DIN', 9891);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cotazym Ecs 20', 'capsule', 'A09AA02', false, 0, '00821373', 'FreeDiams::CA_HCDPD::DIN', 9892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nadolol-80 Tab 80mg', 'tablet', 'C07AA12', false, 0, '00818704', 'FreeDiams::CA_HCDPD::DIN', 9897);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nadolol-160 Tab 160mg', 'tablet', 'C07AA12', false, 0, '00818720', 'FreeDiams::CA_HCDPD::DIN', 9898);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pindolol-5 Tab 5mg', 'tablet', 'C07AA03', false, 0, '00828416', 'FreeDiams::CA_HCDPD::DIN', 9899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pindolol-10 Tab 10mg', 'tablet', 'C07AA03', false, 0, '00828424', 'FreeDiams::CA_HCDPD::DIN', 9900);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pindolol-15 Tab 15mg', 'tablet', 'C07AA03', false, 0, '00828432', 'FreeDiams::CA_HCDPD::DIN', 9901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diltiazem-60 Tab 60mg', 'tablet', 'C08DB01', false, 0, '00828777', 'FreeDiams::CA_HCDPD::DIN', 9902);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diltiazem-30 Tab 30mg', 'tablet', 'C08DB01', false, 0, '00828785', 'FreeDiams::CA_HCDPD::DIN', 9903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atenolol-100 Tab 100mg', 'tablet', 'C07AB03', false, 0, '00828793', 'FreeDiams::CA_HCDPD::DIN', 9904);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atenolol-50 Tab 50mg', 'tablet', 'C07AB03', false, 0, '00828807', 'FreeDiams::CA_HCDPD::DIN', 9905);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nadolol-40 Tab 40mg', 'tablet', 'C07AA12', false, 0, '00828815', 'FreeDiams::CA_HCDPD::DIN', 9906);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cephalexin Tab 250mg', 'tablet', 'J01DB01', false, 0, '00828858', 'FreeDiams::CA_HCDPD::DIN', 9907);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cephalexin Tab 500mg', 'tablet', 'J01DB01', false, 0, '00828866', 'FreeDiams::CA_HCDPD::DIN', 9908);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Metronidazole', 'capsule', 'J01XD01', false, 0, '00783137', 'FreeDiams::CA_HCDPD::DIN', 9910);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandostatin 50mcg/Ml', 'solution', 'H01CB02', false, 0, '00839191', 'FreeDiams::CA_HCDPD::DIN', 9915);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandostatin 100mcg/Ml', 'solution', 'H01CB02', false, 0, '00839205', 'FreeDiams::CA_HCDPD::DIN', 9916);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandostatin 500mcg/Ml', 'solution', 'H01CB02', false, 0, '00839213', 'FreeDiams::CA_HCDPD::DIN', 9917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Prochlorperazine', 'suppository', 'N05AB04', false, 0, '00789720', 'FreeDiams::CA_HCDPD::DIN', 9919);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prochlorperazine Mesylate Inj 5mg/Ml', 'liquid', 'N05AB04', false, 0, '00789747', 'FreeDiams::CA_HCDPD::DIN', 9920);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clotrimaderm Vag Cream 1%', 'cream', 'G01AF02', false, 0, '00812366', 'FreeDiams::CA_HCDPD::DIN', 9926);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clotrimaderm Vag Cream 2%', 'cream', 'G01AF02', false, 0, '00812374', 'FreeDiams::CA_HCDPD::DIN', 9927);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prevex Hc Cream 1%', 'cream', 'D07AA02', false, 0, '00804533', 'FreeDiams::CA_HCDPD::DIN', 9928);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prevex B Cream 0.1%', 'cream', 'D07AC01', false, 0, '00804541', 'FreeDiams::CA_HCDPD::DIN', 9929);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nifedipine', 'capsule', 'C08CA05', false, 0, '00725110', 'FreeDiams::CA_HCDPD::DIN', 9938);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Erythro E-C Cap 250mg', 'capsule (enteric-coated)', 'J01FA01', false, 0, '00726672', 'FreeDiams::CA_HCDPD::DIN', 9939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Verap Tablet 120mg', 'tablet', 'C08DA01', false, 0, '00782491', 'FreeDiams::CA_HCDPD::DIN', 9940);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Salvent Aem 100mcg', 'metered-dose (aerosol)', 'R03AC02', false, 0, '00790419', 'FreeDiams::CA_HCDPD::DIN', 9941);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Voltaren Sr 75 Tab', 'tablet (extended-release)', 'M01AB05', false, 0, '00782459', 'FreeDiams::CA_HCDPD::DIN', 9943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Prochlorperazine Inj 5mg/Ml', 'solution', 'N05AB04', false, 0, '00753645', 'FreeDiams::CA_HCDPD::DIN', 9972);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Nystatin Suspension 100000 Unit/Ml', 'suspension', 'A07AA02', false, 0, '00792667', 'FreeDiams::CA_HCDPD::DIN', 9973);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin C', 'liquid', 'A11GA01', false, 0, '00780634', 'FreeDiams::CA_HCDPD::DIN', 9992);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin K1 Inj 1mg/0.5ml Usp', 'emulsion', 'B02BA01', false, 0, '00781878', 'FreeDiams::CA_HCDPD::DIN', 9993);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin K1 Inj 10mg/Ml Usp', 'emulsion', 'B02BA01', false, 0, '00804312', 'FreeDiams::CA_HCDPD::DIN', 9994);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imipramine', 'tablet', 'N06AA02', false, 0, '00644579', 'FreeDiams::CA_HCDPD::DIN', 10008);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dianeal Pd 101 Capd Solution W 2.5% Dextrose', 'solution', 'B05ZA', false, 0, '00799823', 'FreeDiams::CA_HCDPD::DIN', 10009);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Omnisan Liq', 'liquid', 'V07AV', false, 0, '00804304', 'FreeDiams::CA_HCDPD::DIN', 10010);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluorouracil Injection', 'solution', 'L01BC02', false, 0, '00012882', 'FreeDiams::CA_HCDPD::DIN', 10015);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doxycin Tab 100mg', 'tablet', 'J01AA02', false, 0, '00860751', 'FreeDiams::CA_HCDPD::DIN', 10024);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Optimyxin Oto/Opht Gtte', 'drops', 'S03AA30', false, 0, '00701785', 'FreeDiams::CA_HCDPD::DIN', 10025);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Haloperidol Inj 5mg/Ml Usp', 'liquid', 'N05AD01', false, 0, '00808652', 'FreeDiams::CA_HCDPD::DIN', 10026);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tears Naturale Ii Drop', 'drops', 'S01XA20', false, 0, '00743445', 'FreeDiams::CA_HCDPD::DIN', 10032);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Verap Tab 80mg', 'tablet', 'C08DA01', false, 0, '00782483', 'FreeDiams::CA_HCDPD::DIN', 10034);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Napro-Na Tab 275mg', 'tablet', 'M01AE02', false, 0, '00784354', 'FreeDiams::CA_HCDPD::DIN', 10035);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diclo Tab 25mg', 'tablet (enteric-coated)', 'M01AB05', false, 0, '00839175', 'FreeDiams::CA_HCDPD::DIN', 10036);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diclo Tab 50mg', 'tablet (enteric-coated)', 'M01AB05', false, 0, '00839183', 'FreeDiams::CA_HCDPD::DIN', 10037);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mepivicaine Hydrochloride Injection, Usp 3%', 'solution', 'N01BB03', false, 0, '00753130', 'FreeDiams::CA_HCDPD::DIN', 10038);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride 0.9% Inj 900mg/100ml Usp', 'liquid', 'B05XA03', false, 0, '00060208', 'FreeDiams::CA_HCDPD::DIN', 10040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potass Chloride 20meq In 5% Dextrose Inj Usp', 'liquid', 'B05BB02', false, 0, '00438049', 'FreeDiams::CA_HCDPD::DIN', 10041);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potass Chloride 40meq In 5% Dextrose Inj Usp', 'liquid', 'B05BB02', false, 0, '00438030', 'FreeDiams::CA_HCDPD::DIN', 10042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potass Chlor 20meq 5% Dex And 0.2% Sod Chlor', 'liquid', 'B05BB02', false, 0, '00503142', 'FreeDiams::CA_HCDPD::DIN', 10043);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potass Cl 2mmol/100ml+Dex 5%+0.45%Sod Cl', 'solution', 'B05BB02', false, 0, '00437999', 'FreeDiams::CA_HCDPD::DIN', 10044);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potass Chlor 40meq 5% Dex And 0.45% Sod Chlor', 'liquid', 'B05BB02', false, 0, '00438006', 'FreeDiams::CA_HCDPD::DIN', 10045);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pramox Hc Cream', 'cream', 'D07XA01', false, 0, '00770957', 'FreeDiams::CA_HCDPD::DIN', 10052);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm Syrup', 'syrup', 'R05DA09', false, 0, '00800813', 'FreeDiams::CA_HCDPD::DIN', 10054);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Optimyxin Plus Oto-Opht Gtte', 'drops', 'S03AA30', false, 0, '00807435', 'FreeDiams::CA_HCDPD::DIN', 10062);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin B1', 'solution', 'A11DA01', false, 0, '00816078', 'FreeDiams::CA_HCDPD::DIN', 10063);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylene Blue Injection Usp', 'solution', 'V03AB17', false, 0, '00816108', 'FreeDiams::CA_HCDPD::DIN', 10064);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Camphorated Para Chlorophenol Liq', 'liquid', 'A01AB11', false, 0, '00470171', 'FreeDiams::CA_HCDPD::DIN', 10065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate 2116', 'solution', 'B05ZA', false, 0, '00774936', 'FreeDiams::CA_HCDPD::DIN', 10114);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate 2117', 'solution', 'B05ZA', false, 0, '00774944', 'FreeDiams::CA_HCDPD::DIN', 10115);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Transderm-Nitro 0.4', 'patch (extended release)', 'C01DA02', false, 0, '00852384', 'FreeDiams::CA_HCDPD::DIN', 10116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Doxylin Cap 100mg', 'capsule', 'J01AA02', false, 0, '00725250', 'FreeDiams::CA_HCDPD::DIN', 10117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jaa Pyral 35 Tablet 35mg', 'tablet', 'P02CC01', false, 0, '00786047', 'FreeDiams::CA_HCDPD::DIN', 10128);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ketoprofen-E', 'tablet (enteric-coated)', 'M01AE03', false, 0, '00842664', 'FreeDiams::CA_HCDPD::DIN', 10134);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ketoprofen-E', 'tablet (enteric-coated)', 'M01AE03', false, 0, '00790435', 'FreeDiams::CA_HCDPD::DIN', 10135);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ketoprofen', 'capsule', 'M01AE03', false, 0, '00790427', 'FreeDiams::CA_HCDPD::DIN', 10136);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('X-Seb T Shampoo', 'shampoo', 'D05AA', false, 0, '00509906', 'FreeDiams::CA_HCDPD::DIN', 10141);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('P&S Plus', 'gel', 'D05AA', false, 0, '00560448', 'FreeDiams::CA_HCDPD::DIN', 10142);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dianeal Pd 101 Capd Solution W 4.25% Dextrose', 'solution', 'B05ZA', false, 0, '00799807', 'FreeDiams::CA_HCDPD::DIN', 10143);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dianeal Pd 101 Capd Solution W 1.5% Dextrose', 'liquid', 'B05ZA', false, 0, '00799815', 'FreeDiams::CA_HCDPD::DIN', 10144);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Blephamide Opht Suspension', 'drops', 'S01CA02', false, 0, '00807788', 'FreeDiams::CA_HCDPD::DIN', 10169);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dilaudid', 'liquid', 'N02AA03', false, 0, '00786535', 'FreeDiams::CA_HCDPD::DIN', 10173);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baxedin Liq 0.05%', 'liquid', 'D08AC02', false, 0, '00788422', 'FreeDiams::CA_HCDPD::DIN', 10177);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neo Citran Extra Strength Cold And Sinus', 'powder for solution', 'N02BE51', false, 0, '00843792', 'FreeDiams::CA_HCDPD::DIN', 10188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Asa Tab 325mg', 'tablet', 'N02BA01', false, 0, '00472468', 'FreeDiams::CA_HCDPD::DIN', 10200);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artritol Plus Fort Cap 500mg', 'capsule', 'N02BE01', false, 0, '00752061', 'FreeDiams::CA_HCDPD::DIN', 10205);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ranitidine', 'tablet', 'A02BA02', false, 0, '00828823', 'FreeDiams::CA_HCDPD::DIN', 10208);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diprolene', 'lotion', 'D07AC01', false, 0, '00862975', 'FreeDiams::CA_HCDPD::DIN', 10211);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stomaax Plus', 'suspension', 'A02AF02', false, 0, '00623709', 'FreeDiams::CA_HCDPD::DIN', 10217);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ibuprofen Tab 200mg', 'tablet', 'M01AE01', false, 0, '00441643', 'FreeDiams::CA_HCDPD::DIN', 10294);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Salinex Nasal Lubricant Gel', 'gel', 'R01AX30', false, 0, '00779296', 'FreeDiams::CA_HCDPD::DIN', 10299);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Folic Acid Injection Usp', 'liquid', 'B03BB01', false, 0, '00816086', 'FreeDiams::CA_HCDPD::DIN', 10312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('White Petroleum Jelly 100% Bp', 'cream', 'D02AC', false, 0, '00745790', 'FreeDiams::CA_HCDPD::DIN', 10314);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Docusate Calcium', 'capsule', 'A06AA02', false, 0, '00809055', 'FreeDiams::CA_HCDPD::DIN', 10316);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lupron Depot', 'powder for suspension, sustained-release', 'L02AE02', false, 0, '00836273', 'FreeDiams::CA_HCDPD::DIN', 10318);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Doxy Tabs 100mg', 'tablet', 'J01AA02', false, 0, '00874256', 'FreeDiams::CA_HCDPD::DIN', 10383);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ranitidine', 'tablet', 'A02BA02', false, 0, '00828688', 'FreeDiams::CA_HCDPD::DIN', 10390);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Salbutamol', 'solution', 'R03AC02', false, 0, '00860808', 'FreeDiams::CA_HCDPD::DIN', 10391);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topiderm Hc 2%', 'cream', 'D07AA02', false, 0, '00749834', 'FreeDiams::CA_HCDPD::DIN', 10393);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diltiazem', 'tablet', 'C08DB01', false, 0, '00862924', 'FreeDiams::CA_HCDPD::DIN', 10394);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diltiazem', 'tablet', 'C08DB01', false, 0, '00862932', 'FreeDiams::CA_HCDPD::DIN', 10395);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Methylphenidate Tablets 10mg', 'tablet', 'N06BA04', false, 0, '00584991', 'FreeDiams::CA_HCDPD::DIN', 10398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Methylphenidate Tablets 20mg', 'tablet', 'N06BA04', false, 0, '00585009', 'FreeDiams::CA_HCDPD::DIN', 10399);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Duoquat Liq', 'liquid', 'V07AV', false, 0, '00872989', 'FreeDiams::CA_HCDPD::DIN', 10425);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Airx 109 Super Concentrate Liq W.E. Greer', 'liquid', 'V07AV', false, 0, '00868736', 'FreeDiams::CA_HCDPD::DIN', 10429);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Supeudol 5', 'tablet', 'N02AA05', false, 0, '00789739', 'FreeDiams::CA_HCDPD::DIN', 10433);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nyaderm Oral Sus 100000unit/Ml Usp', 'suspension', 'A07AA02', false, 0, '00779121', 'FreeDiams::CA_HCDPD::DIN', 10435);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 5% And 0.2% Sod Chloride Inj', 'liquid', 'B05BB02', false, 0, '00060704', 'FreeDiams::CA_HCDPD::DIN', 10438);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 5% And 0.45% Sod Chloride Inj', 'liquid', 'B05BB02', false, 0, '00060739', 'FreeDiams::CA_HCDPD::DIN', 10439);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 5% And 0.9% Sod Chloride Inj', 'liquid', 'B05BB02', false, 0, '00060747', 'FreeDiams::CA_HCDPD::DIN', 10440);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 10% And 0.9% Sod Chloride Inj', 'solution', 'B05BB02', false, 0, '00060755', 'FreeDiams::CA_HCDPD::DIN', 10441);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride 0.45% Inj', 'liquid', 'B05XA03', false, 0, '00060186', 'FreeDiams::CA_HCDPD::DIN', 10442);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Acetaminophen Solution 32mg/Ml', 'solution', 'N02BE01', false, 0, '00792691', 'FreeDiams::CA_HCDPD::DIN', 10450);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Acetaminophen Solution 16mg/Ml', 'solution', 'N02BE01', false, 0, '00792713', 'FreeDiams::CA_HCDPD::DIN', 10451);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cosan #160 Disinfectant', 'liquid', 'V07AV', false, 0, '00792527', 'FreeDiams::CA_HCDPD::DIN', 10471);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Statex Dps 50mg/Ml', 'drops', 'N02AA01', false, 0, '00705799', 'FreeDiams::CA_HCDPD::DIN', 10485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diphenhydramine Elixir 2.5mg/Ml', 'elixir', 'R06AA02', false, 0, '00792705', 'FreeDiams::CA_HCDPD::DIN', 10486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Modecate Concentrate', 'liquid', 'N05AB02', false, 0, '00755575', 'FreeDiams::CA_HCDPD::DIN', 10488);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rinsol 9000 Disinfect', 'liquid', 'V07AV', false, 0, '00765236', 'FreeDiams::CA_HCDPD::DIN', 10490);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rinsol 4500 Disinfect', 'liquid', 'V07AV', false, 0, '00772682', 'FreeDiams::CA_HCDPD::DIN', 10491);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prepidil Gel', 'gel', 'G02AD02', false, 0, '00860786', 'FreeDiams::CA_HCDPD::DIN', 10492);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Amilzide Tab', 'tablet', 'C03EA01', false, 0, '00784400', 'FreeDiams::CA_HCDPD::DIN', 10494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intrepid Liq', 'liquid', 'V07AV', false, 0, '02089726', 'FreeDiams::CA_HCDPD::DIN', 15973);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Metoclop Tab 5mg', 'tablet', 'A03FA01', false, 0, '00842826', 'FreeDiams::CA_HCDPD::DIN', 10495);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Metoclop Tab 10mg', 'tablet', 'A03FA01', false, 0, '00842834', 'FreeDiams::CA_HCDPD::DIN', 10496);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anticoagulant Sod Citrate Soltn 4gm/100ml', 'solution', 'V07AC', false, 0, '00060313', 'FreeDiams::CA_HCDPD::DIN', 10497);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermacne Lotion Traitment 5%', 'lotion', 'D10AE01', false, 0, '00649635', 'FreeDiams::CA_HCDPD::DIN', 10498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermacne Nettoyant 0.51%', 'liquid', 'D08AE04', false, 0, '00649627', 'FreeDiams::CA_HCDPD::DIN', 10499);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermacne Savon 0.745%', 'soap bar', 'D08AE04', false, 0, '00682012', 'FreeDiams::CA_HCDPD::DIN', 10500);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Calax Cap 240mg', 'capsule', 'A06AA02', false, 0, '00806226', 'FreeDiams::CA_HCDPD::DIN', 10505);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hexit Shampoo 1.0%', 'shampoo', 'P03AB02', false, 0, '00430617', 'FreeDiams::CA_HCDPD::DIN', 10506);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Phosphates', 'liquid', 'B05XA06', false, 0, '00804789', 'FreeDiams::CA_HCDPD::DIN', 10509);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 5% Inj 5gm/100ml Usp', 'liquid', 'B05BA03', false, 0, '00060348', 'FreeDiams::CA_HCDPD::DIN', 10511);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dianeal Pd 101 Capd Solution W 0.5% Dextrose', 'solution', 'B05ZA', false, 0, '00799793', 'FreeDiams::CA_HCDPD::DIN', 10512);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 3.3% And 0.3% Sod Chloride Inj', 'liquid', 'B05BB02', false, 0, '00060712', 'FreeDiams::CA_HCDPD::DIN', 10515);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Osmitrol 20% Inj Usp', 'solution', 'B05BC01', false, 0, '00060437', 'FreeDiams::CA_HCDPD::DIN', 10516);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Osmitrol 10% Inj Usp', 'liquid', 'B05BC01', false, 0, '00060410', 'FreeDiams::CA_HCDPD::DIN', 10517);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidocaine Hcl 0.2% And Dextrose 5% Inj', 'solution', 'C01BB01', false, 0, '00828599', 'FreeDiams::CA_HCDPD::DIN', 10518);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidocaine Hcl 0.4% And 5% Dextrose Inj', 'solution', 'C01BB01', false, 0, '00828602', 'FreeDiams::CA_HCDPD::DIN', 10519);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidocaine Hcl 0.8% And 5% Dextrose Inj', 'solution', 'C01BB01', false, 0, '00828610', 'FreeDiams::CA_HCDPD::DIN', 10520);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Sod And 0.9% Sod Chloride Inj', 'solution', 'B01AB51', false, 0, '00828750', 'FreeDiams::CA_HCDPD::DIN', 10521);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Suprax', 'powder for suspension', 'J01DD08', false, 0, '00868965', 'FreeDiams::CA_HCDPD::DIN', 10523);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Suprax', 'tablet', 'J01DD08', false, 0, '00868981', 'FreeDiams::CA_HCDPD::DIN', 10525);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Leo Inj 1000unit/Ml', 'liquid', 'B01AB01', false, 0, '00453811', 'FreeDiams::CA_HCDPD::DIN', 10526);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Claritin Tab 10mg', 'tablet', 'R06AX13', false, 0, '00782696', 'FreeDiams::CA_HCDPD::DIN', 10533);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Sulfatrim Oral Sus', 'suspension', 'J01EE01', false, 0, '00846465', 'FreeDiams::CA_HCDPD::DIN', 10535);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceclor', 'powder for suspension', 'J01DC04', false, 0, '00832804', 'FreeDiams::CA_HCDPD::DIN', 10545);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cetrimide Tincture 0.5%', 'tincture', 'D08AJ02', false, 0, '00873195', 'FreeDiams::CA_HCDPD::DIN', 10565);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mestinon Tab 60mg Usp', 'tablet', 'N07AA02', false, 0, '00869961', 'FreeDiams::CA_HCDPD::DIN', 10567);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Docusate Calcium Cap 240mg', 'capsule', 'A06AA02', false, 0, '00842044', 'FreeDiams::CA_HCDPD::DIN', 10569);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Docusate Sodium', 'syrup', 'A06AA02', false, 0, '00848417', 'FreeDiams::CA_HCDPD::DIN', 10575);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tetracycline 1% Onguent Ophthalmic', 'ointment', 'S01AA09', false, 0, '00792594', 'FreeDiams::CA_HCDPD::DIN', 10602);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Tamox Tab 10mg', 'tablet', 'L02BA01', false, 0, '00812404', 'FreeDiams::CA_HCDPD::DIN', 10664);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bricanyl Turbuhaler 0.5 Mg/Aem', 'kit', 'R03AC03', false, 0, '00786616', 'FreeDiams::CA_HCDPD::DIN', 10665);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pulmicort Turbuhaler 200 Mcg/Dose', 'kit', 'R03BA02', false, 0, '00851752', 'FreeDiams::CA_HCDPD::DIN', 10666);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pulmicort Turbuhaler 100 Mcg/Dose', 'kit', 'R03BA02', false, 0, '00852074', 'FreeDiams::CA_HCDPD::DIN', 10667);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexidin Liq 4%', 'liquid', 'D08AC02', false, 0, '00832111', 'FreeDiams::CA_HCDPD::DIN', 10668);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexidin 2 Detergent', 'liquid', 'D08AC02', false, 0, '00832138', 'FreeDiams::CA_HCDPD::DIN', 10669);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('X-Seb Plus Conditioning Shampoo', 'shampoo', 'D11AC30', false, 0, '00866598', 'FreeDiams::CA_HCDPD::DIN', 10673);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('X-Seb T Plus Conditioning Shampoo', 'shampoo', 'D05AA', false, 0, '00866601', 'FreeDiams::CA_HCDPD::DIN', 10674);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jack & Jill Children''S Formula Cough Liquid', 'liquid', 'R05DA20', false, 0, '00823023', 'FreeDiams::CA_HCDPD::DIN', 10675);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pine-A-Bac Liquid', 'liquid', 'V07AV', false, 0, '00888001', 'FreeDiams::CA_HCDPD::DIN', 10686);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitroject Inj 1mg/Ml', 'liquid', 'C01DA02', false, 0, '00614262', 'FreeDiams::CA_HCDPD::DIN', 10705);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitroject Inj 5mg/Ml', 'liquid', 'C01DA02', false, 0, '00778869', 'FreeDiams::CA_HCDPD::DIN', 10706);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eryc Delayed-Release Capsules', 'capsule (enteric-coated)', 'J01FA01', false, 0, '00873454', 'FreeDiams::CA_HCDPD::DIN', 10707);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Bethanechol Chloride Tab 25mg', 'tablet', 'N07AB02', false, 0, '00739162', 'FreeDiams::CA_HCDPD::DIN', 10708);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Bethanechol Chloride Tab 10mg', 'tablet', 'N07AB02', false, 0, '00759171', 'FreeDiams::CA_HCDPD::DIN', 10709);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Bethanechol Chloride Tab 50mg', 'tablet', 'N07AB02', false, 0, '00759198', 'FreeDiams::CA_HCDPD::DIN', 10710);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asa Suppositories 150mg', 'suppository', 'N02BA01', false, 0, '00785547', 'FreeDiams::CA_HCDPD::DIN', 10711);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asa Suppositories 650mg', 'suppository', 'N02BA01', false, 0, '00582867', 'FreeDiams::CA_HCDPD::DIN', 10712);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Benztropine Tab 0.5mg', 'tablet', 'N04AC01', false, 0, '00885452', 'FreeDiams::CA_HCDPD::DIN', 10713);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lotriderm Cream', 'cream', 'D01AC20', false, 0, '00611174', 'FreeDiams::CA_HCDPD::DIN', 10748);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Gentamicin', 'ointment', 'D06AX07', false, 0, '00805025', 'FreeDiams::CA_HCDPD::DIN', 10751);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Gentamicin', 'cream', 'D06AX07', false, 0, '00805386', 'FreeDiams::CA_HCDPD::DIN', 10752);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Tamox Tab 20mg', 'tablet', 'L02BA01', false, 0, '00812390', 'FreeDiams::CA_HCDPD::DIN', 10762);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baxedin Liq 20%', 'liquid', 'D08AC02', false, 0, '00658413', 'FreeDiams::CA_HCDPD::DIN', 10767);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Calciject Inj 100mg/Ml', 'liquid', 'B05XA07', false, 0, '00821780', 'FreeDiams::CA_HCDPD::DIN', 10770);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diclofenac Ect 50mg', 'tablet (enteric-coated)', 'M01AB05', false, 0, '00870978', 'FreeDiams::CA_HCDPD::DIN', 10772);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Tamoxifen', 'tablet', 'L02BA01', false, 0, '00851965', 'FreeDiams::CA_HCDPD::DIN', 10790);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Tamoxifen', 'tablet', 'L02BA01', false, 0, '00851973', 'FreeDiams::CA_HCDPD::DIN', 10791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ami-Hydro Tab', 'tablet', 'C03EA01', false, 0, '00870943', 'FreeDiams::CA_HCDPD::DIN', 10806);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Verapamil Tab 80mg', 'tablet', 'C08DA01', false, 0, '00871028', 'FreeDiams::CA_HCDPD::DIN', 10807);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12207', 'solution', 'B05ZA', false, 0, '00890197', 'FreeDiams::CA_HCDPD::DIN', 10820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Prazo Tab 1mg', 'tablet', 'C02CA01', false, 0, '00882801', 'FreeDiams::CA_HCDPD::DIN', 10828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Prazo Tab 2mg', 'tablet', 'C02CA01', false, 0, '00882828', 'FreeDiams::CA_HCDPD::DIN', 10829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Prazo Tab 5mg', 'tablet', 'C02CA01', false, 0, '00882836', 'FreeDiams::CA_HCDPD::DIN', 10830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zaditen', 'tablet', 'R06AX17', false, 0, '00577308', 'FreeDiams::CA_HCDPD::DIN', 10832);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euglucon', 'tablet', 'A10BB01', false, 0, '00720941', 'FreeDiams::CA_HCDPD::DIN', 10834);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sarna Hc', 'lotion', 'D07AA02', false, 0, '00856711', 'FreeDiams::CA_HCDPD::DIN', 10844);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zaditen', 'syrup', 'R06AX17', false, 0, '00600784', 'FreeDiams::CA_HCDPD::DIN', 10860);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lactate Chloride Dextrose Inj', 'liquid', 'B05BB02', false, 0, '00060976', 'FreeDiams::CA_HCDPD::DIN', 10861);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ringer''S Inj', 'liquid', 'B05BB01', false, 0, '00060925', 'FreeDiams::CA_HCDPD::DIN', 10862);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dianeal Pd4 Capd Solution With 1.5% Dextrose And 2.5meq/L Calcium', 'solution', 'B05ZA', false, 0, '00865095', 'FreeDiams::CA_HCDPD::DIN', 10863);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alcavis 100', 'solution', 'V07AV', false, 0, '02048035', 'FreeDiams::CA_HCDPD::DIN', 16020);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dianeal Pd4 Capd Solution With 2.5% Dextrose And 2.5meq/L Calcium', 'solution', 'B05ZA', false, 0, '00865109', 'FreeDiams::CA_HCDPD::DIN', 10864);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dianeal Pd4 Capd Solution With 4.25% Dextrose And 2.5meq/L Calcium', 'solution', 'B05ZA', false, 0, '00865117', 'FreeDiams::CA_HCDPD::DIN', 10865);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potass Chlor 20meq 5% Dex And 0.9% Sod Chlor', 'solution', 'B05BB02', false, 0, '00786292', 'FreeDiams::CA_HCDPD::DIN', 10866);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potass Chlor 40meq 5% Dex And 0.9% Sod Chlor', 'solution', 'B05BB02', false, 0, '00786306', 'FreeDiams::CA_HCDPD::DIN', 10867);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metronidazole 5 Mg/Ml Injection', 'liquid', 'J01XD01', false, 0, '00870420', 'FreeDiams::CA_HCDPD::DIN', 10871);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Iocide', 'liquid', 'D08AG', false, 0, '00778001', 'FreeDiams::CA_HCDPD::DIN', 10873);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diphenhydramine Cap 25mg', 'capsule', 'R06AA02', false, 0, '00757683', 'FreeDiams::CA_HCDPD::DIN', 10874);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diphenhydramine Cap 50mg', 'capsule', 'R06AA02', false, 0, '00757691', 'FreeDiams::CA_HCDPD::DIN', 10875);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Neostigmine Methylsulfate Inj 0.5mg/Ml', 'liquid', 'N07AA01', false, 0, '00868906', 'FreeDiams::CA_HCDPD::DIN', 10876);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Neostigmine Methylsulfate Inj 1mg/Ml', 'liquid', 'N07AA01', false, 0, '00868930', 'FreeDiams::CA_HCDPD::DIN', 10877);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Docusate Sodium Drops 10mg/Ml', 'drops', 'A06AA02', false, 0, '00880140', 'FreeDiams::CA_HCDPD::DIN', 10878);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Congest Tab 2.5mg', 'tablet', 'G03CA57', false, 0, '00830208', 'FreeDiams::CA_HCDPD::DIN', 10883);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Congest Tab 1.25mg', 'tablet', 'G03CA57', false, 0, '00830216', 'FreeDiams::CA_HCDPD::DIN', 10884);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Congest Tab 0.9mg', 'tablet', 'G03CA57', false, 0, '00830224', 'FreeDiams::CA_HCDPD::DIN', 10885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Congest Tab 0.625mg', 'tablet', 'G03CA57', false, 0, '00830232', 'FreeDiams::CA_HCDPD::DIN', 10886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Congest Tab 0.3mg', 'tablet', 'G03CA57', false, 0, '00830240', 'FreeDiams::CA_HCDPD::DIN', 10887);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doxytab 100mg', 'tablet', 'J01AA02', false, 0, '00887064', 'FreeDiams::CA_HCDPD::DIN', 10897);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clorazepate', 'capsule', 'N05BA05', false, 0, '00860697', 'FreeDiams::CA_HCDPD::DIN', 10899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Capto Tab 100mg', 'tablet', 'C09AA01', false, 0, '00893625', 'FreeDiams::CA_HCDPD::DIN', 10900);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clorazepate', 'capsule', 'N05BA05', false, 0, '00860689', 'FreeDiams::CA_HCDPD::DIN', 10902);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clorazepate', 'capsule', 'N05BA05', false, 0, '00860700', 'FreeDiams::CA_HCDPD::DIN', 10903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Alpraz Tab 0.25mg', 'tablet', 'N05BA12', false, 0, '00865397', 'FreeDiams::CA_HCDPD::DIN', 10904);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Alpraz Tab 0.5mg', 'tablet', 'N05BA12', false, 0, '00865400', 'FreeDiams::CA_HCDPD::DIN', 10905);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Capto Tab 12.5mg', 'tablet', 'C09AA01', false, 0, '00893595', 'FreeDiams::CA_HCDPD::DIN', 10906);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Capto Tab 25mg', 'tablet', 'C09AA01', false, 0, '00893609', 'FreeDiams::CA_HCDPD::DIN', 10907);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Capto Tab 50mg', 'tablet', 'C09AA01', false, 0, '00893617', 'FreeDiams::CA_HCDPD::DIN', 10908);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clonidine Tab 0.1mg', 'tablet', 'C02AC01', false, 0, '00868949', 'FreeDiams::CA_HCDPD::DIN', 10909);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clonidine Tab 0.2mg', 'tablet', 'C02AC01', false, 0, '00868957', 'FreeDiams::CA_HCDPD::DIN', 10910);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidomyxin', 'liquid', 'S02AA30', false, 0, '00874949', 'FreeDiams::CA_HCDPD::DIN', 10912);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vaseretic', 'tablet', 'C09BA02', false, 0, '00657298', 'FreeDiams::CA_HCDPD::DIN', 10913);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diamicron Tab 80mg', 'tablet', 'A10BB09', false, 0, '00765996', 'FreeDiams::CA_HCDPD::DIN', 10918);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alcohol 5% And Dextrose 5% Inj Usp', 'solution', 'B05BA03', false, 0, '00060879', 'FreeDiams::CA_HCDPD::DIN', 10924);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 2.5% And Sod Chloride 0.45% Inj Usp', 'solution', 'B05BB02', false, 0, '00060720', 'FreeDiams::CA_HCDPD::DIN', 10925);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 5% And Sod Chloride 0.33% Inj Usp', 'solution', 'B05BB02', false, 0, '00786179', 'FreeDiams::CA_HCDPD::DIN', 10926);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potass Chloride 10meq In 5% Dextrose Inj Usp', 'solution', 'B05BB02', false, 0, '00786187', 'FreeDiams::CA_HCDPD::DIN', 10927);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potass Chloride 30meq In 5% Dextrose Inj Usp', 'solution', 'B05BB02', false, 0, '00786195', 'FreeDiams::CA_HCDPD::DIN', 10928);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potass Chlor 10meq 5% Dex And 0.2% Sod Chlor', 'solution', 'B05BB02', false, 0, '00786225', 'FreeDiams::CA_HCDPD::DIN', 10929);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potas Chlor 30meq 5% Dex And 0.2% Sod Chlor', 'solution', 'B05BB02', false, 0, '00786233', 'FreeDiams::CA_HCDPD::DIN', 10930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potass Chlor 40meq 5% Dex And 0.2% Sod Chlor', 'solution', 'B05BB02', false, 0, '00503150', 'FreeDiams::CA_HCDPD::DIN', 10931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium 20meq 5% Dextrose And 0.33% Sodium Chloride', 'solution', 'B05BB02', false, 0, '00786241', 'FreeDiams::CA_HCDPD::DIN', 10932);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potass Chlor 30meq 5% Dex And 0.33% Sod Chlor', 'solution', 'B05BB02', false, 0, '00786268', 'FreeDiams::CA_HCDPD::DIN', 10933);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potass Chlor 40meq 5% Dex And 0.33% Sod Chlor', 'solution', 'B05BB02', false, 0, '00786276', 'FreeDiams::CA_HCDPD::DIN', 10934);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potass Chlor 30meq 5% Dex And 0.45% Sod Chlor', 'solution', 'B05BB02', false, 0, '00786284', 'FreeDiams::CA_HCDPD::DIN', 10935);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potas Chlor 20meq 5% Dex And Lactate Ringer', 'solution', 'B05BB02', false, 0, '00786314', 'FreeDiams::CA_HCDPD::DIN', 10936);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Chlor 40meq 5% Dex & Lac Ring', 'solution', 'B05BB02', false, 0, '00786322', 'FreeDiams::CA_HCDPD::DIN', 10937);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potass Chloride 5% Dextr 0.45% Sod Chlor Inj', 'solution', 'B05BB02', false, 0, '00790109', 'FreeDiams::CA_HCDPD::DIN', 10938);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tis-U-Sol Solution', 'liquid', 'B05CB10', false, 0, '00800007', 'FreeDiams::CA_HCDPD::DIN', 10939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Topilene', 'ointment', 'D07AC01', false, 0, '00849669', 'FreeDiams::CA_HCDPD::DIN', 10940);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Topisone', 'lotion', 'D07AC01', false, 0, '00809187', 'FreeDiams::CA_HCDPD::DIN', 10941);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zocor', 'tablet', 'C10AA01', false, 0, '00884332', 'FreeDiams::CA_HCDPD::DIN', 10947);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pindol Tab 5mg', 'tablet', 'C07AA03', false, 0, '00869007', 'FreeDiams::CA_HCDPD::DIN', 10949);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pindol Tab 10mg', 'tablet', 'C07AA03', false, 0, '00869015', 'FreeDiams::CA_HCDPD::DIN', 10950);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pindol Tab 15mg', 'tablet', 'C07AA03', false, 0, '00869023', 'FreeDiams::CA_HCDPD::DIN', 10951);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diflucan Tab 50mg', 'tablet', 'J02AC01', false, 0, '00891800', 'FreeDiams::CA_HCDPD::DIN', 10952);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diflucan Tab 100mg', 'tablet', 'J02AC01', false, 0, '00891819', 'FreeDiams::CA_HCDPD::DIN', 10953);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diflucan Inj 2mg/Ml', 'liquid', 'J02AC01', false, 0, '00891835', 'FreeDiams::CA_HCDPD::DIN', 10954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tobradex Oph Ointment', 'ointment', 'S01CA01', false, 0, '00778915', 'FreeDiams::CA_HCDPD::DIN', 10971);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Docusate Sodium Cap 200mg', 'capsule', 'A06AA02', false, 0, '00765104', 'FreeDiams::CA_HCDPD::DIN', 10975);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Chloral Hydrate Syrup 100mg/Ml', 'syrup', 'N05CC01', false, 0, '00792659', 'FreeDiams::CA_HCDPD::DIN', 10976);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lidocaine Viscous 2%', 'liquid', 'N01BB02', false, 0, '00811874', 'FreeDiams::CA_HCDPD::DIN', 10977);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Docusate Sodium', 'capsule', 'A06AA02', false, 0, '00870196', 'FreeDiams::CA_HCDPD::DIN', 10986);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Gentamicin Ointment 1mg/Gm', 'ointment', 'D06AX07', false, 0, '00872881', 'FreeDiams::CA_HCDPD::DIN', 10995);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Z-Plus Shampoo', 'shampoo', 'D11AX12', false, 0, '00800686', 'FreeDiams::CA_HCDPD::DIN', 10999);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Expectorant Syrup   -(100mg/5ml)', 'syrup', 'R05CA03', false, 0, '00800821', 'FreeDiams::CA_HCDPD::DIN', 11001);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Dexamethasone Sod Phosphate Inj 10mg/Ml', 'liquid', 'H02AB02', false, 0, '00783900', 'FreeDiams::CA_HCDPD::DIN', 11011);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Entrophen Ect 500mg', 'tablet (enteric-coated)', 'N02BA01', false, 0, '00852015', 'FreeDiams::CA_HCDPD::DIN', 11025);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sedatuss Dm Sirop 15mg/5ml', 'syrup', 'R05DA09', false, 0, '00511021', 'FreeDiams::CA_HCDPD::DIN', 11027);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Docusate Sodium Cap 100mg Usp', 'capsule', 'A06AA02', false, 0, '00830267', 'FreeDiams::CA_HCDPD::DIN', 11028);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravachol - Tab 10mg', 'tablet', 'C10AA03', false, 0, '00893749', 'FreeDiams::CA_HCDPD::DIN', 11029);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravachol - Tab 20mg', 'tablet', 'C10AA03', false, 0, '00893757', 'FreeDiams::CA_HCDPD::DIN', 11030);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Dipyridamole-Fc Tab 25mg', 'tablet', 'B01AC07', false, 0, '00895644', 'FreeDiams::CA_HCDPD::DIN', 11034);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Dipyridamole-Fc Tab 50mg', 'tablet', 'B01AC07', false, 0, '00895652', 'FreeDiams::CA_HCDPD::DIN', 11035);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Dipyridamole-Fc Tab 75mg', 'tablet', 'B01AC07', false, 0, '00895660', 'FreeDiams::CA_HCDPD::DIN', 11036);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Plasma-Lyte 56 5% Dextrose Inj', 'liquid', 'B05BB02', false, 0, '00260584', 'FreeDiams::CA_HCDPD::DIN', 11038);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride 3% Inj', 'solution', 'B05XA03', false, 0, '00060232', 'FreeDiams::CA_HCDPD::DIN', 11039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride 5% Inj', 'solution', 'B05XA03', false, 0, '00060240', 'FreeDiams::CA_HCDPD::DIN', 11040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Tylenol Cold And Cough', 'tablet', 'N02BE51', false, 0, '00870455', 'FreeDiams::CA_HCDPD::DIN', 11041);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Hydralazine Tablets 10mg', 'tablet', 'C02DB02', false, 0, '00441619', 'FreeDiams::CA_HCDPD::DIN', 11047);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbon Dioxide 7.1% W Oxygen', 'gas', 'V03AN', false, 0, '00882755', 'FreeDiams::CA_HCDPD::DIN', 11058);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbon Dioxide 12.1% W Oxygen', 'gas', 'V03AN', false, 0, '00882763', 'FreeDiams::CA_HCDPD::DIN', 11059);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbon Dioxide 23.1% W Oxygen', 'gas', 'V03AN', false, 0, '00882771', 'FreeDiams::CA_HCDPD::DIN', 11060);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Gentamicin Cream 1mg/Gm', 'cream', 'D06AX07', false, 0, '00872873', 'FreeDiams::CA_HCDPD::DIN', 11062);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Acetaminophen Solution 80mg/Ml', 'solution', 'N02BE01', false, 0, '00887587', 'FreeDiams::CA_HCDPD::DIN', 11063);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('A.C. & C 8mg Tab', 'tablet', 'N02BA51', false, 0, '00180041', 'FreeDiams::CA_HCDPD::DIN', 11065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triosan Deodorizing Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '00887374', 'FreeDiams::CA_HCDPD::DIN', 11066);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tobradex Oph Sus', 'suspension', 'S01CA01', false, 0, '00778907', 'FreeDiams::CA_HCDPD::DIN', 11068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neostigmine Methylsulfate Injection Usp', 'liquid', 'N07AA01', false, 0, '00874957', 'FreeDiams::CA_HCDPD::DIN', 11095);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ephedrine Sulfate Injection Usp', 'liquid', 'R03CA02', false, 0, '00876534', 'FreeDiams::CA_HCDPD::DIN', 11096);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mevacor', 'tablet', 'C10AA02', false, 0, '00795852', 'FreeDiams::CA_HCDPD::DIN', 11100);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prinivil', 'tablet', 'C09AA03', false, 0, '00839388', 'FreeDiams::CA_HCDPD::DIN', 11101);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prinivil', 'tablet', 'C09AA03', false, 0, '00839396', 'FreeDiams::CA_HCDPD::DIN', 11102);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prinivil', 'tablet', 'C09AA03', false, 0, '00839418', 'FreeDiams::CA_HCDPD::DIN', 11103);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Glyburide', 'tablet', 'A10BB01', false, 0, '01900935', 'FreeDiams::CA_HCDPD::DIN', 11120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Glyburide', 'tablet', 'A10BB01', false, 0, '01900927', 'FreeDiams::CA_HCDPD::DIN', 11122);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Opium And Belladona Sup', 'suppository', 'A07DA02', false, 0, '00815349', 'FreeDiams::CA_HCDPD::DIN', 11124);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neostigmine Methylsulfate Injection Usp', 'liquid', 'N07AA01', false, 0, '00885282', 'FreeDiams::CA_HCDPD::DIN', 11131);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eye Drops 0.5mg/Ml', 'drops', 'S01GA02', false, 0, '00806714', 'FreeDiams::CA_HCDPD::DIN', 11133);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mestinon-Sr', 'tablet (extended-release)', 'N07AA02', false, 0, '00869953', 'FreeDiams::CA_HCDPD::DIN', 11135);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vasotec', 'tablet', 'C09AA02', false, 0, '00851795', 'FreeDiams::CA_HCDPD::DIN', 11136);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Refresh Celluvisc', 'drops', 'S01XA20', false, 0, '00870153', 'FreeDiams::CA_HCDPD::DIN', 11138);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Acetaminophen Tab 325mg', 'tablet', 'N02BE01', false, 0, '00891177', 'FreeDiams::CA_HCDPD::DIN', 11140);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Acetaminophen Tab 500mg', 'tablet', 'N02BE01', false, 0, '00892505', 'FreeDiams::CA_HCDPD::DIN', 11141);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Atenolol', 'tablet', 'C07AB03', false, 0, '01912054', 'FreeDiams::CA_HCDPD::DIN', 11142);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Atenolol', 'tablet', 'C07AB03', false, 0, '01912062', 'FreeDiams::CA_HCDPD::DIN', 11143);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Calcijex Inj 1mcg/Ml', 'solution', 'A11CC04', false, 0, '00891738', 'FreeDiams::CA_HCDPD::DIN', 11150);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Retin-A', 'cream', 'D10AD01', false, 0, '00870021', 'FreeDiams::CA_HCDPD::DIN', 11151);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Retin-A', 'cream', 'D10AD01', false, 0, '00443794', 'FreeDiams::CA_HCDPD::DIN', 11152);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Retin-A', 'gel', 'D10AD01', false, 0, '00443816', 'FreeDiams::CA_HCDPD::DIN', 11153);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Retin-A', 'gel', 'D10AD01', false, 0, '00870013', 'FreeDiams::CA_HCDPD::DIN', 11154);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pain Aid', 'tablet', 'N02BA51', false, 0, '00806773', 'FreeDiams::CA_HCDPD::DIN', 11158);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Indo Cap 25mg', 'capsule', 'M01AB01', false, 0, '00865850', 'FreeDiams::CA_HCDPD::DIN', 11160);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Diltiaz Tab 30mg', 'tablet', 'C08DB01', false, 0, '00886068', 'FreeDiams::CA_HCDPD::DIN', 11161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Diltiaz Tab 60mg', 'tablet', 'C08DB01', false, 0, '00886076', 'FreeDiams::CA_HCDPD::DIN', 11162);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Cloxi Solution 125mg/5ml', 'powder for solution', 'J01CF02', false, 0, '00717630', 'FreeDiams::CA_HCDPD::DIN', 11163);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Cloxi Capsules 500mg', 'capsule', 'J01CF02', false, 0, '00717592', 'FreeDiams::CA_HCDPD::DIN', 11164);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Cloxi Capsules 250mg', 'capsule', 'J01CF02', false, 0, '00717584', 'FreeDiams::CA_HCDPD::DIN', 11165);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Indo Cap 50mg', 'capsule', 'M01AB01', false, 0, '00865869', 'FreeDiams::CA_HCDPD::DIN', 11166);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Medopa Tab 250mg', 'tablet', 'C02AB02', false, 0, '00717509', 'FreeDiams::CA_HCDPD::DIN', 11167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Medopa Tab 500mg', 'tablet', 'C02AB02', false, 0, '00717576', 'FreeDiams::CA_HCDPD::DIN', 11168);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Medopa Tab 125mg', 'tablet', 'C02AB02', false, 0, '00717517', 'FreeDiams::CA_HCDPD::DIN', 11169);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Ampi Suspension 250mg/5ml', 'suspension', 'J01CA01', false, 0, '00717649', 'FreeDiams::CA_HCDPD::DIN', 11170);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Ampi Sus 125mg/5ml', 'suspension', 'J01CA01', false, 0, '00717495', 'FreeDiams::CA_HCDPD::DIN', 11171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Ampi Capsules 500mg', 'capsule', 'J01CA01', false, 0, '00717673', 'FreeDiams::CA_HCDPD::DIN', 11172);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Ampi Capsules 250mg', 'capsule', 'J01CA01', false, 0, '00717657', 'FreeDiams::CA_HCDPD::DIN', 11173);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Verap Tab 120mg', 'tablet', 'C08DA01', false, 0, '00886041', 'FreeDiams::CA_HCDPD::DIN', 11174);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Verap Tab 80mg', 'tablet', 'C08DA01', false, 0, '00886033', 'FreeDiams::CA_HCDPD::DIN', 11175);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Triazide Tab 50 Mg/25 Mg', 'tablet', 'C03EA01', false, 0, '00865532', 'FreeDiams::CA_HCDPD::DIN', 11176);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Ranit Tab 150mg', 'tablet', 'A02BA02', false, 0, '00865737', 'FreeDiams::CA_HCDPD::DIN', 11177);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Pirox Cap 20mg', 'capsule', 'M01AC01', false, 0, '00865788', 'FreeDiams::CA_HCDPD::DIN', 11178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Pirox Cap 10mg', 'capsule', 'M01AC01', false, 0, '00865761', 'FreeDiams::CA_HCDPD::DIN', 11179);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Pindol Tab 10mg', 'tablet', 'C07AA03', false, 0, '00886009', 'FreeDiams::CA_HCDPD::DIN', 11180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Pindol Tab 15mg', 'tablet', 'C07AA03', false, 0, '00886130', 'FreeDiams::CA_HCDPD::DIN', 11181);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Pindol Tab 5mg', 'tablet', 'C07AA03', false, 0, '00886149', 'FreeDiams::CA_HCDPD::DIN', 11182);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Nifed Cap 10mg', 'capsule', 'C08CA05', false, 0, '00865591', 'FreeDiams::CA_HCDPD::DIN', 11183);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Naprox Tab 250mg', 'tablet', 'M01AE02', false, 0, '00865648', 'FreeDiams::CA_HCDPD::DIN', 11184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Naprox Tab 375mg', 'tablet', 'M01AE02', false, 0, '00865656', 'FreeDiams::CA_HCDPD::DIN', 11185);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Naprox Tab 500mg', 'tablet', 'M01AE02', false, 0, '00865664', 'FreeDiams::CA_HCDPD::DIN', 11186);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Naprox Tab 125mg', 'tablet', 'M01AE02', false, 0, '00865621', 'FreeDiams::CA_HCDPD::DIN', 11187);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Metop Tab 50mg', 'tablet', 'C07AB02', false, 0, '00865605', 'FreeDiams::CA_HCDPD::DIN', 11188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Metop Tab 100mg', 'tablet', 'C07AB02', false, 0, '00865613', 'FreeDiams::CA_HCDPD::DIN', 11189);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Loraz Tab 1mg', 'tablet', 'N05BA06', false, 0, '00865680', 'FreeDiams::CA_HCDPD::DIN', 11191);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Loraz Tab 2mg', 'tablet', 'N05BA06', false, 0, '00865699', 'FreeDiams::CA_HCDPD::DIN', 11192);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Diclo Enteric Coated Tab 50mg', 'tablet (enteric-coated)', 'M01AB05', false, 0, '00886025', 'FreeDiams::CA_HCDPD::DIN', 11193);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Diclo Enteric Coated Tab 25mg', 'tablet (enteric-coated)', 'M01AB05', false, 0, '00886017', 'FreeDiams::CA_HCDPD::DIN', 11194);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Loraz Tab 0.5mg', 'tablet', 'N05BA06', false, 0, '00865672', 'FreeDiams::CA_HCDPD::DIN', 11195);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elocom Cream', 'cream', 'D07AC13', false, 0, '00851744', 'FreeDiams::CA_HCDPD::DIN', 11196);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vantex Skin Bleaching Crm W Sunscreen 2%', 'cream', 'D11AX11', false, 0, '00854514', 'FreeDiams::CA_HCDPD::DIN', 11207);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diphenhydramine Hydrochloride Inj 50mg/Ml', 'liquid', 'R06AA02', false, 0, '00878200', 'FreeDiams::CA_HCDPD::DIN', 11223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Testosterone Enanthate Inj 200mg/Ml Usp', 'liquid', 'G03BA03', false, 0, '00739944', 'FreeDiams::CA_HCDPD::DIN', 11224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitro-Dur 0.4', 'patch (extended release)', 'C01DA02', false, 0, '01911902', 'FreeDiams::CA_HCDPD::DIN', 11225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitro-Dur 0.6', 'patch (extended release)', 'C01DA02', false, 0, '01911929', 'FreeDiams::CA_HCDPD::DIN', 11226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitro-Dur 0.2', 'patch (extended release)', 'C01DA02', false, 0, '01911910', 'FreeDiams::CA_HCDPD::DIN', 11227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trialyn Syrup', 'syrup', 'R05FA02', false, 0, '01905635', 'FreeDiams::CA_HCDPD::DIN', 11229);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Salinex Nasal Lubricant', 'spray', 'R01AX30', false, 0, '01910701', 'FreeDiams::CA_HCDPD::DIN', 11232);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Erybid', 'tablet', 'J01FA01', false, 0, '00893862', 'FreeDiams::CA_HCDPD::DIN', 11252);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Niodan 500 Mg Time Release Tablets', 'tablet (extended-release)', 'C04AC01', false, 0, '00779806', 'FreeDiams::CA_HCDPD::DIN', 11254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Opium & Belladonna', 'suppository', 'N02AA02', false, 0, '01901869', 'FreeDiams::CA_HCDPD::DIN', 11257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Phosphates Injection Usp', 'solution', 'B05XA09', false, 0, '00896187', 'FreeDiams::CA_HCDPD::DIN', 11258);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dalacin T 1%', 'solution', 'D10AF01', false, 0, '00582301', 'FreeDiams::CA_HCDPD::DIN', 11260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cortisporin', 'solution', 'S02CA03', false, 0, '01912828', 'FreeDiams::CA_HCDPD::DIN', 11287);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Calcijex Inj 2mcg/Ml', 'solution', 'A11CC04', false, 0, '00891746', 'FreeDiams::CA_HCDPD::DIN', 11291);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Formula 333 Liq', 'liquid', 'V07AV', false, 0, '01909657', 'FreeDiams::CA_HCDPD::DIN', 11296);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Retrovir (Azt)', 'capsule', 'J05AF01', false, 0, '01902660', 'FreeDiams::CA_HCDPD::DIN', 11300);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Unibac Liq 4.5%', 'liquid', 'V07AV', false, 0, '01924508', 'FreeDiams::CA_HCDPD::DIN', 11314);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bradosol Lozenges Extra Strength 3.5mg Mint', 'lozenge', 'R02AA12', false, 0, '00894214', 'FreeDiams::CA_HCDPD::DIN', 11320);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bradosol Lozenges Extra Strength 3.5mg', 'lozenge', 'R02AA12', false, 0, '00895466', 'FreeDiams::CA_HCDPD::DIN', 11321);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Optiray 320 Inj 320mg/Ml', 'solution', 'V08AB07', false, 0, '01900854', 'FreeDiams::CA_HCDPD::DIN', 11328);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Travasol 10% Blend C Inj', 'solution', 'B05BA01', false, 0, '00872296', 'FreeDiams::CA_HCDPD::DIN', 11329);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glycerolyte 57 Solution', 'solution', 'V07AC', false, 0, '00783668', 'FreeDiams::CA_HCDPD::DIN', 11330);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zocor', 'tablet', 'C10AA01', false, 0, '00884324', 'FreeDiams::CA_HCDPD::DIN', 11337);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetazone Forte C8', 'tablet', 'M03BB53', false, 0, '00834319', 'FreeDiams::CA_HCDPD::DIN', 11339);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbosylane', 'capsule', 'A07BA51', false, 0, '00703419', 'FreeDiams::CA_HCDPD::DIN', 11341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Retrovir (Azt)', 'liquid', 'J05AF01', false, 0, '01902644', 'FreeDiams::CA_HCDPD::DIN', 11342);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multi-Phenolic Disinfectant', 'liquid', 'V07AV', false, 0, '00872962', 'FreeDiams::CA_HCDPD::DIN', 11343);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anticoagulant Citrate Dextrose Solution Usp (Acd) Formula B', 'solution', 'V07AC', false, 0, '00788112', 'FreeDiams::CA_HCDPD::DIN', 11354);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Hydromorphone Tab 8mg', 'tablet', 'N02AA03', false, 0, '00885428', 'FreeDiams::CA_HCDPD::DIN', 11363);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftazidime For Injection, Usp', 'powder for solution', 'J01DD02', false, 0, '00886971', 'FreeDiams::CA_HCDPD::DIN', 11370);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftazidime For Injection, Usp', 'powder for solution', 'J01DD02', false, 0, '00886963', 'FreeDiams::CA_HCDPD::DIN', 11371);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftazidime For Injection, Usp', 'powder for solution', 'J01DD02', false, 0, '00886955', 'FreeDiams::CA_HCDPD::DIN', 11372);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anticoagulant Citrate Dextrose Solution Usp (Acd) Formula A', 'solution', 'V07AC', false, 0, '00788139', 'FreeDiams::CA_HCDPD::DIN', 11376);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Acetaminophen W Codeine Elixir', 'elixir', 'N02BE51', false, 0, '00816027', 'FreeDiams::CA_HCDPD::DIN', 11384);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Hydromorphone Tab 1mg', 'tablet', 'N02AA03', false, 0, '00885444', 'FreeDiams::CA_HCDPD::DIN', 11413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zovirax', 'suspension', 'J05AB01', false, 0, '00886157', 'FreeDiams::CA_HCDPD::DIN', 11416);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Ranit Tab 300mg', 'tablet', 'A02BA02', false, 0, '00865745', 'FreeDiams::CA_HCDPD::DIN', 11417);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zovirax 400', 'tablet', 'J05AB01', false, 0, '01911627', 'FreeDiams::CA_HCDPD::DIN', 11420);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clozaril Tab 100mg', 'tablet', 'N05AH02', false, 0, '00894745', 'FreeDiams::CA_HCDPD::DIN', 11421);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clozaril Tab 25mg', 'tablet', 'N05AH02', false, 0, '00894737', 'FreeDiams::CA_HCDPD::DIN', 11422);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Erythromycin', 'ointment', 'S01AA17', false, 0, '01912755', 'FreeDiams::CA_HCDPD::DIN', 11423);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Sulfacetamide Sod Oph Soln 30%', 'drops', 'S01AB04', false, 0, '00762059', 'FreeDiams::CA_HCDPD::DIN', 11424);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Hydromorphone Tab 4mg', 'tablet', 'N02AA03', false, 0, '00885401', 'FreeDiams::CA_HCDPD::DIN', 11425);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetazone Forte', 'tablet', 'M03BB53', false, 0, '00834300', 'FreeDiams::CA_HCDPD::DIN', 11427);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Hydromorphone Tab 2mg', 'tablet', 'N02AA03', false, 0, '00885436', 'FreeDiams::CA_HCDPD::DIN', 11428);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisturel Lotion', 'lotion', 'D02AA', false, 0, '01909169', 'FreeDiams::CA_HCDPD::DIN', 11430);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('D-125 Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '00887331', 'FreeDiams::CA_HCDPD::DIN', 11431);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stievamycin Regular', 'gel', 'D10AF52', false, 0, '01905112', 'FreeDiams::CA_HCDPD::DIN', 11432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Emla Crm', 'cream', 'D04AB30', false, 0, '00886858', 'FreeDiams::CA_HCDPD::DIN', 11440);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elocom Lotion', 'lotion', 'D07AC13', false, 0, '00871095', 'FreeDiams::CA_HCDPD::DIN', 11443);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elocom Ointment', 'ointment', 'D07AC13', false, 0, '00851736', 'FreeDiams::CA_HCDPD::DIN', 11444);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Airx 109 Super Concentrate Larose', 'liquid', 'V07AV', false, 0, '00868752', 'FreeDiams::CA_HCDPD::DIN', 11453);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Isosorbide Tab 10mg', 'tablet', 'C01DA08', false, 0, '00786667', 'FreeDiams::CA_HCDPD::DIN', 11456);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isosorbide Tab 30mg', 'tablet', 'C01DA08', false, 0, '00786640', 'FreeDiams::CA_HCDPD::DIN', 11457);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Terazol 7 Vaginal Cream 0.4%', 'cream', 'G01AG02', false, 0, '00894729', 'FreeDiams::CA_HCDPD::DIN', 11460);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Flurbiprofen Fc Tablets 100mg', 'tablet', 'M01AE09', false, 0, '01912038', 'FreeDiams::CA_HCDPD::DIN', 11465);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Flurbiprofen Fc Tablets 50mg', 'tablet', 'M01AE09', false, 0, '01912046', 'FreeDiams::CA_HCDPD::DIN', 11466);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Glybe', 'tablet', 'A10BB01', false, 0, '00808741', 'FreeDiams::CA_HCDPD::DIN', 11472);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Glybe', 'tablet', 'A10BB01', false, 0, '00808733', 'FreeDiams::CA_HCDPD::DIN', 11473);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinemet Cr 200/50', 'tablet (extended-release)', 'N04BA02', false, 0, '00870935', 'FreeDiams::CA_HCDPD::DIN', 11481);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clonidine Hcl Tab 0.2mg', 'tablet', 'C02AC01', false, 0, '01908162', 'FreeDiams::CA_HCDPD::DIN', 11482);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clonidine Hcl-0.1 Tab 0.1mg', 'tablet', 'C02AC01', false, 0, '01910396', 'FreeDiams::CA_HCDPD::DIN', 11483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alprazolam-0.25 Tab 0.25mg', 'tablet', 'N05BA12', false, 0, '01908189', 'FreeDiams::CA_HCDPD::DIN', 11484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alprazolam-0.5 Tab 0.5mg', 'tablet', 'N05BA12', false, 0, '01908170', 'FreeDiams::CA_HCDPD::DIN', 11485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Captopril-25 Tab 25mg', 'tablet', 'C09AA01', false, 0, '01910337', 'FreeDiams::CA_HCDPD::DIN', 11490);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Health Care E-2 Antis Lot Soap', 'lotion', 'D08AE05', false, 0, '01922734', 'FreeDiams::CA_HCDPD::DIN', 11499);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Docusate Sodium', 'syrup', 'A06AA02', false, 0, '00870226', 'FreeDiams::CA_HCDPD::DIN', 11520);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Docusate Sodium Drops 10mg/Ml', 'drops', 'A06AA02', false, 0, '00870218', 'FreeDiams::CA_HCDPD::DIN', 11521);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isoptin Sr', 'tablet (extended-release)', 'C08DA01', false, 0, '01907123', 'FreeDiams::CA_HCDPD::DIN', 11534);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bacti-Stat 0.3%', 'liquid', 'D08AE04', false, 0, '00779237', 'FreeDiams::CA_HCDPD::DIN', 11537);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doloral 5 Sirop 5mg/Ml', 'syrup', 'N02AA01', false, 0, '00614505', 'FreeDiams::CA_HCDPD::DIN', 11597);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dopamine Hcl 3.2mg/Ml Dextrose 5% Inj Usp', 'solution', 'C01CA04', false, 0, '00761834', 'FreeDiams::CA_HCDPD::DIN', 11624);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dopamine Hcl 1.6mg/Ml Dextrose 5% Inj Usp', 'solution', 'C01CA04', false, 0, '00761826', 'FreeDiams::CA_HCDPD::DIN', 11625);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Hydralazine Tablets 25mg', 'tablet', 'C02DB02', false, 0, '00441627', 'FreeDiams::CA_HCDPD::DIN', 11626);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Hydralazine Tablets 50mg', 'tablet', 'C02DB02', false, 0, '00441635', 'FreeDiams::CA_HCDPD::DIN', 11627);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mineral Oil (Heavy)', 'liquid', 'A06AA01', false, 0, '01935348', 'FreeDiams::CA_HCDPD::DIN', 11629);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norepinephrine Bitartrate Inj 1mg/Ml Usp', 'liquid', 'C01CA03', false, 0, '00893285', 'FreeDiams::CA_HCDPD::DIN', 11641);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isoproterenol Hydrochloride Injection Usp', 'solution', 'C01CA02', false, 0, '00897639', 'FreeDiams::CA_HCDPD::DIN', 11642);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Junior Strength Tylenol Cold And Cough', 'tablet (chewable)', 'N02BE51', false, 0, '00890677', 'FreeDiams::CA_HCDPD::DIN', 11646);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm Cough Syrup', 'syrup', 'R05DA09', false, 0, '00833231', 'FreeDiams::CA_HCDPD::DIN', 11649);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy Elixir', 'elixir', 'R06AA02', false, 0, '00833266', 'FreeDiams::CA_HCDPD::DIN', 11650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benzac Ac Gel 10%', 'gel', 'D10AE01', false, 0, '01912437', 'FreeDiams::CA_HCDPD::DIN', 11657);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benzac Ac 5 Gel 5%', 'gel', 'D10AE01', false, 0, '00899453', 'FreeDiams::CA_HCDPD::DIN', 11658);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('San Iode Liq 1%', 'liquid', 'V07AV', false, 0, '01941992', 'FreeDiams::CA_HCDPD::DIN', 11677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Bisacodyl', 'tablet', 'A06AB02', false, 0, '00587273', 'FreeDiams::CA_HCDPD::DIN', 11680);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topactin Cream 0.05% U.S.P.', 'cream', 'D07AC08', false, 0, '00816132', 'FreeDiams::CA_HCDPD::DIN', 11682);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prostigmin Tablets', 'tablet', 'N07AA01', false, 0, '00869945', 'FreeDiams::CA_HCDPD::DIN', 11691);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Eyelube 0.5%', 'drops', 'S01XA20', false, 0, '00889806', 'FreeDiams::CA_HCDPD::DIN', 11709);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Glyburide Tab 5mg', 'tablet', 'A10BB01', false, 0, '01913662', 'FreeDiams::CA_HCDPD::DIN', 11727);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Glyburide Tab 2.5mg', 'tablet', 'A10BB01', false, 0, '01913654', 'FreeDiams::CA_HCDPD::DIN', 11728);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen 500 Mg With 15 Mg Caffeine And 8 Mg Codeine Phosphate', 'tablet', 'N02BE51', false, 0, '00708712', 'FreeDiams::CA_HCDPD::DIN', 11741);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Engerix B Inj Sus 20mcg/Ml', 'suspension', 'J07BC01', false, 0, '01919431', 'FreeDiams::CA_HCDPD::DIN', 11742);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Modulon Tablets 200mg', 'tablet', 'A03AA05', false, 0, '00803499', 'FreeDiams::CA_HCDPD::DIN', 11743);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Luvox', 'tablet', 'N06AB08', false, 0, '01919369', 'FreeDiams::CA_HCDPD::DIN', 11751);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Luvox', 'tablet', 'N06AB08', false, 0, '01919342', 'FreeDiams::CA_HCDPD::DIN', 11752);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triatec-8 Tab', 'tablet', 'N02BE51', false, 0, '00852163', 'FreeDiams::CA_HCDPD::DIN', 11753);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydrox-Hydrogen Peroxide-Based Disinfectant Liq 3%', 'liquid', 'V07AV', false, 0, '00893250', 'FreeDiams::CA_HCDPD::DIN', 11758);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Captopril', 'tablet', 'C09AA01', false, 0, '01942964', 'FreeDiams::CA_HCDPD::DIN', 11760);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nytol Extra Strength Sleep Aid Caplet 50mg', 'tablet', 'R06AA02', false, 0, '01934414', 'FreeDiams::CA_HCDPD::DIN', 11762);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Captopril', 'tablet', 'C09AA01', false, 0, '01942972', 'FreeDiams::CA_HCDPD::DIN', 11763);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Captopril', 'tablet', 'C09AA01', false, 0, '01942980', 'FreeDiams::CA_HCDPD::DIN', 11764);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Captopril', 'tablet', 'C09AA01', false, 0, '01942999', 'FreeDiams::CA_HCDPD::DIN', 11765);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Tripramine Tab 50mg Bp', 'tablet', 'N06AA06', false, 0, '01940449', 'FreeDiams::CA_HCDPD::DIN', 11767);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Tripramine Tab 25mg Bp', 'tablet', 'N06AA06', false, 0, '01940430', 'FreeDiams::CA_HCDPD::DIN', 11768);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Tripramine Tab 100mg Bp', 'tablet', 'N06AA06', false, 0, '01940457', 'FreeDiams::CA_HCDPD::DIN', 11769);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allernix Elixir', 'elixir', 'R06AA02', false, 0, '00804193', 'FreeDiams::CA_HCDPD::DIN', 11772);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Glyburide', 'tablet', 'A10BB01', false, 0, '01913670', 'FreeDiams::CA_HCDPD::DIN', 11780);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Glyburide', 'tablet', 'A10BB01', false, 0, '01913689', 'FreeDiams::CA_HCDPD::DIN', 11781);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Comprime A Croquer 80mg', 'tablet', 'N02BE01', false, 0, '01905856', 'FreeDiams::CA_HCDPD::DIN', 11794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Solution Oral Gtte 80mg/Ml Usp', 'kit', 'N02BE01', false, 0, '01905864', 'FreeDiams::CA_HCDPD::DIN', 11795);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Sol Orale D''Acetamin 80mg/5ml', 'liquid', 'N02BE01', false, 0, '01905848', 'FreeDiams::CA_HCDPD::DIN', 11796);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Entrophen 650mg Caplet Ect', 'tablet (enteric-coated)', 'N02BA01', false, 0, '01905392', 'FreeDiams::CA_HCDPD::DIN', 11798);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Alprazolam', 'tablet', 'N05BA12', false, 0, '01913484', 'FreeDiams::CA_HCDPD::DIN', 11803);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Alprazolam', 'tablet', 'N05BA12', false, 0, '01913492', 'FreeDiams::CA_HCDPD::DIN', 11804);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Serophene Tab 50mg', 'tablet', 'G03GB02', false, 0, '00893722', 'FreeDiams::CA_HCDPD::DIN', 11805);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germi Stat Gel 2%', 'gel', 'D08AC02', false, 0, '01930079', 'FreeDiams::CA_HCDPD::DIN', 11826);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prostin E2 Vaginal Gel', 'gel', 'G02AD02', false, 0, '01919679', 'FreeDiams::CA_HCDPD::DIN', 11830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prostin E2 Vaginal Gel', 'gel', 'G02AD02', false, 0, '01919687', 'FreeDiams::CA_HCDPD::DIN', 11831);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Md-Cide', 'liquid', 'V07AV', false, 0, '01936948', 'FreeDiams::CA_HCDPD::DIN', 11833);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glutacide', 'liquid', 'V07AV', false, 0, '01936956', 'FreeDiams::CA_HCDPD::DIN', 11834);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Retin-A', 'cream', 'D10AD01', false, 0, '00897329', 'FreeDiams::CA_HCDPD::DIN', 11843);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Retin-A', 'cream', 'D10AD01', false, 0, '00897310', 'FreeDiams::CA_HCDPD::DIN', 11844);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Koffex Dm  (Sucrose Free)', 'syrup', 'R05DA09', false, 0, '01928791', 'FreeDiams::CA_HCDPD::DIN', 11847);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Koffex Dm', 'syrup', 'R05DA09', false, 0, '01928783', 'FreeDiams::CA_HCDPD::DIN', 11848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neostigmine Methylsulfate Injection Usp', 'liquid', 'N07AA01', false, 0, '01915436', 'FreeDiams::CA_HCDPD::DIN', 11852);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amox 500 Cap 500mg', 'capsule', 'J01CA04', false, 0, '00885894', 'FreeDiams::CA_HCDPD::DIN', 11853);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amox 250 Cap 250mg', 'capsule', 'J01CA04', false, 0, '00885886', 'FreeDiams::CA_HCDPD::DIN', 11854);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amox S 250 Sus 250mg/5ml', 'suspension', 'J01CA04', false, 0, '00885916', 'FreeDiams::CA_HCDPD::DIN', 11855);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amox S 125 Sus 125mg/5ml', 'suspension', 'J01CA04', false, 0, '00885908', 'FreeDiams::CA_HCDPD::DIN', 11856);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trisulfa Tab', 'tablet', 'J01EE01', false, 0, '00885924', 'FreeDiams::CA_HCDPD::DIN', 11857);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trisulfa Ds Tab', 'tablet', 'J01EE01', false, 0, '00885932', 'FreeDiams::CA_HCDPD::DIN', 11858);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trisulfa S Suspension', 'suspension', 'J01EE01', false, 0, '00885940', 'FreeDiams::CA_HCDPD::DIN', 11859);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benzac W Wash Gel 10%', 'gel', 'D10AE01', false, 0, '01925199', 'FreeDiams::CA_HCDPD::DIN', 11862);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Sulfacetamide Sodium Liq 10%', 'liquid', 'S01AB04', false, 0, '00838934', 'FreeDiams::CA_HCDPD::DIN', 11868);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Hydromorphone Suppositoire 3mg', 'suppository', 'N02AA03', false, 0, '01916394', 'FreeDiams::CA_HCDPD::DIN', 11869);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lamictal', 'tablet', 'N03AX09', false, 0, '02142112', 'FreeDiams::CA_HCDPD::DIN', 17160);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Hydromorphone Sirop 1mg/Ml', 'syrup', 'N02AA03', false, 0, '01916386', 'FreeDiams::CA_HCDPD::DIN', 11870);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pitrex Crm 1%', 'cream', 'D01AE18', false, 0, '00716928', 'FreeDiams::CA_HCDPD::DIN', 11879);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Androcur-Depot', 'solution', 'G03HA01', false, 0, '00704423', 'FreeDiams::CA_HCDPD::DIN', 11880);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vaporisateur Nasal Decongestionnant', 'solution', 'R01AA07', false, 0, '00788503', 'FreeDiams::CA_HCDPD::DIN', 11887);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clotrimaderm Cream 1%', 'cream', 'D01AC01', false, 0, '00812382', 'FreeDiams::CA_HCDPD::DIN', 11893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Betagan Oph Soln 0.25%', 'liquid', 'S01ED03', false, 0, '00751286', 'FreeDiams::CA_HCDPD::DIN', 11894);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Eyelube 1%', 'drops', 'S01XA20', false, 0, '00874965', 'FreeDiams::CA_HCDPD::DIN', 11898);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neo Citran Dm', 'powder for solution', 'R05DA20', false, 0, '01906704', 'FreeDiams::CA_HCDPD::DIN', 11901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Decongestant Nose Drops 0.1%', 'drops', 'R01AA07', false, 0, '00851256', 'FreeDiams::CA_HCDPD::DIN', 11904);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phazyme Cap 125mg', 'capsule', 'A03AX13', false, 0, '01932268', 'FreeDiams::CA_HCDPD::DIN', 11914);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robitussin Chest Congestion', 'liquid', 'R05CA03', false, 0, '01931032', 'FreeDiams::CA_HCDPD::DIN', 11918);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lotion Kleen Green 0.55%', 'lotion', 'D08AE04', false, 0, '01936905', 'FreeDiams::CA_HCDPD::DIN', 11919);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinutab With Codeine Tablets', 'tablet', 'N02BE51', false, 0, '01938363', 'FreeDiams::CA_HCDPD::DIN', 11921);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Esteam Sani Clean Liq', 'liquid', 'V07AV', false, 0, '01945416', 'FreeDiams::CA_HCDPD::DIN', 11922);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Erythro E-C Cap 333mg', 'capsule (enteric-coated)', 'J01FA01', false, 0, '01925938', 'FreeDiams::CA_HCDPD::DIN', 11929);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisturel Cream', 'cream', 'D02AA', false, 0, '01909142', 'FreeDiams::CA_HCDPD::DIN', 11936);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Retrovir (Azt)', 'syrup', 'J05AF01', false, 0, '01902652', 'FreeDiams::CA_HCDPD::DIN', 11942);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anexate Inj 0.1mg/Ml', 'solution', 'V03AB25', false, 0, '00874019', 'FreeDiams::CA_HCDPD::DIN', 11944);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Amoxi Cap 250mg', 'capsule', 'J01CA04', false, 0, '00865567', 'FreeDiams::CA_HCDPD::DIN', 11949);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Amoxi Cap 500mg', 'capsule', 'J01CA04', false, 0, '00865575', 'FreeDiams::CA_HCDPD::DIN', 11950);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Amoxi Sus 125/5ml', 'suspension', 'J01CA04', false, 0, '00865540', 'FreeDiams::CA_HCDPD::DIN', 11951);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Amoxi Sus 250mg/5ml', 'suspension', 'J01CA04', false, 0, '00865559', 'FreeDiams::CA_HCDPD::DIN', 11952);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Cotrimox Tab 400/80mg', 'tablet', 'J01EE01', false, 0, '00865710', 'FreeDiams::CA_HCDPD::DIN', 11953);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Cotrimox-Ds Tab 800/160mg', 'tablet', 'J01EE01', false, 0, '00865729', 'FreeDiams::CA_HCDPD::DIN', 11954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Cotrimox Sus 40/8mg/Ml', 'suspension', 'J01EE01', false, 0, '00865753', 'FreeDiams::CA_HCDPD::DIN', 11955);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Tetra Capsules 250mg', 'capsule', 'J01AA07', false, 0, '00717606', 'FreeDiams::CA_HCDPD::DIN', 11956);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Pen-Vk Tablets 300mg', 'tablet', 'J01CE02', false, 0, '00717568', 'FreeDiams::CA_HCDPD::DIN', 11957);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Cimet Tab 600mg', 'tablet', 'A02BA01', false, 0, '00865834', 'FreeDiams::CA_HCDPD::DIN', 11958);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Cimet Tab 400mg', 'tablet', 'A02BA01', false, 0, '00865826', 'FreeDiams::CA_HCDPD::DIN', 11959);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Cimet Tab 300mg', 'tablet', 'A02BA01', false, 0, '00865818', 'FreeDiams::CA_HCDPD::DIN', 11960);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Cimet Tab 200mg', 'tablet', 'A02BA01', false, 0, '00865796', 'FreeDiams::CA_HCDPD::DIN', 11961);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Cephalex Tab 500mg', 'tablet', 'J01DB01', false, 0, '00865885', 'FreeDiams::CA_HCDPD::DIN', 11962);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Cephalex Tab 250mg', 'tablet', 'J01DB01', false, 0, '00865877', 'FreeDiams::CA_HCDPD::DIN', 11963);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Atenol Tab 100mg', 'tablet', 'C07AB03', false, 0, '00886122', 'FreeDiams::CA_HCDPD::DIN', 11964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Atenol Tab 50mg', 'tablet', 'C07AB03', false, 0, '00886114', 'FreeDiams::CA_HCDPD::DIN', 11965);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Amilzide 5/50 Mg Tab', 'tablet', 'C03EA01', false, 0, '00886106', 'FreeDiams::CA_HCDPD::DIN', 11966);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Voltaren Ophtha', 'solution', 'S01BC03', false, 0, '01940414', 'FreeDiams::CA_HCDPD::DIN', 11969);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arlidin Tablets 6mg', 'tablet', 'C04AA02', false, 0, '01926713', 'FreeDiams::CA_HCDPD::DIN', 11970);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxsoralen-Ultra Cap 10mg', 'capsule', 'D05BA02', false, 0, '00252654', 'FreeDiams::CA_HCDPD::DIN', 11972);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Claritin Allergy + Sinus', 'tablet (extended-release)', 'R01BA52', false, 0, '01945157', 'FreeDiams::CA_HCDPD::DIN', 11974);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Yohimbine Tab 5.4mg', 'tablet', 'G04BE04', false, 0, '01901885', 'FreeDiams::CA_HCDPD::DIN', 12016);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermex I Antiseptic Lotion Soap', 'lotion', 'D08AE05', false, 0, '01922726', 'FreeDiams::CA_HCDPD::DIN', 12137);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Tablets Regular Strength', 'tablet', 'N02BE01', false, 0, '01904124', 'FreeDiams::CA_HCDPD::DIN', 12154);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Acetaminophen Elx 160mg', 'elixir', 'N02BE01', false, 0, '00833223', 'FreeDiams::CA_HCDPD::DIN', 12159);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride 12% Usp', 'liquid', 'B05CB01', false, 0, '00783625', 'FreeDiams::CA_HCDPD::DIN', 12168);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride 1.6% Solution Usp', 'solution', 'B05CB01', false, 0, '00783633', 'FreeDiams::CA_HCDPD::DIN', 12169);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 0.2% And 0.9% Sod Chlor Solution', 'solution', 'B05CB51', false, 0, '00783641', 'FreeDiams::CA_HCDPD::DIN', 12171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Alpraz Tab 0.25mg', 'tablet', 'N05BA12', false, 0, '01913239', 'FreeDiams::CA_HCDPD::DIN', 12175);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Capto Tab 100mg', 'tablet', 'C09AA01', false, 0, '01913859', 'FreeDiams::CA_HCDPD::DIN', 12176);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Capto Tab 50mg', 'tablet', 'C09AA01', false, 0, '01913840', 'FreeDiams::CA_HCDPD::DIN', 12177);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Capto Tab 25mg', 'tablet', 'C09AA01', false, 0, '01913832', 'FreeDiams::CA_HCDPD::DIN', 12178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Capto Tab 12.5mg', 'tablet', 'C09AA01', false, 0, '01913824', 'FreeDiams::CA_HCDPD::DIN', 12179);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Alpraz Tab 0.5mg', 'tablet', 'N05BA12', false, 0, '01913247', 'FreeDiams::CA_HCDPD::DIN', 12180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tensilon', 'liquid', 'V04CX', false, 0, '00855804', 'FreeDiams::CA_HCDPD::DIN', 12181);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pulmicort Turbuhaler 400 Mcg/Dose', 'kit', 'R03BA02', false, 0, '00851760', 'FreeDiams::CA_HCDPD::DIN', 12182);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('0.9% Sodium Chloride Injection Usp', 'solution', 'B05XA03', false, 0, '01924303', 'FreeDiams::CA_HCDPD::DIN', 12185);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lactated Ringer''S Injection Usp', 'solution', 'B05BB01', false, 0, '01931636', 'FreeDiams::CA_HCDPD::DIN', 12186);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Dm-D-E Syr', 'syrup', 'R05FA02', false, 0, '01944673', 'FreeDiams::CA_HCDPD::DIN', 12192);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Condyline Topical Sol 0.5%', 'liquid', 'D06BB04', false, 0, '01945149', 'FreeDiams::CA_HCDPD::DIN', 12196);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexamethasone Sod Phosph Inj 10mg/Ml Usp', 'liquid', 'H02AB02', false, 0, '00874582', 'FreeDiams::CA_HCDPD::DIN', 12208);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinicide', 'solution', 'V07AV', false, 0, '01918060', 'FreeDiams::CA_HCDPD::DIN', 12210);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atropine Ak', 'drops', 'S01FA01', false, 0, '00622907', 'FreeDiams::CA_HCDPD::DIN', 12215);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tussionex', 'suspension', 'R05DA20', false, 0, '01916971', 'FreeDiams::CA_HCDPD::DIN', 12216);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tussionex', 'tablet (extended-release)', 'R05DA20', false, 0, '01916963', 'FreeDiams::CA_HCDPD::DIN', 12217);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Furosemide Special', 'solution', 'C03CA01', false, 0, '00401633', 'FreeDiams::CA_HCDPD::DIN', 12218);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitrol (Nitroglycerin Ointment 2%, Usp)', 'ointment', 'C01DA02', false, 0, '01926454', 'FreeDiams::CA_HCDPD::DIN', 12220);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flagyl', 'capsule', 'J01XD01', false, 0, '01926853', 'FreeDiams::CA_HCDPD::DIN', 12221);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piportil L4', 'solution', 'N05AC04', false, 0, '01926675', 'FreeDiams::CA_HCDPD::DIN', 12223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('A-Hydrocort Inj 250mg/2ml', 'powder for solution', 'H02AB09', false, 0, '00888206', 'FreeDiams::CA_HCDPD::DIN', 12229);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apresoline Injection 20mg/Ampoule', 'powder for solution', 'C02DB02', false, 0, '00723754', 'FreeDiams::CA_HCDPD::DIN', 12237);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('G-Nol Disinfectant Sol', 'liquid', 'V07AV', false, 0, '01910604', 'FreeDiams::CA_HCDPD::DIN', 12247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Steris 20 Sterilant Conc Liq 35%', 'liquid', 'V07AV', false, 0, '01945408', 'FreeDiams::CA_HCDPD::DIN', 12252);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hosp-I-Septic-G Surface Disin Spr', 'aerosol', 'V07AV', false, 0, '01945475', 'FreeDiams::CA_HCDPD::DIN', 12254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germicidal Multipurpose Clean Spr', 'aerosol', 'V07AV', false, 0, '01945467', 'FreeDiams::CA_HCDPD::DIN', 12255);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dopamine Hcl 0.8mg/Ml Dextrose 5% Inj Usp', 'solution', 'C01CA04', false, 0, '00761850', 'FreeDiams::CA_HCDPD::DIN', 12256);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Akarpine Oph Soln 1%', 'solution', 'S01EB01', false, 0, '00627739', 'FreeDiams::CA_HCDPD::DIN', 12257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Akarpine Oph Soln 2%', 'solution', 'S01EB01', false, 0, '00627747', 'FreeDiams::CA_HCDPD::DIN', 12258);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Akarpine Oph Soln 4%', 'solution', 'S01EB01', false, 0, '00627755', 'FreeDiams::CA_HCDPD::DIN', 12259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Ampicillin Sod Inj 250mg/Vial', 'powder for solution', 'J01CA01', false, 0, '00872644', 'FreeDiams::CA_HCDPD::DIN', 12261);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Ampicillin Sod Inj 500mg/Vial', 'powder for solution', 'J01CA01', false, 0, '00872652', 'FreeDiams::CA_HCDPD::DIN', 12262);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gent-Ak Liq 5mg/Ml', 'liquid', 'S01AA11', false, 0, '00832162', 'FreeDiams::CA_HCDPD::DIN', 12265);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solarcaine First Aid Lidocaine Spray', 'aerosol', 'D04AB01', false, 0, '01923986', 'FreeDiams::CA_HCDPD::DIN', 12266);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ampicillin Sodium Pws 1 Gm/Vial Usp', 'powder for solution', 'J01CA01', false, 0, '01933345', 'FreeDiams::CA_HCDPD::DIN', 12267);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ampicillin Sodium Pws 2 Gm/Vial Usp', 'powder for solution', 'J01CA01', false, 0, '01933353', 'FreeDiams::CA_HCDPD::DIN', 12268);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Sone Cream 0.05%', 'cream', 'D07AC01', false, 0, '01925350', 'FreeDiams::CA_HCDPD::DIN', 12272);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germist A214 Hard Surface Disinfect Spray', 'aerosol', 'V07AV', false, 0, '01945483', 'FreeDiams::CA_HCDPD::DIN', 12288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germifoam A225 Hard Surface Disinfect Foam', 'aerosol', 'V07AV', false, 0, '01945440', 'FreeDiams::CA_HCDPD::DIN', 12289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accupril 5mg Tab', 'tablet', 'C09AA06', false, 0, '01947664', 'FreeDiams::CA_HCDPD::DIN', 12331);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accupril Tab 10mg', 'tablet', 'C09AA06', false, 0, '01947672', 'FreeDiams::CA_HCDPD::DIN', 12332);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accupril Tab 20mg', 'tablet', 'C09AA06', false, 0, '01947680', 'FreeDiams::CA_HCDPD::DIN', 12333);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accupril Tab 40mg', 'tablet', 'C09AA06', false, 0, '01947699', 'FreeDiams::CA_HCDPD::DIN', 12334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Penicillin G Sodium Inj 5000000unit/Vial Usp', 'powder for solution', 'J01CE01', false, 0, '00883751', 'FreeDiams::CA_HCDPD::DIN', 12343);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Docusate Calcium Cap 240mg', 'capsule', 'A06AA02', false, 0, '00830275', 'FreeDiams::CA_HCDPD::DIN', 12344);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('D-Tabs 10000unit', 'tablet', 'A11CC05', false, 0, '00821772', 'FreeDiams::CA_HCDPD::DIN', 12345);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('A-Hydrocort Inj 100mg/2ml', 'powder for solution', 'H02AB09', false, 0, '00888230', 'FreeDiams::CA_HCDPD::DIN', 12346);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Penicillin G Sod Inj Pws 1000000unit/Vial', 'powder for solution', 'J01CE01', false, 0, '01930672', 'FreeDiams::CA_HCDPD::DIN', 12394);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Penicillin G Sod Inj Pws 10000000unit/Vial', 'powder for solution', 'J01CE01', false, 0, '01930680', 'FreeDiams::CA_HCDPD::DIN', 12395);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pathex Disinfectant Solution', 'solution', 'V07AV', false, 0, '01933663', 'FreeDiams::CA_HCDPD::DIN', 12396);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Presept Disinfectant Tab 2.5gm', 'tablet (effervescent)', 'V07AV', false, 0, '01946390', 'FreeDiams::CA_HCDPD::DIN', 12398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Presept Disinfectant Tab 5gm', 'tablet (effervescent)', 'V07AV', false, 0, '01946404', 'FreeDiams::CA_HCDPD::DIN', 12399);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Presept Disinfectant Tab 0.5gm', 'tablet (effervescent)', 'V07AV', false, 0, '01946978', 'FreeDiams::CA_HCDPD::DIN', 12400);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckeye Sanicare Quat-128 Liq', 'liquid', 'V07AV', false, 0, '01962086', 'FreeDiams::CA_HCDPD::DIN', 12403);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckeye Sanicare Quat-256 Liq', 'liquid', 'V07AV', false, 0, '01962116', 'FreeDiams::CA_HCDPD::DIN', 12404);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckeye Sanicare Pine Quat', 'liquid', 'V07AV', false, 0, '01962108', 'FreeDiams::CA_HCDPD::DIN', 12405);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckeye Sanicare Mint Quat Liq', 'liquid', 'V07AV', false, 0, '01962078', 'FreeDiams::CA_HCDPD::DIN', 12406);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckeye Sanicare Lemon Quat Liq', 'liquid', 'V07AV', false, 0, '01962051', 'FreeDiams::CA_HCDPD::DIN', 12407);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Swipes Disinfectant Disposable Cloth', 'pad', 'V07AV', false, 0, '01914243', 'FreeDiams::CA_HCDPD::DIN', 12408);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Dm-D', 'syrup', 'R05DA20', false, 0, '01944711', 'FreeDiams::CA_HCDPD::DIN', 12410);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Dm Syr', 'syrup', 'R05DA09', false, 0, '01944738', 'FreeDiams::CA_HCDPD::DIN', 12411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Oral Sol For Children Usp', 'liquid', 'N02BE01', false, 0, '01958836', 'FreeDiams::CA_HCDPD::DIN', 12412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cyclopentolate Hcl Oph Solution 1%', 'liquid', 'S01FA04', false, 0, '00878189', 'FreeDiams::CA_HCDPD::DIN', 12417);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Panectyl Tab 2.5mg', 'tablet', 'R06AD01', false, 0, '01926306', 'FreeDiams::CA_HCDPD::DIN', 12419);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sectral', 'tablet', 'C07AB04', false, 0, '01926543', 'FreeDiams::CA_HCDPD::DIN', 12421);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sectral', 'tablet', 'C07AB04', false, 0, '01926551', 'FreeDiams::CA_HCDPD::DIN', 12422);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sectral', 'tablet', 'C07AB04', false, 0, '01926578', 'FreeDiams::CA_HCDPD::DIN', 12423);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neuleptil 10mg Capsules', 'capsule', 'N05AC01', false, 0, '01926772', 'FreeDiams::CA_HCDPD::DIN', 12425);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imovane 7.5 - Tab 7.5mg', 'tablet', 'N05CF01', false, 0, '01926799', 'FreeDiams::CA_HCDPD::DIN', 12426);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novamilor Tab Usp', 'tablet', 'C03EA01', false, 0, '01937219', 'FreeDiams::CA_HCDPD::DIN', 12430);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cloxacillin Sodium Sterile Pws 2gm/Vial', 'powder for solution', 'J01CF02', false, 0, '01912410', 'FreeDiams::CA_HCDPD::DIN', 12434);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cloxacillin Sodium Sterile Pws 500mg/Vial', 'powder for solution', 'J01CF02', false, 0, '01912429', 'FreeDiams::CA_HCDPD::DIN', 12435);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Majeptil Tab 10mg', 'tablet', 'N05AB08', false, 0, '01927639', 'FreeDiams::CA_HCDPD::DIN', 12437);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Dm-E Syr', 'syrup', 'R05FA02', false, 0, '01944762', 'FreeDiams::CA_HCDPD::DIN', 12449);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Prazin Tab 1mg', 'tablet', 'C02CA01', false, 0, '01934198', 'FreeDiams::CA_HCDPD::DIN', 12451);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Prazin Tab 2mg', 'tablet', 'C02CA01', false, 0, '01934201', 'FreeDiams::CA_HCDPD::DIN', 12452);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Prazin Tab 5mg', 'tablet', 'C02CA01', false, 0, '01934228', 'FreeDiams::CA_HCDPD::DIN', 12453);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cardura-1 Tab 1mg', 'tablet', 'C02CA04', false, 0, '01958100', 'FreeDiams::CA_HCDPD::DIN', 12455);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cardura-2 Tab 2mg', 'tablet', 'C02CA04', false, 0, '01958097', 'FreeDiams::CA_HCDPD::DIN', 12456);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cardura-4 Tab 4mg', 'tablet', 'C02CA04', false, 0, '01958119', 'FreeDiams::CA_HCDPD::DIN', 12457);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Plendil 5 Mg', 'tablet (extended-release)', 'C08CA02', false, 0, '00851779', 'FreeDiams::CA_HCDPD::DIN', 12458);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Plendil 10 Mg', 'tablet (extended-release)', 'C08CA02', false, 0, '00851787', 'FreeDiams::CA_HCDPD::DIN', 12459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medicament Pour Les Sinus Extra-Fort Caplet', 'tablet', 'N02BE51', false, 0, '00899771', 'FreeDiams::CA_HCDPD::DIN', 12461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neupogen', 'solution', 'L03AA02', false, 0, '01968017', 'FreeDiams::CA_HCDPD::DIN', 12474);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Dm-D For Children', 'syrup', 'R05DA20', false, 0, '01944746', 'FreeDiams::CA_HCDPD::DIN', 12504);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin A Acid 0.05% Gel', 'gel', 'D10AD01', false, 0, '01926489', 'FreeDiams::CA_HCDPD::DIN', 12544);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Parsitan 50mg', 'tablet', 'N04AA05', false, 0, '01927744', 'FreeDiams::CA_HCDPD::DIN', 12549);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reliable Deterrent 25 Dis Cl Liq', 'liquid', 'V07AV', false, 0, '01962000', 'FreeDiams::CA_HCDPD::DIN', 12556);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Tablets Extra Strength', 'tablet', 'N02BE01', false, 0, '01904132', 'FreeDiams::CA_HCDPD::DIN', 12565);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humulin 30/70 Cartridge', 'suspension', 'A10AD01', false, 0, '01959212', 'FreeDiams::CA_HCDPD::DIN', 12568);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humulin R Cartridge', 'solution', 'A10AB01', false, 0, '01959220', 'FreeDiams::CA_HCDPD::DIN', 12569);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humulin N (Cartridge/Kwikpen)', 'suspension', 'A10AC01', false, 0, '01959239', 'FreeDiams::CA_HCDPD::DIN', 12570);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Fluphenazine Tab 1mg', 'tablet', 'N05AB02', false, 0, '00726338', 'FreeDiams::CA_HCDPD::DIN', 12572);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Fluphenazine Tab 2mg', 'tablet', 'N05AB02', false, 0, '00726346', 'FreeDiams::CA_HCDPD::DIN', 12573);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Fluphenazine Tab 5mg', 'tablet', 'N05AB02', false, 0, '00726354', 'FreeDiams::CA_HCDPD::DIN', 12574);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Yohimbine Hydrochloride Tab 2mg', 'tablet', 'G04BE04', false, 0, '00885533', 'FreeDiams::CA_HCDPD::DIN', 12575);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rovamycine 500 Capsule 1500000 Unit', 'capsule', 'J01FA02', false, 0, '01927817', 'FreeDiams::CA_HCDPD::DIN', 12601);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Expectorant Syrup (Sucrose Free)', 'syrup', 'R05CA03', false, 0, '01952129', 'FreeDiams::CA_HCDPD::DIN', 12620);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm Syrup (Sucrose Free)', 'syrup', 'R05DA09', false, 0, '01952137', 'FreeDiams::CA_HCDPD::DIN', 12621);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cocaine Hydrochloride Top Sol 40mg/Ml', 'liquid', 'R02AD03', false, 0, '01962388', 'FreeDiams::CA_HCDPD::DIN', 12625);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germicidal Hand Soap Liq 0.6%', 'liquid', 'D08AE05', false, 0, '01977873', 'FreeDiams::CA_HCDPD::DIN', 12639);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Dexamethasone', 'drops', 'S03BA01', false, 0, '00739839', 'FreeDiams::CA_HCDPD::DIN', 12640);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Chloramphenicol Ophthalmic Soln 0.5%', 'drops', 'S01AA01', false, 0, '00861383', 'FreeDiams::CA_HCDPD::DIN', 12644);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidocaine Hydrochloride Injection 1% Usp', 'solution', 'C01BB01', false, 0, '00884154', 'FreeDiams::CA_HCDPD::DIN', 12645);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Sodium 25000unit/500ml In 5% Dextr Inj', 'solution', 'B01AB01', false, 0, '00894605', 'FreeDiams::CA_HCDPD::DIN', 12646);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Sodium 20000unit/500ml In Dext 5% Inj', 'solution', 'B01AB01', false, 0, '00894648', 'FreeDiams::CA_HCDPD::DIN', 12647);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('2% Lidocaine Hydrochloride And Epinephrine 1:100000 Inj Usp', 'solution', 'N01BB52', false, 0, '01901915', 'FreeDiams::CA_HCDPD::DIN', 12648);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('1% Lidocaine Hydrochloride And Epinephrine 1:100000 Inj Usp', 'solution', 'N01BB52', false, 0, '01901958', 'FreeDiams::CA_HCDPD::DIN', 12649);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vasotec Iv', 'solution', 'C09AA02', false, 0, '01923846', 'FreeDiams::CA_HCDPD::DIN', 12650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Panectyl Tab 5mg', 'tablet', 'R06AD01', false, 0, '01926292', 'FreeDiams::CA_HCDPD::DIN', 12651);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neuleptil 5mg Capsules', 'capsule', 'N05AC01', false, 0, '01926780', 'FreeDiams::CA_HCDPD::DIN', 12653);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flagystatin Vaginal Ovule', 'suppository', 'G01AA51', false, 0, '01926829', 'FreeDiams::CA_HCDPD::DIN', 12654);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zoloft Cap 50mg', 'capsule', 'N06AB06', false, 0, '01962817', 'FreeDiams::CA_HCDPD::DIN', 12662);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fentanyl Citrate Injection', 'solution', 'N01AH01', false, 0, '00888346', 'FreeDiams::CA_HCDPD::DIN', 12664);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Doxepin Cap 25mg Usp', 'capsule', 'N06AA12', false, 0, '01913425', 'FreeDiams::CA_HCDPD::DIN', 12669);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Doxepin Cap 50mg Usp', 'capsule', 'N06AA12', false, 0, '01913433', 'FreeDiams::CA_HCDPD::DIN', 12670);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Doxepin Cap 75mg Usp', 'capsule', 'N06AA12', false, 0, '01913441', 'FreeDiams::CA_HCDPD::DIN', 12671);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Doxepin Cap 100mg Usp', 'capsule', 'N06AA12', false, 0, '01913468', 'FreeDiams::CA_HCDPD::DIN', 12672);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Doxepin Cap 150mg Usp', 'capsule', 'N06AA12', false, 0, '01913476', 'FreeDiams::CA_HCDPD::DIN', 12673);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gentamicin Sulfate In Nacl 0.9% Inj', 'solution', 'J01GB03', false, 0, '01913530', 'FreeDiams::CA_HCDPD::DIN', 12674);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gentamicin Sulfate In Nacl O.9% Inj', 'solution', 'J01GB03', false, 0, '01913549', 'FreeDiams::CA_HCDPD::DIN', 12675);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dopamine Hydrochloride And 5% Dextrose Injection Usp', 'solution', 'C01CA04', false, 0, '00782394', 'FreeDiams::CA_HCDPD::DIN', 12681);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Hydral Tab 10mg', 'tablet', 'C02DB02', false, 0, '01913204', 'FreeDiams::CA_HCDPD::DIN', 12691);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Clonidine Tab 0.2mg', 'tablet', 'C02AC01', false, 0, '01913220', 'FreeDiams::CA_HCDPD::DIN', 12692);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Clonidine Tab 0.1mg', 'tablet', 'C02AC01', false, 0, '01913786', 'FreeDiams::CA_HCDPD::DIN', 12693);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Prazo Tab 1mg', 'tablet', 'C02CA01', false, 0, '01913794', 'FreeDiams::CA_HCDPD::DIN', 12694);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Prazo Tab 2mg', 'tablet', 'C02CA01', false, 0, '01913808', 'FreeDiams::CA_HCDPD::DIN', 12695);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Prazo Tab 5mg', 'tablet', 'C02CA01', false, 0, '01913816', 'FreeDiams::CA_HCDPD::DIN', 12696);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenytoin Sodium Inj 50mg/Ml Usp', 'solution', 'N03AB02', false, 0, '00497304', 'FreeDiams::CA_HCDPD::DIN', 12697);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Lactulose', 'solution', 'A06AD11', false, 0, '00854409', 'FreeDiams::CA_HCDPD::DIN', 12699);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Forte Injection 25mg/Ml Usp', 'solution', 'N02AA01', false, 0, '00869317', 'FreeDiams::CA_HCDPD::DIN', 12701);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Extra Forte Injection 50mg/Ml Usp', 'solution', 'N02AA01', false, 0, '00869325', 'FreeDiams::CA_HCDPD::DIN', 12702);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('A-Hydrocort Inj 500mg/4ml', 'powder for solution', 'H02AB09', false, 0, '00888214', 'FreeDiams::CA_HCDPD::DIN', 12703);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('3.3% Dextrose And 0.3% Sodium Chloride Injection Usp', 'solution', 'B05BB02', false, 0, '01927981', 'FreeDiams::CA_HCDPD::DIN', 12711);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germi Stat Gel 4%', 'gel', 'D08AC02', false, 0, '01930087', 'FreeDiams::CA_HCDPD::DIN', 12713);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Pediatric Formula 44e Liq', 'liquid', 'R05FA02', false, 0, '01938886', 'FreeDiams::CA_HCDPD::DIN', 12717);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Pediatric Formula 44m Liq', 'liquid', 'R05DA20', false, 0, '01938894', 'FreeDiams::CA_HCDPD::DIN', 12718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Pediatric Formula 44d Liq', 'liquid', 'R05DA20', false, 0, '01938908', 'FreeDiams::CA_HCDPD::DIN', 12719);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Pediatric Formula 44 Liq', 'liquid', 'R05DA09', false, 0, '01938916', 'FreeDiams::CA_HCDPD::DIN', 12720);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Formula 44m Liq', 'liquid', 'N02BE51', false, 0, '01938940', 'FreeDiams::CA_HCDPD::DIN', 12722);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Custom Care Dry Cough', 'liquid', 'R05DA09', false, 0, '01938959', 'FreeDiams::CA_HCDPD::DIN', 12723);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sominex Tablets 25mg', 'tablet', 'R06AA02', false, 0, '01944290', 'FreeDiams::CA_HCDPD::DIN', 12725);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine-Epd Injection 1mg/Ml Usp', 'solution', 'N02AA01', false, 0, '01949055', 'FreeDiams::CA_HCDPD::DIN', 12728);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isolyte S (Multi-Electrolyte Injection)', 'solution', 'B05BB01', false, 0, '01931628', 'FreeDiams::CA_HCDPD::DIN', 12741);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Unisom', 'tablet', 'R06AA02', false, 0, '01946986', 'FreeDiams::CA_HCDPD::DIN', 12743);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Unisom-2 Tablets', 'tablet', 'R06AA09', false, 0, '01946994', 'FreeDiams::CA_HCDPD::DIN', 12744);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Duvoid Tablets 25 Mg', 'tablet', 'N07AB02', false, 0, '01947931', 'FreeDiams::CA_HCDPD::DIN', 12745);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Duvoid Tablets 10 Mg', 'tablet', 'N07AB02', false, 0, '01947958', 'FreeDiams::CA_HCDPD::DIN', 12746);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin A Acid 0.01% Gel', 'gel', 'D10AD01', false, 0, '01926462', 'FreeDiams::CA_HCDPD::DIN', 12753);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin A Acid 0.025% Gel', 'gel', 'D10AD01', false, 0, '01926470', 'FreeDiams::CA_HCDPD::DIN', 12754);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Gain Liq 20mg/Ml', 'liquid', 'D11AX01', false, 0, '00885754', 'FreeDiams::CA_HCDPD::DIN', 12757);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Monopril Tab 10mg', 'tablet', 'C09AA09', false, 0, '01907107', 'FreeDiams::CA_HCDPD::DIN', 12759);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Monopril Tab 20mg', 'tablet', 'C09AA09', false, 0, '01907115', 'FreeDiams::CA_HCDPD::DIN', 12760);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anusol Plus Suppositories', 'suppository', 'C05AD07', false, 0, '01945904', 'FreeDiams::CA_HCDPD::DIN', 12763);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anusol Plus Ointment', 'ointment', 'C05AD07', false, 0, '01945912', 'FreeDiams::CA_HCDPD::DIN', 12764);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metricide', 'solution', 'V07AV', false, 0, '01963996', 'FreeDiams::CA_HCDPD::DIN', 12767);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metricide 28', 'liquid', 'V07AV', false, 0, '01964461', 'FreeDiams::CA_HCDPD::DIN', 12768);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metricide Plus 30', 'liquid', 'V07AV', false, 0, '01964496', 'FreeDiams::CA_HCDPD::DIN', 12770);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hytrin Tab 10mg', 'tablet', 'G04CA03', false, 0, '00818674', 'FreeDiams::CA_HCDPD::DIN', 12778);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biaxin Bid 250mg', 'tablet', 'J01FA09', false, 0, '01984853', 'FreeDiams::CA_HCDPD::DIN', 12779);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('10% Dextrose And 0.9% Sodium Chloride Injection Usp', 'solution', 'B05BB02', false, 0, '01927922', 'FreeDiams::CA_HCDPD::DIN', 12787);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balminil Dm  (3mg/Ml Sucrose Free)', 'syrup', 'R05DA09', false, 0, '01928775', 'FreeDiams::CA_HCDPD::DIN', 12788);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Inhibit Gel', 'gel', 'D08AE20', false, 0, '01939661', 'FreeDiams::CA_HCDPD::DIN', 12792);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Oxtriphylline Elixir', 'elixir', 'R03DA54', false, 0, '00792942', 'FreeDiams::CA_HCDPD::DIN', 12803);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coumadin Tab 1mg', 'tablet', 'B01AA03', false, 0, '01918311', 'FreeDiams::CA_HCDPD::DIN', 12818);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coumadin Tab 5mg', 'tablet', 'B01AA03', false, 0, '01918354', 'FreeDiams::CA_HCDPD::DIN', 12819);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Calcimar Solution Inj 200unit/Ml', 'solution', 'H05BA01', false, 0, '01926691', 'FreeDiams::CA_HCDPD::DIN', 12837);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo Zidovudine Cap 100mg', 'capsule', 'J05AF01', false, 0, '01946323', 'FreeDiams::CA_HCDPD::DIN', 12839);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spor-Hc Otic Susp', 'suspension', 'S02CA03', false, 0, '00626600', 'FreeDiams::CA_HCDPD::DIN', 12843);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Myochrysine', 'solution', 'M01CB01', false, 0, '01927604', 'FreeDiams::CA_HCDPD::DIN', 12845);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Myochrysine', 'solution', 'M01CB01', false, 0, '01927612', 'FreeDiams::CA_HCDPD::DIN', 12846);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Erythromycin Lactobionate Pws 500mg', 'powder for solution', 'J01FA01', false, 0, '01958518', 'FreeDiams::CA_HCDPD::DIN', 12858);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Erythromycin Lactobionate Pws 1000mg', 'powder for solution', 'J01FA01', false, 0, '01958542', 'FreeDiams::CA_HCDPD::DIN', 12859);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germi-Stat 0.5% Antiseptic Prep Gel', 'gel', 'D08AC52', false, 0, '01975242', 'FreeDiams::CA_HCDPD::DIN', 12861);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Triacomb Regular Cream', 'cream', 'D07CB01', false, 0, '00550507', 'FreeDiams::CA_HCDPD::DIN', 12862);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cetrimide Cream 0.5%', 'cream', 'D08AJ02', false, 0, '00874426', 'FreeDiams::CA_HCDPD::DIN', 12864);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glyburide-2.5 Tab 2.5mg', 'tablet', 'A10BB01', false, 0, '01959352', 'FreeDiams::CA_HCDPD::DIN', 12865);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ak Mycin Oph Ont 5mg/Gm', 'ointment', 'S01AA17', false, 0, '00641324', 'FreeDiams::CA_HCDPD::DIN', 12875);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Bisacodyl', 'suppository', 'A06AB02', false, 0, '00582883', 'FreeDiams::CA_HCDPD::DIN', 12877);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Timolol', 'tablet', 'C07AA06', false, 0, '01947826', 'FreeDiams::CA_HCDPD::DIN', 12879);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Timolol', 'tablet', 'C07AA06', false, 0, '01947818', 'FreeDiams::CA_HCDPD::DIN', 12880);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rocaltrol Oral Solution 1mcg/Ml', 'solution', 'A11CC04', false, 0, '00824291', 'FreeDiams::CA_HCDPD::DIN', 12885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Duvoid Tablets 50 Mg', 'tablet', 'N07AB02', false, 0, '01947923', 'FreeDiams::CA_HCDPD::DIN', 12887);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenylephrine Hydrochloride Injection Usp', 'liquid', 'C01CA06', false, 0, '01953583', 'FreeDiams::CA_HCDPD::DIN', 12889);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Combantrin Oral Suspension 50mg/Ml', 'suspension', 'P02CC01', false, 0, '01944355', 'FreeDiams::CA_HCDPD::DIN', 12925);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Combantrin Tab 125mg', 'tablet', 'P02CC01', false, 0, '01944363', 'FreeDiams::CA_HCDPD::DIN', 12926);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norvasc Tab 5mg', 'tablet', 'C08CA01', false, 0, '00878928', 'FreeDiams::CA_HCDPD::DIN', 12938);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norvasc Tab 10mg', 'tablet', 'C08CA01', false, 0, '00878936', 'FreeDiams::CA_HCDPD::DIN', 12939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robaxacet-8', 'tablet', 'M03BA53', false, 0, '01934767', 'FreeDiams::CA_HCDPD::DIN', 12942);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robaxisal C-1/8 Tablets', 'tablet', 'M03BA53', false, 0, '01934775', 'FreeDiams::CA_HCDPD::DIN', 12943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robaxisal C 1/4', 'tablet', 'M03BA53', false, 0, '01934783', 'FreeDiams::CA_HCDPD::DIN', 12944);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robaxisal C 1/2', 'tablet', 'N02AA59', false, 0, '01934791', 'FreeDiams::CA_HCDPD::DIN', 12946);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Huile De Bain Therapeutique', 'liquid', 'D02AC', false, 0, '01939068', 'FreeDiams::CA_HCDPD::DIN', 12947);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robitussin Children''S', 'syrup', 'R05DA09', false, 0, '01953966', 'FreeDiams::CA_HCDPD::DIN', 12950);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ciloxan', 'solution', 'S01AX13', false, 0, '01945270', 'FreeDiams::CA_HCDPD::DIN', 12953);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlor-Tripolon Nd Srt', 'tablet (extended-release)', 'R01BA52', false, 0, '01970399', 'FreeDiams::CA_HCDPD::DIN', 12955);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Hylazin Tab 10mg Usp', 'tablet', 'C02DB02', false, 0, '00759465', 'FreeDiams::CA_HCDPD::DIN', 12959);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Dexamethasone Elixir 0.5mg/5ml', 'liquid', 'H02AB02', false, 0, '01946897', 'FreeDiams::CA_HCDPD::DIN', 12967);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine-Epd Injection 0.5mg/Ml Usp', 'solution', 'N02AA01', false, 0, '01949047', 'FreeDiams::CA_HCDPD::DIN', 12968);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eldopaque Crm 2%', 'cream', 'D11AX11', false, 0, '01964526', 'FreeDiams::CA_HCDPD::DIN', 12972);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eldoquin', 'cream', 'D11AX11', false, 0, '01941917', 'FreeDiams::CA_HCDPD::DIN', 12973);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyclen Tablets (28 Day)', 'tablet', 'G03AA11', false, 0, '01992872', 'FreeDiams::CA_HCDPD::DIN', 12988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sulfate Injection 2mg/Ml Usp', 'solution', 'N02AA01', false, 0, '00850314', 'FreeDiams::CA_HCDPD::DIN', 12990);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sulfate Injection 10mg/Ml Usp', 'solution', 'N02AA01', false, 0, '00850322', 'FreeDiams::CA_HCDPD::DIN', 12991);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sulfate Injection 15mg/Ml Usp', 'solution', 'N02AA01', false, 0, '00850330', 'FreeDiams::CA_HCDPD::DIN', 12992);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Iopidine Oph Sol 1%', 'liquid', 'S01EA03', false, 0, '00888354', 'FreeDiams::CA_HCDPD::DIN', 12993);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kidrolase', 'powder for solution', 'L01XX02', false, 0, '01926438', 'FreeDiams::CA_HCDPD::DIN', 12995);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flagystatin Cream', 'cream', 'G01AA51', false, 0, '01926845', 'FreeDiams::CA_HCDPD::DIN', 12996);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flagyl Cream 10%', 'cream', 'G01AF01', false, 0, '01926861', 'FreeDiams::CA_HCDPD::DIN', 12997);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyclen Tablets (21 Day)', 'tablet', 'G03AA11', false, 0, '01968440', 'FreeDiams::CA_HCDPD::DIN', 12998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('E-Z Scrub 747 4%', 'liquid', 'D08AC02', false, 0, '01939947', 'FreeDiams::CA_HCDPD::DIN', 13003);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro Sone Lot 0.05%', 'lotion', 'D07AC01', false, 0, '01944444', 'FreeDiams::CA_HCDPD::DIN', 13005);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mazon Medicated Soap', 'soap bar', 'D05AA', false, 0, '01981293', 'FreeDiams::CA_HCDPD::DIN', 13012);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mazon Medicated Cream', 'cream', 'D05AA', false, 0, '01981307', 'FreeDiams::CA_HCDPD::DIN', 13013);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mazon Medicated Shampoo', 'shampoo', 'D05AA', false, 0, '01981315', 'FreeDiams::CA_HCDPD::DIN', 13014);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bicart Pwr 650gm/Ctg', 'powder', 'B05ZA', false, 0, '00882666', 'FreeDiams::CA_HCDPD::DIN', 13018);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Timolol', 'tablet', 'C07AA06', false, 0, '01947796', 'FreeDiams::CA_HCDPD::DIN', 13021);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Azt Cap 100mg', 'capsule', 'J05AF01', false, 0, '01953877', 'FreeDiams::CA_HCDPD::DIN', 13022);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Dextrose And 0.45% Sodium Chloride Injection Usp', 'solution', 'B05BB02', false, 0, '01927531', 'FreeDiams::CA_HCDPD::DIN', 13033);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('0.15% Potassium Chloride In 3.3% Dextrose And 0.30% Sodium Chloride Injection', 'solution', 'B05BB02', false, 0, '01931741', 'FreeDiams::CA_HCDPD::DIN', 13034);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Provera 2.5mg Tablets', 'tablet', 'G03DA02', false, 0, '00708917', 'FreeDiams::CA_HCDPD::DIN', 13037);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Silace Syr 20mg/5ml', 'liquid', 'A06AA02', false, 0, '00876550', 'FreeDiams::CA_HCDPD::DIN', 13039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Contact', 'liquid', 'D08AE05', false, 0, '00892777', 'FreeDiams::CA_HCDPD::DIN', 13062);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tremytoine Inj 50mg/Ml', 'liquid', 'N03AB02', false, 0, '00498335', 'FreeDiams::CA_HCDPD::DIN', 13063);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Alumina Mag And Simethicone Sus', 'suspension', 'A02AF02', false, 0, '00894079', 'FreeDiams::CA_HCDPD::DIN', 13074);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Prednisolone Sod Phos Oph Sol Forte 1%', 'drops', 'S01BA04', false, 0, '01954237', 'FreeDiams::CA_HCDPD::DIN', 13075);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sulfate Inj 1mg/Ml Usp', 'solution', 'N02AA01', false, 0, '01980696', 'FreeDiams::CA_HCDPD::DIN', 13077);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sulfate Inj 2mg/Ml Usp', 'solution', 'N02AA01', false, 0, '01964437', 'FreeDiams::CA_HCDPD::DIN', 13078);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sulfate Inj 5mg/Ml Usp', 'solution', 'N02AA01', false, 0, '01964429', 'FreeDiams::CA_HCDPD::DIN', 13079);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rovamycine 250 Capsule 750000 Unit', 'capsule', 'J01FA02', false, 0, '01927825', 'FreeDiams::CA_HCDPD::DIN', 13090);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diazepam Solution 1mg/Ml', 'solution', 'N05BA01', false, 0, '00891797', 'FreeDiams::CA_HCDPD::DIN', 13092);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Timolol', 'solution', 'S01ED01', false, 0, '00893781', 'FreeDiams::CA_HCDPD::DIN', 13095);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diodoquin Tab 210mg', 'tablet', 'P01AA', false, 0, '01997769', 'FreeDiams::CA_HCDPD::DIN', 13104);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diodoquin Tab 650mg', 'tablet', 'P01AA', false, 0, '01997750', 'FreeDiams::CA_HCDPD::DIN', 13112);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorphone Hydrochloride Sup 3mg', 'suppository', 'N02AA03', false, 0, '01979914', 'FreeDiams::CA_HCDPD::DIN', 13113);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cortamed Ont 25 Mg/Gm', 'ointment', 'S01BA02', false, 0, '01980661', 'FreeDiams::CA_HCDPD::DIN', 13115);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentamycetin Liq 2.5mg/Ml', 'solution', 'S01AA01', false, 0, '01980556', 'FreeDiams::CA_HCDPD::DIN', 13116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentamycetin Ont 10mg/Gm', 'ointment', 'S01AA01', false, 0, '01980564', 'FreeDiams::CA_HCDPD::DIN', 13117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinutab Nd Extra Strength Tab', 'tablet', 'N02BE51', false, 0, '01938371', 'FreeDiams::CA_HCDPD::DIN', 13120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acular Liq 0.5%', 'solution', 'S01BC05', false, 0, '01968300', 'FreeDiams::CA_HCDPD::DIN', 13121);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zaroxolyn', 'tablet', 'C03BA08', false, 0, '00888400', 'FreeDiams::CA_HCDPD::DIN', 13126);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Yohimbine-Odan 6mg', 'tablet', 'G04BE04', false, 0, '01985604', 'FreeDiams::CA_HCDPD::DIN', 13132);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cloxacillin Sodium For Inj 1000mg', 'powder for solution', 'J01CF02', false, 0, '01975447', 'FreeDiams::CA_HCDPD::DIN', 13134);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Act-Hib', 'kit', 'J07AG51', false, 0, '01959034', 'FreeDiams::CA_HCDPD::DIN', 13140);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ak Chlor Oph Ont 1%', 'ointment', 'S01AA01', false, 0, '00627720', 'FreeDiams::CA_HCDPD::DIN', 13141);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ak Trol Suspension', 'suspension', 'S01CA01', false, 0, '00626597', 'FreeDiams::CA_HCDPD::DIN', 13146);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Myochrysine', 'solution', 'M01CB01', false, 0, '01927620', 'FreeDiams::CA_HCDPD::DIN', 13156);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nasacort', 'metered-dose (aerosol)', 'R01AD11', false, 0, '01913328', 'FreeDiams::CA_HCDPD::DIN', 13157);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neuleptil Gouttes 10mg/Ml', 'drops', 'N05AC01', false, 0, '01926756', 'FreeDiams::CA_HCDPD::DIN', 13159);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nozinan Inj 25mg/Ml', 'solution', 'N05AA02', false, 0, '01927698', 'FreeDiams::CA_HCDPD::DIN', 13163);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piportil L4', 'solution', 'N05AC04', false, 0, '01926667', 'FreeDiams::CA_HCDPD::DIN', 13164);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tears Naturale Free Dps', 'drops', 'S01XA20', false, 0, '01943308', 'FreeDiams::CA_HCDPD::DIN', 13167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Timolol', 'solution', 'S01ED01', false, 0, '00893773', 'FreeDiams::CA_HCDPD::DIN', 13177);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Domperidone', 'tablet', 'A03FA03', false, 0, '01912070', 'FreeDiams::CA_HCDPD::DIN', 13180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pulmicort Nebuamp 0.5 Mg/Ml', 'suspension', 'R03BA02', false, 0, '01978926', 'FreeDiams::CA_HCDPD::DIN', 13190);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pulmicort Nebuamp 0.25 Mg/Ml', 'suspension', 'R03BA02', false, 0, '01978918', 'FreeDiams::CA_HCDPD::DIN', 13191);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spectrum  Liq', 'liquid', 'V07AV', false, 0, '02006529', 'FreeDiams::CA_HCDPD::DIN', 13211);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cerubidine 20mg/Vial', 'powder for solution', 'L01DB02', false, 0, '01926683', 'FreeDiams::CA_HCDPD::DIN', 13226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Formulation Hws-128', 'liquid', 'V07AV', false, 0, '01944037', 'FreeDiams::CA_HCDPD::DIN', 13233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solugel', 'gel', 'D10AE01', false, 0, '01975382', 'FreeDiams::CA_HCDPD::DIN', 13244);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Skin-E-Dip Ont', 'ointment', 'D02AB', false, 0, '01949950', 'FreeDiams::CA_HCDPD::DIN', 13247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Formulation Hws-256', 'liquid', 'V07AV', false, 0, '01944029', 'FreeDiams::CA_HCDPD::DIN', 13249);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexamethasone Sodium Phos Inj 4mg/Ml Usp', 'liquid', 'H02AB02', false, 0, '01977547', 'FreeDiams::CA_HCDPD::DIN', 13255);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Manerix', 'tablet', 'N06AG02', false, 0, '00899356', 'FreeDiams::CA_HCDPD::DIN', 13256);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Caffeine & 8mg Cod. Phos. Tab', 'tablet', 'N02BE51', false, 0, '01997688', 'FreeDiams::CA_HCDPD::DIN', 13259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Triamcinolone Diacetate Sus 40mg/Ml', 'liquid', 'H02AB08', false, 0, '01977555', 'FreeDiams::CA_HCDPD::DIN', 13276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sominex Extra Strength Caplet 50mg', 'tablet', 'R06AA02', false, 0, '01957996', 'FreeDiams::CA_HCDPD::DIN', 13277);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Physiogesic Cream 100mg/Gm', 'cream', 'M02AC', false, 0, '01942190', 'FreeDiams::CA_HCDPD::DIN', 13284);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('0.9% Sodium Chloride Irrigation Usp', 'solution', 'B05CB01', false, 0, '01963937', 'FreeDiams::CA_HCDPD::DIN', 13286);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Water For Irrigation Usp', 'liquid', 'V07AB', false, 0, '01963961', 'FreeDiams::CA_HCDPD::DIN', 13287);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Dextrose And 0.9% Sodium Chloride Injection Usp', 'solution', 'B05BB02', false, 0, '01924435', 'FreeDiams::CA_HCDPD::DIN', 13288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stanhexidine 2% With Isopropyl Alcohol 4%', 'solution', 'D08AC52', false, 0, '01938991', 'FreeDiams::CA_HCDPD::DIN', 13289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stanhexidine 4% With Isopropyl Alcohol 4%', 'solution', 'D08AC52', false, 0, '01938983', 'FreeDiams::CA_HCDPD::DIN', 13290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Formulation Hws-64', 'liquid', 'V07AV', false, 0, '01944045', 'FreeDiams::CA_HCDPD::DIN', 13294);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robitussin Cough Control', 'liquid', 'R05FA02', false, 0, '01931024', 'FreeDiams::CA_HCDPD::DIN', 13296);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robaxin', 'tablet', 'M03BA03', false, 0, '01930990', 'FreeDiams::CA_HCDPD::DIN', 13297);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Progesterone Inj 50mg/Ml Usp', 'liquid', 'G03DA04', false, 0, '01977652', 'FreeDiams::CA_HCDPD::DIN', 13300);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creon 25 Minimicrospheres', 'capsule', 'A09AA02', false, 0, '01985205', 'FreeDiams::CA_HCDPD::DIN', 13302);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bonefos', 'solution', 'M05BA02', false, 0, '01984837', 'FreeDiams::CA_HCDPD::DIN', 13304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bonefos', 'capsule', 'M05BA02', false, 0, '01984845', 'FreeDiams::CA_HCDPD::DIN', 13305);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benzac W 5 Gel 5%', 'gel', 'D10AE01', false, 0, '01925180', 'FreeDiams::CA_HCDPD::DIN', 13311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triatec-8 Fort Tab', 'tablet', 'N02BE51', false, 0, '01977881', 'FreeDiams::CA_HCDPD::DIN', 13312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hycodan Tablets', 'tablet', 'R05DA03', false, 0, '01916599', 'FreeDiams::CA_HCDPD::DIN', 13314);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hycodan Syrup', 'syrup', 'R05DA03', false, 0, '01916580', 'FreeDiams::CA_HCDPD::DIN', 13315);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Percocet-Demi', 'tablet', 'N02BE51', false, 0, '01916491', 'FreeDiams::CA_HCDPD::DIN', 13316);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyanocobalamin Injection 1000mcg/Ml', 'liquid', 'B03BA01', false, 0, '01987003', 'FreeDiams::CA_HCDPD::DIN', 13324);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spectro Gram 2 Skin Cleanser', 'liquid', 'D08AC02', false, 0, '00758485', 'FreeDiams::CA_HCDPD::DIN', 13327);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ak Spor Liq', 'liquid', 'S01AA30', false, 0, '00635065', 'FreeDiams::CA_HCDPD::DIN', 13328);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dovonex Ont 50mcg/Gm', 'ointment', 'D05AX02', false, 0, '01976133', 'FreeDiams::CA_HCDPD::DIN', 13340);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desi Rince Liq 10%', 'solution', 'V07AV', false, 0, '01924451', 'FreeDiams::CA_HCDPD::DIN', 13341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desi Fome Liq 3.5%', 'liquid', 'V07AV', false, 0, '01924486', 'FreeDiams::CA_HCDPD::DIN', 13342);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Steri/Sol Liquid', 'liquid', 'A01AB12', false, 0, '01946900', 'FreeDiams::CA_HCDPD::DIN', 13344);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zap Topical Anesthetic Gel Cool Mint', 'gel', 'D04AB30', false, 0, '01930699', 'FreeDiams::CA_HCDPD::DIN', 13347);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Burn O Sol Spray', 'spray', 'D04AB04', false, 0, '01936220', 'FreeDiams::CA_HCDPD::DIN', 13349);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Airx 109 Super Concentrate Flexo', 'liquid', 'V07AV', false, 0, '00868728', 'FreeDiams::CA_HCDPD::DIN', 13352);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antiseptic Hand Soap Liq 0.3%', 'liquid', 'D08AE04', false, 0, '01972286', 'FreeDiams::CA_HCDPD::DIN', 13357);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oracort Dental Paste 0.1%', 'paste', 'A01AC01', false, 0, '01964054', 'FreeDiams::CA_HCDPD::DIN', 13360);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Cold & Nighttime Cough', 'syrup', 'R05DA20', false, 0, '00896179', 'FreeDiams::CA_HCDPD::DIN', 13361);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gas X Extra Strength', 'tablet', 'A03AX13', false, 0, '00896675', 'FreeDiams::CA_HCDPD::DIN', 13362);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proscar', 'tablet', 'G04CB01', false, 0, '02010909', 'FreeDiams::CA_HCDPD::DIN', 13370);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Perfection Nettoyant Desinfectant Liquide', 'liquid', 'V07AV', false, 0, '02004496', 'FreeDiams::CA_HCDPD::DIN', 13373);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coumadin Tab 4mg', 'tablet', 'B01AA03', false, 0, '02007959', 'FreeDiams::CA_HCDPD::DIN', 13375);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eldoquin Forte', 'cream', 'D11AX11', false, 0, '01941925', 'FreeDiams::CA_HCDPD::DIN', 13382);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentamycetin/Hc', 'suspension', 'S03CA04', false, 0, '01980572', 'FreeDiams::CA_HCDPD::DIN', 13383);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Magnevist', 'solution', 'V08CA01', false, 0, '01989987', 'FreeDiams::CA_HCDPD::DIN', 13384);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desferal 2g', 'powder for solution', 'V03AC01', false, 0, '01981250', 'FreeDiams::CA_HCDPD::DIN', 13390);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cocaine Hydrochloride Topical Sol 10%', 'liquid', 'R02AD03', false, 0, '02004062', 'FreeDiams::CA_HCDPD::DIN', 13391);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zoloft Cap 100mg', 'capsule', 'N06AB06', false, 0, '01962779', 'FreeDiams::CA_HCDPD::DIN', 13392);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Super Quam Liq', 'liquid', 'V07AV', false, 0, '01905694', 'FreeDiams::CA_HCDPD::DIN', 13394);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Capto Tab 6.25mg', 'tablet', 'C09AA01', false, 0, '01999559', 'FreeDiams::CA_HCDPD::DIN', 13401);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxsoralen Lot 10mg/Ml', 'lotion', 'D05AD02', false, 0, '01907476', 'FreeDiams::CA_HCDPD::DIN', 13403);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Testosterone Cypionate Inj 100mg/Ml', 'liquid', 'G03BA03', false, 0, '01977601', 'FreeDiams::CA_HCDPD::DIN', 13410);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Andriol', 'capsule', 'G03BA03', false, 0, '00782327', 'FreeDiams::CA_HCDPD::DIN', 13411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Hydral Tab 50 Mg', 'tablet', 'C02DB02', false, 0, '02004836', 'FreeDiams::CA_HCDPD::DIN', 13412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Hydral Tab 25mg', 'tablet', 'C02DB02', false, 0, '02004828', 'FreeDiams::CA_HCDPD::DIN', 13413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Testosterone Propionate Inj 100mg/Ml Usp', 'liquid', 'G03BA03', false, 0, '01977571', 'FreeDiams::CA_HCDPD::DIN', 13414);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro Zn', 'solution', 'A12CB01', false, 0, '00787000', 'FreeDiams::CA_HCDPD::DIN', 13416);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coumadin Tab 10mg', 'tablet', 'B01AA03', false, 0, '01918362', 'FreeDiams::CA_HCDPD::DIN', 13418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coumadin Tab 2.5mg', 'tablet', 'B01AA03', false, 0, '01918346', 'FreeDiams::CA_HCDPD::DIN', 13419);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbolith Capsules 600mg', 'capsule', 'N05AN01', false, 0, '02011239', 'FreeDiams::CA_HCDPD::DIN', 13429);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prinzide', 'tablet', 'C09BA03', false, 0, '00884413', 'FreeDiams::CA_HCDPD::DIN', 13431);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Clobetasol', 'cream', 'D07AD01', false, 0, '01910272', 'FreeDiams::CA_HCDPD::DIN', 13437);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Clobetasol', 'lotion', 'D07AD01', false, 0, '01910299', 'FreeDiams::CA_HCDPD::DIN', 13438);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Clobetasol', 'ointment', 'D07AD01', false, 0, '01910280', 'FreeDiams::CA_HCDPD::DIN', 13439);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Cough And Chest Congestion Extra Strength With Warming Sensation', 'syrup', 'R05FA02', false, 0, '02003317', 'FreeDiams::CA_HCDPD::DIN', 13440);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lupron Depot', 'powder for suspension, sustained-release', 'L02AE02', false, 0, '00884502', 'FreeDiams::CA_HCDPD::DIN', 13443);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy Tablets 25mg', 'tablet', 'R06AA02', false, 0, '01949454', 'FreeDiams::CA_HCDPD::DIN', 13447);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Theolair Liq 80mg/15ml', 'liquid', 'R03DA04', false, 0, '01966219', 'FreeDiams::CA_HCDPD::DIN', 13450);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro Zn', 'solution', 'A12CB01', false, 0, '00787019', 'FreeDiams::CA_HCDPD::DIN', 13451);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advil Caplets', 'tablet', 'M01AE01', false, 0, '01933531', 'FreeDiams::CA_HCDPD::DIN', 13452);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Amantadine Hydrochloride Cap 100mg', 'capsule', 'N04BB01', false, 0, '01990403', 'FreeDiams::CA_HCDPD::DIN', 13464);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Botox', 'powder for solution', 'M03AX01', false, 0, '01981501', 'FreeDiams::CA_HCDPD::DIN', 13476);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Madame Pearl''S Cough Syrup', 'syrup', 'R05FA02', false, 0, '01968602', 'FreeDiams::CA_HCDPD::DIN', 13479);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro Mn', 'solution', 'A12CX', false, 0, '00786942', 'FreeDiams::CA_HCDPD::DIN', 13486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro Mn', 'solution', 'A12CX', false, 0, '00786950', 'FreeDiams::CA_HCDPD::DIN', 13489);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robitussin Ac', 'syrup', 'R05FA02', false, 0, '01934740', 'FreeDiams::CA_HCDPD::DIN', 13494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Water For Injection Usp', 'liquid', 'V07AB', false, 0, '01927930', 'FreeDiams::CA_HCDPD::DIN', 13509);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tambocor Tab 50mg', 'tablet', 'C01BC04', false, 0, '01966197', 'FreeDiams::CA_HCDPD::DIN', 13513);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tambocor Tab 100mg', 'tablet', 'C01BC04', false, 0, '01966200', 'FreeDiams::CA_HCDPD::DIN', 13514);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Dextromethorphan Hydrobromide Syr 3mg/Ml', 'syrup', 'R05DA09', false, 0, '00816000', 'FreeDiams::CA_HCDPD::DIN', 13517);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro Cr', 'solution', 'A12CX', false, 0, '00786985', 'FreeDiams::CA_HCDPD::DIN', 13523);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stievamycin Forte', 'gel', 'D10AF52', false, 0, '01945262', 'FreeDiams::CA_HCDPD::DIN', 13524);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterrad 100 Cassette Liq 58%', 'liquid', 'V07AV', false, 0, '01980475', 'FreeDiams::CA_HCDPD::DIN', 13535);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coumadin Tab 2mg', 'tablet', 'B01AA03', false, 0, '01918338', 'FreeDiams::CA_HCDPD::DIN', 13536);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vaseline White Petroleum Jelly', 'ointment', 'D02AC', false, 0, '00760390', 'FreeDiams::CA_HCDPD::DIN', 13538);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xeroform Dressing 3%', 'dressing', 'D09AX', false, 0, '00760374', 'FreeDiams::CA_HCDPD::DIN', 13539);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desferal 500mg', 'powder for solution', 'V03AC01', false, 0, '01981242', 'FreeDiams::CA_HCDPD::DIN', 13546);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Salbutamol Sterinebs P.F.', 'solution', 'R03AC02', false, 0, '01926934', 'FreeDiams::CA_HCDPD::DIN', 13550);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Su 319 - Liquid Quaternary Disinfectant', 'liquid', 'V07AV', false, 0, '01995758', 'FreeDiams::CA_HCDPD::DIN', 13553);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Indomethacin', 'suppository', 'M01AB01', false, 0, '01934139', 'FreeDiams::CA_HCDPD::DIN', 13558);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro Se', 'solution', 'A12CX', false, 0, '01986007', 'FreeDiams::CA_HCDPD::DIN', 13559);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro Cu', 'solution', 'A12CX', false, 0, '00786969', 'FreeDiams::CA_HCDPD::DIN', 13563);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Guaitussin Dm Cough Formula Syr', 'syrup', 'R05FA02', false, 0, '01915533', 'FreeDiams::CA_HCDPD::DIN', 13565);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sarna P', 'lotion', 'D04AB07', false, 0, '00874825', 'FreeDiams::CA_HCDPD::DIN', 13570);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Famotidine Tab 20mg Usp', 'tablet', 'A02BA03', false, 0, '01953842', 'FreeDiams::CA_HCDPD::DIN', 13572);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxsoralen Cap 10mg', 'capsule', 'D05BA02', false, 0, '01946374', 'FreeDiams::CA_HCDPD::DIN', 13573);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tantum Liq 0.15%', 'solution', 'A01AD02', false, 0, '01966065', 'FreeDiams::CA_HCDPD::DIN', 13579);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentaspan', 'solution', 'B05AA07', false, 0, '00887110', 'FreeDiams::CA_HCDPD::DIN', 13582);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Famotidine Tab 40mg Usp', 'tablet', 'A02BA03', false, 0, '01953834', 'FreeDiams::CA_HCDPD::DIN', 13583);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alomide Liq 0.1%', 'liquid', 'S01GX05', false, 0, '00893560', 'FreeDiams::CA_HCDPD::DIN', 13591);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Provera Pak 10mg Tablets', 'tablet', 'G03DA02', false, 0, '02010933', 'FreeDiams::CA_HCDPD::DIN', 13592);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro I', 'liquid', 'A12CX', false, 0, '01974548', 'FreeDiams::CA_HCDPD::DIN', 13600);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dristan Non-Drowsy Extra Strength Caplet', 'tablet', 'N02BE51', false, 0, '01932659', 'FreeDiams::CA_HCDPD::DIN', 13607);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Uphold Plus', 'gel', 'D08AE20', false, 0, '01990284', 'FreeDiams::CA_HCDPD::DIN', 13617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robaxin 750', 'tablet', 'M03BA03', false, 0, '01932187', 'FreeDiams::CA_HCDPD::DIN', 13624);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advil Tablets', 'tablet', 'M01AE01', false, 0, '01933558', 'FreeDiams::CA_HCDPD::DIN', 13625);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lithane', 'capsule', 'N05AN01', false, 0, '02013231', 'FreeDiams::CA_HCDPD::DIN', 13626);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polytrim Ophthalmic Solution', 'solution', 'S01AA30', false, 0, '02011956', 'FreeDiams::CA_HCDPD::DIN', 13628);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vivotif', 'capsule (enteric-coated)', 'J07AP01', false, 0, '00885975', 'FreeDiams::CA_HCDPD::DIN', 13630);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arthrotec 50', 'tablet', 'M01AB55', false, 0, '01917056', 'FreeDiams::CA_HCDPD::DIN', 13636);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Prochlor Tab 5mg', 'tablet', 'N05AB04', false, 0, '01964399', 'FreeDiams::CA_HCDPD::DIN', 13641);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Prochlor Tab 10mg', 'tablet', 'N05AB04', false, 0, '01964402', 'FreeDiams::CA_HCDPD::DIN', 13642);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Famotidine Tab 20mg', 'tablet', 'A02BA03', false, 0, '02022133', 'FreeDiams::CA_HCDPD::DIN', 13654);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Famotidine Tab 40mg', 'tablet', 'A02BA03', false, 0, '02022141', 'FreeDiams::CA_HCDPD::DIN', 13655);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Whirl Away', 'aerosol', 'V07AV', false, 0, '01995782', 'FreeDiams::CA_HCDPD::DIN', 13656);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Salbutamol', 'solution', 'R03AC02', false, 0, '01986864', 'FreeDiams::CA_HCDPD::DIN', 13668);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentamycetin/Hc', 'ointment', 'S03CA04', false, 0, '01980580', 'FreeDiams::CA_HCDPD::DIN', 13682);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Airx 78 Plus Liq', 'liquid', 'V07AV', false, 0, '01975625', 'FreeDiams::CA_HCDPD::DIN', 13683);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xanax Tab 1mg', 'tablet', 'N05BA12', false, 0, '00723770', 'FreeDiams::CA_HCDPD::DIN', 13685);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xanax Ts Tab 2mg', 'tablet', 'N05BA12', false, 0, '00813958', 'FreeDiams::CA_HCDPD::DIN', 13686);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Airx 44 Plus Liq', 'liquid', 'V07AV', false, 0, '01975633', 'FreeDiams::CA_HCDPD::DIN', 13687);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actril Cold Sterilant Liq', 'liquid', 'V07AV', false, 0, '02001020', 'FreeDiams::CA_HCDPD::DIN', 13689);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Topilene', 'lotion', 'D07AC01', false, 0, '01927914', 'FreeDiams::CA_HCDPD::DIN', 13690);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('A.C.& C Tablets', 'tablet', 'N02BA51', false, 0, '01922246', 'FreeDiams::CA_HCDPD::DIN', 13699);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Scrub-A-Dub Germicidal Cleaner', 'aerosol', 'V07AV', false, 0, '01996002', 'FreeDiams::CA_HCDPD::DIN', 13705);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aerobex', 'aerosol', 'V07AV', false, 0, '01981595', 'FreeDiams::CA_HCDPD::DIN', 13706);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Dextrose Injection Usp', 'solution', 'B05BA03', false, 0, '01924281', 'FreeDiams::CA_HCDPD::DIN', 13714);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lariam Tab 250mg', 'tablet', 'P01BC02', false, 0, '02018055', 'FreeDiams::CA_HCDPD::DIN', 13721);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prozac Capsules 10mg', 'capsule', 'N06AB03', false, 0, '02018985', 'FreeDiams::CA_HCDPD::DIN', 13723);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophene Codeine Et Cafeine Caplets', 'tablet', 'N02BE51', false, 0, '01996541', 'FreeDiams::CA_HCDPD::DIN', 13761);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophene Codeine Et Cafeine Fort', 'tablet', 'N02BE51', false, 0, '01996568', 'FreeDiams::CA_HCDPD::DIN', 13765);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topicale Gel Pump Pina Colada', 'gel', 'A01AD11', false, 0, '01945726', 'FreeDiams::CA_HCDPD::DIN', 13766);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Westokleen Liq', 'liquid', 'V07AV', false, 0, '02012278', 'FreeDiams::CA_HCDPD::DIN', 13767);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Trazodone Hcl Tab 100mg', 'tablet', 'N06AX05', false, 0, '01937235', 'FreeDiams::CA_HCDPD::DIN', 13780);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benadryl 25mg Caplets', 'tablet', 'R06AA02', false, 0, '02017849', 'FreeDiams::CA_HCDPD::DIN', 13782);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bm-7000 Chemical Autoclave Solution', 'solution', 'V07AV', false, 0, '02025426', 'FreeDiams::CA_HCDPD::DIN', 13786);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Durr System-Hygiene Id 212 Instrument Disinf', 'liquid', 'V07AV', false, 0, '02016877', 'FreeDiams::CA_HCDPD::DIN', 13788);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Livostin Sus Nas 0.5mg/Ml', 'kit', 'R01AC02', false, 0, '02020017', 'FreeDiams::CA_HCDPD::DIN', 13796);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nubain Injection 10mg/Ml', 'solution', 'N02AF02', false, 0, '01913980', 'FreeDiams::CA_HCDPD::DIN', 13803);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Allergy Sinus Caplets', 'tablet', 'N02BE51', false, 0, '01933728', 'FreeDiams::CA_HCDPD::DIN', 13804);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Voltaren Rapide Tablets 50mg', 'tablet', 'M01AB05', false, 0, '00881635', 'FreeDiams::CA_HCDPD::DIN', 13805);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eliminator Surface Dis & Deod Spray', 'aerosol', 'V07AV', false, 0, '01981625', 'FreeDiams::CA_HCDPD::DIN', 13830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('K + 45', 'liquid', 'B05ZA', false, 0, '01905740', 'FreeDiams::CA_HCDPD::DIN', 13833);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Inhibace Tab 5mg', 'tablet', 'C09AA08', false, 0, '01911481', 'FreeDiams::CA_HCDPD::DIN', 13834);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Inhibace Tab 2.5mg', 'tablet', 'C09AA08', false, 0, '01911473', 'FreeDiams::CA_HCDPD::DIN', 13835);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Gemfibrozil Cap 300mg Usp', 'capsule', 'C10AB04', false, 0, '01979574', 'FreeDiams::CA_HCDPD::DIN', 13840);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Gemfibrozil', 'tablet', 'C10AB04', false, 0, '01979582', 'FreeDiams::CA_HCDPD::DIN', 13841);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Leustatin 1mg/Ml', 'solution', 'L01BB04', false, 0, '02022117', 'FreeDiams::CA_HCDPD::DIN', 13846);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Naproxen Sodium Ds', 'tablet', 'M01AE02', false, 0, '02026600', 'FreeDiams::CA_HCDPD::DIN', 13848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Durr System Hygiene Id 220 Ins Disinfection', 'liquid', 'V07AV', false, 0, '02027070', 'FreeDiams::CA_HCDPD::DIN', 13850);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cromolyn Eye Drops', 'solution', 'S01GX01', false, 0, '02009277', 'FreeDiams::CA_HCDPD::DIN', 13857);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol Extra Strength Gelcaps Tab 500mg', 'tablet', 'N02BE01', false, 0, '00863270', 'FreeDiams::CA_HCDPD::DIN', 13865);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ddavp Inj 4mcg/Ml', 'liquid', 'H01BA02', false, 0, '00873993', 'FreeDiams::CA_HCDPD::DIN', 13867);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maitre-D', 'liquid', 'V07AV', false, 0, '02015552', 'FreeDiams::CA_HCDPD::DIN', 13868);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Derma Smoothe/Fs Liq 0.01%', 'liquid', 'D07AC04', false, 0, '00873292', 'FreeDiams::CA_HCDPD::DIN', 13875);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitrogen Nf 99%', 'gas', 'V03AN04', false, 0, '02014394', 'FreeDiams::CA_HCDPD::DIN', 13882);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Helium Usp 99%', 'gas', 'V03AN03', false, 0, '02014475', 'FreeDiams::CA_HCDPD::DIN', 13883);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbon Dioxide Usp', 'gas', 'V03AN02', false, 0, '02014459', 'FreeDiams::CA_HCDPD::DIN', 13884);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Air Usp', 'gas', 'V03AN', false, 0, '02014483', 'FreeDiams::CA_HCDPD::DIN', 13885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen 99%', 'gas', 'V03AN01', false, 0, '02014408', 'FreeDiams::CA_HCDPD::DIN', 13886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitrous Oxide Usp 99%', 'gas', 'N01AX13', false, 0, '02014467', 'FreeDiams::CA_HCDPD::DIN', 13887);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Topisone', 'ointment', 'D07AC01', false, 0, '00805009', 'FreeDiams::CA_HCDPD::DIN', 13888);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Topisone', 'cream', 'D07AC01', false, 0, '00804991', 'FreeDiams::CA_HCDPD::DIN', 13889);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen Usp, Helium Usp, Medical Gas Mixture', 'gas', 'V03AN20', false, 0, '02014440', 'FreeDiams::CA_HCDPD::DIN', 13890);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Durr System-Hygiene Md 520 Impression Disin.', 'liquid', 'V07AV', false, 0, '02029898', 'FreeDiams::CA_HCDPD::DIN', 13891);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbon Dioxide Usp, Compressed Air Usp M.G.M', 'gas', 'V03AN05', false, 0, '02014416', 'FreeDiams::CA_HCDPD::DIN', 13892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen Usp, Nitrogen Nf, Medical Gas Mixture', 'gas', 'V03AN20', false, 0, '02014378', 'FreeDiams::CA_HCDPD::DIN', 13894);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbon Monoxide, Compressed Air Medical G.M.', 'gas', 'V03AN05', false, 0, '02014351', 'FreeDiams::CA_HCDPD::DIN', 13895);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbon Dioxide, Compressed Air Medical G.Mix.', 'gas', 'V03AN05', false, 0, '02014343', 'FreeDiams::CA_HCDPD::DIN', 13896);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbon Dioxide Usp, Compressed Air Usp M.G.M', 'gas', 'V03AN05', false, 0, '02014335', 'FreeDiams::CA_HCDPD::DIN', 13897);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solaquin Forte', 'cream', 'D11AX11', false, 0, '01977830', 'FreeDiams::CA_HCDPD::DIN', 13899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperdal', 'tablet', 'N05AX08', false, 0, '02025299', 'FreeDiams::CA_HCDPD::DIN', 13903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperdal', 'tablet', 'N05AX08', false, 0, '02025280', 'FreeDiams::CA_HCDPD::DIN', 13904);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperdal', 'tablet', 'N05AX08', false, 0, '02025302', 'FreeDiams::CA_HCDPD::DIN', 13906);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ulone Syr', 'syrup', 'R05DB10', false, 0, '01966294', 'FreeDiams::CA_HCDPD::DIN', 13907);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultravate Ointment 0.05%', 'ointment', 'D07AC21', false, 0, '01962728', 'FreeDiams::CA_HCDPD::DIN', 13909);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbon Dioxide Usp, Oxygen Usp Medical G.M.', 'gas', 'V03AN20', false, 0, '02014432', 'FreeDiams::CA_HCDPD::DIN', 13910);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultravate Cream', 'cream', 'D07AC21', false, 0, '01962701', 'FreeDiams::CA_HCDPD::DIN', 13917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbon Monox, Helium, Oxygen, Nitrogen L.D.M.', 'gas', 'V03AN', false, 0, '02014424', 'FreeDiams::CA_HCDPD::DIN', 13920);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperdal', 'tablet', 'N05AX08', false, 0, '02025310', 'FreeDiams::CA_HCDPD::DIN', 13922);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Retisol-A', 'cream', 'D10AD51', false, 0, '02008726', 'FreeDiams::CA_HCDPD::DIN', 13929);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Retisol-A', 'cream', 'D10AD51', false, 0, '02008696', 'FreeDiams::CA_HCDPD::DIN', 13930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Minocycline', 'capsule', 'J01AA08', false, 0, '01914138', 'FreeDiams::CA_HCDPD::DIN', 13943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Selax 250  Cap 250mg', 'capsule', 'A06AA02', false, 0, '02006596', 'FreeDiams::CA_HCDPD::DIN', 13945);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Prednisolone', 'suspension', 'S01BA04', false, 0, '01916203', 'FreeDiams::CA_HCDPD::DIN', 13946);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Minocycline', 'capsule', 'J01AA08', false, 0, '01914146', 'FreeDiams::CA_HCDPD::DIN', 13948);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pharmalgen Wasp Venom Protein', 'powder for solution', 'V01AA07', false, 0, '01948989', 'FreeDiams::CA_HCDPD::DIN', 13950);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pharmalgen Yellow Jacket Venom Protein', 'powder for solution', 'V01AA07', false, 0, '01948962', 'FreeDiams::CA_HCDPD::DIN', 13951);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pharmalgen Yellow Hornet Venom Protein', 'powder for solution', 'V01AA07', false, 0, '01948946', 'FreeDiams::CA_HCDPD::DIN', 13952);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Retisol-A', 'cream', 'D10AD51', false, 0, '02008688', 'FreeDiams::CA_HCDPD::DIN', 13954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Retisol-A', 'cream', 'D10AD51', false, 0, '02008718', 'FreeDiams::CA_HCDPD::DIN', 13958);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitetime Cold Medicine Liq', 'liquid', 'N02BE51', false, 0, '01900501', 'FreeDiams::CA_HCDPD::DIN', 13960);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nubain Injection 20mg/Ml', 'solution', 'N02AF02', false, 0, '01913972', 'FreeDiams::CA_HCDPD::DIN', 13963);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Lp Epidural', 'solution', 'N02AA01', false, 0, '02021056', 'FreeDiams::CA_HCDPD::DIN', 13966);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Claritin Syrup 1mg/Ml', 'syrup', 'R06AX13', false, 0, '02019973', 'FreeDiams::CA_HCDPD::DIN', 13970);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caltine Inj 100 Unit/Ml (1ml Amp)', 'liquid', 'H05BA01', false, 0, '02007134', 'FreeDiams::CA_HCDPD::DIN', 13975);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Durr System-Hygiene Fd 322 Disinf.Hand &Ang.', 'liquid', 'V07AV', false, 0, '02016885', 'FreeDiams::CA_HCDPD::DIN', 13988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lamisil Tab 250mg', 'tablet', 'D01BA02', false, 0, '02031116', 'FreeDiams::CA_HCDPD::DIN', 13990);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Triamcinolone Acetonide Sus 40mg/Ml', 'suspension', 'H02AB08', false, 0, '01977563', 'FreeDiams::CA_HCDPD::DIN', 13998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenol 6%', 'solution', 'N01BX03', false, 0, '02009188', 'FreeDiams::CA_HCDPD::DIN', 13999);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norflex Inj Liq 30mg/Ml', 'liquid', 'M03BC01', false, 0, '01966162', 'FreeDiams::CA_HCDPD::DIN', 14003);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paxil Tab 30mg', 'tablet', 'N06AB05', false, 0, '01940473', 'FreeDiams::CA_HCDPD::DIN', 14006);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paxil Tab 20mg', 'tablet', 'N06AB05', false, 0, '01940481', 'FreeDiams::CA_HCDPD::DIN', 14007);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benoquin Crm 20%', 'cream', 'D11AX13', false, 0, '01966391', 'FreeDiams::CA_HCDPD::DIN', 14008);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dantrium Intravenous     -Pws 20mg/Vial', 'powder for solution', 'M03CA01', false, 0, '01997572', 'FreeDiams::CA_HCDPD::DIN', 14017);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dantrium Capsules    -100mg', 'capsule', 'M03CA01', false, 0, '01997653', 'FreeDiams::CA_HCDPD::DIN', 14018);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dantrium Capsules    -25mg', 'capsule', 'M03CA01', false, 0, '01997602', 'FreeDiams::CA_HCDPD::DIN', 14019);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Lp Epidural', 'solution', 'N02AA01', false, 0, '02021048', 'FreeDiams::CA_HCDPD::DIN', 14020);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermazin Crm 1%', 'cream', 'D06BA01', false, 0, '02010917', 'FreeDiams::CA_HCDPD::DIN', 14024);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ketoprofen', 'suppository', 'M01AE03', false, 0, '02015951', 'FreeDiams::CA_HCDPD::DIN', 14025);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Theo-La Srt 300mg', 'tablet (extended-release)', 'R03DA04', false, 0, '00692700', 'FreeDiams::CA_HCDPD::DIN', 14031);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Theo-La Srt 200mg', 'tablet (extended-release)', 'R03DA04', false, 0, '00692697', 'FreeDiams::CA_HCDPD::DIN', 14032);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Theo-La Srt 100mg', 'tablet (extended-release)', 'R03DA04', false, 0, '00692689', 'FreeDiams::CA_HCDPD::DIN', 14033);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Light Mineral Oil 100% Nf', 'liquid', 'D02AC', false, 0, '01935321', 'FreeDiams::CA_HCDPD::DIN', 14042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Napro-Na Ds Tab 550mg', 'tablet', 'M01AE02', false, 0, '01940309', 'FreeDiams::CA_HCDPD::DIN', 14048);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lovenox', 'solution', 'B01AB05', false, 0, '02012472', 'FreeDiams::CA_HCDPD::DIN', 14049);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('4.25% Travasol Amino Acid Injection With Electrolytes In 10% Dextrose Clinimix', 'solution', 'B05BA10', false, 0, '02014025', 'FreeDiams::CA_HCDPD::DIN', 14066);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Travasol Amino Acid Injection Without Electrolytes In 25% Dextrose Clinimix', 'solution', 'B05BA10', false, 0, '02013959', 'FreeDiams::CA_HCDPD::DIN', 14067);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Travasol Amino Acid Injection With Electrolytes In 25% Dextrose Clinimix', 'solution', 'B05BA10', false, 0, '02014084', 'FreeDiams::CA_HCDPD::DIN', 14068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('2.5% Travasol Amino Acid Injection With Electrolytes In 10% Dextrose Clinimix', 'solution', 'B05BA10', false, 0, '02013975', 'FreeDiams::CA_HCDPD::DIN', 14069);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('4.25% Travasol Amino Acid Injection Without Electrolytes In 25% Dextrose Clinimix', 'solution', 'B05BA10', false, 0, '02013916', 'FreeDiams::CA_HCDPD::DIN', 14071);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('4.25% Travasol Amino Acid Injection With Electrolytes In 25% Dextrose Clinimix', 'solution', 'B05BA10', false, 0, '02014041', 'FreeDiams::CA_HCDPD::DIN', 14072);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('4.25% Travasol Amino Acid Injection Without Electrolytes In 10% Dextrose Clinimix', 'solution', 'B05BA10', false, 0, '02013924', 'FreeDiams::CA_HCDPD::DIN', 14073);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Travasol Amino Acid Injection With Electrolytes In 10% Dextrose Clinimix', 'solution', 'B05BA10', false, 0, '02014076', 'FreeDiams::CA_HCDPD::DIN', 14075);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Travasol Amino Acid Injection With Electrolytes In 16.6% Dextrose Clinimix', 'solution', 'B05BA10', false, 0, '02013967', 'FreeDiams::CA_HCDPD::DIN', 14076);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Travasol Amino Acid Injection Without Electrolytes In 5% Dextrose Clinimix', 'solution', 'B05BA10', false, 0, '02013886', 'FreeDiams::CA_HCDPD::DIN', 14077);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinemet Cr 100/25', 'tablet (extended-release)', 'N04BA02', false, 0, '02028786', 'FreeDiams::CA_HCDPD::DIN', 14082);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Trimipramine Tab 12.5mg', 'tablet', 'N06AA06', false, 0, '02020599', 'FreeDiams::CA_HCDPD::DIN', 14083);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Tab 500mg Usp', 'tablet', 'N02BE01', false, 0, '01927507', 'FreeDiams::CA_HCDPD::DIN', 14084);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Trimipramine Tab 100mg', 'tablet', 'N06AA06', false, 0, '02020629', 'FreeDiams::CA_HCDPD::DIN', 14085);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Trimipramine Tab 50mg', 'tablet', 'N06AA06', false, 0, '02020610', 'FreeDiams::CA_HCDPD::DIN', 14086);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Trimipramine Tab 25mg', 'tablet', 'N06AA06', false, 0, '02020602', 'FreeDiams::CA_HCDPD::DIN', 14087);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Ibuprofen Tab 300mg', 'tablet', 'M01AE01', false, 0, '02020696', 'FreeDiams::CA_HCDPD::DIN', 14089);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Ibuprofen Tab 400mg', 'tablet', 'M01AE01', false, 0, '02020718', 'FreeDiams::CA_HCDPD::DIN', 14090);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Ibuprofen Tab 600mg', 'tablet', 'M01AE01', false, 0, '02020726', 'FreeDiams::CA_HCDPD::DIN', 14091);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Flurbiprofen Tab 50mg', 'tablet', 'M01AE09', false, 0, '02020661', 'FreeDiams::CA_HCDPD::DIN', 14092);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Flurbiprofen Tab 100mg', 'tablet', 'M01AE09', false, 0, '02020688', 'FreeDiams::CA_HCDPD::DIN', 14093);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Glyburide Tab 5mg', 'tablet', 'A10BB01', false, 0, '02020742', 'FreeDiams::CA_HCDPD::DIN', 14094);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Glyburide Tab 2.5mg', 'tablet', 'A10BB01', false, 0, '02020734', 'FreeDiams::CA_HCDPD::DIN', 14095);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pharmalgen Mixed Vespid Venom Protein', 'powder for solution', 'V01AA07', false, 0, '01948873', 'FreeDiams::CA_HCDPD::DIN', 14101);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S. Sulphate 25mg Tab', 'tablet', 'N02AA01', false, 0, '02009749', 'FreeDiams::CA_HCDPD::DIN', 14107);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S. Sulphate 50mg Tab', 'tablet', 'N02AA01', false, 0, '02009706', 'FreeDiams::CA_HCDPD::DIN', 14108);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S. Sulphate 10mg Tab', 'tablet', 'N02AA01', false, 0, '02009765', 'FreeDiams::CA_HCDPD::DIN', 14110);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.O.S. Sulphate 5mg Tab', 'tablet', 'N02AA01', false, 0, '02009773', 'FreeDiams::CA_HCDPD::DIN', 14111);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Desipramine Hydro Tab 50mg', 'tablet', 'N06AA01', false, 0, '01946277', 'FreeDiams::CA_HCDPD::DIN', 14116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Desipramine Hydro Tab 10mg', 'tablet', 'N06AA01', false, 0, '01946250', 'FreeDiams::CA_HCDPD::DIN', 14117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Desipramine Hydro Tab 25mg', 'tablet', 'N06AA01', false, 0, '01946269', 'FreeDiams::CA_HCDPD::DIN', 14118);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Prednisolone', 'suspension', 'S01BA04', false, 0, '01916181', 'FreeDiams::CA_HCDPD::DIN', 14126);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acétaminophčne Comprimé Tablet 325', 'tablet', 'N02BE01', false, 0, '02022214', 'FreeDiams::CA_HCDPD::DIN', 14130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acétaminophčne Comprimé Tablet 500', 'tablet', 'N02BE01', false, 0, '02022222', 'FreeDiams::CA_HCDPD::DIN', 14131);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rivasone Scalp Lot 0.1%', 'lotion', 'D07AC01', false, 0, '01940112', 'FreeDiams::CA_HCDPD::DIN', 14132);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ms Contin Srt 200mg', 'tablet (extended-release)', 'N02AA01', false, 0, '02014327', 'FreeDiams::CA_HCDPD::DIN', 14142);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ms Ir Tab 10mg', 'tablet', 'N02AA01', false, 0, '02014211', 'FreeDiams::CA_HCDPD::DIN', 14144);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isoflurane Usp', 'liquid', 'N01AB06', false, 0, '02032384', 'FreeDiams::CA_HCDPD::DIN', 14158);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elmiron   -(100mg)', 'capsule', 'C05BA04', false, 0, '02029448', 'FreeDiams::CA_HCDPD::DIN', 14161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ms Contin Srt 30mg', 'tablet (extended-release)', 'N02AA01', false, 0, '02014297', 'FreeDiams::CA_HCDPD::DIN', 14176);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bm-28 Plus Activated 2% Glutaraldehyde Liq', 'liquid', 'V07AV', false, 0, '02041227', 'FreeDiams::CA_HCDPD::DIN', 14177);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ms Contin Srt 100mg', 'tablet (extended-release)', 'N02AA01', false, 0, '02014319', 'FreeDiams::CA_HCDPD::DIN', 14178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sclerodex', 'liquid', 'C05BB56', false, 0, '02020939', 'FreeDiams::CA_HCDPD::DIN', 14183);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ortho-Cept Tablets (28 Day)', 'tablet', 'G03AA09', false, 0, '02042533', 'FreeDiams::CA_HCDPD::DIN', 14191);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rocleen-Rml', 'liquid', 'V07AV', false, 0, '02025450', 'FreeDiams::CA_HCDPD::DIN', 14193);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tri-Cyclen Tablets - 21-Day', 'tablet', 'G03AB11', false, 0, '02028700', 'FreeDiams::CA_HCDPD::DIN', 14197);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tri-Cyclen Tablets - 28-Day', 'tablet', 'G03AB11', false, 0, '02029421', 'FreeDiams::CA_HCDPD::DIN', 14199);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophene 80mgco.Croquable Pour Enfant', 'tablet (chewable)', 'N02BE01', false, 0, '02017458', 'FreeDiams::CA_HCDPD::DIN', 14206);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nova Liq', 'liquid', 'V07AV', false, 0, '01904159', 'FreeDiams::CA_HCDPD::DIN', 14211);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Al-Forty Five Liq', 'liquid', 'V07AV', false, 0, '01904485', 'FreeDiams::CA_HCDPD::DIN', 14213);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Al Ninety Liq', 'liquid', 'V07AV', false, 0, '01935305', 'FreeDiams::CA_HCDPD::DIN', 14215);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sleep Aid (Regular Strength) Tab 25mg', 'tablet', 'R06AA02', false, 0, '01994247', 'FreeDiams::CA_HCDPD::DIN', 14223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine Endotracheal', 'solution', 'R02AD02', false, 0, '02003767', 'FreeDiams::CA_HCDPD::DIN', 14240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taxol', 'solution', 'L01CD01', false, 0, '02016796', 'FreeDiams::CA_HCDPD::DIN', 14248);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('10% Dextran 40 In 0.9% Sodium Chloride Injection', 'solution', 'B05AA55', false, 0, '01924206', 'FreeDiams::CA_HCDPD::DIN', 14249);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Dextrose In Lactated Ringer''S Injection', 'solution', 'B05BB02', false, 0, '01931652', 'FreeDiams::CA_HCDPD::DIN', 14250);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('10% Dextrose Injection Usp', 'solution', 'B05BA03', false, 0, '01924427', 'FreeDiams::CA_HCDPD::DIN', 14251);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('G-1085 Liq', 'liquid', 'V07AV', false, 0, '02034689', 'FreeDiams::CA_HCDPD::DIN', 14255);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benadryl Cream 2%', 'cream', 'D04AA32', false, 0, '02019701', 'FreeDiams::CA_HCDPD::DIN', 14257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novolin Ge Toronto', 'solution', 'A10AB01', false, 0, '02024233', 'FreeDiams::CA_HCDPD::DIN', 14260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novolin Ge Nph', 'suspension', 'A10AC01', false, 0, '02024225', 'FreeDiams::CA_HCDPD::DIN', 14261);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novolin Ge 40/60 Penfill', 'suspension', 'A10AD01', false, 0, '02024314', 'FreeDiams::CA_HCDPD::DIN', 14262);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novolin Ge 30/70 Penfill', 'suspension', 'A10AD01', false, 0, '02025248', 'FreeDiams::CA_HCDPD::DIN', 14265);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novolin Ge Nph Penfill', 'suspension', 'A10AC01', false, 0, '02024268', 'FreeDiams::CA_HCDPD::DIN', 14266);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novolin Ge 30/70', 'suspension', 'A10AD01', false, 0, '02024217', 'FreeDiams::CA_HCDPD::DIN', 14269);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novolin Ge 50/50 Penfill', 'suspension', 'A10AD01', false, 0, '02024322', 'FreeDiams::CA_HCDPD::DIN', 14270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lotensin 5mg', 'tablet', 'C09AA07', false, 0, '00885835', 'FreeDiams::CA_HCDPD::DIN', 14273);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lotensin 10mg', 'tablet', 'C09AA07', false, 0, '00885843', 'FreeDiams::CA_HCDPD::DIN', 14274);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lotensin 20mg', 'tablet', 'C09AA07', false, 0, '00885851', 'FreeDiams::CA_HCDPD::DIN', 14276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jaa Prednisone Tab 50mg Usp', 'tablet', 'H02AB07', false, 0, '00868434', 'FreeDiams::CA_HCDPD::DIN', 14281);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jaa Tetra Tab 250mg', 'tablet', 'J01AA07', false, 0, '00889393', 'FreeDiams::CA_HCDPD::DIN', 14282);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Desipramine Hydro Tab 75mg', 'tablet', 'N06AA01', false, 0, '01946242', 'FreeDiams::CA_HCDPD::DIN', 14288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bufferin Extra -Strength', 'tablet', 'N02BA01', false, 0, '01990691', 'FreeDiams::CA_HCDPD::DIN', 14311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bufferin', 'tablet', 'N02BA01', false, 0, '01990667', 'FreeDiams::CA_HCDPD::DIN', 14312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Excedrin Extra-Strength', 'tablet', 'N02BE51', false, 0, '01990675', 'FreeDiams::CA_HCDPD::DIN', 14316);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Survanta Sus Itr 25mg/Ml', 'suspension', 'R07AA30', false, 0, '02016109', 'FreeDiams::CA_HCDPD::DIN', 14318);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germal Liq', 'liquid', 'V07AV', false, 0, '02026236', 'FreeDiams::CA_HCDPD::DIN', 14321);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Burinex Tab 5mg', 'tablet', 'C03CA02', false, 0, '00728276', 'FreeDiams::CA_HCDPD::DIN', 14322);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eldopaque Forte Crm 4%', 'cream', 'D11AX11', false, 0, '01964534', 'FreeDiams::CA_HCDPD::DIN', 14324);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norflex Tab 100mg', 'tablet (extended-release)', 'M03BC01', false, 0, '01966154', 'FreeDiams::CA_HCDPD::DIN', 14325);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olestyr', 'powder for suspension', 'C10AC01', false, 0, '00890960', 'FreeDiams::CA_HCDPD::DIN', 14332);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Burinex Tab 1mg', 'tablet', 'C03CA02', false, 0, '00728284', 'FreeDiams::CA_HCDPD::DIN', 14334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marvelon 21', 'tablet', 'G03AA09', false, 0, '02042487', 'FreeDiams::CA_HCDPD::DIN', 14354);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marvelon 28', 'tablet', 'G03AA09', false, 0, '02042479', 'FreeDiams::CA_HCDPD::DIN', 14355);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('P-1-71-M Nettoyeur Desinfectant Liquide', 'liquid', 'V07AV', false, 0, '02025205', 'FreeDiams::CA_HCDPD::DIN', 14368);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asadol 325mg', 'tablet (enteric-coated)', 'N02BA01', false, 0, '02046253', 'FreeDiams::CA_HCDPD::DIN', 14369);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asadol 650mg', 'tablet (enteric-coated)', 'N02BA01', false, 0, '02046261', 'FreeDiams::CA_HCDPD::DIN', 14370);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Clobetasol Cream', 'cream', 'D07AD01', false, 0, '02024187', 'FreeDiams::CA_HCDPD::DIN', 14381);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Clobetasol Ointment', 'ointment', 'D07AD01', false, 0, '02026767', 'FreeDiams::CA_HCDPD::DIN', 14382);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Caplets Extra Strength', 'tablet', 'N02BE01', false, 0, '01962353', 'FreeDiams::CA_HCDPD::DIN', 14383);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Enalapril Tab 2.5mg', 'tablet', 'C09AA02', false, 0, '02020025', 'FreeDiams::CA_HCDPD::DIN', 14385);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Enalapril Tab 5mg', 'tablet', 'C09AA02', false, 0, '02019884', 'FreeDiams::CA_HCDPD::DIN', 14386);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Enalapril Tab 10mg', 'tablet', 'C09AA02', false, 0, '02019892', 'FreeDiams::CA_HCDPD::DIN', 14387);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Enalapril Tab 20mg', 'tablet', 'C09AA02', false, 0, '02019906', 'FreeDiams::CA_HCDPD::DIN', 14388);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Optiray 350  -74%', 'solution', 'V08AB07', false, 0, '02034484', 'FreeDiams::CA_HCDPD::DIN', 14389);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Amantadine Hydrochloride Syrup 10mg/Ml', 'syrup', 'N04BB01', false, 0, '02022826', 'FreeDiams::CA_HCDPD::DIN', 14393);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ms Contin Srt 60mg', 'tablet (extended-release)', 'N02AA01', false, 0, '02014300', 'FreeDiams::CA_HCDPD::DIN', 14394);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ms Contin Srt 15mg', 'tablet (extended-release)', 'N02AA01', false, 0, '02015439', 'FreeDiams::CA_HCDPD::DIN', 14395);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solugel', 'gel', 'D10AE01', false, 0, '02019825', 'FreeDiams::CA_HCDPD::DIN', 14396);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stievamycin Mild', 'gel', 'D10AF52', false, 0, '02015994', 'FreeDiams::CA_HCDPD::DIN', 14397);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Airx 109 Plus Liq', 'liquid', 'V07AV', false, 0, '01975617', 'FreeDiams::CA_HCDPD::DIN', 14412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ddavp Rhinyle', 'solution', 'H01BA02', false, 0, '00402516', 'FreeDiams::CA_HCDPD::DIN', 14413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Colgate Total Tpt', 'toothpaste', 'A01AA51', false, 0, '02044730', 'FreeDiams::CA_HCDPD::DIN', 14444);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Topilene', 'cream', 'D07AC01', false, 0, '00849650', 'FreeDiams::CA_HCDPD::DIN', 14445);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophene Comprimes Croquables 160mg', 'tablet (chewable)', 'N02BE01', false, 0, '01996169', 'FreeDiams::CA_HCDPD::DIN', 14449);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophene 160mgco.Croquable Pour Enfant', 'tablet', 'N02BE01', false, 0, '02017431', 'FreeDiams::CA_HCDPD::DIN', 14450);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novolin Ge Toronto Penfill', 'solution', 'A10AB01', false, 0, '02024284', 'FreeDiams::CA_HCDPD::DIN', 14459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen 325 Mg Usp Regular Strength', 'tablet', 'N02BE01', false, 0, '00743542', 'FreeDiams::CA_HCDPD::DIN', 14475);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diprivan Eml Iv 1%', 'emulsion', 'N01AX10', false, 0, '02018950', 'FreeDiams::CA_HCDPD::DIN', 14476);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Expectorant Dm Cough Syrup', 'syrup', 'R05FA02', false, 0, '00833258', 'FreeDiams::CA_HCDPD::DIN', 14485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Expectorant Cough Formula Syr 100mg/5ml', 'syrup', 'R05CA03', false, 0, '00813095', 'FreeDiams::CA_HCDPD::DIN', 14486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soflax Capsules 100mg', 'capsule', 'A06AA02', false, 0, '01994344', 'FreeDiams::CA_HCDPD::DIN', 14487);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluviral', 'suspension', 'J07BB01', false, 0, '02015986', 'FreeDiams::CA_HCDPD::DIN', 14488);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Savlodil', 'solution', 'D08AC52', false, 0, '02022206', 'FreeDiams::CA_HCDPD::DIN', 14489);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hibidil', 'solution', 'D08AC02', false, 0, '02022192', 'FreeDiams::CA_HCDPD::DIN', 14490);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sclerodine 6 Injection', 'liquid', 'C05BB', false, 0, '02020793', 'FreeDiams::CA_HCDPD::DIN', 14491);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advil Cold And Sinus', 'tablet', 'M01AE51', false, 0, '02036312', 'FreeDiams::CA_HCDPD::DIN', 14492);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Henry Schein Chemical Autoclave Solution.05%', 'solution', 'V07AV', false, 0, '02007355', 'FreeDiams::CA_HCDPD::DIN', 14494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Henry Schein Antimicrobial Skin Cleanser', 'gel', 'D08AC02', false, 0, '01994042', 'FreeDiams::CA_HCDPD::DIN', 14496);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benzac W Wash Lot 5%', 'lotion', 'D10AE01', false, 0, '00896276', 'FreeDiams::CA_HCDPD::DIN', 14500);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M-Eslon', 'capsule (extended release)', 'N02AA01', false, 0, '02019949', 'FreeDiams::CA_HCDPD::DIN', 14502);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Sucralfate', 'tablet', 'A02BX02', false, 0, '02045702', 'FreeDiams::CA_HCDPD::DIN', 14504);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novamoxin Chewable Tablets 250mg', 'tablet (chewable)', 'J01CA04', false, 0, '02036355', 'FreeDiams::CA_HCDPD::DIN', 14506);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robaxisal Caplets', 'tablet', 'M03BA53', false, 0, '02026783', 'FreeDiams::CA_HCDPD::DIN', 14508);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robaxacet', 'tablet', 'M03BA53', false, 0, '02026805', 'FreeDiams::CA_HCDPD::DIN', 14509);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sporanox', 'capsule', 'J02AC02', false, 0, '02047454', 'FreeDiams::CA_HCDPD::DIN', 14518);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Provera Pak 5mg Tablets', 'tablet', 'G03DA02', false, 0, '02010739', 'FreeDiams::CA_HCDPD::DIN', 14529);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lamisil Crm 1%', 'cream', 'D01AE15', false, 0, '02031094', 'FreeDiams::CA_HCDPD::DIN', 14532);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shampooing Anti-Pelliculaire 1%', 'shampoo', 'D11AX12', false, 0, '02045931', 'FreeDiams::CA_HCDPD::DIN', 14533);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clomipramine Tablets 10mg', 'tablet', 'N06AA04', false, 0, '02040786', 'FreeDiams::CA_HCDPD::DIN', 14535);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clomipramine Tablets 50mg', 'tablet', 'N06AA04', false, 0, '02040751', 'FreeDiams::CA_HCDPD::DIN', 14536);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clomipramine Tablets 25mg', 'tablet', 'N06AA04', false, 0, '02040778', 'FreeDiams::CA_HCDPD::DIN', 14537);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M-Eslon', 'capsule (extended release)', 'N02AA01', false, 0, '02019965', 'FreeDiams::CA_HCDPD::DIN', 14541);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M-Eslon', 'capsule (extended release)', 'N02AA01', false, 0, '02019957', 'FreeDiams::CA_HCDPD::DIN', 14542);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M-Eslon', 'capsule (extended release)', 'N02AA01', false, 0, '02019930', 'FreeDiams::CA_HCDPD::DIN', 14543);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robitussin Children''S Cough And Cold', 'liquid', 'R05DA20', false, 0, '02044013', 'FreeDiams::CA_HCDPD::DIN', 14551);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asacol', 'tablet (enteric-coated)', 'A07EC02', false, 0, '01997580', 'FreeDiams::CA_HCDPD::DIN', 14552);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diflunisal Tab 500mg', 'tablet', 'N02BA11', false, 0, '02039494', 'FreeDiams::CA_HCDPD::DIN', 14553);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diflunisal Tab 250mg', 'tablet', 'N02BA11', false, 0, '02039486', 'FreeDiams::CA_HCDPD::DIN', 14554);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rhinaris-Cs Anti-Allergic Nasal Mist', 'spray, metered dose', 'R01AC01', false, 0, '01950541', 'FreeDiams::CA_HCDPD::DIN', 14565);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Naproxen', 'suppository', 'M01AE02', false, 0, '02017237', 'FreeDiams::CA_HCDPD::DIN', 14566);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Loperamide Hydrochloride Solution.2mg/Ml', 'solution', 'A07DA03', false, 0, '02016095', 'FreeDiams::CA_HCDPD::DIN', 14567);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Salvesept Crm', 'cream', 'D08AC52', false, 0, '01954091', 'FreeDiams::CA_HCDPD::DIN', 14568);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rhinocort Turbuhaler 100 Mcg/Dose', 'powder', 'R01AD05', false, 0, '02035324', 'FreeDiams::CA_HCDPD::DIN', 14570);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glycopyrrolate Injection Usp', 'liquid', 'A03AB02', false, 0, '02039508', 'FreeDiams::CA_HCDPD::DIN', 14577);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isolyte H With Dextrose 5% Inj', 'liquid', 'B05BB02', false, 0, '01931768', 'FreeDiams::CA_HCDPD::DIN', 14578);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('0.45% Sodium Chloride Injection Usp', 'solution', 'B05XA03', false, 0, '01927949', 'FreeDiams::CA_HCDPD::DIN', 14579);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Clonazepam Tab 1.0mg', 'tablet', 'N03AE01', false, 0, '02048728', 'FreeDiams::CA_HCDPD::DIN', 14587);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Clonazepam Tab 0.5mg', 'tablet', 'N03AE01', false, 0, '02048701', 'FreeDiams::CA_HCDPD::DIN', 14588);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Clonazepam Tab 2mg', 'tablet', 'N03AE01', false, 0, '02048736', 'FreeDiams::CA_HCDPD::DIN', 14589);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soflax Dps 10mg/Ml', 'drops', 'A06AA02', false, 0, '02006723', 'FreeDiams::CA_HCDPD::DIN', 14590);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Acetaminophen Suppositories 160mg', 'suppository', 'N02BE01', false, 0, '02046679', 'FreeDiams::CA_HCDPD::DIN', 14591);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Acetaminophen Suppositories 325mg', 'suppository', 'N02BE01', false, 0, '02046687', 'FreeDiams::CA_HCDPD::DIN', 14592);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Acetaminophen Suppositories 120mg', 'suppository', 'N02BE01', false, 0, '02046660', 'FreeDiams::CA_HCDPD::DIN', 14593);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Acetaminophen Suppositories 650mg', 'suppository', 'N02BE01', false, 0, '02046695', 'FreeDiams::CA_HCDPD::DIN', 14594);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen, Caffeine & Codeine', 'tablet', 'N02BE51', false, 0, '02028174', 'FreeDiams::CA_HCDPD::DIN', 14595);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen, Caffeine & Codeine', 'tablet', 'N02BE51', false, 0, '02025337', 'FreeDiams::CA_HCDPD::DIN', 14596);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pharmalgen Wasp Venom Protein', 'powder for solution', 'V01AA07', false, 0, '01948970', 'FreeDiams::CA_HCDPD::DIN', 14597);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pharmalgen Yellow Jacket Venom Protein', 'powder for solution', 'V01AA07', false, 0, '01948954', 'FreeDiams::CA_HCDPD::DIN', 14598);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pharmalgen Mixed Vespid Venom Protein', 'powder for solution', 'V01AA07', false, 0, '01948881', 'FreeDiams::CA_HCDPD::DIN', 14599);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pharmalgen Honey Bee Venom', 'powder for solution', 'V01AA07', false, 0, '01948911', 'FreeDiams::CA_HCDPD::DIN', 14601);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pharmalgen Honey Bee Venom', 'powder for solution', 'V01AA07', false, 0, '01948903', 'FreeDiams::CA_HCDPD::DIN', 14602);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quad-X', 'liquid', 'V07AV', false, 0, '00752320', 'FreeDiams::CA_HCDPD::DIN', 14617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultracare Disinfectant/Cleaner Deodoriz.Conc', 'liquid', 'V07AV', false, 0, '02028883', 'FreeDiams::CA_HCDPD::DIN', 14632);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Entrophen 325mg Caplets', 'tablet (delayed-release)', 'N02BA01', false, 0, '02050161', 'FreeDiams::CA_HCDPD::DIN', 14683);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jaa Aminophylline Tab 100mg', 'tablet', 'R03DA05', false, 0, '00868450', 'FreeDiams::CA_HCDPD::DIN', 14688);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Instrubex G', 'liquid', 'V07AV', false, 0, '01914219', 'FreeDiams::CA_HCDPD::DIN', 14692);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('P.F. Quat Liq', 'liquid', 'V07AV', false, 0, '01933213', 'FreeDiams::CA_HCDPD::DIN', 14705);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Clonidine Tablets 0.2mg', 'tablet', 'C02AC01', false, 0, '02046148', 'FreeDiams::CA_HCDPD::DIN', 14713);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Clonidine Tablets 0.1mg', 'tablet', 'C02AC01', false, 0, '02046121', 'FreeDiams::CA_HCDPD::DIN', 14715);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diclofenac Sr', 'tablet (extended-release)', 'M01AB05', false, 0, '02048698', 'FreeDiams::CA_HCDPD::DIN', 14717);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Plaquenil', 'tablet', 'P01BA02', false, 0, '02017709', 'FreeDiams::CA_HCDPD::DIN', 14735);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitro-Dur 0.8', 'patch (extended release)', 'C01DA02', false, 0, '02011271', 'FreeDiams::CA_HCDPD::DIN', 14742);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyclomen', 'capsule', 'G03XA01', false, 0, '02018160', 'FreeDiams::CA_HCDPD::DIN', 14747);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Diflunisal Tab 250mg', 'tablet', 'N02BA11', false, 0, '02048493', 'FreeDiams::CA_HCDPD::DIN', 14751);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Diflunisal Tab 500mg', 'tablet', 'N02BA11', false, 0, '02048507', 'FreeDiams::CA_HCDPD::DIN', 14752);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('A-Hydrocort Inj 1000mg/8ml', 'powder for solution', 'H02AB09', false, 0, '00888222', 'FreeDiams::CA_HCDPD::DIN', 14755);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Sodium Cromoglycate', 'solution', 'R03BC01', false, 0, '02046113', 'FreeDiams::CA_HCDPD::DIN', 14758);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neuleptil 20mg Capsules', 'capsule', 'N05AC01', false, 0, '01926764', 'FreeDiams::CA_HCDPD::DIN', 14767);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Timolol Tab 20mg', 'tablet', 'C07AA06', false, 0, '02044625', 'FreeDiams::CA_HCDPD::DIN', 14928);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Timolol Tab 10mg', 'tablet', 'C07AA06', false, 0, '02044617', 'FreeDiams::CA_HCDPD::DIN', 14929);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Timolol Tab 5mg', 'tablet', 'C07AA06', false, 0, '02044609', 'FreeDiams::CA_HCDPD::DIN', 14930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Sulfinpyrazone Tab 200mg', 'tablet', 'M04AB02', false, 0, '02045699', 'FreeDiams::CA_HCDPD::DIN', 14931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Propranolol Tab 120mg', 'tablet', 'C07AA05', false, 0, '02044722', 'FreeDiams::CA_HCDPD::DIN', 14933);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Propranolol Tab 80mg', 'tablet', 'C07AA05', false, 0, '02044714', 'FreeDiams::CA_HCDPD::DIN', 14934);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Propranolol Tab 40mg', 'tablet', 'C07AA05', false, 0, '02044706', 'FreeDiams::CA_HCDPD::DIN', 14935);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Propranolol Tab 20mg', 'tablet', 'C07AA05', false, 0, '02044692', 'FreeDiams::CA_HCDPD::DIN', 14936);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Propranolol Tab 10mg', 'tablet', 'C07AA05', false, 0, '02044684', 'FreeDiams::CA_HCDPD::DIN', 14937);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Erythromycin-S 250mg Tablets', 'tablet', 'J01FA01', false, 0, '02051850', 'FreeDiams::CA_HCDPD::DIN', 14938);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Doxycycline Cap 100mg', 'capsule', 'J01AA02', false, 0, '02044668', 'FreeDiams::CA_HCDPD::DIN', 14939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Doxycycline Tab 100mg', 'tablet', 'J01AA02', false, 0, '02044676', 'FreeDiams::CA_HCDPD::DIN', 14940);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Carbamazepine Tab 200mg', 'tablet', 'N03AF01', false, 0, '02042568', 'FreeDiams::CA_HCDPD::DIN', 14941);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen 99% Usp', 'gas', 'V03AN01', false, 0, '00873187', 'FreeDiams::CA_HCDPD::DIN', 15005);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Doxepin Cap 100mg', 'capsule', 'N06AA12', false, 0, '02050048', 'FreeDiams::CA_HCDPD::DIN', 15104);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Doxepin Cap 150mg', 'capsule', 'N06AA12', false, 0, '02050056', 'FreeDiams::CA_HCDPD::DIN', 15105);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Doxepin Cap 25mg', 'capsule', 'N06AA12', false, 0, '02050005', 'FreeDiams::CA_HCDPD::DIN', 15106);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Doxepin Cap 50mg', 'capsule', 'N06AA12', false, 0, '02050013', 'FreeDiams::CA_HCDPD::DIN', 15107);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Doxepin Cap 75mg', 'capsule', 'N06AA12', false, 0, '02050021', 'FreeDiams::CA_HCDPD::DIN', 15108);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Metformin Tab 500mg', 'tablet', 'A10BA02', false, 0, '02045710', 'FreeDiams::CA_HCDPD::DIN', 15115);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Doxepin Cap 10mg', 'capsule', 'N06AA12', false, 0, '02049996', 'FreeDiams::CA_HCDPD::DIN', 15118);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Delsym Dm Suspension 30mg/5ml', 'suspension', 'R05DA09', false, 0, '02018403', 'FreeDiams::CA_HCDPD::DIN', 15140);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyclomen', 'capsule', 'G03XA01', false, 0, '02018152', 'FreeDiams::CA_HCDPD::DIN', 15163);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Macrobid', 'capsule', 'J01XE01', false, 0, '02063662', 'FreeDiams::CA_HCDPD::DIN', 15173);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dicetel', 'tablet', 'A03AX04', false, 0, '01950592', 'FreeDiams::CA_HCDPD::DIN', 15176);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amo Endosol Solution', 'solution', 'S01XA20', false, 0, '02007967', 'FreeDiams::CA_HCDPD::DIN', 15177);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abenol', 'suppository', 'N02BE01', false, 0, '01919385', 'FreeDiams::CA_HCDPD::DIN', 15202);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abenol', 'suppository', 'N02BE01', false, 0, '01919393', 'FreeDiams::CA_HCDPD::DIN', 15204);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abenol', 'suppository', 'N02BE01', false, 0, '01919407', 'FreeDiams::CA_HCDPD::DIN', 15205);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bactroban', 'ointment', 'D06AX09', false, 0, '01916947', 'FreeDiams::CA_HCDPD::DIN', 15207);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clavulin 125 F Oral Sus', 'suspension', 'J01CR02', false, 0, '01916882', 'FreeDiams::CA_HCDPD::DIN', 15208);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clavulin 250 F Oral Sus', 'suspension', 'J01CR02', false, 0, '01916874', 'FreeDiams::CA_HCDPD::DIN', 15209);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexedrine Spansule Src 15mg', 'capsule (sustained-release)', 'N06BA02', false, 0, '01924567', 'FreeDiams::CA_HCDPD::DIN', 15210);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexedrine Spansule Src 10mg', 'capsule (sustained-release)', 'N06BA02', false, 0, '01924559', 'FreeDiams::CA_HCDPD::DIN', 15211);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mesasal', 'tablet (enteric-coated)', 'A07EC02', false, 0, '01914030', 'FreeDiams::CA_HCDPD::DIN', 15218);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Timentin', 'powder for solution', 'J01CR03', false, 0, '01916939', 'FreeDiams::CA_HCDPD::DIN', 15224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexedrine Tablets (5mg)', 'tablet', 'N06BA02', false, 0, '01924516', 'FreeDiams::CA_HCDPD::DIN', 15225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('K10', 'solution', 'A12BA01', false, 0, '01918303', 'FreeDiams::CA_HCDPD::DIN', 15227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Parnate', 'tablet', 'N06AF04', false, 0, '01919598', 'FreeDiams::CA_HCDPD::DIN', 15231);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bm-6400 Ethanol Disinfectant & Cleaner Liq', 'liquid', 'V07AV', false, 0, '02065347', 'FreeDiams::CA_HCDPD::DIN', 15242);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Timol Liq 0.25%', 'liquid', 'S01ED01', false, 0, '02048523', 'FreeDiams::CA_HCDPD::DIN', 15253);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Timol Liq 0.5%', 'liquid', 'S01ED01', false, 0, '02048515', 'FreeDiams::CA_HCDPD::DIN', 15254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Decongestant Nasal Spray 0.1%', 'spray', 'R01AA07', false, 0, '01939998', 'FreeDiams::CA_HCDPD::DIN', 15478);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kenalog-40 Injection 40mg/Ml', 'suspension', 'H02AB08', false, 0, '01999869', 'FreeDiams::CA_HCDPD::DIN', 15481);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kenalog-10 Injection 10mg/Ml', 'suspension', 'H02AB08', false, 0, '01999761', 'FreeDiams::CA_HCDPD::DIN', 15482);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pulmozyme 1mg/Ml', 'solution', 'R05CB13', false, 0, '02046733', 'FreeDiams::CA_HCDPD::DIN', 15483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tryptan Tab 500mg', 'tablet', 'N06AX02', false, 0, '02029456', 'FreeDiams::CA_HCDPD::DIN', 15485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Premarin', 'tablet', 'G03CA57', false, 0, '02043394', 'FreeDiams::CA_HCDPD::DIN', 15486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cordarone', 'tablet', 'C01BD01', false, 0, '02036282', 'FreeDiams::CA_HCDPD::DIN', 15489);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Resectisol (5% Mannitol Irrigation)', 'liquid', 'B05CX04', false, 0, '01963953', 'FreeDiams::CA_HCDPD::DIN', 15491);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Sodium Chloride Injection Usp', 'solution', 'B05XA03', false, 0, '01928007', 'FreeDiams::CA_HCDPD::DIN', 15492);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nephramine Liq Iv', 'solution', 'B05BA01', false, 0, '02029464', 'FreeDiams::CA_HCDPD::DIN', 15493);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lab-X', 'liquid', 'V07AV', false, 0, '02048922', 'FreeDiams::CA_HCDPD::DIN', 15498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Surfex-E', 'liquid', 'V07AV', false, 0, '02048949', 'FreeDiams::CA_HCDPD::DIN', 15499);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Instrubex-E', 'liquid', 'V07AV', false, 0, '02048930', 'FreeDiams::CA_HCDPD::DIN', 15500);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neo-San Liq', 'liquid', 'V07AV', false, 0, '01948377', 'FreeDiams::CA_HCDPD::DIN', 15507);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clear Lemon 10 Liq', 'liquid', 'V07AV', false, 0, '01943545', 'FreeDiams::CA_HCDPD::DIN', 15508);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Percocet', 'tablet', 'N02BE51', false, 0, '01916475', 'FreeDiams::CA_HCDPD::DIN', 15514);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benadryl Elixir', 'elixir', 'R06AA02', false, 0, '02019736', 'FreeDiams::CA_HCDPD::DIN', 15516);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Drula Fade Cream Superforte Medicated', 'cream', 'D11AX11', false, 0, '02010593', 'FreeDiams::CA_HCDPD::DIN', 15518);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zovirax', 'cream', 'D06BB03', false, 0, '02039524', 'FreeDiams::CA_HCDPD::DIN', 15525);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sabril', 'tablet', 'N03AG04', false, 0, '02065819', 'FreeDiams::CA_HCDPD::DIN', 15532);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('20% Dextrose Injection Usp', 'solution', 'B05BA03', false, 0, '01924257', 'FreeDiams::CA_HCDPD::DIN', 15538);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('50% Dextrose Injection Usp', 'solution', 'B05BA03', false, 0, '01924273', 'FreeDiams::CA_HCDPD::DIN', 15539);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glycine Irrigation 1.5% Usp', 'liquid', 'B05CX03', false, 0, '01963945', 'FreeDiams::CA_HCDPD::DIN', 15540);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Baclofen', 'tablet', 'M03BX01', false, 0, '02063735', 'FreeDiams::CA_HCDPD::DIN', 15547);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Baclofen Tab 20mg', 'tablet', 'M03BX01', false, 0, '02063743', 'FreeDiams::CA_HCDPD::DIN', 15548);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kank-A Liq', 'liquid', 'A01AD11', false, 0, '02024659', 'FreeDiams::CA_HCDPD::DIN', 15550);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quat 44 Germicidal Cleaner Deodorant Liq', 'liquid', 'V07AV', false, 0, '02019418', 'FreeDiams::CA_HCDPD::DIN', 15557);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zeasorb Af', 'powder', 'D01AE18', false, 0, '02029081', 'FreeDiams::CA_HCDPD::DIN', 15558);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novamoxin Chewable Tablets 125mg', 'tablet (chewable)', 'J01CA04', false, 0, '02036347', 'FreeDiams::CA_HCDPD::DIN', 15559);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Famotidine Tab 40mg', 'tablet', 'A02BA03', false, 0, '02024209', 'FreeDiams::CA_HCDPD::DIN', 15563);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Famotidine Tab 20mg', 'tablet', 'A02BA03', false, 0, '02024195', 'FreeDiams::CA_HCDPD::DIN', 15564);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermasept Plus Liq 1%', 'liquid', 'D08AE04', false, 0, '02017334', 'FreeDiams::CA_HCDPD::DIN', 15566);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Transderm-Nitro 0.6', 'patch (extended release)', 'C01DA02', false, 0, '02046156', 'FreeDiams::CA_HCDPD::DIN', 15572);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Plendil 2.5 Mg', 'tablet (extended-release)', 'C08CA02', false, 0, '02057778', 'FreeDiams::CA_HCDPD::DIN', 15574);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acet 2', 'tablet', 'N02BE51', false, 0, '00706515', 'FreeDiams::CA_HCDPD::DIN', 15578);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acet 3', 'tablet', 'N02AA59', false, 0, '00706523', 'FreeDiams::CA_HCDPD::DIN', 15579);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acet Codeine 30 Tab', 'tablet', 'N02AA59', false, 0, '01999648', 'FreeDiams::CA_HCDPD::DIN', 15580);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acet Codeine 60 Tab', 'tablet', 'N02AA59', false, 0, '01999656', 'FreeDiams::CA_HCDPD::DIN', 15581);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isoptin Sr', 'tablet (extended-release)', 'C08DA01', false, 0, '01934317', 'FreeDiams::CA_HCDPD::DIN', 15585);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ew 150 Neutral Cleaner Liq 15.36%', 'liquid', 'V07AV', false, 0, '02078090', 'FreeDiams::CA_HCDPD::DIN', 15586);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prostep Trd 30mg Per 7 Sq Cm Patch', 'patch', 'N07BA01', false, 0, '02057743', 'FreeDiams::CA_HCDPD::DIN', 15591);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trimipramine', 'capsule', 'N06AA06', false, 0, '02070987', 'FreeDiams::CA_HCDPD::DIN', 15592);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Theraderm Cream', 'cream', 'D07CB01', false, 0, '02022818', 'FreeDiams::CA_HCDPD::DIN', 15598);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydrocortisone Sodium Succinate Inj 1gm/Vial', 'powder for solution', 'H02AB09', false, 0, '00878626', 'FreeDiams::CA_HCDPD::DIN', 15605);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydrocortisone Sodium Succin Inj 500mg/Vial', 'powder for solution', 'H02AB09', false, 0, '00878618', 'FreeDiams::CA_HCDPD::DIN', 15606);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydrocortisone Sod Succinate Inj 250mg/Vial', 'powder for solution', 'H02AB09', false, 0, '00872539', 'FreeDiams::CA_HCDPD::DIN', 15607);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydrocortisone Sod Succinate Inj 100mg/Vial', 'powder for solution', 'H02AB09', false, 0, '00872520', 'FreeDiams::CA_HCDPD::DIN', 15608);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Cotridin Expectorant', 'syrup', 'R05FA02', false, 0, '02053403', 'FreeDiams::CA_HCDPD::DIN', 15618);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Betoptic S Oph Sus 0.25%', 'suspension', 'S01ED02', false, 0, '01908448', 'FreeDiams::CA_HCDPD::DIN', 15625);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Pindolol', 'tablet', 'C07AA03', false, 0, '02057808', 'FreeDiams::CA_HCDPD::DIN', 15687);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quat 256 Detergent Disinfectant Liq', 'liquid', 'V07AV', false, 0, '02019396', 'FreeDiams::CA_HCDPD::DIN', 15690);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Pindolol', 'tablet', 'C07AA03', false, 0, '02057816', 'FreeDiams::CA_HCDPD::DIN', 15696);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Premarin Vaginal Cream', 'cream', 'G03CA57', false, 0, '02043440', 'FreeDiams::CA_HCDPD::DIN', 15704);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophene Comprimes 160mg', 'tablet', 'N02BE01', false, 0, '01996150', 'FreeDiams::CA_HCDPD::DIN', 15706);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pediatric Digoxin Injection C.S.D.', 'liquid', 'C01AA05', false, 0, '02048272', 'FreeDiams::CA_HCDPD::DIN', 15756);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Digoxin Injection C.S.D.', 'liquid', 'C01AA05', false, 0, '02048264', 'FreeDiams::CA_HCDPD::DIN', 15757);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Premarin', 'tablet', 'G03CA57', false, 0, '02043408', 'FreeDiams::CA_HCDPD::DIN', 15782);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Therapeutic Aquaderm-15', 'cream', 'D02BA30', false, 0, '01957562', 'FreeDiams::CA_HCDPD::DIN', 15799);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prevora Stage 1', 'kit', 'A01AB03', false, 0, '02046245', 'FreeDiams::CA_HCDPD::DIN', 15801);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Premise Disinfectant Liq', 'liquid', 'V07AV', false, 0, '02012952', 'FreeDiams::CA_HCDPD::DIN', 15803);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mersyndol With Codeine', 'tablet', 'N02BE51', false, 0, '02047667', 'FreeDiams::CA_HCDPD::DIN', 15805);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lescol 20mg', 'capsule', 'C10AA04', false, 0, '02061562', 'FreeDiams::CA_HCDPD::DIN', 15820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lescol 40mg', 'capsule', 'C10AA04', false, 0, '02061570', 'FreeDiams::CA_HCDPD::DIN', 15821);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Diflunisal Tab 500mg', 'tablet', 'N02BA11', false, 0, '02058413', 'FreeDiams::CA_HCDPD::DIN', 15823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Gemfibrozil Cap 300mg', 'capsule', 'C10AB04', false, 0, '02058456', 'FreeDiams::CA_HCDPD::DIN', 15824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Gemfibrozil Tab 600mg', 'tablet', 'C10AB04', false, 0, '02058464', 'FreeDiams::CA_HCDPD::DIN', 15825);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Diflunisal Tab 250mg', 'tablet', 'N02BA11', false, 0, '02058405', 'FreeDiams::CA_HCDPD::DIN', 15826);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sani-Dex Antimicrobial Hand Wipes', 'pad', 'D08AE55', false, 0, '00880019', 'FreeDiams::CA_HCDPD::DIN', 15829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sani-Cloth Germicidal', 'strip', 'V07AV', false, 0, '00780014', 'FreeDiams::CA_HCDPD::DIN', 15830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Water For Injection, Usp', 'liquid', 'V07AB', false, 0, '02014882', 'FreeDiams::CA_HCDPD::DIN', 15867);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Travasol Amino Acid Injection With Electrolytes In 20% Dextrose Clinimix', 'solution', 'B05BA10', false, 0, '02014068', 'FreeDiams::CA_HCDPD::DIN', 15868);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Deb Sunprotect Spf 33', 'cream', 'D02BA30', false, 0, '02059959', 'FreeDiams::CA_HCDPD::DIN', 15869);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bac Liq', 'liquid', 'V07AV', false, 0, '02085690', 'FreeDiams::CA_HCDPD::DIN', 15873);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pharmalgen White Faced Hornet Venom', 'powder for solution', 'V01AA07', false, 0, '01949004', 'FreeDiams::CA_HCDPD::DIN', 15874);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benadryl Childrens Liquid 6.25mg/5ml', 'liquid', 'R06AA02', false, 0, '02019698', 'FreeDiams::CA_HCDPD::DIN', 15880);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Premarin', 'tablet', 'G03CA57', false, 0, '02043424', 'FreeDiams::CA_HCDPD::DIN', 15889);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Erysol', 'gel', 'D10AF52', false, 0, '02034506', 'FreeDiams::CA_HCDPD::DIN', 15893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Acyclovir', 'tablet', 'J05AB01', false, 0, '02078651', 'FreeDiams::CA_HCDPD::DIN', 15894);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Acyclovir', 'tablet', 'J05AB01', false, 0, '02078635', 'FreeDiams::CA_HCDPD::DIN', 15895);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Acyclovir', 'tablet', 'J05AB01', false, 0, '02078627', 'FreeDiams::CA_HCDPD::DIN', 15896);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyclomen', 'capsule', 'G03XA01', false, 0, '02018144', 'FreeDiams::CA_HCDPD::DIN', 15897);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Westosan Liq', 'liquid', 'V07AV', false, 0, '02012316', 'FreeDiams::CA_HCDPD::DIN', 15899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ridaura', 'capsule', 'M01CB03', false, 0, '01916823', 'FreeDiams::CA_HCDPD::DIN', 15902);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clavulin 500 F Tab', 'tablet', 'J01CR02', false, 0, '01916858', 'FreeDiams::CA_HCDPD::DIN', 15903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cytomel', 'tablet', 'H03AA02', false, 0, '01919466', 'FreeDiams::CA_HCDPD::DIN', 15908);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cytomel', 'tablet', 'H03AA02', false, 0, '01919458', 'FreeDiams::CA_HCDPD::DIN', 15909);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cycloprine Tablets 10mg', 'tablet', 'M03BX08', false, 0, '02080052', 'FreeDiams::CA_HCDPD::DIN', 15912);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diphenhydramine Hcl Inj Usp 50mg/Ml', 'liquid', 'R06AA02', false, 0, '01997025', 'FreeDiams::CA_HCDPD::DIN', 15917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Minocycline Cap 100mg', 'capsule', 'J01AA08', false, 0, '02084104', 'FreeDiams::CA_HCDPD::DIN', 15925);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Minocycline Cap 50mg', 'capsule', 'J01AA08', false, 0, '02084090', 'FreeDiams::CA_HCDPD::DIN', 15927);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dalacin Vaginal Cream 20 Mg', 'cream', 'G01AA10', false, 0, '02060604', 'FreeDiams::CA_HCDPD::DIN', 15942);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neurontin Cap 100mg', 'capsule', 'N03AX12', false, 0, '02084260', 'FreeDiams::CA_HCDPD::DIN', 15944);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neurontin Cap 300mg', 'capsule', 'N03AX12', false, 0, '02084279', 'FreeDiams::CA_HCDPD::DIN', 15945);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kennelsol Liq', 'liquid', 'V07AV', false, 0, '01938177', 'FreeDiams::CA_HCDPD::DIN', 15947);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pramox Hc Lotion', 'lotion', 'D07XA01', false, 0, '01954210', 'FreeDiams::CA_HCDPD::DIN', 15948);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polytar Af Shampoo', 'shampoo', 'D05AA', false, 0, '01981021', 'FreeDiams::CA_HCDPD::DIN', 15950);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Optiquat Liq', 'liquid', 'V07AV', false, 0, '02089734', 'FreeDiams::CA_HCDPD::DIN', 15954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sport Lip Balm', 'stick', 'D02BA30', false, 0, '02072270', 'FreeDiams::CA_HCDPD::DIN', 15968);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Laura Line Antibacterial Cream Soap 0.2%', 'suspension', 'D08AE04', false, 0, '02078317', 'FreeDiams::CA_HCDPD::DIN', 15971);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Ketoprofen-E Ect 100mg', 'tablet (enteric-coated)', 'M01AE03', false, 0, '02044641', 'FreeDiams::CA_HCDPD::DIN', 16038);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Ketoprofen Cap 50mg', 'capsule', 'M01AE03', false, 0, '02044633', 'FreeDiams::CA_HCDPD::DIN', 16039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Ketoprofen-E Ect 50mg', 'tablet (enteric-coated)', 'M01AE03', false, 0, '02044781', 'FreeDiams::CA_HCDPD::DIN', 16042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vaprox Hydrogen Peroxide Sterilant', 'liquid', 'V07AV', false, 0, '02047616', 'FreeDiams::CA_HCDPD::DIN', 16065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benadryl Capsules 50mg', 'capsule', 'R06AA02', false, 0, '02019671', 'FreeDiams::CA_HCDPD::DIN', 16067);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Navelbine', 'solution', 'L01CA04', false, 0, '02091283', 'FreeDiams::CA_HCDPD::DIN', 16101);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ms Ir Tab 5mg', 'tablet', 'N02AA01', false, 0, '02014203', 'FreeDiams::CA_HCDPD::DIN', 16102);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Uniphyl', 'tablet (extended-release)', 'R03DA04', false, 0, '02014165', 'FreeDiams::CA_HCDPD::DIN', 16103);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Wescodyne Liq', 'liquid', 'V07AV', false, 0, '02012359', 'FreeDiams::CA_HCDPD::DIN', 16108);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ativan', 'tablet', 'N05BA06', false, 0, '02041464', 'FreeDiams::CA_HCDPD::DIN', 16118);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Inderal-La', 'capsule (sustained-release)', 'C07AA05', false, 0, '02042258', 'FreeDiams::CA_HCDPD::DIN', 16123);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Inderal-La', 'capsule (sustained-release)', 'C07AA05', false, 0, '02042266', 'FreeDiams::CA_HCDPD::DIN', 16124);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenolic Detergent S7/Detergent Phenolique S7', 'liquid', 'V07AV', false, 0, '02049007', 'FreeDiams::CA_HCDPD::DIN', 16133);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sensorcaine 0.25%', 'liquid', 'N01BB01', false, 0, '01976141', 'FreeDiams::CA_HCDPD::DIN', 16161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sensorcaine 0.25% With Epinephrine', 'solution', 'N01BB51', false, 0, '01976184', 'FreeDiams::CA_HCDPD::DIN', 16162);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sensorcaine 0.5% With Epinephrine', 'solution', 'N01BB51', false, 0, '01976206', 'FreeDiams::CA_HCDPD::DIN', 16163);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sensorcaine 0.5%', 'liquid', 'N01BB01', false, 0, '01976168', 'FreeDiams::CA_HCDPD::DIN', 16164);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soriatane', 'capsule', 'D05BB02', false, 0, '02070863', 'FreeDiams::CA_HCDPD::DIN', 16167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soriatane', 'capsule', 'D05BB02', false, 0, '02070847', 'FreeDiams::CA_HCDPD::DIN', 16168);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triple Antibiotic Ointment', 'ointment', 'D06AX05', false, 0, '02088339', 'FreeDiams::CA_HCDPD::DIN', 16171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Selegiline  Tab 5mg', 'tablet', 'N04BD01', false, 0, '02068087', 'FreeDiams::CA_HCDPD::DIN', 16175);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckley''S Dm Decongestant', 'liquid', 'R05DA20', false, 0, '02052822', 'FreeDiams::CA_HCDPD::DIN', 16177);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultravist 240', 'solution', 'V08AB05', false, 0, '02078597', 'FreeDiams::CA_HCDPD::DIN', 16178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultravist 300', 'solution', 'V08AB05', false, 0, '02078600', 'FreeDiams::CA_HCDPD::DIN', 16179);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultravist 370', 'solution', 'V08AB05', false, 0, '02078619', 'FreeDiams::CA_HCDPD::DIN', 16180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckeye Sani Q Liq 10%', 'liquid', 'V07AV', false, 0, '02040050', 'FreeDiams::CA_HCDPD::DIN', 16183);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckeye Sanicare Disinf. Restroom Cleaner', 'liquid', 'V07AV', false, 0, '02040042', 'FreeDiams::CA_HCDPD::DIN', 16184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Bromocriptine Tab 2.5mg', 'tablet', 'G02CB01', false, 0, '02087324', 'FreeDiams::CA_HCDPD::DIN', 16195);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neurontin Cap 400mg', 'capsule', 'N03AX12', false, 0, '02084287', 'FreeDiams::CA_HCDPD::DIN', 16210);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zoladex Inj Depot 3.6mg', 'implant', 'L02AE03', false, 0, '02049325', 'FreeDiams::CA_HCDPD::DIN', 16216);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diocarpine 2% Solution', 'liquid', 'S01EB01', false, 0, '02023741', 'FreeDiams::CA_HCDPD::DIN', 16217);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro Plus 4 Concentrate', 'liquid', 'B05XA31', false, 0, '02091143', 'FreeDiams::CA_HCDPD::DIN', 16224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro Plus 5 Concentrate', 'liquid', 'B05XA30', false, 0, '02091178', 'FreeDiams::CA_HCDPD::DIN', 16225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro Plus 6   (Pediatric)', 'liquid', 'B05XA31', false, 0, '02091100', 'FreeDiams::CA_HCDPD::DIN', 16226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro Plus 6    (Concentrate)', 'liquid', 'B05XA31', false, 0, '02091127', 'FreeDiams::CA_HCDPD::DIN', 16227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Microban Hospital Spray', 'spray', 'V07AV', false, 0, '02060329', 'FreeDiams::CA_HCDPD::DIN', 16228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baume Protecteur Fps 15 Avec Filtres Uva/Uvb', 'stick', 'D02BA30', false, 0, '02086328', 'FreeDiams::CA_HCDPD::DIN', 16229);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diopred Suspension  1%', 'suspension', 'S01BA04', false, 0, '02023768', 'FreeDiams::CA_HCDPD::DIN', 16234);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germex Liq', 'aerosol', 'V07AV', false, 0, '02081415', 'FreeDiams::CA_HCDPD::DIN', 16238);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diocarpine 1% Solution', 'solution', 'S01EB01', false, 0, '02023725', 'FreeDiams::CA_HCDPD::DIN', 16241);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diopentolate 1% Solution', 'solution', 'S01FA04', false, 0, '02023644', 'FreeDiams::CA_HCDPD::DIN', 16242);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diogent Solution 0.3%', 'liquid', 'S01AA11', false, 0, '02023822', 'FreeDiams::CA_HCDPD::DIN', 16244);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diotrope 1% Solution', 'solution', 'S01FA06', false, 0, '02023679', 'FreeDiams::CA_HCDPD::DIN', 16255);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diodex Solution 0.1%', 'solution', 'S03BA01', false, 0, '02023865', 'FreeDiams::CA_HCDPD::DIN', 16262);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Entocort Enema 0.02 Mg/Ml', 'kit', 'A07EA06', false, 0, '02052431', 'FreeDiams::CA_HCDPD::DIN', 16264);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Esoterica Regular Cream', 'cream', 'D11AX11', false, 0, '02029952', 'FreeDiams::CA_HCDPD::DIN', 16271);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Esoterica Facial Cream', 'cream', 'D11AX11', false, 0, '02029928', 'FreeDiams::CA_HCDPD::DIN', 16272);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lutrepulse Pws 0.8mg/Vial', 'powder for solution', 'H01CA01', false, 0, '02046210', 'FreeDiams::CA_HCDPD::DIN', 16274);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Depo-Medrol (With Preservative) 40 Mg/Ml', 'suspension', 'H02AB04', false, 0, '01934333', 'FreeDiams::CA_HCDPD::DIN', 16275);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Depo-Medrol (With Preservative) 80 Mg/Ml', 'suspension', 'H02AB04', false, 0, '01934341', 'FreeDiams::CA_HCDPD::DIN', 16276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Sulindac Tab 150mg', 'tablet', 'M01AB02', false, 0, '02042576', 'FreeDiams::CA_HCDPD::DIN', 16293);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Sulindac Tab 200mg', 'tablet', 'M01AB02', false, 0, '02042584', 'FreeDiams::CA_HCDPD::DIN', 16294);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Streptase', 'powder for solution', 'B01AD01', false, 0, '02019000', 'FreeDiams::CA_HCDPD::DIN', 16299);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Streptase', 'powder for solution', 'B01AD01', false, 0, '02019019', 'FreeDiams::CA_HCDPD::DIN', 16422);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nauseatol', 'tablet (chewable)', 'R06AA02', false, 0, '01957414', 'FreeDiams::CA_HCDPD::DIN', 16428);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Cough Caplets', 'tablet', 'N02BE51', false, 0, '02017377', 'FreeDiams::CA_HCDPD::DIN', 16437);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oilatum Liq 63.4%', 'liquid', 'D02AC', false, 0, '02034670', 'FreeDiams::CA_HCDPD::DIN', 16438);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Salbutamol', 'solution', 'R03AC02', false, 0, '02069571', 'FreeDiams::CA_HCDPD::DIN', 16452);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acne Vanishing Treatment For Sensitive Skin', 'lotion', 'D10AE01', false, 0, '02046539', 'FreeDiams::CA_HCDPD::DIN', 16458);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multi 12 Injection', 'liquid', 'B05XC', false, 0, '02100606', 'FreeDiams::CA_HCDPD::DIN', 16462);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diclo Sr 100mg', 'tablet (extended-release)', 'M01AB05', false, 0, '02091194', 'FreeDiams::CA_HCDPD::DIN', 16471);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zocor', 'tablet', 'C10AA01', false, 0, '00884340', 'FreeDiams::CA_HCDPD::DIN', 16473);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Codeine 30mg Tab', 'tablet', 'R05DA04', false, 0, '02009757', 'FreeDiams::CA_HCDPD::DIN', 16474);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Codeine 15 Mg Tab', 'tablet', 'R05DA04', false, 0, '02009889', 'FreeDiams::CA_HCDPD::DIN', 16475);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dioptic''S Atropine Solution 1%', 'solution', 'S01FA01', false, 0, '02023695', 'FreeDiams::CA_HCDPD::DIN', 16476);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dionephrine 2.5% Liq', 'liquid', 'S01FB01', false, 0, '02027100', 'FreeDiams::CA_HCDPD::DIN', 16477);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ms Ir Tab 20mg', 'tablet', 'N02AA01', false, 0, '02014238', 'FreeDiams::CA_HCDPD::DIN', 16480);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ms Ir Tab 30mg', 'tablet', 'N02AA01', false, 0, '02014254', 'FreeDiams::CA_HCDPD::DIN', 16481);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Uniphyl', 'tablet (extended-release)', 'R03DA04', false, 0, '02014181', 'FreeDiams::CA_HCDPD::DIN', 16482);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Docusate', 'capsule', 'A06AA02', false, 0, '02020084', 'FreeDiams::CA_HCDPD::DIN', 16492);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solu-Iv Chd-Alcool Tampon', 'pad', 'D08AC52', false, 0, '02060019', 'FreeDiams::CA_HCDPD::DIN', 16494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlorhexidine Gluconate Solution Usp 20%', 'solution', 'D08AC02', false, 0, '02053632', 'FreeDiams::CA_HCDPD::DIN', 16498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Etoposide Liq Iv 20mg/Ml', 'liquid', 'L01CB01', false, 0, '02080036', 'FreeDiams::CA_HCDPD::DIN', 16507);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultracaine D-S Injection', 'solution', 'N01BB58', false, 0, '01988530', 'FreeDiams::CA_HCDPD::DIN', 16508);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultracaine D-S Forte Injection', 'solution', 'N01BB58', false, 0, '01988557', 'FreeDiams::CA_HCDPD::DIN', 16511);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Flurprofen Fc Tablet 50mg', 'tablet', 'M01AE09', false, 0, '02100509', 'FreeDiams::CA_HCDPD::DIN', 16514);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Flurprofen Fc Tablet 100mg', 'tablet', 'M01AE09', false, 0, '02100517', 'FreeDiams::CA_HCDPD::DIN', 16515);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Salvent 5mg/Ml', 'solution', 'R03AC02', false, 0, '02046741', 'FreeDiams::CA_HCDPD::DIN', 16521);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Orfenace Tablet 100mg', 'tablet', 'M03BC01', false, 0, '02047535', 'FreeDiams::CA_HCDPD::DIN', 16522);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fluphenazine Decanoate Inj (Bp)  25mg/Ml', 'liquid', 'N05AB02', false, 0, '02091275', 'FreeDiams::CA_HCDPD::DIN', 16523);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Baclofen', 'tablet', 'M03BX01', false, 0, '02088401', 'FreeDiams::CA_HCDPD::DIN', 16532);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Charac-25', 'suspension', 'A07BA01', false, 0, '02056429', 'FreeDiams::CA_HCDPD::DIN', 16533);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Baclofen', 'tablet', 'M03BX01', false, 0, '02088398', 'FreeDiams::CA_HCDPD::DIN', 16534);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Inderal-La', 'capsule (sustained-release)', 'C07AA05', false, 0, '02042274', 'FreeDiams::CA_HCDPD::DIN', 16579);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dapsone', 'tablet', 'J04BA02', false, 0, '02041510', 'FreeDiams::CA_HCDPD::DIN', 16584);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ativan', 'tablet', 'N05BA06', false, 0, '02041472', 'FreeDiams::CA_HCDPD::DIN', 16586);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ativan', 'tablet', 'N05BA06', false, 0, '02041448', 'FreeDiams::CA_HCDPD::DIN', 16587);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ativan', 'tablet', 'N05BA06', false, 0, '02041421', 'FreeDiams::CA_HCDPD::DIN', 16588);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ativan', 'tablet', 'N05BA06', false, 0, '02041413', 'FreeDiams::CA_HCDPD::DIN', 16589);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Monistat 7 Vaginal Cream', 'cream', 'G01AF04', false, 0, '02084309', 'FreeDiams::CA_HCDPD::DIN', 16608);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micatin Cream - 2%', 'cream', 'D01AC02', false, 0, '02085852', 'FreeDiams::CA_HCDPD::DIN', 16609);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Monistat 3 Dual-Pak', 'kit', 'G01AF04', false, 0, '02126249', 'FreeDiams::CA_HCDPD::DIN', 16610);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Monistat 7 Dual-Pak', 'kit', 'G01AF04', false, 0, '02126257', 'FreeDiams::CA_HCDPD::DIN', 16611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Monistat 3 Vaginal Ovules', 'suppository', 'G01AF04', false, 0, '02126605', 'FreeDiams::CA_HCDPD::DIN', 16612);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diosulf 10% Solution', 'liquid', 'S01AB04', false, 0, '02023830', 'FreeDiams::CA_HCDPD::DIN', 16623);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dioptrol Suspension', 'suspension', 'S01CA01', false, 0, '02023806', 'FreeDiams::CA_HCDPD::DIN', 16624);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dioptimyd Suspension', 'suspension', 'S01CA02', false, 0, '02023814', 'FreeDiams::CA_HCDPD::DIN', 16625);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diofluor 25% Injection', 'solution', 'V04CX', false, 0, '02027097', 'FreeDiams::CA_HCDPD::DIN', 16626);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diofluor 10% Injection', 'solution', 'V04CX', false, 0, '02027089', 'FreeDiams::CA_HCDPD::DIN', 16627);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diochloram Ointment 1%', 'ointment', 'S01AA01', false, 0, '02026260', 'FreeDiams::CA_HCDPD::DIN', 16628);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diocaine Solution 0.5%', 'liquid', 'S01HA04', false, 0, '02023652', 'FreeDiams::CA_HCDPD::DIN', 16629);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diochloram Solution  0.5%', 'liquid', 'S01AA01', false, 0, '02023857', 'FreeDiams::CA_HCDPD::DIN', 16630);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diocarpine 4% Solution', 'liquid', 'S01EB01', false, 0, '02023733', 'FreeDiams::CA_HCDPD::DIN', 16631);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diophenyl-T  Solution', 'solution', 'S01FA56', false, 0, '02023717', 'FreeDiams::CA_HCDPD::DIN', 16632);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diotrope 0.5% Solution', 'liquid', 'S01FA06', false, 0, '02023660', 'FreeDiams::CA_HCDPD::DIN', 16634);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novahistex Dh', 'syrup', 'R05DA20', false, 0, '02049481', 'FreeDiams::CA_HCDPD::DIN', 16635);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zestoretic Tab 10/12.5mg', 'tablet', 'C09BA03', false, 0, '02103729', 'FreeDiams::CA_HCDPD::DIN', 16636);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novahistine Dh', 'syrup', 'R05DA20', false, 0, '02049473', 'FreeDiams::CA_HCDPD::DIN', 16640);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dioptrol Ointment', 'ointment', 'S01CA01', false, 0, '02023849', 'FreeDiams::CA_HCDPD::DIN', 16648);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dioptimyd Ointment', 'ointment', 'S01CA02', false, 0, '02023784', 'FreeDiams::CA_HCDPD::DIN', 16649);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diosporin Ointment', 'ointment', 'S01AA30', false, 0, '02023792', 'FreeDiams::CA_HCDPD::DIN', 16650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diopentolate 0.5% Solution', 'solution', 'S01FA04', false, 0, '02023687', 'FreeDiams::CA_HCDPD::DIN', 16651);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dionephrine  0.12% Liq', 'liquid', 'S01GA55', false, 0, '02026473', 'FreeDiams::CA_HCDPD::DIN', 16652);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diopticon A Liq', 'liquid', 'S01GA51', false, 0, '02026465', 'FreeDiams::CA_HCDPD::DIN', 16653);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dioptears Liq 0.8%', 'solution', 'S01XA20', false, 0, '02026538', 'FreeDiams::CA_HCDPD::DIN', 16654);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Optilube Pva Liq 1.4%', 'solution', 'S01XA20', false, 0, '02026481', 'FreeDiams::CA_HCDPD::DIN', 16655);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Sucralfate - Tab 1g', 'tablet', 'A02BX02', false, 0, '02125250', 'FreeDiams::CA_HCDPD::DIN', 16656);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Cough & Congestion Extra Strength', 'syrup', 'R05FA02', false, 0, '02039397', 'FreeDiams::CA_HCDPD::DIN', 16662);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Tamoxifen', 'tablet', 'L02BA01', false, 0, '02088428', 'FreeDiams::CA_HCDPD::DIN', 16663);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Tamoxifen', 'tablet', 'L02BA01', false, 0, '02089858', 'FreeDiams::CA_HCDPD::DIN', 16664);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Santyl', 'ointment', 'D03BA02', false, 0, '02063670', 'FreeDiams::CA_HCDPD::DIN', 16678);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dilaudid', 'powder for solution', 'N02AA03', false, 0, '02085895', 'FreeDiams::CA_HCDPD::DIN', 16679);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cetacaine Spray', 'aerosol', 'D04AB30', false, 0, '02028840', 'FreeDiams::CA_HCDPD::DIN', 16688);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robitussin Cough And Cold', 'syrup', 'R05FA02', false, 0, '02068419', 'FreeDiams::CA_HCDPD::DIN', 16698);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humatin Cap 250mg', 'capsule', 'A07AA06', false, 0, '02078759', 'FreeDiams::CA_HCDPD::DIN', 16701);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prinzide', 'tablet', 'C09BA03', false, 0, '02108194', 'FreeDiams::CA_HCDPD::DIN', 16709);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solu-Medrol', 'kit', 'H02AB04', false, 0, '02063727', 'FreeDiams::CA_HCDPD::DIN', 16710);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enviro Solutions 24 Food Serv. Disinf. Clnr.', 'solution', 'V07AV', false, 0, '02106213', 'FreeDiams::CA_HCDPD::DIN', 16719);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enviro Sol. 25 Disinf. Clnr And Odor Counter', 'liquid', 'V07AV', false, 0, '02106221', 'FreeDiams::CA_HCDPD::DIN', 16720);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enviro Solutions 256 Neutral Disinfect.Conc.', 'solution', 'V07AV', false, 0, '02130785', 'FreeDiams::CA_HCDPD::DIN', 16721);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enviro Solutions 64 Gen.Pur.Neutral Disinf.', 'liquid', 'V07AV', false, 0, '02130688', 'FreeDiams::CA_HCDPD::DIN', 16722);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Emla Patch', 'patch', 'D04AB30', false, 0, '02057794', 'FreeDiams::CA_HCDPD::DIN', 16733);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phisohex', 'emulsion', 'D08AE01', false, 0, '02017733', 'FreeDiams::CA_HCDPD::DIN', 16734);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Premarin Intravenous', 'powder for solution', 'G03CA57', false, 0, '02043386', 'FreeDiams::CA_HCDPD::DIN', 16736);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solu-Medrol', 'kit', 'H02AB04', false, 0, '02063719', 'FreeDiams::CA_HCDPD::DIN', 16742);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solu-Medrol', 'kit', 'H02AB04', false, 0, '02063697', 'FreeDiams::CA_HCDPD::DIN', 16743);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dristan Extra Strength Caplets', 'tablet', 'N02BE51', false, 0, '02049198', 'FreeDiams::CA_HCDPD::DIN', 16752);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Verelan 240mg Src', 'capsule (sustained-release)', 'C08DA01', false, 0, '02100495', 'FreeDiams::CA_HCDPD::DIN', 16754);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Verelan Src 180mg', 'capsule (sustained-release)', 'C08DA01', false, 0, '02100487', 'FreeDiams::CA_HCDPD::DIN', 16755);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Verelan Src 120mg', 'capsule (sustained-release)', 'C08DA01', false, 0, '02100479', 'FreeDiams::CA_HCDPD::DIN', 16756);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dual Quat Liq', 'liquid', 'V07AV', false, 0, '01914227', 'FreeDiams::CA_HCDPD::DIN', 16773);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quato 78 Plus', 'liquid', 'V07AV', false, 0, '01975757', 'FreeDiams::CA_HCDPD::DIN', 16774);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Duolube Sterile Ophthalmic Ointment', 'ointment', 'S01XA20', false, 0, '02125706', 'FreeDiams::CA_HCDPD::DIN', 16777);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Sodium In 5% Dextrose Injection, 25000unit/500ml', 'solution', 'B01AB51', false, 0, '01935941', 'FreeDiams::CA_HCDPD::DIN', 16794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imdur - Extended Release Tablets 60 Mg', 'tablet (extended-release)', 'C01DA14', false, 0, '02126559', 'FreeDiams::CA_HCDPD::DIN', 16804);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ogen 1.25', 'tablet', 'G03CA07', false, 0, '02089769', 'FreeDiams::CA_HCDPD::DIN', 16816);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidodan Viscous 2%', 'liquid', 'N01BB02', false, 0, '01968823', 'FreeDiams::CA_HCDPD::DIN', 16823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ogen .625', 'tablet', 'G03CA07', false, 0, '02089793', 'FreeDiams::CA_HCDPD::DIN', 16824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ogen 2.5', 'tablet', 'G03CA07', false, 0, '02089777', 'FreeDiams::CA_HCDPD::DIN', 16827);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dey-Pak Sodium Chloride Solution 3%', 'solution', 'R01AX10', false, 0, '02058251', 'FreeDiams::CA_HCDPD::DIN', 16829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dey-Pak Sodium Chloride Solution 0.9%', 'solution', 'R01AX10', false, 0, '02058235', 'FreeDiams::CA_HCDPD::DIN', 16830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitroglycerin Injection Usp', 'solution', 'C01DA02', false, 0, '00860778', 'FreeDiams::CA_HCDPD::DIN', 16848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Septanest Sp', 'solution', 'N01BB58', false, 0, '02123398', 'FreeDiams::CA_HCDPD::DIN', 16850);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Septanest N', 'liquid', 'N01BB58', false, 0, '02123371', 'FreeDiams::CA_HCDPD::DIN', 16851);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nidagel Vaginal Gel 0.75%', 'gel', 'G01AF01', false, 0, '02125226', 'FreeDiams::CA_HCDPD::DIN', 16852);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentasa Extended-Release Tablets 500mg', 'tablet (extended-release)', 'A07EC02', false, 0, '02099683', 'FreeDiams::CA_HCDPD::DIN', 16855);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diogent Ointment 0.3%', 'ointment', 'S01AA11', false, 0, '02023776', 'FreeDiams::CA_HCDPD::DIN', 16862);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('3m Quat Disinfectant Cleaner Concentrate', 'liquid', 'V07AV', false, 0, '02091852', 'FreeDiams::CA_HCDPD::DIN', 16875);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Relisorm 500 For Inj.-Pws Liq-Kit Iv Sc', 'kit', 'V04CM01', false, 0, '02126702', 'FreeDiams::CA_HCDPD::DIN', 16878);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coversyl - 4mg Tab', 'tablet', 'C09AA04', false, 0, '02123282', 'FreeDiams::CA_HCDPD::DIN', 16879);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coversyl - 2mg Tab', 'tablet', 'C09AA04', false, 0, '02123274', 'FreeDiams::CA_HCDPD::DIN', 16880);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sofra-Tulle Dressing 1%', 'dressing', 'D09AA01', false, 0, '01988840', 'FreeDiams::CA_HCDPD::DIN', 16888);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Baclo - Tab  10mg', 'tablet', 'M03BX01', false, 0, '02136090', 'FreeDiams::CA_HCDPD::DIN', 16890);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Baclo-Tab 20mg', 'tablet', 'M03BX01', false, 0, '02136104', 'FreeDiams::CA_HCDPD::DIN', 16891);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermatone Spf 23 Lips N Face Protector', 'ointment', 'D02BA30', false, 0, '02097591', 'FreeDiams::CA_HCDPD::DIN', 16893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermatone Moisturising Uva/Uvb Creme', 'cream', 'D02BA30', false, 0, '02091704', 'FreeDiams::CA_HCDPD::DIN', 16896);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Sucralfate - Tab 1gm', 'tablet', 'A02BX02', false, 0, '02134829', 'FreeDiams::CA_HCDPD::DIN', 16899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Haloperidol La', 'liquid', 'N05AD01', false, 0, '02130297', 'FreeDiams::CA_HCDPD::DIN', 16901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Haloperidol La', 'liquid', 'N05AD01', false, 0, '02130300', 'FreeDiams::CA_HCDPD::DIN', 16902);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zestoretic Tab 20/12.5mg', 'tablet', 'C09BA03', false, 0, '02045737', 'FreeDiams::CA_HCDPD::DIN', 16903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyanocobalamin Injection Usp 1000mcg/Ml', 'liquid', 'B03BA01', false, 0, '02052717', 'FreeDiams::CA_HCDPD::DIN', 16909);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lithium Citrate', 'syrup', 'N05AN01', false, 0, '02074834', 'FreeDiams::CA_HCDPD::DIN', 16938);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ipravent Solution - Inh 250mcg/Ml', 'solution', 'R03BB01', false, 0, '02126222', 'FreeDiams::CA_HCDPD::DIN', 16947);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Minocycline', 'capsule', 'J01AA08', false, 0, '02108151', 'FreeDiams::CA_HCDPD::DIN', 16949);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Minocycline', 'capsule', 'J01AA08', false, 0, '02108143', 'FreeDiams::CA_HCDPD::DIN', 16950);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novamoxin 250 Sus 50mg/Ml Sugar Reduced', 'powder for solution', 'J01CA04', false, 0, '01934163', 'FreeDiams::CA_HCDPD::DIN', 16954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novamoxin 125 Sus 25mg/Ml Sugar Reduced', 'powder for solution', 'J01CA04', false, 0, '01934171', 'FreeDiams::CA_HCDPD::DIN', 16955);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Nadolol Tablets-80mg', 'tablet', 'C07AA12', false, 0, '02126761', 'FreeDiams::CA_HCDPD::DIN', 16965);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Nadolol Tablets-40mg', 'tablet', 'C07AA12', false, 0, '02126753', 'FreeDiams::CA_HCDPD::DIN', 16966);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bezalip Sr', 'tablet (extended-release)', 'C10AB02', false, 0, '02083523', 'FreeDiams::CA_HCDPD::DIN', 16968);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluorets (Fluorescein Ophthalmic Strips)', 'strip', 'S01JA01', false, 0, '02026252', 'FreeDiams::CA_HCDPD::DIN', 16977);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gentak Sterile Oph Ont 0.3%', 'ointment', 'S01AA11', false, 0, '01989073', 'FreeDiams::CA_HCDPD::DIN', 16983);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceporacin Injection 1g Pws', 'powder for solution', 'J01DB03', false, 0, '02060051', 'FreeDiams::CA_HCDPD::DIN', 16984);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Acetaminophen Oral Soln 160mg/5ml', 'solution', 'N02BE01', false, 0, '01901389', 'FreeDiams::CA_HCDPD::DIN', 16988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Ampicillin Sodium 250mg Usp', 'powder for solution', 'J01CA01', false, 0, '02068540', 'FreeDiams::CA_HCDPD::DIN', 16990);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crystapen 10000000 Iu Pws', 'powder for solution', 'J01CE01', false, 0, '02060108', 'FreeDiams::CA_HCDPD::DIN', 16991);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crystapen 5 000 000 Iu Pws', 'powder for solution', 'J01CE01', false, 0, '02060094', 'FreeDiams::CA_HCDPD::DIN', 16992);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crystapen 1 000 000 Iu Pws', 'powder for solution', 'J01CE01', false, 0, '02060086', 'FreeDiams::CA_HCDPD::DIN', 16993);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimenhydrinate Injection 50mg/Ml Usp', 'liquid', 'A04AD', false, 0, '02061732', 'FreeDiams::CA_HCDPD::DIN', 16994);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Histamine Phosphate Injection Usp Liq Sc', 'liquid', 'V04CG03', false, 0, '02094673', 'FreeDiams::CA_HCDPD::DIN', 16997);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epinephrine Injection Usp 1mg/Ml', 'solution', 'C01CA24', false, 0, '02063204', 'FreeDiams::CA_HCDPD::DIN', 16998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylene Blue Injection Usp Liq Iv', 'solution', 'V03AB17', false, 0, '02094665', 'FreeDiams::CA_HCDPD::DIN', 16999);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Thiamine Hcl Injection 100mg/Ml Usp', 'liquid', 'A11DA01', false, 0, '02062240', 'FreeDiams::CA_HCDPD::DIN', 17000);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidocaine Hcl Inj 2% Usp', 'liquid', 'N01BB02', false, 0, '01947060', 'FreeDiams::CA_HCDPD::DIN', 17002);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bioniche Promethazine Hcl Inj. Usp 25mg/Ml', 'solution', 'R06AD02', false, 0, '02068591', 'FreeDiams::CA_HCDPD::DIN', 17003);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlorpromazine Hcl Inj 25mg/Ml Usp', 'liquid', 'N05AA01', false, 0, '01933272', 'FreeDiams::CA_HCDPD::DIN', 17004);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlorhexidine Gluconate Solution 0.05%', 'solution', 'D08AC02', false, 0, '00832146', 'FreeDiams::CA_HCDPD::DIN', 17006);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cardizem Cd', 'capsule (extended release)', 'C08DB01', false, 0, '02097273', 'FreeDiams::CA_HCDPD::DIN', 17102);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glucophage', 'tablet', 'A10BA02', false, 0, '02099233', 'FreeDiams::CA_HCDPD::DIN', 17104);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rifadin', 'capsule', 'J04AB02', false, 0, '02091887', 'FreeDiams::CA_HCDPD::DIN', 17105);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinutab Extra Strength Tablets', 'tablet', 'N02BE51', false, 0, '01986988', 'FreeDiams::CA_HCDPD::DIN', 17113);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cloxacillin', 'capsule', 'J01CF02', false, 0, '02069679', 'FreeDiams::CA_HCDPD::DIN', 17116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Tiaprofenic Tablets-200mg', 'tablet', 'M01AE11', false, 0, '02136112', 'FreeDiams::CA_HCDPD::DIN', 17118);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Tiaprofenic Tablets -300mg', 'tablet', 'M01AE11', false, 0, '02136120', 'FreeDiams::CA_HCDPD::DIN', 17119);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zestril Tab 20mg', 'tablet', 'C09AA03', false, 0, '02049384', 'FreeDiams::CA_HCDPD::DIN', 17123);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cardizem Cd', 'capsule (extended release)', 'C08DB01', false, 0, '02097249', 'FreeDiams::CA_HCDPD::DIN', 17125);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zestril Tab 5mg', 'tablet', 'C09AA03', false, 0, '02049333', 'FreeDiams::CA_HCDPD::DIN', 17126);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desocort Lotion - 0.05%', 'lotion', 'D07AB08', false, 0, '02115514', 'FreeDiams::CA_HCDPD::DIN', 17137);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desocort Ointment - 0.05%', 'ointment', 'D07AB08', false, 0, '02115522', 'FreeDiams::CA_HCDPD::DIN', 17138);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Clonazepam', 'tablet', 'N03AE01', false, 0, '02103656', 'FreeDiams::CA_HCDPD::DIN', 17142);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Clonazepam', 'tablet', 'N03AE01', false, 0, '02103737', 'FreeDiams::CA_HCDPD::DIN', 17145);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atropine Injection Bp 0.4mg/Ml', 'solution', 'A03BA01', false, 0, '02094681', 'FreeDiams::CA_HCDPD::DIN', 17184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atropine Injection Bp 0.6mg/Ml', 'solution', 'A03BA01', false, 0, '02094703', 'FreeDiams::CA_HCDPD::DIN', 17186);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naproxen-Na Tab 275mg', 'tablet', 'M01AE02', false, 0, '00887056', 'FreeDiams::CA_HCDPD::DIN', 17199);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lamictal', 'tablet', 'N03AX09', false, 0, '02142104', 'FreeDiams::CA_HCDPD::DIN', 17201);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lamictal', 'tablet', 'N03AX09', false, 0, '02142082', 'FreeDiams::CA_HCDPD::DIN', 17203);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Resonium Calcium', 'powder for solution', 'V03AE01', false, 0, '02017741', 'FreeDiams::CA_HCDPD::DIN', 17205);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marinol', 'capsule', 'A04AD10', false, 0, '00611204', 'FreeDiams::CA_HCDPD::DIN', 17207);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marinol', 'capsule', 'A04AD10', false, 0, '00611190', 'FreeDiams::CA_HCDPD::DIN', 17209);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Wipeout Disinfecting And Sanitizing Spray', 'aerosol', 'V07AV', false, 0, '02130572', 'FreeDiams::CA_HCDPD::DIN', 17211);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tim-Ak Liq 0.25%', 'liquid', 'S01ED01', false, 0, '02010259', 'FreeDiams::CA_HCDPD::DIN', 17212);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tim-Ak Liq 0.5%', 'liquid', 'S01ED01', false, 0, '02010240', 'FreeDiams::CA_HCDPD::DIN', 17214);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zestril Tab 10mg', 'tablet', 'C09AA03', false, 0, '02049376', 'FreeDiams::CA_HCDPD::DIN', 17215);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Terazol 3 Dual Pak', 'kit', 'G01AG02', false, 0, '02130874', 'FreeDiams::CA_HCDPD::DIN', 17222);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Sodium In .9% Sodium Chloride Injection', 'solution', 'B01AB51', false, 0, '01990748', 'FreeDiams::CA_HCDPD::DIN', 17227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Gemfibrozil - Tab 600mg', 'tablet', 'C10AB04', false, 0, '02142074', 'FreeDiams::CA_HCDPD::DIN', 17230);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Verapamil Hydrochloride Injection 2.5mg/Ml', 'solution', 'C08DA01', false, 0, '00839299', 'FreeDiams::CA_HCDPD::DIN', 17234);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Endocet', 'tablet', 'N02BE51', false, 0, '01916548', 'FreeDiams::CA_HCDPD::DIN', 17235);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidodan Ointment 5%', 'ointment', 'D04AB01', false, 0, '02083795', 'FreeDiams::CA_HCDPD::DIN', 17236);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biaxin Bid 500mg', 'tablet', 'J01FA09', false, 0, '02126710', 'FreeDiams::CA_HCDPD::DIN', 17240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germinix 16 Liq', 'liquid', 'V07AV', false, 0, '02024780', 'FreeDiams::CA_HCDPD::DIN', 17241);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germinix 20 Liq', 'liquid', 'V07AV', false, 0, '02024799', 'FreeDiams::CA_HCDPD::DIN', 17242);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germinix  Liq', 'liquid', 'V07AV', false, 0, '02025442', 'FreeDiams::CA_HCDPD::DIN', 17243);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Baclofen Tablets - 10mg', 'tablet', 'M03BX01', false, 0, '02139332', 'FreeDiams::CA_HCDPD::DIN', 17246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Baclofen Tablets - 20mg', 'tablet', 'M03BX01', false, 0, '02139391', 'FreeDiams::CA_HCDPD::DIN', 17247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sulcrate Tablets 1gm', 'tablet', 'A02BX02', false, 0, '02100622', 'FreeDiams::CA_HCDPD::DIN', 17250);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cardizem Cd', 'capsule (extended release)', 'C08DB01', false, 0, '02097265', 'FreeDiams::CA_HCDPD::DIN', 17253);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cardizem Cd', 'capsule (extended release)', 'C08DB01', false, 0, '02097257', 'FreeDiams::CA_HCDPD::DIN', 17254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentrax Gold Shampoo 4%', 'shampoo', 'D05AA', false, 0, '00864706', 'FreeDiams::CA_HCDPD::DIN', 17265);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lioresal Intrathecal 2mg/Ml', 'solution', 'M03BX01', false, 0, '02131064', 'FreeDiams::CA_HCDPD::DIN', 17276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lioresal Intrathecal 0.05mg/Ml', 'solution', 'M03BX01', false, 0, '02131048', 'FreeDiams::CA_HCDPD::DIN', 17277);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Streptase', 'powder for solution', 'B01AD01', false, 0, '02018993', 'FreeDiams::CA_HCDPD::DIN', 17279);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose Inj Liq 50%', 'liquid', 'B05BA03', false, 0, '00824941', 'FreeDiams::CA_HCDPD::DIN', 17398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Charactol-25', 'suspension', 'A07BA01', false, 0, '02060205', 'FreeDiams::CA_HCDPD::DIN', 17399);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbachol Injection  Liq Sc 0.25mg/Ml', 'liquid', 'N07AB01', false, 0, '02095157', 'FreeDiams::CA_HCDPD::DIN', 17400);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ergonovine Maleate Injection 0.25mg/Ml Usp', 'solution', 'G02AB03', false, 0, '01996096', 'FreeDiams::CA_HCDPD::DIN', 17401);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bacteriostatic Water For Injection Usp', 'liquid', 'V07AB', false, 0, '02131536', 'FreeDiams::CA_HCDPD::DIN', 17402);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Salazopyrin Tab 500mg', 'tablet', 'A07EC01', false, 0, '02064480', 'FreeDiams::CA_HCDPD::DIN', 17416);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Salazopyrin En-Tabs 500 Mg', 'tablet (enteric-coated)', 'A07EC01', false, 0, '02064472', 'FreeDiams::CA_HCDPD::DIN', 17417);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sonibex', 'liquid', 'V07AV', false, 0, '02072602', 'FreeDiams::CA_HCDPD::DIN', 17426);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diorouge Liq', 'liquid', 'S01GA55', false, 0, '02026511', 'FreeDiams::CA_HCDPD::DIN', 17733);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diopticon Liq 0.1%', 'liquid', 'S01GA01', false, 0, '02026546', 'FreeDiams::CA_HCDPD::DIN', 17734);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kayexalate', 'powder', 'V03AE01', false, 0, '02026961', 'FreeDiams::CA_HCDPD::DIN', 17752);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prednisone 50 Tab 50mg', 'tablet', 'H02AB07', false, 0, '00607517', 'FreeDiams::CA_HCDPD::DIN', 17756);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Akwa Tears', 'ointment', 'S01XA20', false, 0, '00626562', 'FreeDiams::CA_HCDPD::DIN', 17759);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enviro Chem Neutral Disinfectant', 'liquid', 'V07AV', false, 0, '02130661', 'FreeDiams::CA_HCDPD::DIN', 17768);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dyna Quat 256', 'liquid', 'V07AV', false, 0, '02116510', 'FreeDiams::CA_HCDPD::DIN', 17771);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dyna Quat 64 - 3.85% Liq', 'liquid', 'V07AV', false, 0, '02116502', 'FreeDiams::CA_HCDPD::DIN', 17772);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bacteriostatic Nacl Diluent For Inhalation', 'liquid', 'R01AX30', false, 0, '02094657', 'FreeDiams::CA_HCDPD::DIN', 17778);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Inderal-La', 'capsule (sustained-release)', 'C07AA05', false, 0, '02042231', 'FreeDiams::CA_HCDPD::DIN', 17780);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allernix Extra Strength', 'tablet', 'R06AA02', false, 0, '02097575', 'FreeDiams::CA_HCDPD::DIN', 17781);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diflucan One', 'capsule', 'J02AC01', false, 0, '02141442', 'FreeDiams::CA_HCDPD::DIN', 17789);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allernix', 'tablet', 'R06AA02', false, 0, '02097583', 'FreeDiams::CA_HCDPD::DIN', 17794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zemuron', 'solution', 'M03AC09', false, 0, '02108208', 'FreeDiams::CA_HCDPD::DIN', 17797);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neoral 100mg', 'capsule', 'L04AD01', false, 0, '02150670', 'FreeDiams::CA_HCDPD::DIN', 17799);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Telebrix 38 Oral', 'solution', 'V08AA05', false, 0, '02131684', 'FreeDiams::CA_HCDPD::DIN', 17800);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neoral Oral Solution 100mg/Ml', 'solution', 'L04AD01', false, 0, '02150697', 'FreeDiams::CA_HCDPD::DIN', 17801);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neoral 25mg', 'capsule', 'L04AD01', false, 0, '02150689', 'FreeDiams::CA_HCDPD::DIN', 17813);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neoral 50mg', 'capsule', 'L04AD01', false, 0, '02150662', 'FreeDiams::CA_HCDPD::DIN', 17814);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ativan', 'tablet', 'N05BA06', false, 0, '02041456', 'FreeDiams::CA_HCDPD::DIN', 17817);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dilaudid-Hp-Plus', 'solution', 'N02AA03', false, 0, '02146118', 'FreeDiams::CA_HCDPD::DIN', 17822);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dilaudid-Xp', 'liquid', 'N02AA03', false, 0, '02145863', 'FreeDiams::CA_HCDPD::DIN', 17823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metrogel 0.75%', 'gel', 'D06BX01', false, 0, '02092832', 'FreeDiams::CA_HCDPD::DIN', 17824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Acebutolol', 'tablet', 'C07AB04', false, 0, '02147602', 'FreeDiams::CA_HCDPD::DIN', 17826);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Acebutolol', 'tablet', 'C07AB04', false, 0, '02147610', 'FreeDiams::CA_HCDPD::DIN', 17827);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Acebutolol', 'tablet', 'C07AB04', false, 0, '02147629', 'FreeDiams::CA_HCDPD::DIN', 17828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carboplatin Injection - Liq  Iv  10mg/Ml', 'liquid', 'L01XA02', false, 0, '02125439', 'FreeDiams::CA_HCDPD::DIN', 17830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Metoprolol-B Tablets - 100mg', 'tablet', 'C07AB02', false, 0, '02145421', 'FreeDiams::CA_HCDPD::DIN', 17831);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Monistat Derm Cream', 'cream', 'D01AC02', false, 0, '02126567', 'FreeDiams::CA_HCDPD::DIN', 17832);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Metoprolol-B Tablets - 50mg', 'tablet', 'C07AB02', false, 0, '02145413', 'FreeDiams::CA_HCDPD::DIN', 17833);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bentylol Syrup 10mg/5ml', 'syrup', 'A03AA07', false, 0, '02102978', 'FreeDiams::CA_HCDPD::DIN', 17841);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bentylol Tablet 20mg', 'tablet', 'A03AA07', false, 0, '02103095', 'FreeDiams::CA_HCDPD::DIN', 17842);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lipidil Micro - Cap 200mg', 'capsule', 'C10AB05', false, 0, '02146959', 'FreeDiams::CA_HCDPD::DIN', 17849);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solu-Medrol', 'kit', 'H02AB04', false, 0, '02063700', 'FreeDiams::CA_HCDPD::DIN', 19021);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zonalon Cream 5%', 'cream', 'D04AX', false, 0, '02142147', 'FreeDiams::CA_HCDPD::DIN', 17850);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sulcrate Suspension Plus - 1g/5ml', 'suspension', 'A02BX02', false, 0, '02103567', 'FreeDiams::CA_HCDPD::DIN', 17852);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Cold Medication Daytime Relief', 'tablet', 'N02BE51', false, 0, '02083736', 'FreeDiams::CA_HCDPD::DIN', 17880);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Cold Medication (Night Time Relief) Caplets', 'tablet', 'N02BE51', false, 0, '02039842', 'FreeDiams::CA_HCDPD::DIN', 17887);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dipentum', 'capsule', 'A07EC03', false, 0, '02063808', 'FreeDiams::CA_HCDPD::DIN', 17893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Bacitracin Ointment 500units/Gm', 'ointment', 'D06AX05', false, 0, '02094754', 'FreeDiams::CA_HCDPD::DIN', 17895);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidocaine And Epinephrine Inj.Usp2% 1:100000', 'liquid', 'N01BB52', false, 0, '02062151', 'FreeDiams::CA_HCDPD::DIN', 17901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zestoretic Tab 20/25mg', 'tablet', 'C09BA03', false, 0, '02045729', 'FreeDiams::CA_HCDPD::DIN', 17903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tenoretic 100/25mg Tab', 'tablet', 'C07CB03', false, 0, '02049988', 'FreeDiams::CA_HCDPD::DIN', 17904);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tenormin 50mg', 'tablet', 'C07AB03', false, 0, '02039532', 'FreeDiams::CA_HCDPD::DIN', 17905);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tenormin 100mg', 'tablet', 'C07AB03', false, 0, '02039540', 'FreeDiams::CA_HCDPD::DIN', 17906);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crown Antiseptic Hand Soap', 'liquid', 'D08AE04', false, 0, '02143968', 'FreeDiams::CA_HCDPD::DIN', 17953);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lioresal Intrathecal 0.5mg/Ml', 'solution', 'M03BX01', false, 0, '02131056', 'FreeDiams::CA_HCDPD::DIN', 17954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidocaine Hydrochloride Injection 1%', 'solution', 'N01BB02', false, 0, '02067021', 'FreeDiams::CA_HCDPD::DIN', 17964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rosone Ointment 0.05%', 'ointment', 'D07AC01', false, 0, '02122057', 'FreeDiams::CA_HCDPD::DIN', 17968);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('F-H Disinfectant Deterg Sanitizer', 'liquid', 'V07AV', false, 0, '00801836', 'FreeDiams::CA_HCDPD::DIN', 17969);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Alprazolam', 'tablet', 'N05BA12', false, 0, '02137534', 'FreeDiams::CA_HCDPD::DIN', 17972);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Alprazolam', 'tablet', 'N05BA12', false, 0, '02137542', 'FreeDiams::CA_HCDPD::DIN', 17973);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Amantadine', 'capsule', 'N04BB01', false, 0, '02139200', 'FreeDiams::CA_HCDPD::DIN', 17975);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rosone Lotion 0.05%', 'lotion', 'D07AC01', false, 0, '02122030', 'FreeDiams::CA_HCDPD::DIN', 17992);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zoloft', 'capsule', 'N06AB06', false, 0, '02132702', 'FreeDiams::CA_HCDPD::DIN', 18005);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rolene Cream 0.05%', 'cream', 'D07AC01', false, 0, '02122073', 'FreeDiams::CA_HCDPD::DIN', 18006);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rolene Ointment 0.05%', 'ointment', 'D07AC01', false, 0, '02122081', 'FreeDiams::CA_HCDPD::DIN', 18007);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rolene Lotion 0.05%', 'lotion', 'D07AC01', false, 0, '02122065', 'FreeDiams::CA_HCDPD::DIN', 18008);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rosone Cream 0.05%', 'cream', 'D07AC01', false, 0, '02122049', 'FreeDiams::CA_HCDPD::DIN', 18009);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diflucan Pws 50mg/5ml', 'powder for solution', 'J02AC01', false, 0, '02024152', 'FreeDiams::CA_HCDPD::DIN', 18010);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidocaine Hcl Inj 2% Usp', 'solution', 'C01BB01', false, 0, '01901982', 'FreeDiams::CA_HCDPD::DIN', 18012);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Afterburn', 'gel', 'D04AB01', false, 0, '02122286', 'FreeDiams::CA_HCDPD::DIN', 18014);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Oral Solution 80 Mg/Ml', 'solution', 'N02BE01', false, 0, '01904140', 'FreeDiams::CA_HCDPD::DIN', 18015);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ac-Quat Nr - Liq', 'liquid', 'V07AV', false, 0, '02146371', 'FreeDiams::CA_HCDPD::DIN', 18016);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naloxone Hcl Injection - 1mg/Ml Usp', 'liquid', 'V03AB15', false, 0, '02148714', 'FreeDiams::CA_HCDPD::DIN', 18024);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naloxone Hcl Injection - 0.4mg/Ml Usp', 'liquid', 'V03AB15', false, 0, '02148706', 'FreeDiams::CA_HCDPD::DIN', 18025);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dioptic''S Balanced Salt Solution', 'solution', 'B05CB10', false, 0, '02023709', 'FreeDiams::CA_HCDPD::DIN', 18029);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Trazodone D Tablets 150mg', 'tablet', 'N06AX05', false, 0, '02147653', 'FreeDiams::CA_HCDPD::DIN', 18040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Trazodone Tablets 100mg', 'tablet', 'N06AX05', false, 0, '02147645', 'FreeDiams::CA_HCDPD::DIN', 18045);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Trazodone Tablets 50mg', 'tablet', 'N06AX05', false, 0, '02147637', 'FreeDiams::CA_HCDPD::DIN', 18046);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Metformin', 'tablet', 'A10BA02', false, 0, '02148765', 'FreeDiams::CA_HCDPD::DIN', 18058);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Metoclopramide-Tab 5mg', 'tablet', 'A03FA01', false, 0, '02143275', 'FreeDiams::CA_HCDPD::DIN', 18060);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Metoclopramide-Tab 10mg', 'tablet', 'A03FA01', false, 0, '02143283', 'FreeDiams::CA_HCDPD::DIN', 18061);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Indapamide', 'tablet', 'C03BA11', false, 0, '02153483', 'FreeDiams::CA_HCDPD::DIN', 18065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biaxin - 125mg/5ml', 'granules for suspension', 'J01FA09', false, 0, '02146908', 'FreeDiams::CA_HCDPD::DIN', 18066);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Salvent Tablets - 4mg', 'tablet', 'R03CC02', false, 0, '02146851', 'FreeDiams::CA_HCDPD::DIN', 18067);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Salvent Tablets - 2mg', 'tablet', 'R03CC02', false, 0, '02146843', 'FreeDiams::CA_HCDPD::DIN', 18068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cholamine Light - Pwr 4g/Dose', 'kit', 'C10AC01', false, 0, '02139197', 'FreeDiams::CA_HCDPD::DIN', 18069);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cholamine - Pwr  4g/Dose', 'kit', 'C10AC01', false, 0, '02139189', 'FreeDiams::CA_HCDPD::DIN', 18070);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Loperamide Tablets-2mg', 'tablet', 'A07DA03', false, 0, '02132591', 'FreeDiams::CA_HCDPD::DIN', 18071);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyklokapron 500 Mg', 'tablet', 'B02AA02', false, 0, '02064405', 'FreeDiams::CA_HCDPD::DIN', 18072);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Oxybutyn - Tab 5mg', 'tablet', 'G04BD04', false, 0, '02158590', 'FreeDiams::CA_HCDPD::DIN', 18073);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vesanoid - Cap 10mg', 'capsule', 'L01XX14', false, 0, '02145839', 'FreeDiams::CA_HCDPD::DIN', 18080);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mycobutin', 'capsule', 'J04AB04', false, 0, '02063786', 'FreeDiams::CA_HCDPD::DIN', 18081);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prevent X Hand Sanitizer And Antiseptic Skin Protectant', 'lotion', 'D08AJ51', false, 0, '02053667', 'FreeDiams::CA_HCDPD::DIN', 18082);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitroglycerin In 5% Dextrose Inj.-400mcg/Ml', 'solution', 'C01DA02', false, 0, '02145316', 'FreeDiams::CA_HCDPD::DIN', 18085);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitroglycerin In 5% Dextrose Inj.-200mcg/Ml', 'solution', 'C01DA02', false, 0, '02145308', 'FreeDiams::CA_HCDPD::DIN', 18086);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitroglycerin In 5% Dextrose Inj.-100mcg/Ml', 'solution', 'C01DA02', false, 0, '02145294', 'FreeDiams::CA_HCDPD::DIN', 18087);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Azeo-Pangen Pancreatin Tablets 325mg Usp', 'tablet', 'A09AA02', false, 0, '00822566', 'FreeDiams::CA_HCDPD::DIN', 18096);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Optilube Ont', 'ointment', 'S01XA20', false, 0, '02026457', 'FreeDiams::CA_HCDPD::DIN', 18099);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride Injection Usp', 'solution', 'B05XA03', false, 0, '02150204', 'FreeDiams::CA_HCDPD::DIN', 18136);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tenoretic 50/25mg Tab', 'tablet', 'C07CB03', false, 0, '02049961', 'FreeDiams::CA_HCDPD::DIN', 18139);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Atenolol', 'tablet', 'C07AB03', false, 0, '02146894', 'FreeDiams::CA_HCDPD::DIN', 18161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12306', 'solution', 'B05ZA', false, 0, '02160870', 'FreeDiams::CA_HCDPD::DIN', 18167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mucaine - Sus', 'suspension', 'A02AX', false, 0, '02125013', 'FreeDiams::CA_HCDPD::DIN', 18186);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Atenolol', 'tablet', 'C07AB03', false, 0, '02147432', 'FreeDiams::CA_HCDPD::DIN', 18188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Trazodone', 'tablet', 'N06AX05', false, 0, '02144298', 'FreeDiams::CA_HCDPD::DIN', 18189);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Trazodone', 'tablet', 'N06AX05', false, 0, '02144271', 'FreeDiams::CA_HCDPD::DIN', 18190);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Trazodone', 'tablet', 'N06AX05', false, 0, '02144263', 'FreeDiams::CA_HCDPD::DIN', 18191);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12265', 'solution', 'B05ZA', false, 0, '02158167', 'FreeDiams::CA_HCDPD::DIN', 18199);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12264', 'solution', 'B05ZA', false, 0, '02158159', 'FreeDiams::CA_HCDPD::DIN', 18200);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12262', 'solution', 'B05ZA', false, 0, '02158221', 'FreeDiams::CA_HCDPD::DIN', 18202);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12255', 'solution', 'B05ZA', false, 0, '02158256', 'FreeDiams::CA_HCDPD::DIN', 18206);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Virobex-P', 'liquid', 'D08AE05', false, 0, '02131471', 'FreeDiams::CA_HCDPD::DIN', 18208);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxipor Lotion', 'lotion', 'D05AA', false, 0, '02230134', 'FreeDiams::CA_HCDPD::DIN', 48713);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Leucovorin Calcium Injection Im Iv 10mg/Ml', 'solution', 'V03AF03', false, 0, '02087316', 'FreeDiams::CA_HCDPD::DIN', 18209);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Duovent Udv', 'solution', 'R03AK03', false, 0, '02148633', 'FreeDiams::CA_HCDPD::DIN', 18210);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Salofalk (R) 5-Asa Suppositories - 500mg', 'suppository', 'A07EC02', false, 0, '02112760', 'FreeDiams::CA_HCDPD::DIN', 18212);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Salofalk (R) 5-Asa Enteric Coated Tab- 500mg', 'tablet (enteric-coated)', 'A07EC02', false, 0, '02112787', 'FreeDiams::CA_HCDPD::DIN', 18214);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bentylol Tablet 10mg', 'tablet', 'A03AA07', false, 0, '02103087', 'FreeDiams::CA_HCDPD::DIN', 18227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Iopidine Liq Oph 0.5%', 'liquid', 'S01EA03', false, 0, '02076306', 'FreeDiams::CA_HCDPD::DIN', 18228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Talwin', 'tablet', 'N02AD01', false, 0, '02137984', 'FreeDiams::CA_HCDPD::DIN', 18230);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fragmin 10 000iu(Anti-Xa)/Ml', 'solution', 'B01AB04', false, 0, '02132664', 'FreeDiams::CA_HCDPD::DIN', 18235);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diclofenac Sr', 'tablet (extended-release)', 'M01AB05', false, 0, '02158582', 'FreeDiams::CA_HCDPD::DIN', 18239);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anodan-Hc Ointment', 'ointment', 'C05AA01', false, 0, '02128446', 'FreeDiams::CA_HCDPD::DIN', 18240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gentamicin(E) 120mg Liq Iv 1.2mg/Ml', 'solution', 'J01GB03', false, 0, '02082144', 'FreeDiams::CA_HCDPD::DIN', 18241);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gentamicin(E) 100mg Liq Iv 1mg/Ml', 'solution', 'J01GB03', false, 0, '02082136', 'FreeDiams::CA_HCDPD::DIN', 18242);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gentamicin(E) 80mg Liq Iv 1.6mg/Ml', 'solution', 'J01GB03', false, 0, '02082152', 'FreeDiams::CA_HCDPD::DIN', 18243);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12248', 'solution', 'B05ZA', false, 0, '02158329', 'FreeDiams::CA_HCDPD::DIN', 18268);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Wartec', 'liquid', 'D06BB04', false, 0, '02074788', 'FreeDiams::CA_HCDPD::DIN', 18274);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sofra-Tulle Strip 1%', 'dressing', 'D09AA01', false, 0, '01987682', 'FreeDiams::CA_HCDPD::DIN', 18285);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Octostim Liq Inj. 15mcg/Ml', 'liquid', 'H01BA02', false, 0, '02024179', 'FreeDiams::CA_HCDPD::DIN', 18289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Microlax Micro Enema', 'kit', 'A06AG20', false, 0, '02063905', 'FreeDiams::CA_HCDPD::DIN', 18290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Staphicide S', 'liquid', 'V07AV', false, 0, '02160560', 'FreeDiams::CA_HCDPD::DIN', 18304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fragmin 5000iu(Anti-Xa)/0.2ml', 'solution', 'B01AB04', false, 0, '02132648', 'FreeDiams::CA_HCDPD::DIN', 18306);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fragmin 2500iu(Anti-Xa)/0.2ml', 'solution', 'B01AB04', false, 0, '02132621', 'FreeDiams::CA_HCDPD::DIN', 18307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Calcium-45  0.25-4.5', 'powder', 'B05ZA', false, 0, '02161060', 'FreeDiams::CA_HCDPD::DIN', 18310);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proleukin', 'powder for solution', 'L03AC01', false, 0, '02130181', 'FreeDiams::CA_HCDPD::DIN', 18314);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorphone Hydrochloride Injection Usp', 'solution', 'N02AA03', false, 0, '02145901', 'FreeDiams::CA_HCDPD::DIN', 18315);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Demerol', 'tablet', 'N02AB02', false, 0, '02138018', 'FreeDiams::CA_HCDPD::DIN', 18316);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose-45  5.55-4.5', 'powder', 'B05ZA', false, 0, '02160978', 'FreeDiams::CA_HCDPD::DIN', 18319);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Calcium-45  0.5-4.5', 'powder', 'B05ZA', false, 0, '02160986', 'FreeDiams::CA_HCDPD::DIN', 18321);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorphone Hp 10', 'solution', 'N02AA03', false, 0, '02145928', 'FreeDiams::CA_HCDPD::DIN', 18323);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorphone Hp 50', 'solution', 'N02AA03', false, 0, '02146126', 'FreeDiams::CA_HCDPD::DIN', 18324);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorphone Hp 20', 'solution', 'N02AA03', false, 0, '02145936', 'FreeDiams::CA_HCDPD::DIN', 18325);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fresh 100', 'liquid', 'V07AV', false, 0, '02164035', 'FreeDiams::CA_HCDPD::DIN', 18329);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Primaquine', 'tablet', 'P01BA03', false, 0, '02017776', 'FreeDiams::CA_HCDPD::DIN', 18330);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Piroxicam Suppositories -20mg', 'suppository', 'M01AC01', false, 0, '02154463', 'FreeDiams::CA_HCDPD::DIN', 18333);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cocaine Hydrochloride Topical Sol 10%', 'liquid', 'R02AD03', false, 0, '02006308', 'FreeDiams::CA_HCDPD::DIN', 18334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Piroxicam Suppositories-10mg', 'suppository', 'M01AC01', false, 0, '02154420', 'FreeDiams::CA_HCDPD::DIN', 18335);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asaphen', 'tablet (chewable)', 'N02BA01', false, 0, '02009013', 'FreeDiams::CA_HCDPD::DIN', 18349);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Sotalol - Tab 160 Mg', 'tablet', 'C07AA07', false, 0, '02163772', 'FreeDiams::CA_HCDPD::DIN', 18350);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Oxybutynin - Tab 5mg', 'tablet', 'G04BD04', false, 0, '02163543', 'FreeDiams::CA_HCDPD::DIN', 18355);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Clonazepam - Tab 2mg', 'tablet', 'N03AE01', false, 0, '02131013', 'FreeDiams::CA_HCDPD::DIN', 18366);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyklokapron 100 Mg/Ml', 'solution', 'B02AA02', false, 0, '02064413', 'FreeDiams::CA_HCDPD::DIN', 18371);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenokil Ii', 'liquid', 'V07AV', false, 0, '02160412', 'FreeDiams::CA_HCDPD::DIN', 18412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Metformin - Tab 500mg', 'tablet', 'A10BA02', false, 0, '02162822', 'FreeDiams::CA_HCDPD::DIN', 18416);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Indigo Carmine', 'solution', 'V04CH02', false, 0, '02014815', 'FreeDiams::CA_HCDPD::DIN', 18417);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ic-Green', 'powder', 'V04CX', false, 0, '02014793', 'FreeDiams::CA_HCDPD::DIN', 18418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Doxylin -Tab 100mg', 'tablet', 'J01AA02', false, 0, '02158574', 'FreeDiams::CA_HCDPD::DIN', 18421);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hygenipak Green Anti-Microbial Skin Cleanser', 'gel', 'D08AE20', false, 0, '02158442', 'FreeDiams::CA_HCDPD::DIN', 18442);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zinecard', 'powder for solution', 'V03AF02', false, 0, '02153432', 'FreeDiams::CA_HCDPD::DIN', 18480);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zinecard', 'powder for solution', 'V03AF02', false, 0, '02153440', 'FreeDiams::CA_HCDPD::DIN', 18481);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intralipid 10%', 'emulsion', 'B05BA02', false, 0, '02065681', 'FreeDiams::CA_HCDPD::DIN', 18484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Maprotiline - Tab 75mg', 'tablet', 'N06AA21', false, 0, '02158639', 'FreeDiams::CA_HCDPD::DIN', 18485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Maprotiline - Tab 50mg', 'tablet', 'N06AA21', false, 0, '02158620', 'FreeDiams::CA_HCDPD::DIN', 18486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Maprotiline - Tab 25mg', 'tablet', 'N06AA21', false, 0, '02158612', 'FreeDiams::CA_HCDPD::DIN', 18489);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ocuflox - Liq Oph 0.3%', 'liquid', 'S01AX11', false, 0, '02143291', 'FreeDiams::CA_HCDPD::DIN', 18491);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentasa Suppository - 1g', 'suppository', 'A07EC02', false, 0, '02153564', 'FreeDiams::CA_HCDPD::DIN', 18493);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentasa Enema 4g/100ml', 'kit', 'A07EC02', false, 0, '02153556', 'FreeDiams::CA_HCDPD::DIN', 18494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentasa Enema 1g/100ml', 'kit', 'A07EC02', false, 0, '02153521', 'FreeDiams::CA_HCDPD::DIN', 18496);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prometrium', 'capsule', 'G03DA04', false, 0, '02166704', 'FreeDiams::CA_HCDPD::DIN', 18500);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pharmorubicin Pfs', 'solution', 'L01DB03', false, 0, '02065703', 'FreeDiams::CA_HCDPD::DIN', 18504);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Salofalk (R) 4gm/60gm Rectal Suspension', 'suspension', 'A07EC02', false, 0, '02112809', 'FreeDiams::CA_HCDPD::DIN', 18509);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Salofalk (R) 2gm/60gm Rectal Suspension', 'suspension', 'A07EC02', false, 0, '02112795', 'FreeDiams::CA_HCDPD::DIN', 18510);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alnox Gas', 'gas', 'N01AX63', false, 0, '02071010', 'FreeDiams::CA_HCDPD::DIN', 18513);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Microcide  -  Liquid - 5.0%', 'liquid', 'V07AV', false, 0, '02170205', 'FreeDiams::CA_HCDPD::DIN', 18514);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prevacid - Src 15mg', 'capsule (delayed release)', 'A02BC03', false, 0, '02165503', 'FreeDiams::CA_HCDPD::DIN', 18515);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prevacid - Src 30mg', 'capsule (delayed release)', 'A02BC03', false, 0, '02165511', 'FreeDiams::CA_HCDPD::DIN', 18516);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eprex Sterile Solution 10000iu/Ml', 'solution', 'B03XA01', false, 0, '02126591', 'FreeDiams::CA_HCDPD::DIN', 18517);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dovonex - Crm 50mcg/Gm', 'cream', 'D05AX02', false, 0, '02150956', 'FreeDiams::CA_HCDPD::DIN', 18519);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eprex Sterile Solution 4000iu/Ml', 'solution', 'B03XA01', false, 0, '02126583', 'FreeDiams::CA_HCDPD::DIN', 18529);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Clopamine Tablets- 50mg', 'tablet', 'N06AA04', false, 0, '02130173', 'FreeDiams::CA_HCDPD::DIN', 18530);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eprex Sterile Solution 2000iu/Ml', 'solution', 'B03XA01', false, 0, '02126575', 'FreeDiams::CA_HCDPD::DIN', 18538);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Dayquil Sinus Pr.And Pain Rel.W.Ibupr.', 'tablet', 'M01AE51', false, 0, '02070898', 'FreeDiams::CA_HCDPD::DIN', 18539);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pancuronium Bromide 2mg/Ml', 'solution', 'M03AC01', false, 0, '02080028', 'FreeDiams::CA_HCDPD::DIN', 18549);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Travasol Amino Acid Injection Without Electrolytes In 20% Dextrose Clinimix', 'solution', 'B05BA10', false, 0, '02013940', 'FreeDiams::CA_HCDPD::DIN', 18550);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Colestid Orange Granules', 'granules', 'C10AC02', false, 0, '02132699', 'FreeDiams::CA_HCDPD::DIN', 18552);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dormer 211 Face Cream Spf 15', 'cream', 'D02BA30', false, 0, '02035472', 'FreeDiams::CA_HCDPD::DIN', 18554);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorph Contin-Controlled Release Cap - 3mg', 'capsule (sustained-release)', 'N02AA03', false, 0, '02125323', 'FreeDiams::CA_HCDPD::DIN', 18556);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorph Contin-Controlled Release Cap - 6mg', 'capsule (sustained-release)', 'N02AA03', false, 0, '02125331', 'FreeDiams::CA_HCDPD::DIN', 18558);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alertonic', 'elixir', 'A13A', false, 0, '02103052', 'FreeDiams::CA_HCDPD::DIN', 18602);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn-Pf 10%', 'solution', 'B05BA01', false, 0, '00731366', 'FreeDiams::CA_HCDPD::DIN', 18606);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn Ii 8.5% Injection', 'solution', 'B05BA01', false, 0, '00742627', 'FreeDiams::CA_HCDPD::DIN', 18607);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn Ii 7% Injection', 'solution', 'B05BA01', false, 0, '00742635', 'FreeDiams::CA_HCDPD::DIN', 18608);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Droperidol Injection Usp 2.5mg/Ml', 'solution', 'N01AX01', false, 0, '02167832', 'FreeDiams::CA_HCDPD::DIN', 18611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Verapamil Hydrochloride Injection Usp', 'liquid', 'C08DA01', false, 0, '02166739', 'FreeDiams::CA_HCDPD::DIN', 18614);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('B-Quat Liquid Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '01941674', 'FreeDiams::CA_HCDPD::DIN', 18626);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Colestid Tablets 1 G', 'tablet', 'C10AC02', false, 0, '02132680', 'FreeDiams::CA_HCDPD::DIN', 18627);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn Ii 10% With Electrolytes', 'solution', 'B05BA10', false, 0, '00742651', 'FreeDiams::CA_HCDPD::DIN', 18628);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('R & C Shampoo With Conditioner', 'shampoo', 'P03AC51', false, 0, '02125447', 'FreeDiams::CA_HCDPD::DIN', 18634);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nolvadex-D Tab 20mg', 'tablet', 'L02BA01', false, 0, '02048485', 'FreeDiams::CA_HCDPD::DIN', 18639);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estring', 'ring (slow-release)', 'G03CA03', false, 0, '02168898', 'FreeDiams::CA_HCDPD::DIN', 18640);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diazemuls', 'emulsion', 'N05BA01', false, 0, '02065614', 'FreeDiams::CA_HCDPD::DIN', 18641);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn Ii 10%', 'solution', 'B05BA01', false, 0, '00742619', 'FreeDiams::CA_HCDPD::DIN', 18644);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn Ii 7% With 50% Dextrose', 'solution', 'B05BA10', false, 0, '00742759', 'FreeDiams::CA_HCDPD::DIN', 18645);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn-Pf 7%', 'solution', 'B05BA01', false, 0, '00731358', 'FreeDiams::CA_HCDPD::DIN', 18646);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intralipid 20%', 'emulsion', 'B05BA02', false, 0, '02065673', 'FreeDiams::CA_HCDPD::DIN', 18647);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sani-12  -  Liquid', 'liquid', 'V07AV', false, 0, '02168413', 'FreeDiams::CA_HCDPD::DIN', 18662);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygene - Gas Inh', 'gas', 'V03AN01', false, 0, '02170175', 'FreeDiams::CA_HCDPD::DIN', 18663);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jaa Pyral S Suspension 50mg/76', 'suspension', 'P02CC01', false, 0, '00786063', 'FreeDiams::CA_HCDPD::DIN', 18664);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hexalen', 'capsule', 'L01XX03', false, 0, '02126230', 'FreeDiams::CA_HCDPD::DIN', 18669);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adriamycin Pfs', 'solution', 'L01DB01', false, 0, '02071002', 'FreeDiams::CA_HCDPD::DIN', 18674);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Visipaque', 'solution', 'V08AB09', false, 0, '02145766', 'FreeDiams::CA_HCDPD::DIN', 18685);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('70% Dextrose Injection Usp', 'solution', 'B05BA03', false, 0, '02014874', 'FreeDiams::CA_HCDPD::DIN', 18686);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Renalin Liquid Disinfectant', 'liquid', 'V07AV', false, 0, '02072572', 'FreeDiams::CA_HCDPD::DIN', 18687);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu Colour Moisturshade Liquid Finish Spf 15', 'liquid', 'D02BA30', false, 0, '02160838', 'FreeDiams::CA_HCDPD::DIN', 18691);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Red Cote Tab 5mg', 'tablet', 'V04CX', false, 0, '00690112', 'FreeDiams::CA_HCDPD::DIN', 18692);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Visipaque', 'solution', 'V08AB09', false, 0, '02145774', 'FreeDiams::CA_HCDPD::DIN', 18694);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn Ii 8.5% M In 20% Dextrose (Dual Chamber)', 'solution', 'B05BA10', false, 0, '00742716', 'FreeDiams::CA_HCDPD::DIN', 18697);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn Ii 7% M In 10% Dextrose(Dual Chamber)', 'solution', 'B05BA10', false, 0, '00742724', 'FreeDiams::CA_HCDPD::DIN', 18698);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn Ii In Dextrose Injection', 'solution', 'B05BA10', false, 0, '00742783', 'FreeDiams::CA_HCDPD::DIN', 18699);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn Ii With Electrolytes In Dextrose With Calcium', 'solution', 'B05BA10', false, 0, '00851566', 'FreeDiams::CA_HCDPD::DIN', 18700);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn Ii With Electrolytes In Dextrose Injection With Calcium', 'solution', 'B05BA10', false, 0, '00851531', 'FreeDiams::CA_HCDPD::DIN', 18701);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn Ii In Dextrose Injection', 'solution', 'B05BA10', false, 0, '00839302', 'FreeDiams::CA_HCDPD::DIN', 18702);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn Ii 7% With 10% Dextrose', 'solution', 'B05BA10', false, 0, '00742740', 'FreeDiams::CA_HCDPD::DIN', 18703);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sanitrol-Mb Liq', 'liquid', 'V07AV', false, 0, '02073021', 'FreeDiams::CA_HCDPD::DIN', 18713);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medi-Quat 4 Liq', 'liquid', 'V07AV', false, 0, '02069164', 'FreeDiams::CA_HCDPD::DIN', 18714);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hepalean 25,000 Usp', 'solution', 'B01AB01', false, 0, '00740535', 'FreeDiams::CA_HCDPD::DIN', 18721);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn Ii 8.5% With 50% Dextrose', 'solution', 'B05BA10', false, 0, '00742767', 'FreeDiams::CA_HCDPD::DIN', 18727);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn Ii In Dextrose Injection', 'solution', 'B05BA10', false, 0, '00839310', 'FreeDiams::CA_HCDPD::DIN', 18729);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Qt75 Sanitizer', 'liquid', 'V07AV', false, 0, '02161559', 'FreeDiams::CA_HCDPD::DIN', 18733);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluanxol Depot 10%- Liq Im 100mg/Ml', 'solution', 'N05AF01', false, 0, '02156040', 'FreeDiams::CA_HCDPD::DIN', 18737);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dey-Pak Sodium Chloride Solution 10%', 'solution', 'R01AX10', false, 0, '02058243', 'FreeDiams::CA_HCDPD::DIN', 18738);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluanxol 0.5mg - Tab', 'tablet', 'N05AF01', false, 0, '02156008', 'FreeDiams::CA_HCDPD::DIN', 18739);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluanxol 3mg - Tab', 'tablet', 'N05AF01', false, 0, '02156016', 'FreeDiams::CA_HCDPD::DIN', 18740);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minims Cyclopentolate Hydrochloride 1%', 'drops', 'S01FA04', false, 0, '02148382', 'FreeDiams::CA_HCDPD::DIN', 18742);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dey-Pak Sodium Chloride Solution 0.45%', 'solution', 'R01AX10', false, 0, '02058227', 'FreeDiams::CA_HCDPD::DIN', 18743);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minims Pilocarpine Nitrate 2%', 'drops', 'S01EB01', false, 0, '02148463', 'FreeDiams::CA_HCDPD::DIN', 18744);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minims Fluorescein Sodium 2%', 'liquid', 'S01JA01', false, 0, '02148390', 'FreeDiams::CA_HCDPD::DIN', 18747);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minims Tetracaine Hydrochloride 1%', 'drops', 'S01HA03', false, 0, '02148544', 'FreeDiams::CA_HCDPD::DIN', 18749);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minims Prednisolone Sodium Phosphate .5%', 'drops', 'S01BA04', false, 0, '02148498', 'FreeDiams::CA_HCDPD::DIN', 18750);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minims Tetracaine Hydrochloride 0.5%', 'drops', 'S01HA03', false, 0, '02148528', 'FreeDiams::CA_HCDPD::DIN', 18751);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Baclofen-Tab 20mg', 'tablet', 'M03BX01', false, 0, '02138298', 'FreeDiams::CA_HCDPD::DIN', 18752);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Baclofen-Tab 10mg', 'tablet', 'M03BX01', false, 0, '02138271', 'FreeDiams::CA_HCDPD::DIN', 18753);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Min-Ovral 21', 'tablet', 'G03AA07', false, 0, '02042320', 'FreeDiams::CA_HCDPD::DIN', 18754);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Min-Ovral 28', 'tablet', 'G03AA07', false, 0, '02042339', 'FreeDiams::CA_HCDPD::DIN', 18755);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minims Tropicamide 1%', 'drops', 'S01FA06', false, 0, '02148536', 'FreeDiams::CA_HCDPD::DIN', 18758);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minims Phenylephrine Hydrochloride 10%', 'drops', 'S01FB01', false, 0, '02148455', 'FreeDiams::CA_HCDPD::DIN', 18759);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Cyclobenzaprine-Tab 10mg', 'tablet', 'M03BX08', false, 0, '02171848', 'FreeDiams::CA_HCDPD::DIN', 18760);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Tiaprofenic - Tab 300mg', 'tablet', 'M01AE11', false, 0, '02146886', 'FreeDiams::CA_HCDPD::DIN', 18761);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Tiaprofenic - Tab 200mg', 'tablet', 'M01AE11', false, 0, '02146878', 'FreeDiams::CA_HCDPD::DIN', 18762);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Famvir Tablets 500mg', 'tablet', 'J05AB09', false, 0, '02177102', 'FreeDiams::CA_HCDPD::DIN', 18768);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Resto Assainissant Desinfectant Liquide', 'liquid', 'V07AV', false, 0, '02173131', 'FreeDiams::CA_HCDPD::DIN', 18770);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('2 + 2 Nettoyant Desinfectant Liquide', 'solution', 'V07AV', false, 0, '02173158', 'FreeDiams::CA_HCDPD::DIN', 18771);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soflax Syrup 4mg/Ml', 'syrup', 'A06AA02', false, 0, '02006758', 'FreeDiams::CA_HCDPD::DIN', 18776);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Timoptic-Xe', 'solution (long-acting)', 'S01ED01', false, 0, '02171880', 'FreeDiams::CA_HCDPD::DIN', 18777);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Timoptic-Xe', 'solution (long-acting)', 'S01ED01', false, 0, '02171899', 'FreeDiams::CA_HCDPD::DIN', 18778);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Sotalol - Tab 160mg', 'tablet', 'C07AA07', false, 0, '02167794', 'FreeDiams::CA_HCDPD::DIN', 18779);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zep-Amine A Liq', 'liquid', 'V07AV', false, 0, '01941054', 'FreeDiams::CA_HCDPD::DIN', 18782);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Digibind', 'powder for solution', 'V03AB24', false, 0, '02146967', 'FreeDiams::CA_HCDPD::DIN', 18784);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alkeran', 'kit', 'L01AA03', false, 0, '02087286', 'FreeDiams::CA_HCDPD::DIN', 18786);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Refresh', 'drops', 'S01XA20', false, 0, '02138670', 'FreeDiams::CA_HCDPD::DIN', 18791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Leminee 23 (Cleaner/Disinfectant)', 'solution', 'V07AV', false, 0, '02160366', 'FreeDiams::CA_HCDPD::DIN', 18799);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluanxol Depot 2% -Liq Im 20mg/Ml', 'solution', 'N05AF01', false, 0, '02156032', 'FreeDiams::CA_HCDPD::DIN', 18800);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Valproic Soft Gel Cap -  Anticonvulsant', 'capsule', 'N03AG01', false, 0, '02100630', 'FreeDiams::CA_HCDPD::DIN', 18804);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cyclobenzaprine - Tab 10mg', 'tablet', 'M03BX08', false, 0, '02177145', 'FreeDiams::CA_HCDPD::DIN', 18806);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nerisalic Oily Cream', 'cream', 'D07XC04', false, 0, '02028719', 'FreeDiams::CA_HCDPD::DIN', 18807);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Up-87 Lotion Soap/Up-87 Savon Lotion', 'lotion', 'D08AE04', false, 0, '02164329', 'FreeDiams::CA_HCDPD::DIN', 18812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bal In Oil 3ml Ampules/10', 'solution', 'V03AB09', false, 0, '02014807', 'FreeDiams::CA_HCDPD::DIN', 18814);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teramine N.R.', 'liquid', 'V07AV', false, 0, '02012294', 'FreeDiams::CA_HCDPD::DIN', 18815);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('40% Dextrose Injection, Usp', 'solution', 'B05BA03', false, 0, '02014858', 'FreeDiams::CA_HCDPD::DIN', 18823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('50% Dextrose Injection, Usp', 'solution', 'B05BA03', false, 0, '02014866', 'FreeDiams::CA_HCDPD::DIN', 18824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('33.3% Dextrose Injection, Usp', 'solution', 'B05BA03', false, 0, '02014831', 'FreeDiams::CA_HCDPD::DIN', 18825);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('13.3% Dextrose Injection, Usp', 'solution', 'B05BA03', false, 0, '02015072', 'FreeDiams::CA_HCDPD::DIN', 18826);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('20% Dextrose Injection, Usp', 'solution', 'B05BA03', false, 0, '02015080', 'FreeDiams::CA_HCDPD::DIN', 18827);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glucophage', 'tablet', 'A10BA02', false, 0, '02162849', 'FreeDiams::CA_HCDPD::DIN', 18835);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Acebutolol - Tab 100mg', 'tablet', 'C07AB04', false, 0, '02165546', 'FreeDiams::CA_HCDPD::DIN', 18843);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Acebutolol - Tab 400mg', 'tablet', 'C07AB04', false, 0, '02165562', 'FreeDiams::CA_HCDPD::DIN', 18844);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Acebutolol - Tab 200mg', 'tablet', 'C07AB04', false, 0, '02165554', 'FreeDiams::CA_HCDPD::DIN', 18845);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Bromazepam - Tab 1.5mg', 'tablet', 'N05BA08', false, 0, '02171856', 'FreeDiams::CA_HCDPD::DIN', 18846);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Bromazepam - Tab 3mg', 'tablet', 'N05BA08', false, 0, '02171864', 'FreeDiams::CA_HCDPD::DIN', 18847);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Bromazepam - Tab 6mg', 'tablet', 'N05BA08', false, 0, '02171872', 'FreeDiams::CA_HCDPD::DIN', 18848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Clonazepam - Tab 0.5mg', 'tablet', 'N03AE01', false, 0, '02173344', 'FreeDiams::CA_HCDPD::DIN', 18849);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Clonazepam - Tab 2mg', 'tablet', 'N03AE01', false, 0, '02173352', 'FreeDiams::CA_HCDPD::DIN', 18850);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Salbutamol - Tab 2mg', 'tablet', 'R03CC02', false, 0, '02165368', 'FreeDiams::CA_HCDPD::DIN', 18851);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Salbutamol - Tab 4mg', 'tablet', 'R03CC02', false, 0, '02165376', 'FreeDiams::CA_HCDPD::DIN', 18852);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Trazodone - Tab 50mg', 'tablet', 'N06AX05', false, 0, '02165384', 'FreeDiams::CA_HCDPD::DIN', 18853);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Trazodone - Tab 100mg', 'tablet', 'N06AX05', false, 0, '02165392', 'FreeDiams::CA_HCDPD::DIN', 18854);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Trazodone-D - Tab 150mg', 'tablet', 'N06AX05', false, 0, '02165406', 'FreeDiams::CA_HCDPD::DIN', 18855);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minims Phenylephrine Hydrochloride 2.5%', 'drops', 'S01FB01', false, 0, '02148447', 'FreeDiams::CA_HCDPD::DIN', 18860);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minims Atropine Sulphate 1%', 'drops', 'S01FA01', false, 0, '02148358', 'FreeDiams::CA_HCDPD::DIN', 18862);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Orgaran', 'liquid', 'B01AB09', false, 0, '02129043', 'FreeDiams::CA_HCDPD::DIN', 18868);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Captopril', 'tablet', 'C09AA01', false, 0, '02163586', 'FreeDiams::CA_HCDPD::DIN', 18869);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Captopril', 'tablet', 'C09AA01', false, 0, '02163594', 'FreeDiams::CA_HCDPD::DIN', 18870);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Captopril', 'tablet', 'C09AA01', false, 0, '02163578', 'FreeDiams::CA_HCDPD::DIN', 18871);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Captopril', 'tablet', 'C09AA01', false, 0, '02163551', 'FreeDiams::CA_HCDPD::DIN', 18872);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Beclo Aq', 'kit', 'R01AD01', false, 0, '02172712', 'FreeDiams::CA_HCDPD::DIN', 18874);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M-Eslon', 'capsule (extended release)', 'N02AA01', false, 0, '02177757', 'FreeDiams::CA_HCDPD::DIN', 18877);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M-Eslon', 'capsule (extended release)', 'N02AA01', false, 0, '02177749', 'FreeDiams::CA_HCDPD::DIN', 18878);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Contrastaph', 'liquid', 'V07AV', false, 0, '00783455', 'FreeDiams::CA_HCDPD::DIN', 18892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zep-O-San Liq', 'liquid', 'V07AV', false, 0, '01941062', 'FreeDiams::CA_HCDPD::DIN', 18900);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Formula 12167 Liq 10.4%', 'liquid', 'V07AV', false, 0, '01983342', 'FreeDiams::CA_HCDPD::DIN', 18901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carnitor - Liq Iv 200mg/Ml', 'solution', 'A16AA01', false, 0, '02144344', 'FreeDiams::CA_HCDPD::DIN', 18903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enteric Coated Asa Tablets 325mg', 'tablet (delayed-release)', 'N02BA01', false, 0, '02010526', 'FreeDiams::CA_HCDPD::DIN', 18909);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Custom Care Chest Congestion/Cough', 'liquid', 'R05FA02', false, 0, '02141639', 'FreeDiams::CA_HCDPD::DIN', 18910);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carnitor -Tab 330mg', 'tablet', 'A16AA01', false, 0, '02144328', 'FreeDiams::CA_HCDPD::DIN', 18931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Deamy', 'liquid', 'V07AV', false, 0, '02184761', 'FreeDiams::CA_HCDPD::DIN', 18934);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Calcium Gluconate Injection Usp 10%', 'liquid', 'B05XA30', false, 0, '02141019', 'FreeDiams::CA_HCDPD::DIN', 18936);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride Injection, Usp', 'solution', 'B05XA03', false, 0, '02139510', 'FreeDiams::CA_HCDPD::DIN', 18937);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clindamycin Injection, Usp', 'liquid', 'J01FF01', false, 0, '02139286', 'FreeDiams::CA_HCDPD::DIN', 18964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cortenema Sus 100mg/60ml', 'kit', 'A07EA02', false, 0, '02112736', 'FreeDiams::CA_HCDPD::DIN', 18968);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Manerix', 'tablet', 'N06AG02', false, 0, '02166747', 'FreeDiams::CA_HCDPD::DIN', 18969);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Depo-Medrol (With Preservative) 20 Mg/Ml', 'suspension', 'H02AB04', false, 0, '01934325', 'FreeDiams::CA_HCDPD::DIN', 18988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taxotere', 'solution', 'L01CD02', false, 0, '02177099', 'FreeDiams::CA_HCDPD::DIN', 18989);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taxotere', 'solution', 'L01CD02', false, 0, '02177080', 'FreeDiams::CA_HCDPD::DIN', 18990);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('0.15% Potassium Chloride In 5% Dextrose And 0.45% Sodium Chloride Injection', 'solution', 'B05BB02', false, 0, '01931547', 'FreeDiams::CA_HCDPD::DIN', 18991);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Valproic-Cap 250mg', 'capsule', 'N03AG01', false, 0, '02140047', 'FreeDiams::CA_HCDPD::DIN', 18998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Hydroxyzine', 'capsule', 'N05BB01', false, 0, '02166348', 'FreeDiams::CA_HCDPD::DIN', 18999);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Hydroxyzine', 'capsule', 'N05BB01', false, 0, '02166321', 'FreeDiams::CA_HCDPD::DIN', 19000);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Hydroxyzine', 'capsule', 'N05BB01', false, 0, '02166313', 'FreeDiams::CA_HCDPD::DIN', 19001);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Indapamide Hemihydrate Tab 2.5mg', 'tablet', 'C03BA11', false, 0, '02049341', 'FreeDiams::CA_HCDPD::DIN', 19009);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aredia 90mg', 'powder for solution', 'M05BA03', false, 0, '02059789', 'FreeDiams::CA_HCDPD::DIN', 19018);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aredia 30mg', 'powder for solution', 'M05BA03', false, 0, '02059762', 'FreeDiams::CA_HCDPD::DIN', 19020);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aller-Aide Elixir - 12.5mg/5ml', 'elixir', 'R06AA02', false, 0, '02146142', 'FreeDiams::CA_HCDPD::DIN', 19023);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robitussin Cough Control Extra Strength', 'liquid', 'R05FA02', false, 0, '02142775', 'FreeDiams::CA_HCDPD::DIN', 19026);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minitran - Patch Trd 54mg/20 Sq Cm', 'patch', 'C01DA02', false, 0, '02163535', 'FreeDiams::CA_HCDPD::DIN', 19028);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minitran - Patch Trd 36mg/13.3 Sq Cm', 'patch', 'C01DA02', false, 0, '02163527', 'FreeDiams::CA_HCDPD::DIN', 19029);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Relisorm 100 For Inj.-Pws Liq-Kit Sc Iv', 'kit', 'V04CM01', false, 0, '02126699', 'FreeDiams::CA_HCDPD::DIN', 19030);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rifater', 'tablet', 'J04AM05', false, 0, '02148625', 'FreeDiams::CA_HCDPD::DIN', 19033);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rifadin', 'capsule', 'J04AB02', false, 0, '02092808', 'FreeDiams::CA_HCDPD::DIN', 19034);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aquaderm-30', 'cream', 'D02BA30', false, 0, '02147963', 'FreeDiams::CA_HCDPD::DIN', 19037);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Cephalexin - Tab 500mg', 'tablet', 'J01DB01', false, 0, '02177854', 'FreeDiams::CA_HCDPD::DIN', 19042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Cephalexin - Tab 250mg', 'tablet', 'J01DB01', false, 0, '02177846', 'FreeDiams::CA_HCDPD::DIN', 19043);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robitussin Chest Congestion Extra Strength', 'liquid', 'R05CA03', false, 0, '02142783', 'FreeDiams::CA_HCDPD::DIN', 19044);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Bromazepam - Tab 6mg', 'tablet', 'N05BA08', false, 0, '02177188', 'FreeDiams::CA_HCDPD::DIN', 19047);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clonazepam - Tab 2mg', 'tablet', 'N03AE01', false, 0, '02177897', 'FreeDiams::CA_HCDPD::DIN', 19048);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Codeine Contin 200mg Controlled Release Tab', 'tablet (extended-release)', 'R05DA04', false, 0, '02163799', 'FreeDiams::CA_HCDPD::DIN', 19049);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Codeine Contin 100mg Controlled Release Tab', 'tablet (extended-release)', 'R05DA04', false, 0, '02163748', 'FreeDiams::CA_HCDPD::DIN', 19050);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Codeine Contin 150mg Controlled Release Tab', 'tablet (extended-release)', 'R05DA04', false, 0, '02163780', 'FreeDiams::CA_HCDPD::DIN', 19051);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Bromazepam - Tab 3mg', 'tablet', 'N05BA08', false, 0, '02177161', 'FreeDiams::CA_HCDPD::DIN', 19056);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Bromazepam - Tab 1.5mg', 'tablet', 'N05BA08', false, 0, '02177153', 'FreeDiams::CA_HCDPD::DIN', 19057);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Salbutamol Sterinebs P.F.', 'solution', 'R03AC02', false, 0, '02173360', 'FreeDiams::CA_HCDPD::DIN', 19058);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robitussin Cough & Cold Extra Strength', 'syrup', 'R05FA02', false, 0, '02172380', 'FreeDiams::CA_HCDPD::DIN', 19060);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clonazepam - Tab 0.5mg', 'tablet', 'N03AE01', false, 0, '02177889', 'FreeDiams::CA_HCDPD::DIN', 19063);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fluoxetine - Cap 20mg', 'capsule', 'N06AB03', false, 0, '02177587', 'FreeDiams::CA_HCDPD::DIN', 19064);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cephalexin - Tab 500mg', 'tablet', 'J01DB01', false, 0, '02177803', 'FreeDiams::CA_HCDPD::DIN', 19065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cephalexin - Tab 250mg', 'tablet', 'J01DB01', false, 0, '02177781', 'FreeDiams::CA_HCDPD::DIN', 19066);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cephalexin 125 - Sus 125mg/5ml', 'suspension', 'J01DB01', false, 0, '02177811', 'FreeDiams::CA_HCDPD::DIN', 19068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cephalexin 250 - Sus 250mg/5ml', 'suspension', 'J01DB01', false, 0, '02177838', 'FreeDiams::CA_HCDPD::DIN', 19069);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Cephalexin 125 - Sus 125mg/5ml', 'suspension', 'J01DB01', false, 0, '02177862', 'FreeDiams::CA_HCDPD::DIN', 19070);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02177625', 'FreeDiams::CA_HCDPD::DIN', 19071);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Cephalexin 250 - Sus 250mg/5ml', 'suspension', 'J01DB01', false, 0, '02177870', 'FreeDiams::CA_HCDPD::DIN', 19072);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Fluoxetine - Cap 10mg', 'capsule', 'N06AB03', false, 0, '02177617', 'FreeDiams::CA_HCDPD::DIN', 19073);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fluoxetine - Cap 10mg', 'capsule', 'N06AB03', false, 0, '02177579', 'FreeDiams::CA_HCDPD::DIN', 19074);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diovol Plus Af - Tab', 'tablet', 'A02AF02', false, 0, '02157624', 'FreeDiams::CA_HCDPD::DIN', 19075);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Acetate Injection, Usp', 'solution', 'B05XA17', false, 0, '02139553', 'FreeDiams::CA_HCDPD::DIN', 19078);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diovol Plus Af-Suspension', 'suspension', 'A02AF02', false, 0, '02157616', 'FreeDiams::CA_HCDPD::DIN', 19082);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Painaid Free Acetaminophen Tablets - 500mg', 'tablet', 'N02BE01', false, 0, '02144514', 'FreeDiams::CA_HCDPD::DIN', 19084);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hot Lemon Relief For Symptoms Of Cough And Cold', 'powder for solution', 'R05DA20', false, 0, '00893463', 'FreeDiams::CA_HCDPD::DIN', 19088);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lozide - Tab 1.25mg', 'tablet', 'C03BA11', false, 0, '02179709', 'FreeDiams::CA_HCDPD::DIN', 19089);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carnitor - Liq Orl 100mg/Ml', 'liquid', 'A16AA01', false, 0, '02144336', 'FreeDiams::CA_HCDPD::DIN', 19094);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adalat Xl - Srt 60mg', 'tablet (extended-release)', 'C08CA05', false, 0, '02155990', 'FreeDiams::CA_HCDPD::DIN', 19098);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adalat Xl - Srt 30mg', 'tablet (extended-release)', 'C08CA05', false, 0, '02155907', 'FreeDiams::CA_HCDPD::DIN', 19099);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co-Ne-O2-N2 Mixture', 'gas', 'V03AN20', false, 0, '02182238', 'FreeDiams::CA_HCDPD::DIN', 19100);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co-He-O2-N2 Mixture', 'gas', 'V03AN20', false, 0, '02154773', 'FreeDiams::CA_HCDPD::DIN', 19101);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Entonox', 'gas', 'N01AX63', false, 0, '02154757', 'FreeDiams::CA_HCDPD::DIN', 19102);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Dm-D-E-A Cold And Sinus Liquid Gels', 'capsule', 'N02BE51', false, 0, '02156563', 'FreeDiams::CA_HCDPD::DIN', 19103);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hi Sept', 'liquid', 'V07AV', false, 0, '02160293', 'FreeDiams::CA_HCDPD::DIN', 19113);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ketoprofen Sr', 'tablet (extended-release)', 'M01AE03', false, 0, '02172577', 'FreeDiams::CA_HCDPD::DIN', 19115);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diclo Sr - 75mg', 'tablet (extended-release)', 'M01AB05', false, 0, '02162814', 'FreeDiams::CA_HCDPD::DIN', 19125);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balminil Dm + Decongestant', 'syrup', 'R05DA20', false, 0, '02132028', 'FreeDiams::CA_HCDPD::DIN', 19129);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Travasol Amino Acid Injection Without Electrolytes In 16.6% Dextrose Clinimix', 'liquid', 'B05BA10', false, 0, '02046709', 'FreeDiams::CA_HCDPD::DIN', 19143);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cozaar', 'tablet', 'C09CA01', false, 0, '02182815', 'FreeDiams::CA_HCDPD::DIN', 19167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cozaar', 'tablet', 'C09CA01', false, 0, '02182874', 'FreeDiams::CA_HCDPD::DIN', 19168);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allopurinol-200 - Tab 200mg', 'tablet', 'M04AA01', false, 0, '02130157', 'FreeDiams::CA_HCDPD::DIN', 19183);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Furosemide-80 Tab 80mg', 'tablet', 'C03CA01', false, 0, '00667080', 'FreeDiams::CA_HCDPD::DIN', 19189);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gemfibrozil-600 - Tab 600mg', 'tablet', 'C10AB04', false, 0, '02136058', 'FreeDiams::CA_HCDPD::DIN', 19191);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sucralfate-1 - Tab 1g', 'tablet', 'A02BX02', false, 0, '02130939', 'FreeDiams::CA_HCDPD::DIN', 19192);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diofluor Strips  -  1 Mg', 'strip', 'S01JA01', false, 0, '02160773', 'FreeDiams::CA_HCDPD::DIN', 19197);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefoxitin For Injection, Usp', 'powder for solution', 'J01DC01', false, 0, '02128187', 'FreeDiams::CA_HCDPD::DIN', 19200);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefoxitin For Injection, Usp', 'powder for solution', 'J01DC01', false, 0, '02128195', 'FreeDiams::CA_HCDPD::DIN', 19201);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Innohep Multi-Dose Vial- 10000 Anti-Xa Iu/Ml', 'liquid', 'B01AB10', false, 0, '02167840', 'FreeDiams::CA_HCDPD::DIN', 19202);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidex Ointment 0.05%', 'ointment', 'D07AC08', false, 0, '02161966', 'FreeDiams::CA_HCDPD::DIN', 19203);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minocycline-100', 'capsule', 'J01AA08', false, 0, '02154366', 'FreeDiams::CA_HCDPD::DIN', 19204);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minocycline-50', 'capsule', 'J01AA08', false, 0, '02153394', 'FreeDiams::CA_HCDPD::DIN', 19207);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Loperamide Hydrochloride Solution-Orl', 'solution', 'A07DA03', false, 0, '02138301', 'FreeDiams::CA_HCDPD::DIN', 19218);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Desipramine - Tab 100mg', 'tablet', 'N06AA01', false, 0, '02168952', 'FreeDiams::CA_HCDPD::DIN', 19220);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Clonazepam- Tab 0.25mg', 'tablet', 'N03AE01', false, 0, '02179660', 'FreeDiams::CA_HCDPD::DIN', 19221);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ectosone Regular Lotion 0.1%', 'lotion', 'D07AC01', false, 0, '00750050', 'FreeDiams::CA_HCDPD::DIN', 19225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefzil Powder For Oral Suspension-250mg/5ml', 'powder for solution', 'J01DC10', false, 0, '02163683', 'FreeDiams::CA_HCDPD::DIN', 19226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefzil Powder For Oral Suspension-125mg/5ml', 'powder for solution', 'J01DC10', false, 0, '02163675', 'FreeDiams::CA_HCDPD::DIN', 19227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefzil Tablets - 500mg', 'tablet', 'J01DC10', false, 0, '02163667', 'FreeDiams::CA_HCDPD::DIN', 19228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefzil Tablets - 250mg', 'tablet', 'J01DC10', false, 0, '02163659', 'FreeDiams::CA_HCDPD::DIN', 19229);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Megace Os', 'suspension', 'L02AB01', false, 0, '02168979', 'FreeDiams::CA_HCDPD::DIN', 19230);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Metformin - Tab 500mg', 'tablet', 'A10BA02', false, 0, '02167786', 'FreeDiams::CA_HCDPD::DIN', 19231);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Nifed Pa - Srt 20mg', 'tablet (extended-release)', 'C08CA05', false, 0, '02181525', 'FreeDiams::CA_HCDPD::DIN', 19232);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Salbutamol', 'solution', 'R03AC02', false, 0, '02154412', 'FreeDiams::CA_HCDPD::DIN', 19237);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Betaseron', 'powder for solution', 'L03AB08', false, 0, '02169649', 'FreeDiams::CA_HCDPD::DIN', 19241);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Timolol', 'solution', 'S01ED01', false, 0, '02166720', 'FreeDiams::CA_HCDPD::DIN', 19242);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentamycetin Ophthalmic Solution 0.5% - Liq', 'solution', 'S01AA01', false, 0, '02164051', 'FreeDiams::CA_HCDPD::DIN', 19243);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol With Codeine Elixir', 'elixir', 'N02BE51', false, 0, '02163942', 'FreeDiams::CA_HCDPD::DIN', 19244);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atrovent Nasal Spray - 21mcg/Aem', 'kit', 'R01AX03', false, 0, '02163705', 'FreeDiams::CA_HCDPD::DIN', 19245);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol With Codeine No. 2 - Tab', 'tablet', 'N02BE51', false, 0, '02163934', 'FreeDiams::CA_HCDPD::DIN', 19248);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol With Codeine No. 3 - Tab', 'tablet', 'N02AA59', false, 0, '02163926', 'FreeDiams::CA_HCDPD::DIN', 19249);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol With Codeine No. 4 - Tab', 'tablet', 'N02AA59', false, 0, '02163918', 'FreeDiams::CA_HCDPD::DIN', 19250);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Timolol', 'solution', 'S01ED01', false, 0, '02166712', 'FreeDiams::CA_HCDPD::DIN', 19252);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Noritate', 'cream', 'D06BX01', false, 0, '02156091', 'FreeDiams::CA_HCDPD::DIN', 19257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Idamycin Powder -10mg/Vial', 'powder for solution', 'L01DB06', false, 0, '02068095', 'FreeDiams::CA_HCDPD::DIN', 19258);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Idamycin Powder  -5mg/Vial', 'powder for solution', 'L01DB06', false, 0, '02065630', 'FreeDiams::CA_HCDPD::DIN', 19259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitrous Oxide, Usp', 'gas', 'N01AX13', false, 0, '02154811', 'FreeDiams::CA_HCDPD::DIN', 19262);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbon Dioxide Usp', 'gas', 'V03AN02', false, 0, '02154730', 'FreeDiams::CA_HCDPD::DIN', 19263);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Isoniazid 300mg Tablets', 'tablet', 'J04AC01', false, 0, '02181428', 'FreeDiams::CA_HCDPD::DIN', 19268);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Piroxicam', 'suppository', 'M01AC01', false, 0, '02177129', 'FreeDiams::CA_HCDPD::DIN', 19269);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Piroxicam', 'suppository', 'M01AC01', false, 0, '02177137', 'FreeDiams::CA_HCDPD::DIN', 19270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Acetaminophen Suppositories-120mg', 'suppository', 'N02BE01', false, 0, '02137410', 'FreeDiams::CA_HCDPD::DIN', 19271);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Acetaminophen Suppositories-325mg', 'suppository', 'N02BE01', false, 0, '02137437', 'FreeDiams::CA_HCDPD::DIN', 19272);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jaa Pyral P Oral Paste - 125mg/G', 'paste', 'P02CC01', false, 0, '02175339', 'FreeDiams::CA_HCDPD::DIN', 19275);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('10% Travamulsion  Liq Iv', 'liquid', 'B05BA02', false, 0, '02016028', 'FreeDiams::CA_HCDPD::DIN', 19284);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('20% Travamulsion  Liq Iv', 'liquid', 'B05BA02', false, 0, '02016036', 'FreeDiams::CA_HCDPD::DIN', 19285);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Methocarbamol Inj 100mg/Ml', 'liquid', 'M03BA03', false, 0, '00872865', 'FreeDiams::CA_HCDPD::DIN', 19287);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heliox', 'gas', 'V03AN20', false, 0, '02154846', 'FreeDiams::CA_HCDPD::DIN', 19290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medical Air Usp', 'gas', 'V03AN05', false, 0, '02154781', 'FreeDiams::CA_HCDPD::DIN', 19291);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitrogen Nf', 'gas', 'V03AN04', false, 0, '02154803', 'FreeDiams::CA_HCDPD::DIN', 19292);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbogen', 'gas', 'V03AN20', false, 0, '02154749', 'FreeDiams::CA_HCDPD::DIN', 19293);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Helium Usp', 'gas', 'V03AN03', false, 0, '02154765', 'FreeDiams::CA_HCDPD::DIN', 19294);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen, Usp', 'gas', 'V03AN01', false, 0, '02154838', 'FreeDiams::CA_HCDPD::DIN', 19299);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro Marc', 'liquid', 'V07AV', false, 0, '02160374', 'FreeDiams::CA_HCDPD::DIN', 19302);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Optimyxin Ophthalmic Ointment', 'ointment', 'S01AA30', false, 0, '02160889', 'FreeDiams::CA_HCDPD::DIN', 19303);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Didrocal', 'kit', 'M05BB01', false, 0, '02176017', 'FreeDiams::CA_HCDPD::DIN', 19304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn Ii 15%', 'solution', 'B05BA01', false, 0, '02126745', 'FreeDiams::CA_HCDPD::DIN', 19306);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minims Cyclopentolate Hydrochloride 0.5%', 'drops', 'S01FA04', false, 0, '02148331', 'FreeDiams::CA_HCDPD::DIN', 19307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidemol Emollient Cream 0.05%', 'cream', 'D07AC08', false, 0, '02163152', 'FreeDiams::CA_HCDPD::DIN', 19312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anaprox D.S. Tablets 550mg', 'tablet', 'M01AE02', false, 0, '02162717', 'FreeDiams::CA_HCDPD::DIN', 19313);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naprosyn Sr 750mg Tablets', 'tablet (extended-release)', 'M01AE02', false, 0, '02162466', 'FreeDiams::CA_HCDPD::DIN', 19314);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naprosyn E 500mg Tablets - Ect', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02162423', 'FreeDiams::CA_HCDPD::DIN', 19315);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naprosyn E 375mg Tablets - Ect', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02162415', 'FreeDiams::CA_HCDPD::DIN', 19316);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidex Gel 0.05%', 'gel', 'D07AC08', false, 0, '02161974', 'FreeDiams::CA_HCDPD::DIN', 19317);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Liquid Makeup Spf 16', 'liquid', 'D02BA30', false, 0, '02154064', 'FreeDiams::CA_HCDPD::DIN', 19330);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ketoprofen E-100 - Ect', 'tablet (enteric-coated)', 'M01AE03', false, 0, '02150824', 'FreeDiams::CA_HCDPD::DIN', 19338);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ketoprofen E-50  - Ect 50mg', 'tablet (enteric-coated)', 'M01AE03', false, 0, '02150816', 'FreeDiams::CA_HCDPD::DIN', 19339);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ketoprofen Capsules', 'capsule', 'M01AE03', false, 0, '02150808', 'FreeDiams::CA_HCDPD::DIN', 19340);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sani Quat', 'liquid', 'V07AV', false, 0, '02160528', 'FreeDiams::CA_HCDPD::DIN', 19346);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clomid', 'tablet', 'G03GB02', false, 0, '02091879', 'FreeDiams::CA_HCDPD::DIN', 19347);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Toradol 10mg Tablets', 'tablet', 'M01AB15', false, 0, '02162660', 'FreeDiams::CA_HCDPD::DIN', 19348);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bretylium Tosylate Injection Usp', 'solution', 'C01BD02', false, 0, '02185377', 'FreeDiams::CA_HCDPD::DIN', 19356);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Procainamide Hydrochloride Inj. Usp', 'solution', 'C01BA02', false, 0, '02184486', 'FreeDiams::CA_HCDPD::DIN', 19357);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soothe Aid Loz 2.4mg', 'lozenge', 'R02AA12', false, 0, '00806668', 'FreeDiams::CA_HCDPD::DIN', 19363);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enol Plus Germicidal Detergent Liq', 'liquid', 'V07AV', false, 0, '00846635', 'FreeDiams::CA_HCDPD::DIN', 19364);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbachol Tablets 2mg', 'tablet', 'N07AB01', false, 0, '02060043', 'FreeDiams::CA_HCDPD::DIN', 19401);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estrace', 'tablet', 'G03CA03', false, 0, '02148595', 'FreeDiams::CA_HCDPD::DIN', 19405);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estrace', 'tablet', 'G03CA03', false, 0, '02148587', 'FreeDiams::CA_HCDPD::DIN', 19406);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoclopramide Hydrochloride Injection', 'liquid', 'A03FA01', false, 0, '02185431', 'FreeDiams::CA_HCDPD::DIN', 19409);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sip-Tol', 'liquid', 'V07AV', false, 0, '02168847', 'FreeDiams::CA_HCDPD::DIN', 19411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('3m Steri-Gas', 'gas', 'V07AV', false, 0, '02154900', 'FreeDiams::CA_HCDPD::DIN', 19413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Caplet 325mg Usp', 'tablet', 'N02BE01', false, 0, '01977415', 'FreeDiams::CA_HCDPD::DIN', 19418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Caplet 500mg', 'tablet', 'N02BE01', false, 0, '01977474', 'FreeDiams::CA_HCDPD::DIN', 19419);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Emcyt', 'capsule', 'L01XX11', false, 0, '02063794', 'FreeDiams::CA_HCDPD::DIN', 19428);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Flu Nighttime Gelcap', 'tablet', 'N02BE51', false, 0, '02167670', 'FreeDiams::CA_HCDPD::DIN', 19429);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enteric Coated Asa Tab 650mg', 'tablet (delayed-release)', 'N02BA01', false, 0, '00794244', 'FreeDiams::CA_HCDPD::DIN', 19434);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ddavp Tablets 0.1mg', 'tablet', 'H01BA02', false, 0, '00824305', 'FreeDiams::CA_HCDPD::DIN', 19436);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micozole', 'cream', 'G01AF04', false, 0, '02231106', 'FreeDiams::CA_HCDPD::DIN', 50390);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adenocard Injection -Pre-Filled Syringe', 'solution', 'C01EB10', false, 0, '02145820', 'FreeDiams::CA_HCDPD::DIN', 19437);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ddavp Tablets 0.2mg', 'tablet', 'H01BA02', false, 0, '00824143', 'FreeDiams::CA_HCDPD::DIN', 19441);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Phosphates Injection, Usp', 'solution', 'B05XA06', false, 0, '02139545', 'FreeDiams::CA_HCDPD::DIN', 19442);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Protamine Sulfate Injection, Usp', 'solution', 'V03AB14', false, 0, '02139537', 'FreeDiams::CA_HCDPD::DIN', 19443);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anaprox 275mg Tablets', 'tablet', 'M01AE02', false, 0, '02162725', 'FreeDiams::CA_HCDPD::DIN', 19446);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naprosyn E 250mg Tablets - Ect', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02162792', 'FreeDiams::CA_HCDPD::DIN', 19448);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dequadin Oral Paint', 'liquid', 'R02AA02', false, 0, '02091453', 'FreeDiams::CA_HCDPD::DIN', 19449);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dalacin C 300 Mg', 'capsule', 'J01FF01', false, 0, '02182866', 'FreeDiams::CA_HCDPD::DIN', 19455);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Florinef', 'tablet', 'H02AA02', false, 0, '02086026', 'FreeDiams::CA_HCDPD::DIN', 19460);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aspirin - Tablets', 'tablet', 'N02BA01', false, 0, '02150328', 'FreeDiams::CA_HCDPD::DIN', 19474);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aspirin Extra Strength - Tablets', 'tablet', 'N02BA01', false, 0, '02150336', 'FreeDiams::CA_HCDPD::DIN', 19475);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aspirin - Children''S Size - Tablets', 'tablet', 'N02BA01', false, 0, '02150352', 'FreeDiams::CA_HCDPD::DIN', 19477);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Canesten Comfortab 3', 'vaginal tablet', 'G01AF02', false, 0, '02150840', 'FreeDiams::CA_HCDPD::DIN', 19479);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Canesten Comfortab 1', 'vaginal tablet', 'G01AF02', false, 0, '02150859', 'FreeDiams::CA_HCDPD::DIN', 19480);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Canesten Cream 6', 'cream', 'G01AF02', false, 0, '02150891', 'FreeDiams::CA_HCDPD::DIN', 19483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Canesten Cream 3', 'cream', 'G01AF02', false, 0, '02150905', 'FreeDiams::CA_HCDPD::DIN', 19484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Canesten 1% Topical Cream', 'cream', 'D01AC01', false, 0, '02150867', 'FreeDiams::CA_HCDPD::DIN', 19487);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bactine First Aid Spray', 'kit', 'D04AB01', false, 0, '02150379', 'FreeDiams::CA_HCDPD::DIN', 19488);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aspirin Arthritis Pain Relief', 'tablet (delayed-release)', 'N02BA01', false, 0, '02150417', 'FreeDiams::CA_HCDPD::DIN', 19489);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sevorane Af', 'liquid', 'N01AB08', false, 0, '02172763', 'FreeDiams::CA_HCDPD::DIN', 19497);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proclean 130', 'liquid', 'V07AV', false, 0, '02160447', 'FreeDiams::CA_HCDPD::DIN', 19504);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlorhexseptic-Liq 0.5mg/Ml', 'liquid', 'D08AC02', false, 0, '02004992', 'FreeDiams::CA_HCDPD::DIN', 19506);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ketoprofen', 'suppository', 'M01AE03', false, 0, '02148773', 'FreeDiams::CA_HCDPD::DIN', 19507);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefazolin For Injection - 500mg Pws', 'powder for solution', 'J01DB04', false, 0, '02108119', 'FreeDiams::CA_HCDPD::DIN', 19521);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-5 Asa - Ect 400mg', 'tablet (enteric-coated)', 'A07EC02', false, 0, '02171929', 'FreeDiams::CA_HCDPD::DIN', 19524);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cellcept', 'capsule', 'L04AA06', false, 0, '02192748', 'FreeDiams::CA_HCDPD::DIN', 19525);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefazolin For Injection - 1gm Pws', 'powder for solution', 'J01DB04', false, 0, '02108127', 'FreeDiams::CA_HCDPD::DIN', 19532);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Clopamine Tablets - 25mg', 'tablet', 'N06AA04', false, 0, '02130165', 'FreeDiams::CA_HCDPD::DIN', 19533);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefazolin For Injection -10gm Pws', 'powder for solution', 'J01DB04', false, 0, '02108135', 'FreeDiams::CA_HCDPD::DIN', 19534);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Ketotifen - Syr 1mg/5ml', 'syrup', 'R06AX17', false, 0, '02176084', 'FreeDiams::CA_HCDPD::DIN', 19550);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cytovene - Pws 500mg/10m/-Vial Iv', 'powder for solution', 'J05AB06', false, 0, '02162695', 'FreeDiams::CA_HCDPD::DIN', 19553);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pancuronium Bromide - Liq Iv 2mg/Ml', 'liquid', 'M03AC01', false, 0, '02169630', 'FreeDiams::CA_HCDPD::DIN', 19555);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pancuronium Bromide - Liq Iv 1mg/Ml', 'liquid', 'M03AC01', false, 0, '02169622', 'FreeDiams::CA_HCDPD::DIN', 19556);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Nifed Pa - Tab 10mg', 'tablet', 'C08CA05', false, 0, '02197448', 'FreeDiams::CA_HCDPD::DIN', 19557);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('E 2 Sanitizing Hand Soap Liq 3%', 'liquid', 'D08AE05', false, 0, '01941968', 'FreeDiams::CA_HCDPD::DIN', 19577);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cytarabine - Pws 500mg/Vial', 'powder for solution', 'L01BC01', false, 0, '02167875', 'FreeDiams::CA_HCDPD::DIN', 19578);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cytarabine-Pws 100mg/Vial', 'powder for solution', 'L01BC01', false, 0, '02167867', 'FreeDiams::CA_HCDPD::DIN', 19581);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cytarabine - Pws 1gn/Vial', 'powder for solution', 'L01BC01', false, 0, '02167883', 'FreeDiams::CA_HCDPD::DIN', 19582);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cytarabine - Pws 2gm/Vial', 'powder for solution', 'L01BC01', false, 0, '02167891', 'FreeDiams::CA_HCDPD::DIN', 19583);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Levobunolol', 'solution', 'S01ED03', false, 0, '02031159', 'FreeDiams::CA_HCDPD::DIN', 19584);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Motrin Ib Tablet - 200mg', 'tablet', 'M01AE01', false, 0, '02186934', 'FreeDiams::CA_HCDPD::DIN', 19585);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synthroid - Tab 50mcg', 'tablet', 'H03AA01', false, 0, '02172070', 'FreeDiams::CA_HCDPD::DIN', 19587);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synthroid - Tab 25mcg', 'tablet', 'H03AA01', false, 0, '02172062', 'FreeDiams::CA_HCDPD::DIN', 19588);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synthroid - Tab 112mcg', 'tablet', 'H03AA01', false, 0, '02171228', 'FreeDiams::CA_HCDPD::DIN', 19589);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Levobunolol', 'solution', 'S01ED03', false, 0, '02031167', 'FreeDiams::CA_HCDPD::DIN', 19592);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synthroid - Tab 125mcg', 'tablet', 'H03AA01', false, 0, '02172119', 'FreeDiams::CA_HCDPD::DIN', 19594);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synthroid - Tab 75mcg', 'tablet', 'H03AA01', false, 0, '02172089', 'FreeDiams::CA_HCDPD::DIN', 19595);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synthroid - Tab 300mcg', 'tablet', 'H03AA01', false, 0, '02172151', 'FreeDiams::CA_HCDPD::DIN', 19596);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synthroid - Tab 200mcg', 'tablet', 'H03AA01', false, 0, '02172143', 'FreeDiams::CA_HCDPD::DIN', 19597);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synthroid - Tab 150mcg', 'tablet', 'H03AA01', false, 0, '02172127', 'FreeDiams::CA_HCDPD::DIN', 19598);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synthroid - Tab 88mcg', 'tablet', 'H03AA01', false, 0, '02172097', 'FreeDiams::CA_HCDPD::DIN', 19599);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synthroid - Tab 175mcg', 'tablet', 'H03AA01', false, 0, '02172135', 'FreeDiams::CA_HCDPD::DIN', 19600);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synthroid - Tab 100mcg', 'tablet', 'H03AA01', false, 0, '02172100', 'FreeDiams::CA_HCDPD::DIN', 19601);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Travasol Amino Acid Injection Without Electrolytes In 10% Dextrose Clinimix', 'solution', 'B05BA10', false, 0, '02013932', 'FreeDiams::CA_HCDPD::DIN', 19610);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lever 2000 Antibacterial Liquid Soap', 'liquid', 'D08AE04', false, 0, '02194252', 'FreeDiams::CA_HCDPD::DIN', 19611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('3tc', 'tablet', 'J05AF05', false, 0, '02192683', 'FreeDiams::CA_HCDPD::DIN', 19614);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('3tc', 'solution', 'J05AF05', false, 0, '02192691', 'FreeDiams::CA_HCDPD::DIN', 19615);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Renova', 'cream', 'D10AD01', false, 0, '02052407', 'FreeDiams::CA_HCDPD::DIN', 19617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Back-Aid Forte - Tab', 'tablet', 'M03BB53', false, 0, '02171287', 'FreeDiams::CA_HCDPD::DIN', 19624);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cough Syrup With Codeine', 'syrup', 'R05FA02', false, 0, '02099748', 'FreeDiams::CA_HCDPD::DIN', 19625);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soluprep Chd-Alcohol-Spg-Liq', 'kit', 'D08AC52', false, 0, '02116472', 'FreeDiams::CA_HCDPD::DIN', 19626);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandostatin 200mcg/Ml', 'solution', 'H01CB02', false, 0, '02049392', 'FreeDiams::CA_HCDPD::DIN', 19627);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Clonazepam-R Tab 0.5mg', 'tablet', 'N03AE01', false, 0, '02207818', 'FreeDiams::CA_HCDPD::DIN', 19628);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fosamax', 'tablet', 'M05BA04', false, 0, '02201038', 'FreeDiams::CA_HCDPD::DIN', 19642);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fosamax', 'tablet', 'M05BA04', false, 0, '02201011', 'FreeDiams::CA_HCDPD::DIN', 19643);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Casodex Tab 50mg', 'tablet', 'L02BB03', false, 0, '02184478', 'FreeDiams::CA_HCDPD::DIN', 19647);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glucobay', 'tablet', 'A10BF01', false, 0, '02190885', 'FreeDiams::CA_HCDPD::DIN', 19648);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rhinalar Nasal Mist', 'kit', 'R01AD04', false, 0, '02162687', 'FreeDiams::CA_HCDPD::DIN', 19650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atrovent Nasal Spray - 42mcg/Aem', 'kit', 'R01AX03', false, 0, '02163713', 'FreeDiams::CA_HCDPD::DIN', 19651);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glucobay', 'tablet', 'A10BF01', false, 0, '02190893', 'FreeDiams::CA_HCDPD::DIN', 19655);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naprosyn 25mg/Ml Suspension', 'suspension', 'M01AE02', false, 0, '02162431', 'FreeDiams::CA_HCDPD::DIN', 19661);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Sotalol', 'tablet', 'C07AA07', false, 0, '02084228', 'FreeDiams::CA_HCDPD::DIN', 19662);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Sotalol', 'tablet', 'C07AA07', false, 0, '02084236', 'FreeDiams::CA_HCDPD::DIN', 19663);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Valproic', 'capsule', 'N03AG01', false, 0, '02184648', 'FreeDiams::CA_HCDPD::DIN', 19664);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Depo-Provera Sterile Aqueous Suspension 150 Mg/Ml', 'suspension', 'G03AC06', false, 0, '00585092', 'FreeDiams::CA_HCDPD::DIN', 19667);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo Meprazine Tab 25mg', 'tablet', 'N05AA02', false, 0, '01964925', 'FreeDiams::CA_HCDPD::DIN', 19668);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Miconazole 3 Day Ovule Treatment 400mg', 'suppository', 'G01AF04', false, 0, '02171775', 'FreeDiams::CA_HCDPD::DIN', 19677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diclofenac', 'suppository', 'M01AB05', false, 0, '02174685', 'FreeDiams::CA_HCDPD::DIN', 19678);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methotrexate Na Inj.Im Iv Iar Int Ivr25mg/Ml', 'solution', 'L01BA01', false, 0, '02099705', 'FreeDiams::CA_HCDPD::DIN', 19681);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Photofrin Pws Iv 75mg/Vial', 'powder for solution', 'L01XD01', false, 0, '02019876', 'FreeDiams::CA_HCDPD::DIN', 19685);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Photofrin Pws Iv 15mg/Vial', 'powder for solution', 'L01XD01', false, 0, '02020033', 'FreeDiams::CA_HCDPD::DIN', 19686);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kytril Tablets 1mg', 'tablet', 'A04AA02', false, 0, '02185881', 'FreeDiams::CA_HCDPD::DIN', 19688);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kytril 1mg/1ml', 'liquid', 'A04AA02', false, 0, '02088371', 'FreeDiams::CA_HCDPD::DIN', 19689);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Calmylin Ace', 'syrup', 'R05FA02', false, 0, '02198630', 'FreeDiams::CA_HCDPD::DIN', 19690);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Atenolol', 'tablet', 'C07AB03', false, 0, '02171791', 'FreeDiams::CA_HCDPD::DIN', 19691);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Atenolol', 'tablet', 'C07AB03', false, 0, '02171805', 'FreeDiams::CA_HCDPD::DIN', 19692);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Magnesium Sulfate Injection Usp', 'solution', 'B05XA05', false, 0, '02139499', 'FreeDiams::CA_HCDPD::DIN', 19701);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vancomycin Hydrochloride For Injection, Usp', 'powder for solution', 'J01XA01', false, 0, '02139375', 'FreeDiams::CA_HCDPD::DIN', 19703);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vancomycin Hydrochloride For Injection, Usp', 'powder for solution', 'J01XA01', false, 0, '02139383', 'FreeDiams::CA_HCDPD::DIN', 19705);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Losec 20 Mg', 'tablet (delayed-release)', 'A02BC01', false, 0, '02190915', 'FreeDiams::CA_HCDPD::DIN', 19716);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Tiaprofenic Acid', 'tablet', 'M01AE11', false, 0, '02179679', 'FreeDiams::CA_HCDPD::DIN', 19720);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Tiaprofenic Acid', 'tablet', 'M01AE11', false, 0, '02179687', 'FreeDiams::CA_HCDPD::DIN', 19722);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tegretol - Sus 100mg/5ml', 'suspension', 'N03AF01', false, 0, '02194333', 'FreeDiams::CA_HCDPD::DIN', 19729);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Megestrol - Tab 40mg', 'tablet', 'L02AB01', false, 0, '02185415', 'FreeDiams::CA_HCDPD::DIN', 19730);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Megestrol - Tab 160mg', 'tablet', 'L02AB01', false, 0, '02185423', 'FreeDiams::CA_HCDPD::DIN', 19731);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate 2152', 'solution', 'B05ZA', false, 0, '02210061', 'FreeDiams::CA_HCDPD::DIN', 19735);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate 2163', 'solution', 'B05ZA', false, 0, '02209780', 'FreeDiams::CA_HCDPD::DIN', 19739);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate 2161', 'solution', 'B05ZA', false, 0, '02210096', 'FreeDiams::CA_HCDPD::DIN', 19744);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Propranolol Tablets', 'tablet', 'C07AA05', false, 0, '02137321', 'FreeDiams::CA_HCDPD::DIN', 19750);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Propranolol Tablets', 'tablet', 'C07AA05', false, 0, '02137313', 'FreeDiams::CA_HCDPD::DIN', 19751);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vincristine Sulphate Injection-Liq Iv 1mg/Ml', 'liquid', 'L01CA02', false, 0, '02143305', 'FreeDiams::CA_HCDPD::DIN', 19756);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olestyr', 'powder for suspension', 'C10AC01', false, 0, '02210320', 'FreeDiams::CA_HCDPD::DIN', 19757);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Levocarb - Tablets 25 Mg/250 Mg', 'tablet', 'N04BA02', false, 0, '02182858', 'FreeDiams::CA_HCDPD::DIN', 19758);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Salbutamol', 'solution', 'R03AC02', false, 0, '02208245', 'FreeDiams::CA_HCDPD::DIN', 19761);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Salbutamol', 'solution', 'R03AC02', false, 0, '02208237', 'FreeDiams::CA_HCDPD::DIN', 19762);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Salbutamol', 'solution', 'R03AC02', false, 0, '02208229', 'FreeDiams::CA_HCDPD::DIN', 19763);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Levocarb - Tab 10mg/100mg', 'tablet', 'N04BA02', false, 0, '02182831', 'FreeDiams::CA_HCDPD::DIN', 19766);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Levocarb - Tab 25 Mg/100 Mg', 'tablet', 'N04BA02', false, 0, '02182823', 'FreeDiams::CA_HCDPD::DIN', 19767);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multi-Phen', 'liquid', 'V07AV', false, 0, '02210983', 'FreeDiams::CA_HCDPD::DIN', 19768);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Counteract Cough Medicine - Liq', 'liquid', 'R05FA02', false, 0, '02208857', 'FreeDiams::CA_HCDPD::DIN', 19772);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aspirin Arthritis Pain Relief Extra Strength', 'tablet (delayed-release)', 'N02BA01', false, 0, '02150425', 'FreeDiams::CA_HCDPD::DIN', 19790);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hypotears', 'drops', 'S01XA20', false, 0, '02133253', 'FreeDiams::CA_HCDPD::DIN', 19791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ipratropium Udv', 'solution', 'R03BB01', false, 0, '02097168', 'FreeDiams::CA_HCDPD::DIN', 19798);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Buspirone - Tab 10mg', 'tablet', 'N05BE01', false, 0, '02207672', 'FreeDiams::CA_HCDPD::DIN', 19799);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oncotice', 'powder for solution', 'L03AX03', false, 0, '02153513', 'FreeDiams::CA_HCDPD::DIN', 19802);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nasacort Aq', 'spray, metered dose', 'R01AD11', false, 0, '02213834', 'FreeDiams::CA_HCDPD::DIN', 19807);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solunet C Eponge 4%', 'liquid', 'D08AC02', false, 0, '01925202', 'FreeDiams::CA_HCDPD::DIN', 19810);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Water For Injection Usp', 'liquid', 'V07AB', false, 0, '02214733', 'FreeDiams::CA_HCDPD::DIN', 19812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Acyclovir - Tab 200mg', 'tablet', 'J05AB01', false, 0, '02197405', 'FreeDiams::CA_HCDPD::DIN', 19814);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Acyclovir - Tab 400mg', 'tablet', 'J05AB01', false, 0, '02197413', 'FreeDiams::CA_HCDPD::DIN', 19815);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Acyclovir - Tab 800mg', 'tablet', 'J05AB01', false, 0, '02197421', 'FreeDiams::CA_HCDPD::DIN', 19816);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Sotalol - Tab 80mg', 'tablet', 'C07AA07', false, 0, '02200996', 'FreeDiams::CA_HCDPD::DIN', 19817);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Insomnal Ds', 'capsule', 'R06AA02', false, 0, '02153165', 'FreeDiams::CA_HCDPD::DIN', 19820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cyclobenzaprine - Tab 10mg', 'tablet', 'M03BX08', false, 0, '02212048', 'FreeDiams::CA_HCDPD::DIN', 19827);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lithium Carbonate - Cap 600mg', 'capsule', 'N05AN01', false, 0, '02216159', 'FreeDiams::CA_HCDPD::DIN', 19893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lithium Carbonate - Cap 150mg', 'capsule', 'N05AN01', false, 0, '02216132', 'FreeDiams::CA_HCDPD::DIN', 19894);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02216590', 'FreeDiams::CA_HCDPD::DIN', 19895);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Optiray 240 (Ultraject) 51%', 'solution', 'V08AB07', false, 0, '02035332', 'FreeDiams::CA_HCDPD::DIN', 19898);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Optiray 350 (Ultraject) 74%', 'solution', 'V08AB07', false, 0, '02079992', 'FreeDiams::CA_HCDPD::DIN', 19899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Ranitidine', 'tablet', 'A02BA02', false, 0, '02207761', 'FreeDiams::CA_HCDPD::DIN', 19910);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Famotidine', 'tablet', 'A02BA03', false, 0, '02196018', 'FreeDiams::CA_HCDPD::DIN', 19913);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Ranitidine', 'tablet', 'A02BA02', false, 0, '02207788', 'FreeDiams::CA_HCDPD::DIN', 19914);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Famotidine', 'tablet', 'A02BA03', false, 0, '02196026', 'FreeDiams::CA_HCDPD::DIN', 19915);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02216582', 'FreeDiams::CA_HCDPD::DIN', 19916);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Invirase - Cap 200mg', 'capsule', 'J05AE01', false, 0, '02216965', 'FreeDiams::CA_HCDPD::DIN', 19918);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rhovane', 'tablet', 'N05CF01', false, 0, '02008203', 'FreeDiams::CA_HCDPD::DIN', 19922);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro Plus 4 Regular Strength', 'liquid', 'B05XA31', false, 0, '02091135', 'FreeDiams::CA_HCDPD::DIN', 19923);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Correctol Laxative - Ect 5mg', 'tablet (enteric-coated)', 'A06AB02', false, 0, '02210630', 'FreeDiams::CA_HCDPD::DIN', 19925);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lithium Carbonate - Cap 300mg', 'capsule', 'N05AN01', false, 0, '02216140', 'FreeDiams::CA_HCDPD::DIN', 19933);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol No.1 Caplets', 'tablet', 'N02BE51', false, 0, '02181061', 'FreeDiams::CA_HCDPD::DIN', 19935);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trazodone-50 - Tab 50mg', 'tablet', 'N06AX05', false, 0, '02164353', 'FreeDiams::CA_HCDPD::DIN', 19936);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trazodone - 100 - Tab 100mg', 'tablet', 'N06AX05', false, 0, '02164361', 'FreeDiams::CA_HCDPD::DIN', 19937);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trazodone-150 D - Tab 150mg', 'tablet', 'N06AX05', false, 0, '02164388', 'FreeDiams::CA_HCDPD::DIN', 19938);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acebutolol-100-Tab 100mg', 'tablet', 'C07AB04', false, 0, '02164396', 'FreeDiams::CA_HCDPD::DIN', 19939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acebutolol-200 - Tab 200mg', 'tablet', 'C07AB04', false, 0, '02164418', 'FreeDiams::CA_HCDPD::DIN', 19940);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acebutolol - 400 - Tab 400mg', 'tablet', 'C07AB04', false, 0, '02164426', 'FreeDiams::CA_HCDPD::DIN', 19941);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aller-Aide - (Caplet 25mg)', 'tablet', 'R06AA02', false, 0, '02176483', 'FreeDiams::CA_HCDPD::DIN', 19951);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dovonex Solution - Top 50mcg/Ml', 'solution', 'D05AX02', false, 0, '02194341', 'FreeDiams::CA_HCDPD::DIN', 19952);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02216361', 'FreeDiams::CA_HCDPD::DIN', 19961);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02216353', 'FreeDiams::CA_HCDPD::DIN', 19962);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Uscalrite Tec E-1 - Liq Top 0.5%', 'liquid', 'D08AE05', false, 0, '02207583', 'FreeDiams::CA_HCDPD::DIN', 19976);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Desipramine - Tab 25mg', 'tablet', 'N06AA01', false, 0, '02211947', 'FreeDiams::CA_HCDPD::DIN', 20000);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Sotalol 80mg Tablets', 'tablet', 'C07AA07', false, 0, '02210428', 'FreeDiams::CA_HCDPD::DIN', 20002);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maxipime For Injection-Pws Iv 2gm', 'powder for solution', 'J01DE01', false, 0, '02163640', 'FreeDiams::CA_HCDPD::DIN', 20003);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maxipime For Injection -Pws Iv Im 1g', 'powder for solution', 'J01DE01', false, 0, '02163632', 'FreeDiams::CA_HCDPD::DIN', 20004);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidex Cream 0.05%', 'cream', 'D07AC08', false, 0, '02161923', 'FreeDiams::CA_HCDPD::DIN', 20008);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synalar Solution 0.01%', 'solution', 'D07AC04', false, 0, '02162504', 'FreeDiams::CA_HCDPD::DIN', 20009);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Buspirone - Tab 10mg', 'tablet', 'N05BE01', false, 0, '02211076', 'FreeDiams::CA_HCDPD::DIN', 20011);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Loperamide - Tab 2mg', 'tablet', 'A07DA03', false, 0, '02212005', 'FreeDiams::CA_HCDPD::DIN', 20012);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cavicide', 'liquid', 'V07AV', false, 0, '02161656', 'FreeDiams::CA_HCDPD::DIN', 20013);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Desipramine - Tab 10mg', 'tablet', 'N06AA01', false, 0, '02216248', 'FreeDiams::CA_HCDPD::DIN', 20014);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Desipramine - Tab 25mg', 'tablet', 'N06AA01', false, 0, '02216256', 'FreeDiams::CA_HCDPD::DIN', 20015);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Verapamil Sr', 'tablet (extended-release)', 'C08DA01', false, 0, '02210355', 'FreeDiams::CA_HCDPD::DIN', 20017);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Verapamil Sr', 'tablet (extended-release)', 'C08DA01', false, 0, '02210347', 'FreeDiams::CA_HCDPD::DIN', 20018);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Immucyst', 'kit', 'L03AX03', false, 0, '02194376', 'FreeDiams::CA_HCDPD::DIN', 20020);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Desipramine - Tab 100mg', 'tablet', 'N06AA01', false, 0, '02216280', 'FreeDiams::CA_HCDPD::DIN', 20021);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Desipramine - Tab 75mg', 'tablet', 'N06AA01', false, 0, '02216272', 'FreeDiams::CA_HCDPD::DIN', 20022);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Desipramine - Tab 50mg', 'tablet', 'N06AA01', false, 0, '02216264', 'FreeDiams::CA_HCDPD::DIN', 20023);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Megestrol', 'tablet', 'L02AB01', false, 0, '02195925', 'FreeDiams::CA_HCDPD::DIN', 20026);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Verapamil Sr', 'tablet (extended-release)', 'C08DA01', false, 0, '02210363', 'FreeDiams::CA_HCDPD::DIN', 20028);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Megestrol', 'tablet', 'L02AB01', false, 0, '02195917', 'FreeDiams::CA_HCDPD::DIN', 20029);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Desipramine - Tab 10mg', 'tablet', 'N06AA01', false, 0, '02211939', 'FreeDiams::CA_HCDPD::DIN', 20031);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Desipramine - Tab 50mg', 'tablet', 'N06AA01', false, 0, '02211955', 'FreeDiams::CA_HCDPD::DIN', 20032);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Desipramine - Tab 75mg', 'tablet', 'N06AA01', false, 0, '02211963', 'FreeDiams::CA_HCDPD::DIN', 20033);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12236', 'solution', 'B05ZA', false, 0, '02217244', 'FreeDiams::CA_HCDPD::DIN', 20040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12290', 'solution', 'B05ZA', false, 0, '02217643', 'FreeDiams::CA_HCDPD::DIN', 20041);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibacterial Body Cleansing Gel - 0.55%', 'gel', 'D08AE04', false, 0, '02188422', 'FreeDiams::CA_HCDPD::DIN', 20042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12293', 'solution', 'B05ZA', false, 0, '02217554', 'FreeDiams::CA_HCDPD::DIN', 20044);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12292', 'solution', 'B05ZA', false, 0, '02217236', 'FreeDiams::CA_HCDPD::DIN', 20045);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12302', 'solution', 'B05ZA', false, 0, '02217635', 'FreeDiams::CA_HCDPD::DIN', 20046);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen Usp 99%', 'gas', 'V03AN01', false, 0, '02183358', 'FreeDiams::CA_HCDPD::DIN', 20047);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterrad Booster', 'liquid', 'V07AV', false, 0, '02125579', 'FreeDiams::CA_HCDPD::DIN', 20058);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Motion Sickness Liq', 'liquid', 'R06AA02', false, 0, '01904116', 'FreeDiams::CA_HCDPD::DIN', 20059);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Drixoral Syrup', 'syrup', 'R01BA52', false, 0, '02175576', 'FreeDiams::CA_HCDPD::DIN', 20066);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Q-111 Liq', 'liquid', 'V07AV', false, 0, '02059487', 'FreeDiams::CA_HCDPD::DIN', 20068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12304', 'solution', 'B05ZA', false, 0, '02218860', 'FreeDiams::CA_HCDPD::DIN', 20076);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trusopt', 'solution', 'S01EC03', false, 0, '02216205', 'FreeDiams::CA_HCDPD::DIN', 20083);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Desipramine Tablets - 50mg', 'tablet', 'N06AA01', false, 0, '02130106', 'FreeDiams::CA_HCDPD::DIN', 20084);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Desipramine Tablets - 25mg', 'tablet', 'N06AA01', false, 0, '02130092', 'FreeDiams::CA_HCDPD::DIN', 20085);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bacterge', 'liquid', 'V07AV', false, 0, '02059460', 'FreeDiams::CA_HCDPD::DIN', 20091);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Activase Rt-Pa', 'kit', 'B01AD02', false, 0, '02147440', 'FreeDiams::CA_HCDPD::DIN', 20105);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Differin - Gel Top 0.1%', 'gel', 'D10AD03', false, 0, '02148749', 'FreeDiams::CA_HCDPD::DIN', 20107);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12300', 'solution', 'B05ZA', false, 0, '02217597', 'FreeDiams::CA_HCDPD::DIN', 20111);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Magnesium-45 0.5-4.5', 'powder for solution', 'B05ZA', false, 0, '02219301', 'FreeDiams::CA_HCDPD::DIN', 20112);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12275', 'solution', 'B05ZA', false, 0, '02218879', 'FreeDiams::CA_HCDPD::DIN', 20114);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12299', 'solution', 'B05ZA', false, 0, '02217260', 'FreeDiams::CA_HCDPD::DIN', 20115);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12286', 'solution', 'B05ZA', false, 0, '02217252', 'FreeDiams::CA_HCDPD::DIN', 20116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Clobetasol Ointment - 0.05%', 'ointment', 'D07AD01', false, 0, '02126192', 'FreeDiams::CA_HCDPD::DIN', 20117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12305', 'solution', 'B05ZA', false, 0, '02217600', 'FreeDiams::CA_HCDPD::DIN', 20118);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12294', 'solution', 'B05ZA', false, 0, '02217619', 'FreeDiams::CA_HCDPD::DIN', 20119);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12291', 'solution', 'B05ZA', false, 0, '02217279', 'FreeDiams::CA_HCDPD::DIN', 20121);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Clobetasol Crm 0.05%', 'cream', 'D07AD01', false, 0, '02093162', 'FreeDiams::CA_HCDPD::DIN', 20127);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bacimyxin Onguent', 'ointment', 'D06AX05', false, 0, '00876488', 'FreeDiams::CA_HCDPD::DIN', 20131);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Parvolex - 200mg/Ml', 'liquid', 'R05CB01', false, 0, '02181460', 'FreeDiams::CA_HCDPD::DIN', 20133);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polyderm Ointment Usp', 'ointment', 'D06AX30', false, 0, '02181908', 'FreeDiams::CA_HCDPD::DIN', 20134);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Bromazepam', 'tablet', 'N05BA08', false, 0, '02192705', 'FreeDiams::CA_HCDPD::DIN', 20147);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Ipramide - Liq 0.25mg/Ml', 'solution', 'R03BB01', false, 0, '02210479', 'FreeDiams::CA_HCDPD::DIN', 20153);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Forane', 'liquid', 'N01AB06', false, 0, '02188856', 'FreeDiams::CA_HCDPD::DIN', 20160);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Brevicon 0.5/35 Tablets (21-Day Pack)', 'tablet', 'G03AA05', false, 0, '02187086', 'FreeDiams::CA_HCDPD::DIN', 20162);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hygenipak Plus Anti-Microbial Skin Cleanser', 'liquid', 'D08AE04', false, 0, '02217937', 'FreeDiams::CA_HCDPD::DIN', 20166);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorph Contin-Controlled Release Cap - 12mg', 'capsule (sustained-release)', 'N02AA03', false, 0, '02125366', 'FreeDiams::CA_HCDPD::DIN', 20171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorph Contin-Controlled Release Cap - 24mg', 'capsule (sustained-release)', 'N02AA03', false, 0, '02125382', 'FreeDiams::CA_HCDPD::DIN', 20172);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxycontin 10mg', 'tablet (extended-release)', 'N02AA05', false, 0, '02202441', 'FreeDiams::CA_HCDPD::DIN', 20173);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxycontin 20mg', 'tablet (extended-release)', 'N02AA05', false, 0, '02202468', 'FreeDiams::CA_HCDPD::DIN', 20174);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxycontin 40mg', 'tablet (extended-release)', 'N02AA05', false, 0, '02202476', 'FreeDiams::CA_HCDPD::DIN', 20175);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxycontin 80mg', 'tablet (extended-release)', 'N02AA05', false, 0, '02202484', 'FreeDiams::CA_HCDPD::DIN', 20176);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Metoprolol-B Tab 100mg', 'tablet', 'C07AB02', false, 0, '02172569', 'FreeDiams::CA_HCDPD::DIN', 20187);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Metoprolol-B - Tab 50mg', 'tablet', 'C07AB02', false, 0, '02172550', 'FreeDiams::CA_HCDPD::DIN', 20188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Levocarb - Tab 10mg/100mg', 'tablet', 'N04BA02', false, 0, '02195933', 'FreeDiams::CA_HCDPD::DIN', 20189);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Levocarb - Tab 25mg/250mg', 'tablet', 'N04BA02', false, 0, '02195968', 'FreeDiams::CA_HCDPD::DIN', 20190);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Veramil Sr - Srt 240 Mg', 'tablet (extended-release)', 'C08DA01', false, 0, '02211920', 'FreeDiams::CA_HCDPD::DIN', 20200);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Piroxicam', 'capsule', 'M01AC01', false, 0, '00836230', 'FreeDiams::CA_HCDPD::DIN', 20205);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Piroxicam', 'capsule', 'M01AC01', false, 0, '00836249', 'FreeDiams::CA_HCDPD::DIN', 20206);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oro-Clense Oral Rinse - Liq 0.12%', 'liquid', 'A01AB03', false, 0, '02209055', 'FreeDiams::CA_HCDPD::DIN', 20216);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valtrex', 'tablet', 'J05AB11', false, 0, '02219492', 'FreeDiams::CA_HCDPD::DIN', 20218);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sure 5', 'liquid', 'V07AV', false, 0, '02059428', 'FreeDiams::CA_HCDPD::DIN', 20223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Levocarb-Tab 25mg/100mg', 'tablet', 'N04BA02', false, 0, '02195941', 'FreeDiams::CA_HCDPD::DIN', 20239);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Panadol Tablet 500mg', 'tablet', 'N02BE01', false, 0, '02142732', 'FreeDiams::CA_HCDPD::DIN', 20255);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Havrix - Sus Im 1440 Elisa Units/Ml', 'suspension', 'J07BC02', false, 0, '02187078', 'FreeDiams::CA_HCDPD::DIN', 20256);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synalar Ointment 0.025%', 'ointment', 'D07AC04', false, 0, '02162512', 'FreeDiams::CA_HCDPD::DIN', 20258);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02192756', 'FreeDiams::CA_HCDPD::DIN', 20259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02192764', 'FreeDiams::CA_HCDPD::DIN', 20260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sucrets Cough Control Extra Strength Lozenges', 'lozenge', 'R05DA09', false, 0, '02206196', 'FreeDiams::CA_HCDPD::DIN', 20261);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diclofenac', 'suppository', 'M01AB05', false, 0, '02174677', 'FreeDiams::CA_HCDPD::DIN', 20263);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Finale - Liq Hom Hos', 'liquid', 'V07AV', false, 0, '02213117', 'FreeDiams::CA_HCDPD::DIN', 20265);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vangard 256 - Liq Hom Hos', 'liquid', 'V07AV', false, 0, '02213095', 'FreeDiams::CA_HCDPD::DIN', 20266);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vangard - Liq Hom Hos', 'liquid', 'V07AV', false, 0, '02213109', 'FreeDiams::CA_HCDPD::DIN', 20267);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pinosan - Liq Hom Hos', 'liquid', 'V07AV', false, 0, '02213133', 'FreeDiams::CA_HCDPD::DIN', 20268);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pine Oil Disinf Deod Cleanser', 'liquid', 'V07AV', false, 0, '00438391', 'FreeDiams::CA_HCDPD::DIN', 20271);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('4.25% Travasol Amino Acid Injection With Electrolytes In 10% Dextrose', 'solution', 'B05BA10', false, 0, '02142414', 'FreeDiams::CA_HCDPD::DIN', 20276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Travasol Amino Acid Injection Without Electrolytes In 16.6% Dextrose', 'solution', 'B05BA10', false, 0, '02142260', 'FreeDiams::CA_HCDPD::DIN', 20278);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Travasol Amino Acid Injection Without Electrolytes In 20% Dextrose', 'solution', 'B05BA10', false, 0, '02142252', 'FreeDiams::CA_HCDPD::DIN', 20279);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Travasol Amino Acid Injection With Electrolytes In 20% Dextrose', 'solution', 'B05BA10', false, 0, '02142368', 'FreeDiams::CA_HCDPD::DIN', 20281);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Travasol Amino Acid Injection With Electrolytes In 25% Dextrose', 'solution', 'B05BA10', false, 0, '02142341', 'FreeDiams::CA_HCDPD::DIN', 20282);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Typhim Vi', 'solution', 'J07AP03', false, 0, '02130955', 'FreeDiams::CA_HCDPD::DIN', 20287);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('2.5% Travasol Amino Acid Injection With Electrolytes In 10% Dextrose', 'solution', 'B05BA10', false, 0, '02143267', 'FreeDiams::CA_HCDPD::DIN', 20288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('4.25% Travasol Amino Acid Injection Without Electrlytes In 10% Dextrose', 'solution', 'B05BA10', false, 0, '02142317', 'FreeDiams::CA_HCDPD::DIN', 20289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Travasol Amino Acid Injection With Electolytes In 16.6% Dextrose', 'solution', 'B05BA10', false, 0, '02142376', 'FreeDiams::CA_HCDPD::DIN', 20290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Travasol Amino Acid Injection With Electrolytes In 10% Dextrose', 'solution', 'B05BA10', false, 0, '02142384', 'FreeDiams::CA_HCDPD::DIN', 20291);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('4.25% Travasol Amino Acid Injection With Electrolytes In 25% Dextrose', 'solution', 'B05BA10', false, 0, '02142392', 'FreeDiams::CA_HCDPD::DIN', 20292);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Oxtriphylline Syr Pediatric 10mg/Ml', 'syrup', 'R03DA02', false, 0, '00792934', 'FreeDiams::CA_HCDPD::DIN', 20293);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benzagel 5 Lotion', 'lotion', 'D10AE01', false, 0, '02166607', 'FreeDiams::CA_HCDPD::DIN', 20298);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benzagel 5 Wash', 'liquid', 'D10AE01', false, 0, '02162121', 'FreeDiams::CA_HCDPD::DIN', 20299);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Travasol Amino Acid Injection Without Electrolytes In 10% Dextrose', 'solution', 'B05BA10', false, 0, '02142279', 'FreeDiams::CA_HCDPD::DIN', 20302);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('4.25% Travasol Amino Acid Injection Without Electrolytes In 25% Dextrose', 'solution', 'B05BA10', false, 0, '02142295', 'FreeDiams::CA_HCDPD::DIN', 20303);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Propranolol Tablets - 80mg', 'tablet', 'C07AA05', false, 0, '02137348', 'FreeDiams::CA_HCDPD::DIN', 20305);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Trazodone Tablets-100mg', 'tablet', 'N06AX05', false, 0, '02128969', 'FreeDiams::CA_HCDPD::DIN', 20306);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Trazodone Tablets - 50mg', 'tablet', 'N06AX05', false, 0, '02128950', 'FreeDiams::CA_HCDPD::DIN', 20307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baclofen-10 - Tab', 'tablet', 'M03BX01', false, 0, '02152584', 'FreeDiams::CA_HCDPD::DIN', 20308);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baclofen-20 - Tab', 'tablet', 'M03BX01', false, 0, '02152592', 'FreeDiams::CA_HCDPD::DIN', 20309);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Metoprolol (Type L)', 'tablet', 'C07AB02', false, 0, '02174545', 'FreeDiams::CA_HCDPD::DIN', 20310);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Metoprolol (Type L)', 'tablet', 'C07AB02', false, 0, '02174553', 'FreeDiams::CA_HCDPD::DIN', 20311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lansoyl Sugar Free - Jelly - 78%', 'gel', 'A06AA01', false, 0, '02186926', 'FreeDiams::CA_HCDPD::DIN', 20312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro Plus 6   (Regular)', 'liquid', 'B05XA31', false, 0, '02091119', 'FreeDiams::CA_HCDPD::DIN', 20314);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zerit - Cap 15mg', 'capsule', 'J05AF04', false, 0, '02216086', 'FreeDiams::CA_HCDPD::DIN', 20322);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zerit - Cap 40mg', 'capsule', 'J05AF04', false, 0, '02216116', 'FreeDiams::CA_HCDPD::DIN', 20323);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zerit - Cap 30mg', 'capsule', 'J05AF04', false, 0, '02216108', 'FreeDiams::CA_HCDPD::DIN', 20324);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zerit - Cap 20mg', 'capsule', 'J05AF04', false, 0, '02216094', 'FreeDiams::CA_HCDPD::DIN', 20325);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Cotridin', 'syrup', 'R05DA20', false, 0, '02169126', 'FreeDiams::CA_HCDPD::DIN', 20329);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Saniterge', 'liquid', 'V07AV', false, 0, '02059401', 'FreeDiams::CA_HCDPD::DIN', 20341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen Usp - Gas 100%', 'gas', 'V03AN01', false, 0, '02219719', 'FreeDiams::CA_HCDPD::DIN', 20349);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caverject Sterile Powder - Kit 23.2mcg/Vial', 'kit', 'G04BE01', false, 0, '02215756', 'FreeDiams::CA_HCDPD::DIN', 20353);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bacteriostatic Water For Injection Usp-Pre-Filled Syringe', 'liquid', 'V07AB', false, 0, '02215721', 'FreeDiams::CA_HCDPD::DIN', 20354);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Levobunolol - Liq 0.25%', 'liquid', 'S01ED03', false, 0, '02197456', 'FreeDiams::CA_HCDPD::DIN', 20355);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Levobunolol - Liq 0.5%', 'liquid', 'S01ED03', false, 0, '02197464', 'FreeDiams::CA_HCDPD::DIN', 20356);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rhume Et De La Toux', 'powder for solution', 'R05DA20', false, 0, '01908626', 'FreeDiams::CA_HCDPD::DIN', 21167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Self Tanner', 'lotion', 'D02BA30', false, 0, '02237188', 'FreeDiams::CA_HCDPD::DIN', 60506);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rhume Et De La Grippe', 'powder for solution', 'N02BE51', false, 0, '01908634', 'FreeDiams::CA_HCDPD::DIN', 21168);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('6% Dextran 70 In 0.9% Sodium Chloride Injection', 'solution', 'B05AA55', false, 0, '01924192', 'FreeDiams::CA_HCDPD::DIN', 21686);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alcohol 5% And Dextrose 5% Injection Usp', 'solution', 'B05BA03', false, 0, '01924230', 'FreeDiams::CA_HCDPD::DIN', 21687);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('10% Dextran 40 In 5% Dextrose Injection', 'solution', 'B05AA55', false, 0, '01924249', 'FreeDiams::CA_HCDPD::DIN', 21688);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('70% Dextrose Injection Usp', 'liquid', 'B05BA03', false, 0, '01924265', 'FreeDiams::CA_HCDPD::DIN', 21689);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hyperlyte Cr Multi-Electrolyte Concentrate', 'liquid', 'B05BB01', false, 0, '01924311', 'FreeDiams::CA_HCDPD::DIN', 21691);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bod San 4.5 Liq', 'liquid', 'V07AV', false, 0, '01924478', 'FreeDiams::CA_HCDPD::DIN', 21701);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('0.15% Potassium Chloride In 5% Dextrose Injection Usp', 'solution', 'B05BB02', false, 0, '01931539', 'FreeDiams::CA_HCDPD::DIN', 21713);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5% Dextrose And 0.20% Sodium Chloride Injection Usp', 'solution', 'B05BB02', false, 0, '01927558', 'FreeDiams::CA_HCDPD::DIN', 21715);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('0.30% Potassium Chloride In 5% Dextrose And 0.45% Sodium Chloride Injection', 'solution', 'B05BB02', false, 0, '01931571', 'FreeDiams::CA_HCDPD::DIN', 21752);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('0.15% Potassium Chloride In 5% Dextrose And 0.20% Sodium Chloride Injection Usp', 'liquid', 'B05BB02', false, 0, '01931598', 'FreeDiams::CA_HCDPD::DIN', 21753);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('0.15% Potassium Chloride In 5% Dextrose And 0.33% Sodium Chloride Injection Usp', 'liquid', 'B05BB02', false, 0, '01931601', 'FreeDiams::CA_HCDPD::DIN', 21754);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('0.15% Potassium Chloride In 5% Dextrose And 0.9% Sodium Chloride Injection', 'solution', 'B05BB02', false, 0, '01931644', 'FreeDiams::CA_HCDPD::DIN', 21755);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 2.5% In Half Strength Lactated Ringer''S Injection, Usp', 'liquid', 'B05BB02', false, 0, '01931660', 'FreeDiams::CA_HCDPD::DIN', 21756);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isolyte S Ph 7.4 (Multi-Electrolyte Injection)', 'solution', 'B05BB01', false, 0, '01931679', 'FreeDiams::CA_HCDPD::DIN', 21757);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isolyte R In 5% Dextrose', 'liquid', 'B05BB02', false, 0, '01931709', 'FreeDiams::CA_HCDPD::DIN', 21764);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isolyte M In 5% Dextrose', 'liquid', 'B05BB02', false, 0, '01931776', 'FreeDiams::CA_HCDPD::DIN', 21767);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Agro-Squad 2-1', 'liquid', 'V07AV', false, 0, '01935070', 'FreeDiams::CA_HCDPD::DIN', 21969);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Pediatric Drops 80 Mg/Ml Usp', 'drops', 'N02BE01', false, 0, '01935275', 'FreeDiams::CA_HCDPD::DIN', 21989);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Sodium 1000units In 0.9% Sodium Chloride Injection Usp', 'solution', 'B01AB51', false, 0, '01935933', 'FreeDiams::CA_HCDPD::DIN', 21993);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isolyte S With 5% Dextrose Inj', 'solution', 'B05BB02', false, 0, '01935992', 'FreeDiams::CA_HCDPD::DIN', 21998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ringer''S Injection Usp', 'liquid', 'B05BB01', false, 0, '01936034', 'FreeDiams::CA_HCDPD::DIN', 21999);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baxedin Pre-Op', 'solution', 'D08AC02', false, 0, '01936441', 'FreeDiams::CA_HCDPD::DIN', 22030);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen 325mg Tab', 'tablet', 'N02BE01', false, 0, '01938088', 'FreeDiams::CA_HCDPD::DIN', 22086);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Extra Strength Tab 500mg Usp', 'tablet', 'N02BE01', false, 0, '01939122', 'FreeDiams::CA_HCDPD::DIN', 22143);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methoxisal-C 1/8', 'tablet', 'M03BA53', false, 0, '01941895', 'FreeDiams::CA_HCDPD::DIN', 22274);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('40% Dextrose Injection Usp', 'solution', 'B05BA03', false, 0, '01947230', 'FreeDiams::CA_HCDPD::DIN', 22423);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cold Medication Extra Strength D Tab', 'tablet', 'N02BE51', false, 0, '01957619', 'FreeDiams::CA_HCDPD::DIN', 22846);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cold Medication Extra Strength N Tab', 'tablet', 'N02BE51', false, 0, '01957627', 'FreeDiams::CA_HCDPD::DIN', 22847);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Activated Charcoal Capsule 260mg', 'capsule', 'A07BA01', false, 0, '00789674', 'FreeDiams::CA_HCDPD::DIN', 22917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anticoagulant Cit Phos Dex Adenine Sol Usp', 'solution', 'V07AC', false, 0, '01960865', 'FreeDiams::CA_HCDPD::DIN', 23039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hyperlyte (Multi-Electrolyte Concentrate)', 'liquid', 'B05XA30', false, 0, '01963910', 'FreeDiams::CA_HCDPD::DIN', 23184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Dexamethasone Tab 4mg', 'tablet', 'H02AB02', false, 0, '01964070', 'FreeDiams::CA_HCDPD::DIN', 23194);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo Meprazine Tab 5mg', 'tablet', 'N05AA02', false, 0, '01964909', 'FreeDiams::CA_HCDPD::DIN', 23257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Dexamethasone Tab 0.75mg Usp', 'tablet', 'H02AB02', false, 0, '01964968', 'FreeDiams::CA_HCDPD::DIN', 23260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Dexamethasone Tab 0.5mg Usp', 'tablet', 'H02AB02', false, 0, '01964976', 'FreeDiams::CA_HCDPD::DIN', 23261);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methoxisal-C 1/4', 'tablet', 'M03BA53', false, 0, '01966367', 'FreeDiams::CA_HCDPD::DIN', 23354);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methoxisal-C 1/2', 'tablet', 'M03BA53', false, 0, '01966375', 'FreeDiams::CA_HCDPD::DIN', 23355);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('0.30% Potassium Chloride In 5% Dextrose', 'liquid', 'B05BB02', false, 0, '01967770', 'FreeDiams::CA_HCDPD::DIN', 23494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trianal-C 1/2 Capsule', 'capsule', 'N02AA79', false, 0, '01971387', 'FreeDiams::CA_HCDPD::DIN', 23669);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trianal Tablet', 'tablet', 'N02BA71', false, 0, '01971409', 'FreeDiams::CA_HCDPD::DIN', 23671);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trianal Capsules', 'capsule', 'N02BA71', false, 0, '01971417', 'FreeDiams::CA_HCDPD::DIN', 23672);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sleep Aid (Extra Strength) Tab 50mg', 'tablet', 'R06AA02', false, 0, '01991086', 'FreeDiams::CA_HCDPD::DIN', 24750);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Disinfectant Spray', 'aerosol', 'V07AV', false, 0, '02004259', 'FreeDiams::CA_HCDPD::DIN', 25672);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Foaming Germicidal Cleanser', 'aerosol', 'V07AV', false, 0, '02004313', 'FreeDiams::CA_HCDPD::DIN', 25675);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimenhydrinate Tablets', 'tablet', 'R06AA02', false, 0, '02006669', 'FreeDiams::CA_HCDPD::DIN', 25821);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cocaine Hydrochloride  Topical Sol 4%', 'liquid', 'R02AD03', false, 0, '02006316', 'FreeDiams::CA_HCDPD::DIN', 25828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Relievol Sinus Caplets Extra Strength, Non Drowsy Formula', 'tablet', 'N02BE51', false, 0, '02009412', 'FreeDiams::CA_HCDPD::DIN', 25897);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Relievol Allergy Sinus Caplets Extra Strength', 'tablet', 'N02BE51', false, 0, '02009420', 'FreeDiams::CA_HCDPD::DIN', 25898);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Westokleen Plus Liq', 'liquid', 'V07AV', false, 0, '02012227', 'FreeDiams::CA_HCDPD::DIN', 26014);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Liquid Chlorine 12%', 'liquid', 'V07AV', false, 0, '02012243', 'FreeDiams::CA_HCDPD::DIN', 26016);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Totacide-28 Liq 2%', 'liquid', 'V07AV', false, 0, '02012286', 'FreeDiams::CA_HCDPD::DIN', 26018);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Acetaminophen Tablets', 'tablet', 'N02BE01', false, 0, '02015676', 'FreeDiams::CA_HCDPD::DIN', 26144);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cough Syrup Dm', 'syrup', 'R05DA09', false, 0, '02015781', 'FreeDiams::CA_HCDPD::DIN', 26149);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chrom-O-Red Disclosing Solution Concentrate', 'liquid', 'V04C', false, 0, '02021137', 'FreeDiams::CA_HCDPD::DIN', 26307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hot Lemon Relief-Extra Strength Pck-Pws', 'kit', 'N02BE51', false, 0, '02023105', 'FreeDiams::CA_HCDPD::DIN', 26396);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hot Lemon Relief  Pck-Pws', 'kit', 'N02BE51', false, 0, '02023113', 'FreeDiams::CA_HCDPD::DIN', 26397);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sirop Docusate De Sodium Usp 20mg/5ml', 'syrup', 'A06AA02', false, 0, '02024624', 'FreeDiams::CA_HCDPD::DIN', 26438);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soflax', 'capsule', 'A06AA02', false, 0, '02029529', 'FreeDiams::CA_HCDPD::DIN', 26561);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cetacaine Liquid', 'liquid', 'D04AB30', false, 0, '02028867', 'FreeDiams::CA_HCDPD::DIN', 26564);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zepynamic A Aer', 'aerosol', 'V07AV', false, 0, '02035812', 'FreeDiams::CA_HCDPD::DIN', 26739);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antacid With Alumina, Magnesia Plus Simethicone Oral Suspension U.S.P.', 'suspension', 'A02AF02', false, 0, '02039273', 'FreeDiams::CA_HCDPD::DIN', 26833);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Tylenol Cold Suspension', 'suspension', 'N02BE51', false, 0, '02039982', 'FreeDiams::CA_HCDPD::DIN', 26863);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Tylenol Cold And Cough', 'suspension', 'N02BE51', false, 0, '02039990', 'FreeDiams::CA_HCDPD::DIN', 26864);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultrase Mt12 Capsules', 'capsule (enteric-coated)', 'A09AA02', false, 0, '02045834', 'FreeDiams::CA_HCDPD::DIN', 27081);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultrase Mt20 Capsules', 'capsule (enteric-coated)', 'A09AA02', false, 0, '02045869', 'FreeDiams::CA_HCDPD::DIN', 27084);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Refresh Plus Dps 5mg/Ml', 'drops', 'S01XA20', false, 0, '02049260', 'FreeDiams::CA_HCDPD::DIN', 27183);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Sinus Relief Daytime', 'tablet', 'N02BE51', false, 0, '02050242', 'FreeDiams::CA_HCDPD::DIN', 27225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen Usp', 'gas', 'V03AN01', false, 0, '02052881', 'FreeDiams::CA_HCDPD::DIN', 27306);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Compound Benzoin Tincture Usp 10% Swabstick', 'tincture', 'D08AX', false, 0, '02053659', 'FreeDiams::CA_HCDPD::DIN', 27350);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('100% Ethylene Oxide', 'gas', 'V07AV', false, 0, '02055422', 'FreeDiams::CA_HCDPD::DIN', 27366);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cough Syrup Expectorant', 'syrup', 'R05CA03', false, 0, '02059185', 'FreeDiams::CA_HCDPD::DIN', 27461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cough Syrup Dm Decongestant', 'syrup', 'R05DA20', false, 0, '02059193', 'FreeDiams::CA_HCDPD::DIN', 27462);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cough Syrup Dm - Decongestant - Expectorant', 'syrup', 'R05FA02', false, 0, '02059207', 'FreeDiams::CA_HCDPD::DIN', 27463);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Barriere Cream 20%', 'cream', 'D02AA', false, 0, '02060841', 'FreeDiams::CA_HCDPD::DIN', 27514);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Betnesol Retention Enema 5mg/100ml', 'enema', 'A07EA04', false, 0, '02060884', 'FreeDiams::CA_HCDPD::DIN', 27517);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Unisom Sleep Gels Capsules 50mg', 'capsule', 'R06AA02', false, 0, '02061597', 'FreeDiams::CA_HCDPD::DIN', 27528);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benadryl Allergy Tablets', 'tablet (chewable)', 'R06AA02', false, 0, '02061287', 'FreeDiams::CA_HCDPD::DIN', 27547);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Succinylcholine Chloride Inj. 20mg/Ml Usp', 'liquid', 'M03AB01', false, 0, '02062232', 'FreeDiams::CA_HCDPD::DIN', 27606);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('A-456-N', 'liquid', 'V07AV', false, 0, '02067234', 'FreeDiams::CA_HCDPD::DIN', 27723);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('3133 Eclips No.1 Disinfectant Detergent Liq', 'liquid', 'V07AV', false, 0, '02067250', 'FreeDiams::CA_HCDPD::DIN', 27724);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('3134 Eclips No.2 Disinfectant Detergent', 'liquid', 'V07AV', false, 0, '02067269', 'FreeDiams::CA_HCDPD::DIN', 27725);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soluprep  Gluconate De Chlorhexidine 0.05%', 'sponge', 'D08AC02', false, 0, '02072955', 'FreeDiams::CA_HCDPD::DIN', 27903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carboxide Gas 10%', 'gas', 'V07AV', false, 0, '02074192', 'FreeDiams::CA_HCDPD::DIN', 27931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxyfume-2000 Gas 8.6%', 'gas', 'V07AV', false, 0, '02074206', 'FreeDiams::CA_HCDPD::DIN', 27932);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proclearz Antifungal Liquid', 'liquid', 'D01AE18', false, 0, '02078341', 'FreeDiams::CA_HCDPD::DIN', 27993);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tears Naturale P.M.', 'ointment', 'S01XA20', false, 0, '02082519', 'FreeDiams::CA_HCDPD::DIN', 28169);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solunet Mousse (Chlorhexidine 4%)', 'aerosol', 'D08AC02', false, 0, '02083884', 'FreeDiams::CA_HCDPD::DIN', 28206);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Colace Syrup 4 Mg/Ml', 'syrup', 'A06AA02', false, 0, '02086018', 'FreeDiams::CA_HCDPD::DIN', 28280);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Barriere Hc', 'cream', 'D07AA02', false, 0, '02086034', 'FreeDiams::CA_HCDPD::DIN', 28281);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Super Net Disinfectant/Cleaner Liq 4.4%', 'liquid', 'V07AV', false, 0, '02086344', 'FreeDiams::CA_HCDPD::DIN', 28306);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Propaderm   -Cream 0.025%', 'cream', 'D07AC15', false, 0, '02089602', 'FreeDiams::CA_HCDPD::DIN', 28440);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Colace Drops 10 Mg/Ml', 'solution', 'A06AA02', false, 0, '02090163', 'FreeDiams::CA_HCDPD::DIN', 28453);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mucomyst', 'solution', 'R05CB01', false, 0, '02091526', 'FreeDiams::CA_HCDPD::DIN', 28513);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Seelect A-M 256 Liq', 'liquid', 'V07AV', false, 0, '02091550', 'FreeDiams::CA_HCDPD::DIN', 28516);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dequadin Lozenges 0.25 Mg', 'lozenge', 'R02AA02', false, 0, '02100207', 'FreeDiams::CA_HCDPD::DIN', 28979);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Swish Food Service Disinfectant', 'liquid', 'V07AV', false, 0, '02105357', 'FreeDiams::CA_HCDPD::DIN', 29436);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quato 109 Disinfectant Concentrate', 'liquid', 'V07AV', false, 0, '02105365', 'FreeDiams::CA_HCDPD::DIN', 29437);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quato 44 General Purpose Disinfectant', 'liquid', 'V07AV', false, 0, '02105373', 'FreeDiams::CA_HCDPD::DIN', 29438);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Charcodote Tfs Sus 200mg/Ml', 'suspension', 'A07BA01', false, 0, '02105462', 'FreeDiams::CA_HCDPD::DIN', 29506);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Charcodote-Aqueous Sus 200mg/Ml', 'suspension', 'A07BA01', false, 0, '02105470', 'FreeDiams::CA_HCDPD::DIN', 29507);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Colace Capsules 100 Mg', 'capsule', 'A06AA02', false, 0, '02106256', 'FreeDiams::CA_HCDPD::DIN', 29540);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trandate', 'tablet', 'C07AG01', false, 0, '02106272', 'FreeDiams::CA_HCDPD::DIN', 29542);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trandate', 'tablet', 'C07AG01', false, 0, '02106280', 'FreeDiams::CA_HCDPD::DIN', 29543);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fs Antimicrobial Hand Cleaner - 2.5% Liq', 'liquid', 'D08AJ01', false, 0, '02119242', 'FreeDiams::CA_HCDPD::DIN', 30372);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solu-I.V. Tiges Montees Chd Alcool - Stk', 'stick', 'D08AC52', false, 0, '02119803', 'FreeDiams::CA_HCDPD::DIN', 30398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bronchophan Expectorant (Sans Sucrose)', 'syrup', 'R05CA03', false, 0, '02121999', 'FreeDiams::CA_HCDPD::DIN', 30557);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Virkon', 'powder for solution', 'V07AV', false, 0, '02125021', 'FreeDiams::CA_HCDPD::DIN', 30727);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Nystatin 100.000 Iu/Ml Oral Suspension', 'suspension', 'A07AA02', false, 0, '02125145', 'FreeDiams::CA_HCDPD::DIN', 30739);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Methylphenidate', 'tablet', 'N06BA04', false, 0, '02126486', 'FreeDiams::CA_HCDPD::DIN', 30780);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Methylphenidate', 'tablet', 'N06BA04', false, 0, '02126494', 'FreeDiams::CA_HCDPD::DIN', 30781);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cough Syrup Dm Expectorant', 'syrup', 'R05FA02', false, 0, '02128349', 'FreeDiams::CA_HCDPD::DIN', 30826);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf/Fps 33 Dermatone Moisturizing Uva/Uvb Sunscreen Creme', 'cream', 'D02BA30', false, 0, '02129876', 'FreeDiams::CA_HCDPD::DIN', 30927);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Cough And Sore Throat', 'syrup', 'N02BE51', false, 0, '02130564', 'FreeDiams::CA_HCDPD::DIN', 30945);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hypotears Eye Ointment', 'ointment', 'S01XA20', false, 0, '02133288', 'FreeDiams::CA_HCDPD::DIN', 31093);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Miochol E', 'powder for solution', 'S01EB09', false, 0, '02133326', 'FreeDiams::CA_HCDPD::DIN', 31096);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paraldehyde Injection Bp', 'liquid', 'N05CC05', false, 0, '02137135', 'FreeDiams::CA_HCDPD::DIN', 31279);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Thiosulfate Injection Usp 25%', 'liquid', 'V03AB06', false, 0, '02137186', 'FreeDiams::CA_HCDPD::DIN', 31283);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sulphate Injection 1mg/Ml', 'liquid', 'N02AA01', false, 0, '02137232', 'FreeDiams::CA_HCDPD::DIN', 31285);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sulphate Injection 2mg/Ml', 'liquid', 'N02AA01', false, 0, '02137240', 'FreeDiams::CA_HCDPD::DIN', 31286);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sulphate Injection 50mg/Ml', 'liquid', 'N02AA01', false, 0, '02137267', 'FreeDiams::CA_HCDPD::DIN', 31288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vasopressin Injection, Usp', 'solution', 'H01BA01', false, 0, '02139502', 'FreeDiams::CA_HCDPD::DIN', 31359);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Acetate Injection, Usp', 'solution', 'B05XA08', false, 0, '02139529', 'FreeDiams::CA_HCDPD::DIN', 31360);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxytocin Injection, Usp', 'solution', 'H01BB02', false, 0, '02139561', 'FreeDiams::CA_HCDPD::DIN', 31361);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diomycin-Ont 5mg/Gm', 'ointment', 'S01AA17', false, 0, '02141574', 'FreeDiams::CA_HCDPD::DIN', 31467);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy Formula Caplets', 'tablet', 'R06AA02', false, 0, '02141728', 'FreeDiams::CA_HCDPD::DIN', 31477);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy Formula Liquid', 'elixir', 'R06AA02', false, 0, '02141736', 'FreeDiams::CA_HCDPD::DIN', 31478);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Water For Injection', 'liquid', 'V07AB', false, 0, '02142546', 'FreeDiams::CA_HCDPD::DIN', 31491);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cough Syrup Dm - Decongestant For Children', 'syrup', 'R05DA20', false, 0, '02142740', 'FreeDiams::CA_HCDPD::DIN', 31502);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Junior Strength Acetaminophen Tablets-160mg', 'tablet (chewable)', 'N02BE01', false, 0, '02142805', 'FreeDiams::CA_HCDPD::DIN', 31506);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hot Lemon Relief Regular Strength', 'powder', 'N02BE51', false, 0, '02143186', 'FreeDiams::CA_HCDPD::DIN', 31530);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidodan Jelly 2%', 'jelly', 'D04AB01', false, 0, '02143879', 'FreeDiams::CA_HCDPD::DIN', 31563);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen With Codeine - Caplet', 'tablet', 'N02BE51', false, 0, '02143933', 'FreeDiams::CA_HCDPD::DIN', 31568);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Water-Jel Burn Jel-2%', 'gel', 'D04AB01', false, 0, '02144409', 'FreeDiams::CA_HCDPD::DIN', 31582);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apap (Acetaminophen 325mg)', 'tablet', 'N02BE01', false, 0, '01989510', 'FreeDiams::CA_HCDPD::DIN', 32410);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Palmer''S Skin Success Fade Cream-For Dry Skn', 'cream', 'D11AX11', false, 0, '02046075', 'FreeDiams::CA_HCDPD::DIN', 32776);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Palmer''S Skin Success Fade Cream-For Oily Sk', 'cream', 'D11AX11', false, 0, '02046083', 'FreeDiams::CA_HCDPD::DIN', 32777);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Palmer''S Skin Success Fade Cream-Normal Skin', 'cream', 'D11AX11', false, 0, '02046091', 'FreeDiams::CA_HCDPD::DIN', 32778);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hot Lemon Relief For Symptoms Of Cold And Flu Regular Strength', 'powder', 'N02BE51', false, 0, '02047349', 'FreeDiams::CA_HCDPD::DIN', 32780);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avon Moisture Shield-Tinted Spf 15 Crm', 'cream', 'D02BA30', false, 0, '02050773', 'FreeDiams::CA_HCDPD::DIN', 32792);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinus Pain And Nasal Congestion Relief', 'tablet', 'N02BE51', false, 0, '02129981', 'FreeDiams::CA_HCDPD::DIN', 33120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophene Regulier 325mg - Tab', 'tablet', 'N02BE01', false, 0, '02158698', 'FreeDiams::CA_HCDPD::DIN', 33272);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Blue Collyrium', 'liquid', 'S01GA51', false, 0, '02171937', 'FreeDiams::CA_HCDPD::DIN', 33329);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Decongestant Nasal Mist Long Lasting', 'liquid', 'R01AA05', false, 0, '02213907', 'FreeDiams::CA_HCDPD::DIN', 33430);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bismuth', 'liquid', 'A07BB', false, 0, '02220709', 'FreeDiams::CA_HCDPD::DIN', 33448);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Myoflex Extra Strength - Crm 15%', 'cream', 'M02AC', false, 0, '02226022', 'FreeDiams::CA_HCDPD::DIN', 33476);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophene - Liq 160 Mg/5 Ml', 'liquid', 'N02BE01', false, 0, '02226871', 'FreeDiams::CA_HCDPD::DIN', 33482);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophene - Liq 80 Mg/Ml', 'liquid', 'N02BE01', false, 0, '02226898', 'FreeDiams::CA_HCDPD::DIN', 33483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Oil Free Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02208318', 'FreeDiams::CA_HCDPD::DIN', 33490);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dr. Scholl''S Athlete''S Foot Powder - 1%', 'powder', 'D01AE18', false, 0, '02220733', 'FreeDiams::CA_HCDPD::DIN', 33528);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antiphlogistine Rub A-535 No Odour', 'ointment', 'M02AC', false, 0, '02222132', 'FreeDiams::CA_HCDPD::DIN', 33537);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antiseptic Throat Lozenges (With Hexylresorcinol)', 'lozenge', 'R02AA12', false, 0, '02228432', 'FreeDiams::CA_HCDPD::DIN', 33590);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Klean-Prep', 'powder for solution', 'A06AD65', false, 0, '02147793', 'FreeDiams::CA_HCDPD::DIN', 33649);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Seequin 2 Ids', 'gel', 'D11AX11', false, 0, '02152053', 'FreeDiams::CA_HCDPD::DIN', 33818);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckeye Sanicare Quat-256 Pdf', 'liquid', 'V07AV', false, 0, '02152363', 'FreeDiams::CA_HCDPD::DIN', 33839);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen 300 Mg With 15 Mg Caffeine And 8 Mg Codeine Phosphate', 'tablet', 'N02BE51', false, 0, '02154234', 'FreeDiams::CA_HCDPD::DIN', 33917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Drixoral Day/Night - Srt/Tabs', 'kit', 'R01BA52', false, 0, '02154285', 'FreeDiams::CA_HCDPD::DIN', 33922);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tridesilon 0.05% Desonide Cream', 'cream', 'D07AB08', false, 0, '02154862', 'FreeDiams::CA_HCDPD::DIN', 33930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tridesilon 0.05% Desonide Ointment', 'ointment', 'D07AB08', false, 0, '02154870', 'FreeDiams::CA_HCDPD::DIN', 33931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cidex Plus 28 Day Solution - 3.4%', 'solution', 'V07AV', false, 0, '02158396', 'FreeDiams::CA_HCDPD::DIN', 34111);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cidex Activated Dialdehyde Solution', 'solution', 'V07AV', false, 0, '02158418', 'FreeDiams::CA_HCDPD::DIN', 34112);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Allergy Sinus Medication', 'tablet', 'N02BE51', false, 0, '02159546', 'FreeDiams::CA_HCDPD::DIN', 34150);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germguard Detergent', 'liquid', 'V07AV', false, 0, '02160250', 'FreeDiams::CA_HCDPD::DIN', 34190);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spray Nine', 'spray', 'V07AV', false, 0, '02160331', 'FreeDiams::CA_HCDPD::DIN', 34197);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rapidyne Liquid 25%', 'liquid', 'V07AV', false, 0, '02160501', 'FreeDiams::CA_HCDPD::DIN', 34205);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vittal Liq 1.89%', 'liquid', 'V07AV', false, 0, '02160684', 'FreeDiams::CA_HCDPD::DIN', 34215);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chloraprep One-Step', 'solution', 'D08AC52', false, 0, '02160757', 'FreeDiams::CA_HCDPD::DIN', 34222);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Endbac 128 Disinfectant Cleaner Concentrate', 'liquid', 'V07AV', false, 0, '02161575', 'FreeDiams::CA_HCDPD::DIN', 34234);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diphenhydramine Hydrochloride Elixir U.S.P.', 'elixir', 'R06AA02', false, 0, '02164574', 'FreeDiams::CA_HCDPD::DIN', 34247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benzagel 5 Gel', 'gel', 'D10AE01', false, 0, '02162113', 'FreeDiams::CA_HCDPD::DIN', 34258);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dycholium Tablet 300mg', 'tablet', 'A05AA', false, 0, '02162148', 'FreeDiams::CA_HCDPD::DIN', 34260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidodan Jelly 2%(Single Use Syringe)', 'jelly', 'D04AB01', false, 0, '02167603', 'FreeDiams::CA_HCDPD::DIN', 34463);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Birex Se', 'solution', 'V07AV', false, 0, '02168723', 'FreeDiams::CA_HCDPD::DIN', 34513);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Loxapac Im Injection', 'liquid', 'N05AH01', false, 0, '02169991', 'FreeDiams::CA_HCDPD::DIN', 34560);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Virazole', 'kit', 'J05AB04', false, 0, '02170140', 'FreeDiams::CA_HCDPD::DIN', 34574);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diphenhydramine Hcl Children''S Liquid', 'syrup', 'R06AA02', false, 0, '02171279', 'FreeDiams::CA_HCDPD::DIN', 34604);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Calmylin Pse With Codeine', 'liquid', 'R05FA02', false, 0, '02172917', 'FreeDiams::CA_HCDPD::DIN', 34650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minocin', 'capsule', 'J01AA08', false, 0, '02173506', 'FreeDiams::CA_HCDPD::DIN', 34671);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minocin', 'capsule', 'J01AA08', false, 0, '02173514', 'FreeDiams::CA_HCDPD::DIN', 34672);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aller-Aide Plus  - (Caplet 50mg)', 'tablet', 'R06AA02', false, 0, '02176580', 'FreeDiams::CA_HCDPD::DIN', 34825);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benzoinspray - Aer 25%', 'aerosol', 'D08AX', false, 0, '02177447', 'FreeDiams::CA_HCDPD::DIN', 34874);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12272', 'solution', 'B05ZA', false, 0, '02178125', 'FreeDiams::CA_HCDPD::DIN', 34878);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12273', 'solution', 'B05ZA', false, 0, '02178133', 'FreeDiams::CA_HCDPD::DIN', 34879);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate D12316', 'solution', 'B05ZA', false, 0, '02178168', 'FreeDiams::CA_HCDPD::DIN', 34881);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluorets  - Stp Oph 1mg', 'strip', 'S01JA01', false, 0, '02179539', 'FreeDiams::CA_HCDPD::DIN', 34944);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Sol Hc Ointment', 'ointment', 'C05AA01', false, 0, '02179547', 'FreeDiams::CA_HCDPD::DIN', 34945);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol No.1 Forte Caplets', 'tablet', 'N02BE51', false, 0, '02181088', 'FreeDiams::CA_HCDPD::DIN', 35047);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cotazym Ecs 4', 'capsule', 'A09AA02', false, 0, '02181215', 'FreeDiams::CA_HCDPD::DIN', 35065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Acetate-Omega', 'liquid', 'B05XA08', false, 0, '02181746', 'FreeDiams::CA_HCDPD::DIN', 35083);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imodium - Caplet 2mg', 'tablet', 'A07DA03', false, 0, '02183862', 'FreeDiams::CA_HCDPD::DIN', 35201);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Motrin Ib Caplet - 200mg', 'tablet', 'M01AE01', false, 0, '02187124', 'FreeDiams::CA_HCDPD::DIN', 35329);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorphone', 'tablet', 'N02AA03', false, 0, '02192101', 'FreeDiams::CA_HCDPD::DIN', 35655);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorphone', 'tablet', 'N02AA03', false, 0, '02192144', 'FreeDiams::CA_HCDPD::DIN', 35658);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyclocort', 'ointment', 'D07AC11', false, 0, '02192268', 'FreeDiams::CA_HCDPD::DIN', 35663);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyclocort', 'lotion', 'D07AC11', false, 0, '02192276', 'FreeDiams::CA_HCDPD::DIN', 35664);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyclocort', 'cream', 'D07AC11', false, 0, '02192284', 'FreeDiams::CA_HCDPD::DIN', 35665);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Thiamiject Injection  - Liq Im Iv 100mg/Ml', 'liquid', 'A11DA01', false, 0, '02193221', 'FreeDiams::CA_HCDPD::DIN', 35700);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aristocort R', 'ointment', 'D07AB09', false, 0, '02194031', 'FreeDiams::CA_HCDPD::DIN', 35783);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aristocort R', 'cream', 'D07AB09', false, 0, '02194058', 'FreeDiams::CA_HCDPD::DIN', 35784);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aristocort C', 'cream', 'D07AB09', false, 0, '02194066', 'FreeDiams::CA_HCDPD::DIN', 35785);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aristospan', 'suspension', 'H02AB08', false, 0, '02194155', 'FreeDiams::CA_HCDPD::DIN', 35794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Nystatin', 'cream', 'G01AA01', false, 0, '02194163', 'FreeDiams::CA_HCDPD::DIN', 35795);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Nystatin', 'tablet', 'A07AA02', false, 0, '02194198', 'FreeDiams::CA_HCDPD::DIN', 35797);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Nystatin', 'drops', 'A07AA02', false, 0, '02194201', 'FreeDiams::CA_HCDPD::DIN', 35798);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Nystatin', 'ointment', 'D01AA01', false, 0, '02194228', 'FreeDiams::CA_HCDPD::DIN', 35799);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Nystatin', 'cream', 'D01AA01', false, 0, '02194236', 'FreeDiams::CA_HCDPD::DIN', 35800);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neo Citran Extra Strength For Coughs, Colds, And Flu', 'kit', 'N02BE51', false, 0, '02196174', 'FreeDiams::CA_HCDPD::DIN', 35886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creon 10 Minimicrospheres', 'capsule', 'A09AA02', false, 0, '02200104', 'FreeDiams::CA_HCDPD::DIN', 36179);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cough Syrup Dm - Decongestant - Expectorant Extra Strength', 'syrup', 'R05FA02', false, 0, '02200708', 'FreeDiams::CA_HCDPD::DIN', 36232);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balminil Dm + Expectorant', 'syrup', 'R05FA02', false, 0, '02201712', 'FreeDiams::CA_HCDPD::DIN', 36293);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rivasa 80mg Croquable - Tab', 'tablet (chewable)', 'N02BA01', false, 0, '02202352', 'FreeDiams::CA_HCDPD::DIN', 36346);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rivasa Fc', 'tablet', 'N02BA01', false, 0, '02202360', 'FreeDiams::CA_HCDPD::DIN', 36347);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sporicidin Brand Disinfectant Towelettes', 'wipe', 'V07AV', false, 0, '02203294', 'FreeDiams::CA_HCDPD::DIN', 36396);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sporicidin Brand Disinfectant Solution/Spray', 'solution', 'V07AV', false, 0, '02203316', 'FreeDiams::CA_HCDPD::DIN', 36398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultrase - Ecc', 'capsule (enteric-coated)', 'A09AA02', false, 0, '02203324', 'FreeDiams::CA_HCDPD::DIN', 36399);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mineral Oil, Light Sterile, Omega Std.- 100%', 'liquid', 'D02AC', false, 0, '02203375', 'FreeDiams::CA_HCDPD::DIN', 36404);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Magnesium Sulfate In 5% Dextrose Inj(20mg/Ml)', 'solution', 'B05XA55', false, 0, '02203499', 'FreeDiams::CA_HCDPD::DIN', 36412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexamethasone-Omega', 'liquid', 'H02AB02', false, 0, '02204266', 'FreeDiams::CA_HCDPD::DIN', 36480);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexamethasone-Omega', 'liquid', 'H02AB02', false, 0, '02204274', 'FreeDiams::CA_HCDPD::DIN', 36481);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenoplus - Liq Hom', 'liquid', 'V07AV', false, 0, '02205432', 'FreeDiams::CA_HCDPD::DIN', 36549);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reliable Deterrent 128 - Liq  7.68%', 'liquid', 'V07AV', false, 0, '02208040', 'FreeDiams::CA_HCDPD::DIN', 36709);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pethidine Injection B.P.', 'solution', 'N02AB02', false, 0, '02208148', 'FreeDiams::CA_HCDPD::DIN', 36719);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sbs 40 Medicated Skin Cream', 'cream', 'D08AE55', false, 0, '02208164', 'FreeDiams::CA_HCDPD::DIN', 36721);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bioson - Liq', 'liquid', 'V07AV', false, 0, '02208709', 'FreeDiams::CA_HCDPD::DIN', 36750);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Otrivin Cold And Allergy Decongestant Nasal Spray With Moisturizers', 'spray', 'R01AA07', false, 0, '02208903', 'FreeDiams::CA_HCDPD::DIN', 36767);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Preparation H-Pe Gel', 'gel', 'C05AX03', false, 0, '02209594', 'FreeDiams::CA_HCDPD::DIN', 36788);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biotext - Liq Hos', 'liquid', 'V07AV', false, 0, '02209640', 'FreeDiams::CA_HCDPD::DIN', 36791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biovac - Liq Hos', 'liquid', 'V07AV', false, 0, '02209659', 'FreeDiams::CA_HCDPD::DIN', 36792);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Sodium 20000units In 5% Dextrose Inj', 'solution', 'B01AB51', false, 0, '02209713', 'FreeDiams::CA_HCDPD::DIN', 36794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Sodium 25000units In 5% Dextrose Inj', 'solution', 'B01AB51', false, 0, '02209721', 'FreeDiams::CA_HCDPD::DIN', 36795);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biosurf - Liq Hos', 'liquid', 'V07AV', false, 0, '02209756', 'FreeDiams::CA_HCDPD::DIN', 36797);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Egozinc-Hc', 'suppository', 'C05AA01', false, 0, '02210517', 'FreeDiams::CA_HCDPD::DIN', 36799);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate 2171', 'solution', 'B05ZA', false, 0, '02210134', 'FreeDiams::CA_HCDPD::DIN', 36814);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sleep-Aid Extra Strength - Tab  50mg', 'tablet', 'R06AA02', false, 0, '02210657', 'FreeDiams::CA_HCDPD::DIN', 36824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biomers - Liq Ins', 'liquid', 'V07AV', false, 0, '02210711', 'FreeDiams::CA_HCDPD::DIN', 36829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate 2182', 'solution', 'B05ZA', false, 0, '02210835', 'FreeDiams::CA_HCDPD::DIN', 36836);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eltroxin', 'tablet', 'H03AA01', false, 0, '02213192', 'FreeDiams::CA_HCDPD::DIN', 36945);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eltroxin', 'tablet', 'H03AA01', false, 0, '02213206', 'FreeDiams::CA_HCDPD::DIN', 36946);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eltroxin', 'tablet', 'H03AA01', false, 0, '02213214', 'FreeDiams::CA_HCDPD::DIN', 36947);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eltroxin', 'tablet', 'H03AA01', false, 0, '02213222', 'FreeDiams::CA_HCDPD::DIN', 36948);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eltroxin', 'tablet', 'H03AA01', false, 0, '02213230', 'FreeDiams::CA_HCDPD::DIN', 36949);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermovate Cream', 'cream', 'D07AD01', false, 0, '02213265', 'FreeDiams::CA_HCDPD::DIN', 36952);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermovate Ointment', 'ointment', 'D07AD01', false, 0, '02213273', 'FreeDiams::CA_HCDPD::DIN', 36953);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermovate Scalp Application', 'solution', 'D07AD01', false, 0, '02213281', 'FreeDiams::CA_HCDPD::DIN', 36954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Serevent Diskhaler Disk (50mcg/Dose)', 'powder', 'R03AC12', false, 0, '02214261', 'FreeDiams::CA_HCDPD::DIN', 36988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spectro Eczemacare Medicated Cream', 'cream', 'D07AB01', false, 0, '02214415', 'FreeDiams::CA_HCDPD::DIN', 37001);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen Usp', 'gas', 'V03AN01', false, 0, '02214768', 'FreeDiams::CA_HCDPD::DIN', 37030);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinutab N.T. Extra Strength Caplets', 'tablet', 'N02BE51', false, 0, '02215241', 'FreeDiams::CA_HCDPD::DIN', 37037);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Dm For Children - Syr 7.5mg/5ml', 'syrup', 'R05DA09', false, 0, '02215268', 'FreeDiams::CA_HCDPD::DIN', 37038);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neocitran Extra Strength Cold And Flu', 'powder', 'N02BE51', false, 0, '02215403', 'FreeDiams::CA_HCDPD::DIN', 37051);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxyfume 2002  -  Gas 10%', 'gas', 'V07AV', false, 0, '02215853', 'FreeDiams::CA_HCDPD::DIN', 37068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bion Tears  -  Liq Oph', 'drops', 'S01XA20', false, 0, '02216051', 'FreeDiams::CA_HCDPD::DIN', 37084);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluress', 'solution', 'S01JA51', false, 0, '02216728', 'FreeDiams::CA_HCDPD::DIN', 37090);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Acetaminophen Caplets', 'tablet', 'N02BE01', false, 0, '02216817', 'FreeDiams::CA_HCDPD::DIN', 37097);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Regular Strength Acetaminophen Tablets', 'tablet', 'N02BE01', false, 0, '02216833', 'FreeDiams::CA_HCDPD::DIN', 37099);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Strength Neocitran Total Flu', 'powder', 'N02BE51', false, 0, '02217147', 'FreeDiams::CA_HCDPD::DIN', 37105);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glutxact', 'liquid', 'V07AV', false, 0, '02217198', 'FreeDiams::CA_HCDPD::DIN', 37109);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gluterate', 'solution', 'V07AV', false, 0, '02217902', 'FreeDiams::CA_HCDPD::DIN', 37137);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin All-In-One Cold And Flu Extra Strength', 'tablet', 'N02BE51', false, 0, '02218186', 'FreeDiams::CA_HCDPD::DIN', 37150);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carter''S Little Pills', 'tablet', 'A06AB02', false, 0, '02219190', 'FreeDiams::CA_HCDPD::DIN', 37161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylonor - Aem Asp', 'kit', 'N01BB52', false, 0, '02218607', 'FreeDiams::CA_HCDPD::DIN', 37164);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cold Flu Relief', 'liquid', 'N02BE51', false, 0, '02218836', 'FreeDiams::CA_HCDPD::DIN', 37183);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Onguent Hémorroďdal', 'ointment', 'C05AD07', false, 0, '02218887', 'FreeDiams::CA_HCDPD::DIN', 37185);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diphenist 50mg/Ml', 'liquid', 'R06AA02', false, 0, '02219336', 'FreeDiams::CA_HCDPD::DIN', 37198);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gentamicin', 'solution', 'S01AA11', false, 0, '02219581', 'FreeDiams::CA_HCDPD::DIN', 37211);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Benztropine Solution - Liq 0.4mg/Ml', 'solution', 'N04AC01', false, 0, '02219727', 'FreeDiams::CA_HCDPD::DIN', 37223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nix Dermal Cream', 'cream', 'P03AC04', false, 0, '02219905', 'FreeDiams::CA_HCDPD::DIN', 37239);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Penicillin G Sodium For Injection, Usp', 'powder for solution', 'J01CE01', false, 0, '02220261', 'FreeDiams::CA_HCDPD::DIN', 37244);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Penicillin G Sodium For Injection, Usp', 'powder for solution', 'J01CE01', false, 0, '02220288', 'FreeDiams::CA_HCDPD::DIN', 37245);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Penicillin G Sodium For Injection, Usp', 'powder for solution', 'J01CE01', false, 0, '02220296', 'FreeDiams::CA_HCDPD::DIN', 37246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sulfacet-R', 'lotion', 'D10AB52', false, 0, '02220407', 'FreeDiams::CA_HCDPD::DIN', 37254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lubricating Nasal Gel', 'gel', 'R01AX10', false, 0, '02220806', 'FreeDiams::CA_HCDPD::DIN', 37257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Bicarbonate Usp For Hemodialysis D12276', 'powder', 'B05ZA', false, 0, '02221616', 'FreeDiams::CA_HCDPD::DIN', 37283);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proctosedyl Ointment', 'ointment', 'C05AA01', false, 0, '02223252', 'FreeDiams::CA_HCDPD::DIN', 37334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proctosedyl Suppositories', 'suppository', 'C05AA01', false, 0, '02223260', 'FreeDiams::CA_HCDPD::DIN', 37335);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vaxigrip', 'suspension', 'J07BB02', false, 0, '02223929', 'FreeDiams::CA_HCDPD::DIN', 37348);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract Standardized Mite Dp (10,000 Au/Ml)', 'liquid', 'V01AA03', false, 0, '02223937', 'FreeDiams::CA_HCDPD::DIN', 37349);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract Standardized Mite Dp (30,000 Au/Ml)', 'liquid', 'V01AA03', false, 0, '02223945', 'FreeDiams::CA_HCDPD::DIN', 37350);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract Standardized Mite Df (10,000 Au/Ml)', 'liquid', 'V01AA03', false, 0, '02223953', 'FreeDiams::CA_HCDPD::DIN', 37351);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract Standardized Mite Df (30,000 Au/Ml)', 'liquid', 'V01AA07', false, 0, '02223961', 'FreeDiams::CA_HCDPD::DIN', 37352);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract Mixture Of Standardized Mites (15,000 Au/Ml)', 'liquid', 'V01AA03', false, 0, '02223988', 'FreeDiams::CA_HCDPD::DIN', 37353);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract Mixture Of Standardized Mites (5,000 Au/Ml)', 'liquid', 'V01AA03', false, 0, '02223996', 'FreeDiams::CA_HCDPD::DIN', 37354);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diabeta', 'tablet', 'A10BB01', false, 0, '02224550', 'FreeDiams::CA_HCDPD::DIN', 37356);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diabeta', 'tablet', 'A10BB01', false, 0, '02224569', 'FreeDiams::CA_HCDPD::DIN', 37357);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cophylac Drops', 'drops', 'R05DA20', false, 0, '02224577', 'FreeDiams::CA_HCDPD::DIN', 37358);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Relefact Trh Injection 200mcg/Ml', 'liquid', 'V04CJ02', false, 0, '02224615', 'FreeDiams::CA_HCDPD::DIN', 37362);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sofracort Sterile Ear/Eye Drops', 'drops', 'S03CA01', false, 0, '02224623', 'FreeDiams::CA_HCDPD::DIN', 37363);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lasix', 'tablet', 'C03CA01', false, 0, '02224690', 'FreeDiams::CA_HCDPD::DIN', 37369);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lasix', 'tablet', 'C03CA01', false, 0, '02224704', 'FreeDiams::CA_HCDPD::DIN', 37370);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lasix Oral Solution 10mg/Ml', 'solution', 'C03CA01', false, 0, '02224720', 'FreeDiams::CA_HCDPD::DIN', 37372);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lasix Special', 'tablet', 'C03CA01', false, 0, '02224755', 'FreeDiams::CA_HCDPD::DIN', 37375);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rythmodan', 'capsule', 'C01BA03', false, 0, '02224801', 'FreeDiams::CA_HCDPD::DIN', 37379);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rythmodan', 'capsule', 'C01BA03', false, 0, '02224828', 'FreeDiams::CA_HCDPD::DIN', 37380);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soframycin Nasal Spray', 'spray', 'R01AB01', false, 0, '02224860', 'FreeDiams::CA_HCDPD::DIN', 37384);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soframycin Skin Ointment', 'ointment', 'D06AX30', false, 0, '02224879', 'FreeDiams::CA_HCDPD::DIN', 37385);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soframycin Eye Drops 0.5%', 'drops', 'S01AA07', false, 0, '02224887', 'FreeDiams::CA_HCDPD::DIN', 37386);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soframycin Sterile Eye Ointment 0.5%', 'ointment', 'S01AA07', false, 0, '02224895', 'FreeDiams::CA_HCDPD::DIN', 37387);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creme Blanchissante - Crm 2%', 'cream', 'D11AX11', false, 0, '02225603', 'FreeDiams::CA_HCDPD::DIN', 37415);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Venomil Honey Bee Venom (120 Mcg)', 'powder for solution', 'V01AA07', false, 0, '02226197', 'FreeDiams::CA_HCDPD::DIN', 37436);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Venomil Wasp Venom Protein (120mcg)', 'powder for solution', 'V01AA07', false, 0, '02226219', 'FreeDiams::CA_HCDPD::DIN', 37438);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Venomil White-Faced Hornet Venom Protein (120mcg)', 'powder for solution', 'V01AA07', false, 0, '02226235', 'FreeDiams::CA_HCDPD::DIN', 37440);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Venomil Yellow Hornet Venom Protein (120mcg)', 'powder for solution', 'V01AA07', false, 0, '02226251', 'FreeDiams::CA_HCDPD::DIN', 37442);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Venomil Yellow Jacket Venom Protein (120mcg)', 'powder for solution', 'V01AA07', false, 0, '02226286', 'FreeDiams::CA_HCDPD::DIN', 37444);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Venomil Mixed Vespid Venom Protein (360mcg)', 'powder for solution', 'V01AA07', false, 0, '02226294', 'FreeDiams::CA_HCDPD::DIN', 37445);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Proctosone', 'ointment', 'C05AA01', false, 0, '02226383', 'FreeDiams::CA_HCDPD::DIN', 37454);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Proctosone', 'suppository', 'C05AA01', false, 0, '02226391', 'FreeDiams::CA_HCDPD::DIN', 37455);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Pollens', 'liquid', 'V01AA20', false, 0, '02226928', 'FreeDiams::CA_HCDPD::DIN', 37484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Non-Pollens', 'liquid', 'V01AA20', false, 0, '02226944', 'FreeDiams::CA_HCDPD::DIN', 37486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ampicillin For Injection', 'powder for solution', 'J01CA01', false, 0, '02226995', 'FreeDiams::CA_HCDPD::DIN', 37491);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ampicillin For Injection', 'powder for solution', 'J01CA01', false, 0, '02227002', 'FreeDiams::CA_HCDPD::DIN', 37492);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ampicillin For Injection', 'powder for solution', 'J01CA01', false, 0, '02227010', 'FreeDiams::CA_HCDPD::DIN', 37493);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ampicillin For Injection', 'powder for solution', 'J01CA01', false, 0, '02227029', 'FreeDiams::CA_HCDPD::DIN', 37494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('C V Medicated Lotion Soap - Liq 0.5%', 'liquid', 'D08AE04', false, 0, '02227118', 'FreeDiams::CA_HCDPD::DIN', 37501);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artificial Tears', 'solution', 'S01XA20', false, 0, '02227908', 'FreeDiams::CA_HCDPD::DIN', 37542);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artificial Tears Plus', 'solution', 'S01XA20', false, 0, '02227916', 'FreeDiams::CA_HCDPD::DIN', 37543);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metriguard', 'liquid', 'V07AV', false, 0, '02227959', 'FreeDiams::CA_HCDPD::DIN', 37547);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte Dry Pack For Bicarbonate Dialysis', 'powder', 'B05ZA', false, 0, '02228084', 'FreeDiams::CA_HCDPD::DIN', 37559);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cholografin Meglumine Inj. - Liq Iv', 'liquid', 'V08AC04', false, 0, '02228556', 'FreeDiams::CA_HCDPD::DIN', 37569);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gastrografin - Liq Orl', 'solution', 'V08AA01', false, 0, '02228564', 'FreeDiams::CA_HCDPD::DIN', 37570);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinografin - Liq Iu', 'liquid', 'V08AA', false, 0, '02228599', 'FreeDiams::CA_HCDPD::DIN', 37573);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kinevac (Sincalide) For Injection 5mcg/Vial', 'powder for solution', 'V04CC03', false, 0, '02228602', 'FreeDiams::CA_HCDPD::DIN', 37574);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Women''S Laxative', 'tablet', 'A06AB02', false, 0, '02228696', 'FreeDiams::CA_HCDPD::DIN', 37582);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biotech-Transfer Skin Shield Barrier Lotion', 'lotion', 'D08AE04', false, 0, '02171651', 'FreeDiams::CA_HCDPD::DIN', 37625);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Microbial Cleanser', 'liquid', 'D08AE04', false, 0, '02177528', 'FreeDiams::CA_HCDPD::DIN', 37672);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Microbial Moisturizer', 'lotion', 'D08AE04', false, 0, '02177536', 'FreeDiams::CA_HCDPD::DIN', 37673);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Panoxyl Creamy Wash 4%', 'liquid', 'D10AE01', false, 0, '02188708', 'FreeDiams::CA_HCDPD::DIN', 37729);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Genie Plus - Liq', 'solution', 'V07AV', false, 0, '02190826', 'FreeDiams::CA_HCDPD::DIN', 37743);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shampoo Control - 2%', 'shampoo', 'D11AX12', false, 0, '02207389', 'FreeDiams::CA_HCDPD::DIN', 37795);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quat Rinse', 'liquid', 'V07AV', false, 0, '02207591', 'FreeDiams::CA_HCDPD::DIN', 37812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Af79 Concentrate - Liq  Hom Hos', 'liquid', 'V07AV', false, 0, '02210940', 'FreeDiams::CA_HCDPD::DIN', 37819);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Panoxyl Aquagel 2.5%', 'gel', 'D10AE01', false, 0, '02214830', 'FreeDiams::CA_HCDPD::DIN', 37835);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Panoxyl Aquagel 5%', 'gel', 'D10AE01', false, 0, '02214849', 'FreeDiams::CA_HCDPD::DIN', 37836);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Panoxyl Wash 5% - Lot', 'lotion', 'D10AE01', false, 0, '02214857', 'FreeDiams::CA_HCDPD::DIN', 37837);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Quat Germicidal Detergent', 'liquid', 'V07AV', false, 0, '02213354', 'FreeDiams::CA_HCDPD::DIN', 37840);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Perle + Antiseptic Lotion Soap / Savon Lotion Antiseptique', 'lotion', 'D08AE04', false, 0, '02215551', 'FreeDiams::CA_HCDPD::DIN', 37844);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Bac - Asp 0.5%', 'spray', 'D08AE04', false, 0, '02219433', 'FreeDiams::CA_HCDPD::DIN', 37869);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artistry Lip Colour Sheer Spf 15', 'stick', 'D02BA30', false, 0, '02221209', 'FreeDiams::CA_HCDPD::DIN', 37913);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Luxiva Preventage Firming Eye Cream Spf-15', 'cream', 'D02BA30', false, 0, '02221233', 'FreeDiams::CA_HCDPD::DIN', 37916);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ali-Flex - Liq 2.4%', 'liquid', 'V07AV', false, 0, '02227223', 'FreeDiams::CA_HCDPD::DIN', 37952);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quinine - Odan', 'tablet', 'P01BC01', false, 0, '00695432', 'FreeDiams::CA_HCDPD::DIN', 38054);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quinine - Odan', 'capsule', 'P01BC01', false, 0, '00695440', 'FreeDiams::CA_HCDPD::DIN', 38055);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quinine - Odan', 'capsule', 'P01BC01', false, 0, '00695459', 'FreeDiams::CA_HCDPD::DIN', 38056);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lactulose Syr 667mg/Ml', 'syrup', 'A06AD11', false, 0, '00703486', 'FreeDiams::CA_HCDPD::DIN', 38260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('S2', 'solution', 'R03AA01', false, 0, '00525103', 'FreeDiams::CA_HCDPD::DIN', 39484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Dimenhydrinate Syr 3mg/Ml', 'syrup', 'R06AA02', false, 0, '00757705', 'FreeDiams::CA_HCDPD::DIN', 40419);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cyproheptadine Hcl Tab 4mg', 'tablet', 'R06AX02', false, 0, '00757713', 'FreeDiams::CA_HCDPD::DIN', 40420);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Warrior', 'liquid', 'V07AV', false, 0, '00779830', 'FreeDiams::CA_HCDPD::DIN', 41219);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Detergicide Liquid', 'liquid', 'V07AV', false, 0, '00779849', 'FreeDiams::CA_HCDPD::DIN', 41220);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lemon Gard', 'liquid', 'V07AV', false, 0, '00779857', 'FreeDiams::CA_HCDPD::DIN', 41221);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vaseline Original Petroleum Jelly', 'ointment', 'D02AC', false, 0, '00365351', 'FreeDiams::CA_HCDPD::DIN', 41367);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dettol', 'liquid', 'D08AE05', false, 0, '00373435', 'FreeDiams::CA_HCDPD::DIN', 41477);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mineral Oil', 'liquid', 'A06AA01', false, 0, '00485802', 'FreeDiams::CA_HCDPD::DIN', 41536);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Calamine Lotion With Antihistamine', 'suspension', 'D04AA32', false, 0, '00538493', 'FreeDiams::CA_HCDPD::DIN', 41558);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylene Blue Solution 1%', 'liquid', 'V04CG05', false, 0, '00524476', 'FreeDiams::CA_HCDPD::DIN', 41559);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vaseline Baby Petroleum Jelly', 'ointment', 'D02AC', false, 0, '00524484', 'FreeDiams::CA_HCDPD::DIN', 41564);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tinactin Cream 10mg/Gm', 'cream', 'D01AE18', false, 0, '00576034', 'FreeDiams::CA_HCDPD::DIN', 41608);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tinactin Pwr 10mg/Gm', 'powder', 'D01AE18', false, 0, '00576042', 'FreeDiams::CA_HCDPD::DIN', 41611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tinactin Aerosol Pwr 10mg/Gm', 'aerosol', 'D01AE18', false, 0, '00576050', 'FreeDiams::CA_HCDPD::DIN', 41612);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jack & Jill Cough Syrup', 'syrup', 'R05CA10', false, 0, '00622036', 'FreeDiams::CA_HCDPD::DIN', 41646);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Otrivin Cold And Allergy Decongestant Nose Drops', 'solution', 'R01AA07', false, 0, '00650854', 'FreeDiams::CA_HCDPD::DIN', 41683);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Otrivin Cold And Allergy Decongestant Nasal Spray', 'spray', 'R01AA07', false, 0, '00653330', 'FreeDiams::CA_HCDPD::DIN', 41684);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mild Multi-Tar Plus Shampoo', 'shampoo', 'D05AA', false, 0, '00628042', 'FreeDiams::CA_HCDPD::DIN', 41695);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Huile Minerale Lourde Liq 100% Usp', 'liquid', 'A06AA01', false, 0, '00704172', 'FreeDiams::CA_HCDPD::DIN', 41698);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlor-Tripolon Tab 12mg Long Acting', 'tablet (extended-release)', 'R06AB04', false, 0, '00738964', 'FreeDiams::CA_HCDPD::DIN', 41734);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlor-Tripolon Tab 4mg', 'tablet', 'R06AB04', false, 0, '00738972', 'FreeDiams::CA_HCDPD::DIN', 41738);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Regular Strength Tylenol Sinus Caplets', 'tablet', 'N02BE51', false, 0, '00778400', 'FreeDiams::CA_HCDPD::DIN', 41753);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Petrolatum Blanc Ont Usp', 'ointment', 'D02AC', false, 0, '00790516', 'FreeDiams::CA_HCDPD::DIN', 41756);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bradosol Lozenges Regular Strength 2.4mg (Cherry, Mint, Lemon, Orange, Honey-Eucalyptus)', 'lozenge', 'R02AA12', false, 0, '00846589', 'FreeDiams::CA_HCDPD::DIN', 41796);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gas-X Regular Strength', 'tablet', 'A03AX13', false, 0, '01907875', 'FreeDiams::CA_HCDPD::DIN', 41821);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinutab N.D.Reg Strength Tab', 'tablet', 'N02BE51', false, 0, '01926055', 'FreeDiams::CA_HCDPD::DIN', 41830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinutab Regular Strength Tablets', 'tablet', 'N02BE51', false, 0, '01926004', 'FreeDiams::CA_HCDPD::DIN', 41831);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Colourless Antiseptic', 'liquid', 'D08AE05', false, 0, '01918850', 'FreeDiams::CA_HCDPD::DIN', 41864);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tempra Children''S Syrup', 'syrup', 'N02BE01', false, 0, '00884553', 'FreeDiams::CA_HCDPD::DIN', 41867);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Infant Tempra Drops', 'drops', 'N02BE01', false, 0, '00875988', 'FreeDiams::CA_HCDPD::DIN', 41869);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medi-Dan Shampoo', 'shampoo', 'D05AA', false, 0, '00888591', 'FreeDiams::CA_HCDPD::DIN', 41889);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Drixoral Decongestant Nasal Spray 0.05%', 'solution', 'R01AA05', false, 0, '00740861', 'FreeDiams::CA_HCDPD::DIN', 41903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxysept Disinfecting Solution', 'solution', 'S01XA20', false, 0, '01955489', 'FreeDiams::CA_HCDPD::DIN', 41919);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aosept Solution 3%', 'solution', 'S01XA20', false, 0, '01947389', 'FreeDiams::CA_HCDPD::DIN', 41925);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solarcaine First Aid Spray', 'aerosol', 'D04AB04', false, 0, '01918893', 'FreeDiams::CA_HCDPD::DIN', 41931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dr. Scholl''S Athlete''S Foot Spray Powder', 'kit', 'D01AE18', false, 0, '01919245', 'FreeDiams::CA_HCDPD::DIN', 41933);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Sunscreen Lotion Spf8', 'lotion', 'D02BA30', false, 0, '01931199', 'FreeDiams::CA_HCDPD::DIN', 41935);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Absorbine Jr Extra Strength Liniment', 'liquid', 'M02AX10', false, 0, '01942271', 'FreeDiams::CA_HCDPD::DIN', 41939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dristan Nasal Mist', 'spray', 'R01AB01', false, 0, '01929313', 'FreeDiams::CA_HCDPD::DIN', 41952);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Long Lasting Dristan Nasal Mist', 'spray', 'R01AA05', false, 0, '01929372', 'FreeDiams::CA_HCDPD::DIN', 41954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Drula Fade Cream Medium-Medicated', 'cream', 'D11AX11', false, 0, '01933949', 'FreeDiams::CA_HCDPD::DIN', 41955);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Drula Fade Cream Normal-Medicated', 'cream', 'D11AX11', false, 0, '01933957', 'FreeDiams::CA_HCDPD::DIN', 41956);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Drula Fade Cream Extra-Medicated', 'cream', 'D11AX11', false, 0, '01933965', 'FreeDiams::CA_HCDPD::DIN', 41957);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Long Lasting Dristan Mentholated Nasal Spray', 'spray', 'R01AA05', false, 0, '01929380', 'FreeDiams::CA_HCDPD::DIN', 41970);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Athlete''S Foot Gel 1%', 'gel', 'D01AE18', false, 0, '01918826', 'FreeDiams::CA_HCDPD::DIN', 41971);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balminil Expectorant', 'syrup', 'R05CA03', false, 0, '00608920', 'FreeDiams::CA_HCDPD::DIN', 41988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balminil Expectorant (Sucrose Free)', 'syrup', 'R05CA03', false, 0, '00609951', 'FreeDiams::CA_HCDPD::DIN', 41989);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sensitive Eyes Multi Purpose Solution', 'solution', 'S01XA20', false, 0, '01911325', 'FreeDiams::CA_HCDPD::DIN', 41994);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Visine Original', 'drops', 'S01GA02', false, 0, '01942425', 'FreeDiams::CA_HCDPD::DIN', 42015);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Denorex Medicated Shampoo With Conditioners', 'shampoo', 'D05AA', false, 0, '01942379', 'FreeDiams::CA_HCDPD::DIN', 42042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Denorex Medicated Shampoo - Regular', 'shampoo', 'D05AA', false, 0, '01931245', 'FreeDiams::CA_HCDPD::DIN', 42043);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Double Strength Children''S Tempra Syrup', 'syrup', 'N02BE01', false, 0, '00875996', 'FreeDiams::CA_HCDPD::DIN', 42066);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dristan Nd Caplets', 'tablet', 'N02BE51', false, 0, '01929402', 'FreeDiams::CA_HCDPD::DIN', 42082);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Denorex Medicated Shampoo Spring Fresh', 'shampoo', 'D05AA', false, 0, '01931237', 'FreeDiams::CA_HCDPD::DIN', 42099);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Absorbine Jr Liniment', 'liquid', 'M02AX10', false, 0, '01942301', 'FreeDiams::CA_HCDPD::DIN', 42113);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pediatrix', 'solution', 'N02BE01', false, 0, '02027798', 'FreeDiams::CA_HCDPD::DIN', 42135);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pediatrix Drops', 'drops', 'N02BE01', false, 0, '02027801', 'FreeDiams::CA_HCDPD::DIN', 42136);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polytopic', 'ointment', 'D06AX05', false, 0, '01942921', 'FreeDiams::CA_HCDPD::DIN', 42145);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Blistex Lip Balm', 'ointment', 'D02BA30', false, 0, '02013878', 'FreeDiams::CA_HCDPD::DIN', 42159);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Madelon', 'tablet', 'N02BA51', false, 0, '00800511', 'FreeDiams::CA_HCDPD::DIN', 42161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Absorbine Power Gel', 'gel', 'M02AX10', false, 0, '01999524', 'FreeDiams::CA_HCDPD::DIN', 42186);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Boston Advance Comfort Formula Conditioning Solution', 'solution', 'S01XA20', false, 0, '02019868', 'FreeDiams::CA_HCDPD::DIN', 42237);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solo-Care', 'solution', 'S01XA20', false, 0, '02076225', 'FreeDiams::CA_HCDPD::DIN', 42295);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Blistex Ultra Lip Balm', 'ointment', 'D02BA30', false, 0, '02051524', 'FreeDiams::CA_HCDPD::DIN', 42310);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Correctol Stool Softener 100mg/Cap', 'capsule', 'A06AA02', false, 0, '02063549', 'FreeDiams::CA_HCDPD::DIN', 42328);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun-Shades Lip Balm Spf 15 - Vanilla Stk', 'stick', 'D02BA30', false, 0, '02045672', 'FreeDiams::CA_HCDPD::DIN', 42329);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun-Shades Lip Balm Spf 15 - Pina Colada Stk', 'stick', 'D02BA30', false, 0, '02045613', 'FreeDiams::CA_HCDPD::DIN', 42332);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Conditioner Lip Balm', 'ointment', 'D02AX', false, 0, '01977717', 'FreeDiams::CA_HCDPD::DIN', 42334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Infants'' Tylenol Acetaminophen Sus Dps', 'kit', 'N02BE01', false, 0, '02046059', 'FreeDiams::CA_HCDPD::DIN', 42341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Aspercreme Creme Rub 15%', 'cream', 'M02AC', false, 0, '02074702', 'FreeDiams::CA_HCDPD::DIN', 42373);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aspercreme Creme Rub 10%', 'cream', 'M02AC', false, 0, '02074710', 'FreeDiams::CA_HCDPD::DIN', 42374);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marcelle Essentials Protection + Spf 15 Fps Oil-Free Multi-Defense Lotion/ Fluide Multi-Défense Sans Huile', 'lotion', 'D02BA30', false, 0, '02093006', 'FreeDiams::CA_HCDPD::DIN', 42376);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marcelle Essentials Protection + Spf 15 Fps Multi-Defense Cream/ Crčme Multi-Défense', 'cream', 'D02BA30', false, 0, '02093014', 'FreeDiams::CA_HCDPD::DIN', 42377);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dristan Tablets', 'tablet', 'N02BE51', false, 0, '02092964', 'FreeDiams::CA_HCDPD::DIN', 42382);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Tylenol Acetaminophen Sus Liq', 'suspension', 'N02BE01', false, 0, '02046040', 'FreeDiams::CA_HCDPD::DIN', 42388);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pepto Bismol Liquid 17.6mg/Ml', 'liquid', 'A07BB', false, 0, '02097079', 'FreeDiams::CA_HCDPD::DIN', 42395);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cepacol Antiseptic Lozenges', 'lozenge', 'R02AA06', false, 0, '02099357', 'FreeDiams::CA_HCDPD::DIN', 42462);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cepacol Mouthwash/Gargle', 'mouthwash/gargle', 'R02AA06', false, 0, '02099373', 'FreeDiams::CA_HCDPD::DIN', 42479);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oral-B Anti-Bacterial With Fluoride', 'mouthwash/gargle', 'A01AA51', false, 0, '02128810', 'FreeDiams::CA_HCDPD::DIN', 42480);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oral-B Antibacterial With Fluoride Alc.Free', 'mouthwash/gargle', 'A01AA51', false, 0, '02130823', 'FreeDiams::CA_HCDPD::DIN', 42483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Orabase Paste', 'paste', 'A01AD11', false, 0, '02035286', 'FreeDiams::CA_HCDPD::DIN', 42486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Sinex Decongestant Nasal Spray 0.05%', 'liquid', 'R01AA05', false, 0, '02008149', 'FreeDiams::CA_HCDPD::DIN', 42497);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Absorbine Jr Antifungal Liq', 'liquid', 'D01AE20', false, 0, '01974386', 'FreeDiams::CA_HCDPD::DIN', 42528);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Chewable Acetaminophen Tablets 80mg', 'tablet (chewable)', 'N02BE01', false, 0, '02129957', 'FreeDiams::CA_HCDPD::DIN', 42569);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Chest Congestion Extra Strength', 'syrup', 'R05CA03', false, 0, '02161494', 'FreeDiams::CA_HCDPD::DIN', 42606);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medicated Blistex Dct Lip Balm', 'ointment', 'D02BA30', false, 0, '02157292', 'FreeDiams::CA_HCDPD::DIN', 42607);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exorex Gel 1 - Eml-1%', 'emulsion', 'D05AA', false, 0, '02184672', 'FreeDiams::CA_HCDPD::DIN', 42609);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exorex Gel 2 - Eml-2%', 'emulsion', 'D05AA', false, 0, '02184680', 'FreeDiams::CA_HCDPD::DIN', 42610);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Visine Workplace', 'drops', 'S01GA04', false, 0, '02151014', 'FreeDiams::CA_HCDPD::DIN', 42643);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alka-Seltzer-Evt', 'tablet (effervescent)', 'N02BA51', false, 0, '02152746', 'FreeDiams::CA_HCDPD::DIN', 42652);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Visine Allergy', 'drops', 'S01GA52', false, 0, '02144093', 'FreeDiams::CA_HCDPD::DIN', 42685);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Myoflex Regular Cream - 10%', 'cream', 'M02AC', false, 0, '02152827', 'FreeDiams::CA_HCDPD::DIN', 42699);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pepto Bismol Caplet - 262mg/Caplet', 'tablet', 'A07BB', false, 0, '02177994', 'FreeDiams::CA_HCDPD::DIN', 42736);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluorouracil Injection Usp', 'solution', 'L01BC02', false, 0, '02182742', 'FreeDiams::CA_HCDPD::DIN', 42841);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methotrexate Tablets, Usp 10 Mg', 'tablet', 'L01BA01', false, 0, '02182750', 'FreeDiams::CA_HCDPD::DIN', 42842);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methotrexate Injection, Usp', 'solution', 'L01BA01', false, 0, '02182777', 'FreeDiams::CA_HCDPD::DIN', 42844);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kadian Capsules', 'capsule (sustained-release)', 'N02AA01', false, 0, '02184435', 'FreeDiams::CA_HCDPD::DIN', 42846);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kadian Capsules', 'capsule (sustained-release)', 'N02AA01', false, 0, '02184443', 'FreeDiams::CA_HCDPD::DIN', 42847);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kadian Capsules', 'capsule (sustained-release)', 'N02AA01', false, 0, '02184451', 'FreeDiams::CA_HCDPD::DIN', 42848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Gemfibrozil', 'capsule', 'C10AB04', false, 0, '02185407', 'FreeDiams::CA_HCDPD::DIN', 42867);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Nizatidine 150mg Capsules', 'capsule', 'A02BA04', false, 0, '02185814', 'FreeDiams::CA_HCDPD::DIN', 42870);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cefaclor', 'capsule', 'J01DC04', false, 0, '02185830', 'FreeDiams::CA_HCDPD::DIN', 42872);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cefaclor', 'capsule', 'J01DC04', false, 0, '02185849', 'FreeDiams::CA_HCDPD::DIN', 42873);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cefaclor 125 - Pws 25mg/Ml', 'powder for solution', 'J01DC04', false, 0, '02185857', 'FreeDiams::CA_HCDPD::DIN', 42874);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cefaclor 250 - Pws 50mg/Ml', 'powder for solution', 'J01DC04', false, 0, '02185865', 'FreeDiams::CA_HCDPD::DIN', 42875);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cefaclor 375 B.I.D.', 'powder for solution', 'J01DC04', false, 0, '02185873', 'FreeDiams::CA_HCDPD::DIN', 42876);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pepcid Ac (Film-Coated Tab) - 10mg', 'tablet', 'A02BA03', false, 0, '02185938', 'FreeDiams::CA_HCDPD::DIN', 42879);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trasylol', 'solution', 'B02AB01', false, 0, '02186845', 'FreeDiams::CA_HCDPD::DIN', 42886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Brevicon 0.5/35 Tablets (28-Day Pack)', 'tablet', 'G03AA05', false, 0, '02187094', 'FreeDiams::CA_HCDPD::DIN', 42888);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synphasic 21 Tablets', 'tablet', 'G03AB04', false, 0, '02187108', 'FreeDiams::CA_HCDPD::DIN', 42889);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synphasic 28 Tablets', 'tablet', 'G03AB04', false, 0, '02187116', 'FreeDiams::CA_HCDPD::DIN', 42890);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synarel', 'metered-dose (aerosol)', 'H01CA02', false, 0, '02188783', 'FreeDiams::CA_HCDPD::DIN', 42902);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Brevibloc Injection 10mg/Ml', 'liquid', 'C07AB09', false, 0, '02188880', 'FreeDiams::CA_HCDPD::DIN', 42910);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Brevicon 1/35 Tablets (21-Day Pack)', 'tablet', 'G03AA05', false, 0, '02189054', 'FreeDiams::CA_HCDPD::DIN', 42921);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Brevicon 1/35 Tablets (28-Day Pack)', 'tablet', 'G03AA05', false, 0, '02189062', 'FreeDiams::CA_HCDPD::DIN', 42922);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Plasbumin-5 - Liq Iv 50mg/Ml', 'solution', 'B05AA01', false, 0, '02189100', 'FreeDiams::CA_HCDPD::DIN', 42926);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Plasbumin-25 - Liq Iv 250mg/Ml', 'solution', 'B05AA01', false, 0, '02189119', 'FreeDiams::CA_HCDPD::DIN', 42927);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Thrombate Iii', 'powder for solution', 'B01AB02', false, 0, '02189143', 'FreeDiams::CA_HCDPD::DIN', 42930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rejuva-A', 'cream', 'D10AD01', false, 0, '02192640', 'FreeDiams::CA_HCDPD::DIN', 42932);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diarr-Eze - Liq Orl 0.2mg/Ml', 'solution', 'A07DA03', false, 0, '02192667', 'FreeDiams::CA_HCDPD::DIN', 42934);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doxorubicin Hydrochloride For Injection Usp', 'powder for solution', 'L01DB01', false, 0, '02194457', 'FreeDiams::CA_HCDPD::DIN', 42943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doxorubicin Hydrochloride For Injection Usp', 'powder for solution', 'L01DB01', false, 0, '02194465', 'FreeDiams::CA_HCDPD::DIN', 42944);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doxorubicin Hydrochloride For Injection Usp', 'powder for solution', 'L01DB01', false, 0, '02194473', 'FreeDiams::CA_HCDPD::DIN', 42945);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoclopramide Hydrochloride Injection Hs', 'liquid', 'A03FA01', false, 0, '02197480', 'FreeDiams::CA_HCDPD::DIN', 42950);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Select 1/35 (21-Day)', 'tablet', 'G03AA05', false, 0, '02197502', 'FreeDiams::CA_HCDPD::DIN', 42952);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitoman', 'tablet', 'N07XX06', false, 0, '02199270', 'FreeDiams::CA_HCDPD::DIN', 42959);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Select 1/35 (28-Day)', 'tablet', 'G03AA05', false, 0, '02199297', 'FreeDiams::CA_HCDPD::DIN', 42960);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ciloxan 0.3% - Ont', 'ointment', 'S01AX13', false, 0, '02200864', 'FreeDiams::CA_HCDPD::DIN', 42964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Nifedipine-Pa', 'tablet (extended-release)', 'C08CA05', false, 0, '02200937', 'FreeDiams::CA_HCDPD::DIN', 42967);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Feiba Nf', 'kit', 'B02BD03', false, 0, '02202581', 'FreeDiams::CA_HCDPD::DIN', 42981);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Acebutolol', 'tablet', 'C07AB04', false, 0, '02204517', 'FreeDiams::CA_HCDPD::DIN', 42996);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Acebutolol', 'tablet', 'C07AB04', false, 0, '02204525', 'FreeDiams::CA_HCDPD::DIN', 42997);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Acebutolol', 'tablet', 'C07AB04', false, 0, '02204533', 'FreeDiams::CA_HCDPD::DIN', 42998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prolastin-C', 'powder for solution', 'B02AB02', false, 0, '02204606', 'FreeDiams::CA_HCDPD::DIN', 43004);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexiron - Liq Im Iv 50mg/Ml', 'liquid', 'B03AC06', false, 0, '02205963', 'FreeDiams::CA_HCDPD::DIN', 43006);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Immunine Vh', 'powder for solution', 'B02BD04', false, 0, '02206021', 'FreeDiams::CA_HCDPD::DIN', 43011);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Acyclovir - Tab 200mg', 'tablet', 'J05AB01', false, 0, '02207621', 'FreeDiams::CA_HCDPD::DIN', 43018);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Acyclovir - Tab 400mg', 'tablet', 'J05AB01', false, 0, '02207648', 'FreeDiams::CA_HCDPD::DIN', 43019);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Acyclovir - Tab 800mg', 'tablet', 'J05AB01', false, 0, '02207656', 'FreeDiams::CA_HCDPD::DIN', 43020);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Periogard - Liq Orl Rinse 0.12%', 'liquid', 'A01AB03', false, 0, '02207796', 'FreeDiams::CA_HCDPD::DIN', 43029);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Probeta - Liq Oph', 'liquid', 'S01ED53', false, 0, '02209071', 'FreeDiams::CA_HCDPD::DIN', 43034);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dobutamine Hydrochloride Injection', 'solution', 'C01CA07', false, 0, '02210401', 'FreeDiams::CA_HCDPD::DIN', 43041);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Desipramine - Tab  100mg', 'tablet', 'N06AA01', false, 0, '02211971', 'FreeDiams::CA_HCDPD::DIN', 43060);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zithromax - Tab  250mg', 'tablet', 'J01FA10', false, 0, '02212021', 'FreeDiams::CA_HCDPD::DIN', 43063);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Nifedipine-Pa - Prolonged Action Tab', 'tablet (extended-release)', 'C08CA05', false, 0, '02212102', 'FreeDiams::CA_HCDPD::DIN', 43071);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imitrex Df - Tab 50mg', 'tablet', 'N02CC01', false, 0, '02212153', 'FreeDiams::CA_HCDPD::DIN', 43076);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imitrex Df - Tab 100mg', 'tablet', 'N02CC01', false, 0, '02212161', 'FreeDiams::CA_HCDPD::DIN', 43077);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imitrex Injection 12mg/Ml', 'liquid', 'N02CC01', false, 0, '02212188', 'FreeDiams::CA_HCDPD::DIN', 43078);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fortaz - Inj 1g/Vial', 'powder for solution', 'J01DD02', false, 0, '02212218', 'FreeDiams::CA_HCDPD::DIN', 43080);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fortaz - Inj 2g/Vial', 'powder for solution', 'J01DD02', false, 0, '02212226', 'FreeDiams::CA_HCDPD::DIN', 43081);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fortaz - Inj 6g/Vial', 'powder for solution', 'J01DD02', false, 0, '02212234', 'FreeDiams::CA_HCDPD::DIN', 43082);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftin - Tab 250mg', 'tablet', 'J01DC02', false, 0, '02212277', 'FreeDiams::CA_HCDPD::DIN', 43086);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftin - Tab 500mg', 'tablet', 'J01DC02', false, 0, '02212285', 'FreeDiams::CA_HCDPD::DIN', 43087);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftin - Pws 125mg/5ml', 'powder for solution', 'J01DC02', false, 0, '02212307', 'FreeDiams::CA_HCDPD::DIN', 43089);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zantac', 'tablet', 'A02BA02', false, 0, '02212331', 'FreeDiams::CA_HCDPD::DIN', 43092);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zantac', 'tablet', 'A02BA02', false, 0, '02212358', 'FreeDiams::CA_HCDPD::DIN', 43093);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zantac', 'solution', 'A02BA02', false, 0, '02212366', 'FreeDiams::CA_HCDPD::DIN', 43094);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zantac', 'solution', 'A02BA02', false, 0, '02212374', 'FreeDiams::CA_HCDPD::DIN', 43095);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ventolin Nebules P.F. - 2.5mg/2.5ml', 'solution', 'R03AC02', false, 0, '02213419', 'FreeDiams::CA_HCDPD::DIN', 43100);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ventolin Nebules P.F. - 5mg/2.5ml', 'solution', 'R03AC02', false, 0, '02213427', 'FreeDiams::CA_HCDPD::DIN', 43101);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ventolin I.V. Infusion Solution 5.0mg Salbutamol In 5ml (1000mcg/Ml)', 'solution', 'R03CC02', false, 0, '02213451', 'FreeDiams::CA_HCDPD::DIN', 43104);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ventolin Respirator Solution', 'solution', 'R03AC02', false, 0, '02213486', 'FreeDiams::CA_HCDPD::DIN', 43108);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zofran', 'tablet', 'A04AA01', false, 0, '02213567', 'FreeDiams::CA_HCDPD::DIN', 43116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zofran', 'tablet', 'A04AA01', false, 0, '02213575', 'FreeDiams::CA_HCDPD::DIN', 43117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flonase - Aem-Sus Nas  50mcg/Md', 'metered-dose pump', 'R01AD08', false, 0, '02213672', 'FreeDiams::CA_HCDPD::DIN', 43126);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zofran', 'liquid', 'A04AA01', false, 0, '02213745', 'FreeDiams::CA_HCDPD::DIN', 43137);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Revia', 'tablet', 'N07BB04', false, 0, '02213826', 'FreeDiams::CA_HCDPD::DIN', 43143);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Saizen 10iu  -  Kit', 'powder for solution', 'H01AC01', false, 0, '02215136', 'FreeDiams::CA_HCDPD::DIN', 43151);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caverject Sterile Powder - Pws 23.2mcg/Vial', 'powder for solution', 'G04BE01', false, 0, '02215187', 'FreeDiams::CA_HCDPD::DIN', 43155);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lo-Femenal 21 Tablets', 'tablet', 'G03AA06', false, 0, '02215640', 'FreeDiams::CA_HCDPD::DIN', 43160);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imovane - Tab 5mg', 'tablet', 'N05CF01', false, 0, '02216167', 'FreeDiams::CA_HCDPD::DIN', 43171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intralipid 30%', 'emulsion', 'B05BA02', false, 0, '02216175', 'FreeDiams::CA_HCDPD::DIN', 43172);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nutropin - Kit  Pws(10mg) & Liq(10ml) Im Sc', 'kit', 'H01AC01', false, 0, '02216191', 'FreeDiams::CA_HCDPD::DIN', 43174);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Clobetasol Scalp Application', 'lotion', 'D07AD01', false, 0, '02216213', 'FreeDiams::CA_HCDPD::DIN', 43175);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Ipratropium Sterinebs', 'solution', 'R03BB01', false, 0, '02216221', 'FreeDiams::CA_HCDPD::DIN', 43176);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Salagen Tablets', 'tablet', 'N07AX01', false, 0, '02216345', 'FreeDiams::CA_HCDPD::DIN', 43182);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Salbutamol Respirator Solution-1mg/Ml', 'solution', 'R03AC02', false, 0, '02216949', 'FreeDiams::CA_HCDPD::DIN', 43194);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reopro', 'solution', 'B01AC13', false, 0, '02216973', 'FreeDiams::CA_HCDPD::DIN', 43196);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract, Standardardized Mite, D. Farinae', 'liquid', 'V01AA07', false, 0, '02217082', 'FreeDiams::CA_HCDPD::DIN', 43205);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract, Standardized Mite, D.Pteronyssinus', 'liquid', 'V01AA07', false, 0, '02217104', 'FreeDiams::CA_HCDPD::DIN', 43207);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Valproic', 'capsule', 'N03AG01', false, 0, '02217414', 'FreeDiams::CA_HCDPD::DIN', 43211);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mepron', 'suspension', 'P01AX06', false, 0, '02217422', 'FreeDiams::CA_HCDPD::DIN', 43212);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Winrho Sdf', 'kit', 'J06BB01', false, 0, '02217430', 'FreeDiams::CA_HCDPD::DIN', 43216);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Winrho Sdf', 'kit', 'J06BB01', false, 0, '02217449', 'FreeDiams::CA_HCDPD::DIN', 43217);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Standardized Cat Hair Ap', 'solution', 'V01AA11', false, 0, '02217457', 'FreeDiams::CA_HCDPD::DIN', 43218);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Standardized Cat Pelt Ap', 'solution', 'V01AA11', false, 0, '02217465', 'FreeDiams::CA_HCDPD::DIN', 43219);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lisinopril Tablet 5 Mg', 'tablet', 'C09AA03', false, 0, '02217481', 'FreeDiams::CA_HCDPD::DIN', 43221);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lisinopril Tablet 10 Mg', 'tablet', 'C09AA03', false, 0, '02217503', 'FreeDiams::CA_HCDPD::DIN', 43222);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lisinopril Tablet 20 Mg', 'tablet', 'C09AA03', false, 0, '02217511', 'FreeDiams::CA_HCDPD::DIN', 43223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lisinopril Tablet 40 Mg', 'tablet', 'C09AA03', false, 0, '02217538', 'FreeDiams::CA_HCDPD::DIN', 43224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Ketotifen Syrup - 1mg/5ml', 'syrup', 'R06AX17', false, 0, '02218305', 'FreeDiams::CA_HCDPD::DIN', 43232);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Zopiclone - Tab 7.5mg', 'tablet', 'N05CF01', false, 0, '02218313', 'FreeDiams::CA_HCDPD::DIN', 43233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Valproic - Ecc 500mg', 'capsule (enteric-coated)', 'N03AG01', false, 0, '02218321', 'FreeDiams::CA_HCDPD::DIN', 43234);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Terazosin - Tab 1mg', 'tablet', 'G04CA03', false, 0, '02218941', 'FreeDiams::CA_HCDPD::DIN', 43244);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Terazosin - Tab 2mg', 'tablet', 'G04CA03', false, 0, '02218968', 'FreeDiams::CA_HCDPD::DIN', 43245);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Terazosin - Tab 5mg', 'tablet', 'G04CA03', false, 0, '02218976', 'FreeDiams::CA_HCDPD::DIN', 43246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Terazosin - Tab 10mg', 'tablet', 'G04CA03', false, 0, '02218984', 'FreeDiams::CA_HCDPD::DIN', 43247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Fluvoxamine', 'tablet', 'N06AB08', false, 0, '02218453', 'FreeDiams::CA_HCDPD::DIN', 43250);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Fluvoxamine', 'tablet', 'N06AB08', false, 0, '02218461', 'FreeDiams::CA_HCDPD::DIN', 43251);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Merrem Pws Iv 500 Mg/Vial', 'powder for solution', 'J01DH02', false, 0, '02218488', 'FreeDiams::CA_HCDPD::DIN', 43253);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Merrem Pws Iv 1 G/Vial', 'powder for solution', 'J01DH02', false, 0, '02218496', 'FreeDiams::CA_HCDPD::DIN', 43254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxybutyn - 5mg', 'tablet', 'G04BD04', false, 0, '02220059', 'FreeDiams::CA_HCDPD::DIN', 43268);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hymenoptera Venom Product - Honey Bee Venom (550 Mcg)', 'powder for solution', 'V01AA07', false, 0, '02220075', 'FreeDiams::CA_HCDPD::DIN', 43270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Relenza', 'powder', 'J05AH01', false, 0, '02240863', 'FreeDiams::CA_HCDPD::DIN', 64454);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hymenoptera Venom Products-Yellow Hornet Venom Protein (550 Mcg)', 'powder for solution', 'V01AA07', false, 0, '02220083', 'FreeDiams::CA_HCDPD::DIN', 43271);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hymenoptera Venom Product-Wasp Venom Protein (550 Mcg)', 'powder for solution', 'V01AA07', false, 0, '02220091', 'FreeDiams::CA_HCDPD::DIN', 43272);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hymenoptera Venom Product-White-Faced Hornet Venom Protein (550 Mcg)', 'powder for solution', 'V01AA07', false, 0, '02220105', 'FreeDiams::CA_HCDPD::DIN', 43273);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hymenoptera Venom Product - Yellow Jacket Venom Protein (550 Mcg)', 'powder for solution', 'V01AA07', false, 0, '02220113', 'FreeDiams::CA_HCDPD::DIN', 43274);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Nizatidine', 'capsule', 'A02BA04', false, 0, '02220156', 'FreeDiams::CA_HCDPD::DIN', 43277);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Nizatidine', 'capsule', 'A02BA04', false, 0, '02220164', 'FreeDiams::CA_HCDPD::DIN', 43278);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lovastatin - Tab 20mg', 'tablet', 'C10AA02', false, 0, '02220172', 'FreeDiams::CA_HCDPD::DIN', 43279);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lovastatin - Tab 40mg', 'tablet', 'C10AA02', false, 0, '02220180', 'FreeDiams::CA_HCDPD::DIN', 43280);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bromazepam-3 - Tab 3mg', 'tablet', 'N05BA08', false, 0, '02220520', 'FreeDiams::CA_HCDPD::DIN', 43282);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bromazepam-6 - Tab 6mg', 'tablet', 'N05BA08', false, 0, '02220539', 'FreeDiams::CA_HCDPD::DIN', 43283);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxybutynine-5  -  Tab 5mg', 'tablet', 'G04BD04', false, 0, '02220636', 'FreeDiams::CA_HCDPD::DIN', 43291);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyclobenzaprine-10  -  Tab 10mg', 'tablet', 'M03BX08', false, 0, '02220644', 'FreeDiams::CA_HCDPD::DIN', 43292);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Infufer', 'liquid', 'B03AC01', false, 0, '02221780', 'FreeDiams::CA_HCDPD::DIN', 43298);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Medroxyprogesterone', 'tablet', 'G03DA02', false, 0, '02221284', 'FreeDiams::CA_HCDPD::DIN', 43299);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Medroxyprogesterone', 'tablet', 'G03DA02', false, 0, '02221292', 'FreeDiams::CA_HCDPD::DIN', 43300);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Medroxyprogesterone', 'tablet', 'G03DA02', false, 0, '02221306', 'FreeDiams::CA_HCDPD::DIN', 43301);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hymenoptera Venom Product-Mixed Vespid Venom Protein (1650 Mcg)', 'powder for solution', 'V01AA07', false, 0, '02221314', 'FreeDiams::CA_HCDPD::DIN', 43302);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ketotifen - Syr 1mg/5ml', 'syrup', 'R06AX17', false, 0, '02221330', 'FreeDiams::CA_HCDPD::DIN', 43304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Frisium Tablet 10mg', 'tablet', 'N05BA09', false, 0, '02221799', 'FreeDiams::CA_HCDPD::DIN', 43305);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Loprox Cream', 'cream', 'D01AE14', false, 0, '02221802', 'FreeDiams::CA_HCDPD::DIN', 43306);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Loprox Lotion', 'lotion', 'D01AE14', false, 0, '02221810', 'FreeDiams::CA_HCDPD::DIN', 43307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Altace', 'capsule', 'C09AA05', false, 0, '02221829', 'FreeDiams::CA_HCDPD::DIN', 43308);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Altace', 'capsule', 'C09AA05', false, 0, '02221837', 'FreeDiams::CA_HCDPD::DIN', 43309);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Altace', 'capsule', 'C09AA05', false, 0, '02221845', 'FreeDiams::CA_HCDPD::DIN', 43310);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Altace', 'capsule', 'C09AA05', false, 0, '02221853', 'FreeDiams::CA_HCDPD::DIN', 43311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anandron', 'tablet', 'L02BB02', false, 0, '02221861', 'FreeDiams::CA_HCDPD::DIN', 43312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topicort', 'cream', 'D07AC03', false, 0, '02221896', 'FreeDiams::CA_HCDPD::DIN', 43314);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topicort Mild', 'cream', 'D07AC03', false, 0, '02221918', 'FreeDiams::CA_HCDPD::DIN', 43315);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topicort Gel', 'gel', 'D07AC03', false, 0, '02221926', 'FreeDiams::CA_HCDPD::DIN', 43316);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topicort Ointment', 'ointment', 'D07AC03', false, 0, '02221934', 'FreeDiams::CA_HCDPD::DIN', 43317);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trental', 'tablet (extended-release)', 'C04AD03', false, 0, '02221977', 'FreeDiams::CA_HCDPD::DIN', 43321);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Renedil', 'tablet (extended-release)', 'C08CA02', false, 0, '02221985', 'FreeDiams::CA_HCDPD::DIN', 43322);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Renedil', 'tablet (extended-release)', 'C08CA02', false, 0, '02221993', 'FreeDiams::CA_HCDPD::DIN', 43323);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Renedil', 'tablet (extended-release)', 'C08CA02', false, 0, '02222000', 'FreeDiams::CA_HCDPD::DIN', 43324);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravachol - Tab 40mg', 'tablet', 'C10AA03', false, 0, '02222051', 'FreeDiams::CA_HCDPD::DIN', 43329);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diltiaz Sr - Src 60mg', 'capsule (sustained-release)', 'C08DB01', false, 0, '02222957', 'FreeDiams::CA_HCDPD::DIN', 43330);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diltiaz Sr - 90mg/Src', 'capsule (sustained-release)', 'C08DB01', false, 0, '02222965', 'FreeDiams::CA_HCDPD::DIN', 43331);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diltiaz Sr - Src 120mg', 'capsule (sustained-release)', 'C08DB01', false, 0, '02222973', 'FreeDiams::CA_HCDPD::DIN', 43332);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Nortriptyline - Cap 10mg', 'capsule', 'N06AA10', false, 0, '02223139', 'FreeDiams::CA_HCDPD::DIN', 43346);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Nortriptyline - Cap 25mg', 'capsule', 'N06AA10', false, 0, '02223147', 'FreeDiams::CA_HCDPD::DIN', 43347);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buspirone-10 - Tab 10mg', 'tablet', 'N05BE01', false, 0, '02223163', 'FreeDiams::CA_HCDPD::DIN', 43349);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Desipramine Sc - Tab 25mg', 'tablet', 'N06AA01', false, 0, '02223325', 'FreeDiams::CA_HCDPD::DIN', 43354);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Desipramine Fc - 50mg Tab', 'tablet', 'N06AA01', false, 0, '02223333', 'FreeDiams::CA_HCDPD::DIN', 43355);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Desipramine Sc - Tab 10mg', 'tablet', 'N06AA01', false, 0, '02223341', 'FreeDiams::CA_HCDPD::DIN', 43356);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Desipramine Sc -Tab 75mg', 'tablet', 'N06AA01', false, 0, '02223368', 'FreeDiams::CA_HCDPD::DIN', 43357);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Oxybutynin', 'syrup', 'G04BD04', false, 0, '02223376', 'FreeDiams::CA_HCDPD::DIN', 43358);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intron A', 'kit', 'L03AB05', false, 0, '02223406', 'FreeDiams::CA_HCDPD::DIN', 43361);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Fluoxetine - Cap 10mg', 'capsule', 'N06AB03', false, 0, '02223481', 'FreeDiams::CA_HCDPD::DIN', 43365);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Fluoxetine - Cap 20mg', 'capsule', 'N06AB03', false, 0, '02223503', 'FreeDiams::CA_HCDPD::DIN', 43366);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Nortriptyline - Cap 10mg', 'capsule', 'N06AA10', false, 0, '02223511', 'FreeDiams::CA_HCDPD::DIN', 43367);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Nortriptyline - Cap 25mg', 'capsule', 'N06AA10', false, 0, '02223538', 'FreeDiams::CA_HCDPD::DIN', 43368);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reactine', 'tablet', 'R06AE07', false, 0, '02223546', 'FreeDiams::CA_HCDPD::DIN', 43369);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reactine', 'tablet', 'R06AE07', false, 0, '02223554', 'FreeDiams::CA_HCDPD::DIN', 43370);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Metformin - Tab 500mg', 'tablet', 'A10BA02', false, 0, '02223562', 'FreeDiams::CA_HCDPD::DIN', 43371);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Temazepam', 'capsule', 'N05CD07', false, 0, '02223570', 'FreeDiams::CA_HCDPD::DIN', 43372);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Temazepam', 'capsule', 'N05CD07', false, 0, '02223589', 'FreeDiams::CA_HCDPD::DIN', 43373);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Indapamide - Tab 2.5mg', 'tablet', 'C03BA11', false, 0, '02223597', 'FreeDiams::CA_HCDPD::DIN', 43374);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Fenofibrate', 'capsule', 'C10AB05', false, 0, '02223600', 'FreeDiams::CA_HCDPD::DIN', 43375);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Indapamide 2.5mg Tablets', 'tablet', 'C03BA11', false, 0, '02223678', 'FreeDiams::CA_HCDPD::DIN', 43381);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Clonazepam-R - Tab 0.5mg', 'tablet', 'N03AE01', false, 0, '02224100', 'FreeDiams::CA_HCDPD::DIN', 43383);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Albumin (Human) 5% Solution Usp   - Iv', 'solution', 'B05AA01', false, 0, '02223694', 'FreeDiams::CA_HCDPD::DIN', 43384);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Albumin (Human) 25% Solution Usp - Iv', 'solution', 'B05AA01', false, 0, '02223708', 'FreeDiams::CA_HCDPD::DIN', 43385);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zithromax - Pws Orl 100mg/5ml', 'powder for suspension', 'J01FA10', false, 0, '02223716', 'FreeDiams::CA_HCDPD::DIN', 43386);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zithromax - Pws Orl 200mg/5ml', 'powder for solution', 'J01FA10', false, 0, '02223724', 'FreeDiams::CA_HCDPD::DIN', 43387);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diluent For Allergenic Extract Sterile Albumin Saline With Phenol', 'liquid', 'V07AB', false, 0, '02223732', 'FreeDiams::CA_HCDPD::DIN', 43388);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norprolac', 'tablet', 'G02CB04', false, 0, '02223740', 'FreeDiams::CA_HCDPD::DIN', 43389);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norprolac', 'tablet', 'G02CB04', false, 0, '02223759', 'FreeDiams::CA_HCDPD::DIN', 43390);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norprolac', 'tablet', 'G02CB04', false, 0, '02223767', 'FreeDiams::CA_HCDPD::DIN', 43391);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norprolac', 'tablet', 'G02CB04', false, 0, '02223775', 'FreeDiams::CA_HCDPD::DIN', 43392);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oesclim', 'patch', 'G03CA03', false, 0, '02243722', 'FreeDiams::CA_HCDPD::DIN', 67654);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diclofenac-Sr 75mg - Srt', 'tablet (extended-release)', 'M01AB05', false, 0, '02224119', 'FreeDiams::CA_HCDPD::DIN', 43393);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diclofenac-Sr 100mg - Srt', 'tablet (extended-release)', 'M01AB05', false, 0, '02224127', 'FreeDiams::CA_HCDPD::DIN', 43394);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arimidex Tab 1mg', 'tablet', 'L02BG03', false, 0, '02224135', 'FreeDiams::CA_HCDPD::DIN', 43395);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tripacel Hybrid', 'suspension', 'J07AJ52', false, 0, '02224143', 'FreeDiams::CA_HCDPD::DIN', 43396);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Claforan - Pws Inj 500mg/Vial', 'powder for solution', 'J01DD01', false, 0, '02225085', 'FreeDiams::CA_HCDPD::DIN', 43410);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Claforan - Pws Inj 1.0g/Vial', 'powder for solution', 'J01DD01', false, 0, '02225093', 'FreeDiams::CA_HCDPD::DIN', 43411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Claforan - Pws Inj 2.0g/Vial', 'powder for solution', 'J01DD01', false, 0, '02225107', 'FreeDiams::CA_HCDPD::DIN', 43412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Suprefact', 'solution', 'L02AE01', false, 0, '02225158', 'FreeDiams::CA_HCDPD::DIN', 43416);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Suprefact', 'solution', 'L02AE01', false, 0, '02225166', 'FreeDiams::CA_HCDPD::DIN', 43417);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Fluoxetine - Solution 20mg/5ml', 'solution', 'N06AB03', false, 0, '02225174', 'FreeDiams::CA_HCDPD::DIN', 43418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Loperamide-2 - Tab 2mg', 'tablet', 'A07DA03', false, 0, '02225182', 'FreeDiams::CA_HCDPD::DIN', 43419);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estrace', 'tablet', 'G03CA03', false, 0, '02225190', 'FreeDiams::CA_HCDPD::DIN', 43420);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Optiray 240 (Ioversol Injection 51%)', 'solution', 'V08AB07', false, 0, '02225263', 'FreeDiams::CA_HCDPD::DIN', 43427);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benzamycin', 'gel', 'D10AF52', false, 0, '02225271', 'FreeDiams::CA_HCDPD::DIN', 43428);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Propranolol Hydrochloride Injection Usp', 'solution', 'C07AA05', false, 0, '02225883', 'FreeDiams::CA_HCDPD::DIN', 43431);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zoladex La Inj Depot 10.8mg', 'implant', 'L02AE03', false, 0, '02225905', 'FreeDiams::CA_HCDPD::DIN', 43433);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Temazepam', 'capsule', 'N05CD07', false, 0, '02225964', 'FreeDiams::CA_HCDPD::DIN', 43438);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Temazepam', 'capsule', 'N05CD07', false, 0, '02225972', 'FreeDiams::CA_HCDPD::DIN', 43439);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Fenofibrate', 'capsule', 'C10AB05', false, 0, '02225980', 'FreeDiams::CA_HCDPD::DIN', 43440);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Activase Rt-Pa - Kit (Pws & Liq)', 'kit', 'B01AD02', false, 0, '02225689', 'FreeDiams::CA_HCDPD::DIN', 43443);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metrocream - Crm 0.75%', 'cream', 'D06BX01', false, 0, '02226839', 'FreeDiams::CA_HCDPD::DIN', 43445);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Indapamide Hemihydrate 1.25mg - Tab', 'tablet', 'C03BA11', false, 0, '02227339', 'FreeDiams::CA_HCDPD::DIN', 43448);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Suprane 1ml/Ml', 'liquid', 'N01AB07', false, 0, '02227428', 'FreeDiams::CA_HCDPD::DIN', 43455);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Cimetidine', 'tablet', 'A02BA01', false, 0, '02227444', 'FreeDiams::CA_HCDPD::DIN', 43457);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Cimetidine', 'tablet', 'A02BA01', false, 0, '02227452', 'FreeDiams::CA_HCDPD::DIN', 43458);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Cimetidine', 'tablet', 'A02BA01', false, 0, '02227460', 'FreeDiams::CA_HCDPD::DIN', 43459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Cimetidine', 'tablet', 'A02BA01', false, 0, '02227479', 'FreeDiams::CA_HCDPD::DIN', 43460);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermatop Ointment 0.1%', 'ointment', 'D07AC18', false, 0, '02227517', 'FreeDiams::CA_HCDPD::DIN', 43464);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Diclo Sr - Srt 75mg', 'tablet (extended-release)', 'M01AB05', false, 0, '02228203', 'FreeDiams::CA_HCDPD::DIN', 43472);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Diclo Sr - Srt 100mg', 'tablet (extended-release)', 'M01AB05', false, 0, '02228211', 'FreeDiams::CA_HCDPD::DIN', 43473);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Zopiclone Tablets - 7.5mg', 'tablet', 'N05CF01', false, 0, '02228270', 'FreeDiams::CA_HCDPD::DIN', 43478);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rivanase Aq.Nasal Spray 50mcg/Metered Dose', 'metered-dose (aerosol)', 'R01AD01', false, 0, '02228300', 'FreeDiams::CA_HCDPD::DIN', 43481);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minox - Liq Top 20mg/Ml', 'solution', 'D11AX01', false, 0, '02228319', 'FreeDiams::CA_HCDPD::DIN', 43482);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dobutamine Hydrochloride Injection-12.5mg/Ml', 'liquid', 'C01CA07', false, 0, '02228335', 'FreeDiams::CA_HCDPD::DIN', 43484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Loperacap', 'tablet', 'A07DA03', false, 0, '02228343', 'FreeDiams::CA_HCDPD::DIN', 43485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Loperamide - Caplet 2mg', 'tablet', 'A07DA03', false, 0, '02228351', 'FreeDiams::CA_HCDPD::DIN', 43486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Migranal Nasal Spray 4mg/Ml', 'liquid', 'N02CA01', false, 0, '02228947', 'FreeDiams::CA_HCDPD::DIN', 43498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Suprefact Depot 2 Months', 'implant', 'L02AE01', false, 0, '02228955', 'FreeDiams::CA_HCDPD::DIN', 43499);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isovue 200 Injection', 'liquid', 'V08AB04', false, 0, '02229013', 'FreeDiams::CA_HCDPD::DIN', 43504);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isovue 300 Injection', 'liquid', 'V08AB04', false, 0, '02229021', 'FreeDiams::CA_HCDPD::DIN', 43505);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isovue 370 Injection', 'liquid', 'V08AB04', false, 0, '02229048', 'FreeDiams::CA_HCDPD::DIN', 43506);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prohance - Liq Iv 279.3mg/Ml', 'solution', 'V08CA04', false, 0, '02229056', 'FreeDiams::CA_HCDPD::DIN', 43507);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ketorolac - Tab Orl 10mg', 'tablet', 'M01AB15', false, 0, '02229080', 'FreeDiams::CA_HCDPD::DIN', 43510);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pulmicort Nebuamp 0.125 Mg/Ml', 'suspension', 'R03BA02', false, 0, '02229099', 'FreeDiams::CA_HCDPD::DIN', 43511);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Famvir Tablets 125mg', 'tablet', 'J05AB09', false, 0, '02229110', 'FreeDiams::CA_HCDPD::DIN', 43513);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Famvir Tablets 250mg', 'tablet', 'J05AB09', false, 0, '02229129', 'FreeDiams::CA_HCDPD::DIN', 43514);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norvir - Liq  Orl 80mg/Ml', 'solution', 'J05AE03', false, 0, '02229145', 'FreeDiams::CA_HCDPD::DIN', 43516);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crixivan', 'capsule', 'J05AE02', false, 0, '02229161', 'FreeDiams::CA_HCDPD::DIN', 43518);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crixivan', 'capsule', 'J05AE02', false, 0, '02229196', 'FreeDiams::CA_HCDPD::DIN', 43520);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyprexa  -2.5mg', 'tablet', 'N05AH03', false, 0, '02229250', 'FreeDiams::CA_HCDPD::DIN', 43530);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyprexa - 5mg', 'tablet', 'N05AH03', false, 0, '02229269', 'FreeDiams::CA_HCDPD::DIN', 43531);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyprexa  -7.5mg', 'tablet', 'N05AH03', false, 0, '02229277', 'FreeDiams::CA_HCDPD::DIN', 43532);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyprexa - 10mg', 'tablet', 'N05AH03', false, 0, '02229285', 'FreeDiams::CA_HCDPD::DIN', 43533);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Entocort Capsule 3mg', 'capsule (sustained-release)', 'A07EA06', false, 0, '02229293', 'FreeDiams::CA_HCDPD::DIN', 43534);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Desonide', 'cream', 'D07AB08', false, 0, '02229315', 'FreeDiams::CA_HCDPD::DIN', 43536);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Desonide', 'ointment', 'D07AB08', false, 0, '02229323', 'FreeDiams::CA_HCDPD::DIN', 43537);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daypro', 'tablet', 'M01AE12', false, 0, '02027860', 'FreeDiams::CA_HCDPD::DIN', 43573);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paxil Tab 10mg', 'tablet', 'N06AB05', false, 0, '02027887', 'FreeDiams::CA_HCDPD::DIN', 43575);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Optiray 300  - 64%', 'solution', 'V08AB07', false, 0, '02034492', 'FreeDiams::CA_HCDPD::DIN', 43599);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Optiray 320 (Ultraject) 68%', 'solution', 'V08AB07', false, 0, '02035626', 'FreeDiams::CA_HCDPD::DIN', 43604);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synovisol Irrigation Solution 2.6%', 'solution', 'V07AB', false, 0, '02052458', 'FreeDiams::CA_HCDPD::DIN', 43651);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flutamide', 'tablet', 'L02BB01', false, 0, '02059673', 'FreeDiams::CA_HCDPD::DIN', 43664);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sabril', 'powder', 'N03AG04', false, 0, '02068036', 'FreeDiams::CA_HCDPD::DIN', 43682);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pancuronium Bromide 1mg/Ml', 'solution', 'M03AC01', false, 0, '02078570', 'FreeDiams::CA_HCDPD::DIN', 43714);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Timolol', 'liquid', 'S01ED01', false, 0, '02083345', 'FreeDiams::CA_HCDPD::DIN', 43718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Timolol', 'liquid', 'S01ED01', false, 0, '02083353', 'FreeDiams::CA_HCDPD::DIN', 43719);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cutivate', 'cream', 'D07AC17', false, 0, '02089912', 'FreeDiams::CA_HCDPD::DIN', 43758);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Salbutamol Oral Liquid', 'solution', 'R03CC02', false, 0, '02091186', 'FreeDiams::CA_HCDPD::DIN', 43769);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ipratropium Udv', 'solution', 'R03BB01', false, 0, '02097176', 'FreeDiams::CA_HCDPD::DIN', 43798);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Domperidone - Tab 10mg', 'tablet', 'A03FA03', false, 0, '02103613', 'FreeDiams::CA_HCDPD::DIN', 43813);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Losec Capsules 10mg', 'capsule (delayed release)', 'A02BC01', false, 0, '02119579', 'FreeDiams::CA_HCDPD::DIN', 43827);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Ketocon Tablets - 200mg', 'tablet', 'J02AB02', false, 0, '02122197', 'FreeDiams::CA_HCDPD::DIN', 43830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stilamin - Pws Liq Iv', 'kit', 'H01CB01', false, 0, '02125269', 'FreeDiams::CA_HCDPD::DIN', 43833);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stilamin - Pws Iv  3mg/Amp', 'powder for solution', 'H01CB01', false, 0, '02125277', 'FreeDiams::CA_HCDPD::DIN', 43834);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorph Contin-Controlled Release Cap - 30mg', 'capsule (sustained-release)', 'N02AA03', false, 0, '02125390', 'FreeDiams::CA_HCDPD::DIN', 43838);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cisplatin Injection', 'solution', 'L01XA01', false, 0, '02126613', 'FreeDiams::CA_HCDPD::DIN', 43840);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cytarabine Injection', 'solution', 'L01BC01', false, 0, '02126656', 'FreeDiams::CA_HCDPD::DIN', 43843);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carboplatin Injection 10mg/Ml', 'solution', 'L01XA02', false, 0, '02126680', 'FreeDiams::CA_HCDPD::DIN', 43846);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Amantadine Hydrochloride Capsules-100mg', 'capsule', 'N04BB01', false, 0, '02130963', 'FreeDiams::CA_HCDPD::DIN', 43886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Clonazepam - Tab 0.5mg', 'tablet', 'N03AE01', false, 0, '02130998', 'FreeDiams::CA_HCDPD::DIN', 43888);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bleomycin Sulphate For Injection Usp', 'powder for solution', 'L01DC01', false, 0, '02131692', 'FreeDiams::CA_HCDPD::DIN', 43892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vancomycin Hydrochloride For Injection, Usp', 'powder for solution', 'J01XA01', false, 0, '02139243', 'FreeDiams::CA_HCDPD::DIN', 43933);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adenocard - Liq Rapid Bolus Iv 3mg/Ml', 'solution', 'C01EB10', false, 0, '02139308', 'FreeDiams::CA_HCDPD::DIN', 43936);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Valproic 50mg/Ml Syrup', 'syrup', 'N03AG01', false, 0, '02140063', 'FreeDiams::CA_HCDPD::DIN', 43944);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('20% Prosol', 'liquid', 'B05BA01', false, 0, '02141450', 'FreeDiams::CA_HCDPD::DIN', 43947);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Clonazepam - Tab 0.5mg', 'tablet', 'N03AE01', false, 0, '02145227', 'FreeDiams::CA_HCDPD::DIN', 43969);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Clonazepam - Tab 1mg', 'tablet', 'N03AE01', false, 0, '02145235', 'FreeDiams::CA_HCDPD::DIN', 43970);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Clonazepam - Tab 2mg', 'tablet', 'N03AE01', false, 0, '02145243', 'FreeDiams::CA_HCDPD::DIN', 43971);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Canesten Cream 1', 'cream', 'G01AF02', false, 0, '02150883', 'FreeDiams::CA_HCDPD::DIN', 44016);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imovax Polio', 'suspension', 'J07BF03', false, 0, '01959042', 'FreeDiams::CA_HCDPD::DIN', 44019);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naproxen-Na Df -Tab 550mg', 'tablet', 'M01AE02', false, 0, '02153386', 'FreeDiams::CA_HCDPD::DIN', 44029);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gliclazide -Tab 80mg', 'tablet', 'A10BB09', false, 0, '02155850', 'FreeDiams::CA_HCDPD::DIN', 44051);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cipro 250 - Tab 250mg', 'tablet', 'J01MA02', false, 0, '02155958', 'FreeDiams::CA_HCDPD::DIN', 44057);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cipro 500 - Tab 500mg', 'tablet', 'J01MA02', false, 0, '02155966', 'FreeDiams::CA_HCDPD::DIN', 44058);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cipro 750 - Tab 750mg', 'tablet', 'J01MA02', false, 0, '02155974', 'FreeDiams::CA_HCDPD::DIN', 44059);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Domperidone', 'tablet', 'A03FA03', false, 0, '02157195', 'FreeDiams::CA_HCDPD::DIN', 44066);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('8.5% Freamine Iii', 'liquid', 'B05BA01', false, 0, '02158647', 'FreeDiams::CA_HCDPD::DIN', 44068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02161737', 'FreeDiams::CA_HCDPD::DIN', 44074);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02161745', 'FreeDiams::CA_HCDPD::DIN', 44075);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02161753', 'FreeDiams::CA_HCDPD::DIN', 44076);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Toradol Im 10mg/Ml', 'liquid', 'M01AB15', false, 0, '02162644', 'FreeDiams::CA_HCDPD::DIN', 44090);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vexol Ophthalmic Suspension -  1%', 'suspension', 'S01BA13', false, 0, '02163691', 'FreeDiams::CA_HCDPD::DIN', 44105);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lederle Leucovorin', 'tablet', 'V03AF03', false, 0, '02170493', 'FreeDiams::CA_HCDPD::DIN', 44146);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methotrexate', 'tablet', 'L01BA01', false, 0, '02170698', 'FreeDiams::CA_HCDPD::DIN', 44161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tazocin', 'powder for solution', 'J01CR05', false, 0, '02170795', 'FreeDiams::CA_HCDPD::DIN', 44168);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tazocin', 'powder for solution', 'J01CR05', false, 0, '02170809', 'FreeDiams::CA_HCDPD::DIN', 44169);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tazocin', 'powder for solution', 'J01CR05', false, 0, '02170817', 'FreeDiams::CA_HCDPD::DIN', 44170);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Omnipaque 180', 'solution', 'V08AB02', false, 0, '02172720', 'FreeDiams::CA_HCDPD::DIN', 44184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Omnipaque 240', 'solution', 'V08AB02', false, 0, '02172739', 'FreeDiams::CA_HCDPD::DIN', 44185);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Omnipaque 300', 'solution', 'V08AB02', false, 0, '02172747', 'FreeDiams::CA_HCDPD::DIN', 44186);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Omnipaque 350', 'solution', 'V08AB02', false, 0, '02172755', 'FreeDiams::CA_HCDPD::DIN', 44187);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Omniscan', 'solution', 'V08CA03', false, 0, '02172771', 'FreeDiams::CA_HCDPD::DIN', 44188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prograf', 'capsule', 'L04AD02', false, 0, '02175983', 'FreeDiams::CA_HCDPD::DIN', 44210);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prograf', 'capsule', 'L04AD02', false, 0, '02175991', 'FreeDiams::CA_HCDPD::DIN', 44211);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prograf', 'solution', 'L04AD02', false, 0, '02176009', 'FreeDiams::CA_HCDPD::DIN', 44212);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Naproxen Sr Tablets 750mg', 'tablet (extended-release)', 'M01AE02', false, 0, '02177072', 'FreeDiams::CA_HCDPD::DIN', 44216);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fluoxetine Liquid - 20mg/5ml', 'solution', 'N06AB03', false, 0, '02177595', 'FreeDiams::CA_HCDPD::DIN', 44218);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Nortriptyline', 'capsule', 'N06AA10', false, 0, '02177692', 'FreeDiams::CA_HCDPD::DIN', 44225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Nortriptyline', 'capsule', 'N06AA10', false, 0, '02177706', 'FreeDiams::CA_HCDPD::DIN', 44226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Nizatidine 150mg Capsules', 'capsule', 'A02BA04', false, 0, '02177714', 'FreeDiams::CA_HCDPD::DIN', 44227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Nizatidine', 'capsule', 'A02BA04', false, 0, '02177722', 'FreeDiams::CA_HCDPD::DIN', 44228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Nortriptyline 10mg Capsules', 'capsule', 'N06AA10', false, 0, '02178729', 'FreeDiams::CA_HCDPD::DIN', 44232);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Nortriptyline 25mg Capsules', 'capsule', 'N06AA10', false, 0, '02178737', 'FreeDiams::CA_HCDPD::DIN', 44233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Inhibace Plus - Tab', 'tablet', 'C09BA08', false, 0, '02181479', 'FreeDiams::CA_HCDPD::DIN', 44252);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cozaar', 'tablet', 'C09CA01', false, 0, '02182882', 'FreeDiams::CA_HCDPD::DIN', 44255);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pregnyl', 'kit', 'G03GA01', false, 0, '02182904', 'FreeDiams::CA_HCDPD::DIN', 44257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nizoral  - 2%', 'shampoo', 'D01AC08', false, 0, '02182920', 'FreeDiams::CA_HCDPD::DIN', 44259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methotrexate Injection, Usp', 'solution', 'L01BA01', false, 0, '02182947', 'FreeDiams::CA_HCDPD::DIN', 44261);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methotrexate Injection, Usp', 'solution', 'L01BA01', false, 0, '02182955', 'FreeDiams::CA_HCDPD::DIN', 44262);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Methotrexate Tablets  - 2.5mg', 'tablet', 'L01BA01', false, 0, '02182963', 'FreeDiams::CA_HCDPD::DIN', 44263);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methotrexate Injection, Usp', 'solution', 'L01BA01', false, 0, '02182971', 'FreeDiams::CA_HCDPD::DIN', 44264);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Leucovorin Calcium Injection Usp', 'liquid', 'V03AF03', false, 0, '02182998', 'FreeDiams::CA_HCDPD::DIN', 44265);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Leucovorin Calcium Injection Usp', 'liquid', 'V03AF03', false, 0, '02183005', 'FreeDiams::CA_HCDPD::DIN', 44266);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vincristine Sulfate Injection Usp', 'solution', 'L01CA02', false, 0, '02183013', 'FreeDiams::CA_HCDPD::DIN', 44267);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vinblastine Sulfate Injection', 'solution', 'L01CA01', false, 0, '02183056', 'FreeDiams::CA_HCDPD::DIN', 44270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Septopal', 'implant', 'J01GB03', false, 0, '00646350', 'FreeDiams::CA_HCDPD::DIN', 44317);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asepticare Aerosol Disinfectant', 'aerosol', 'V07AV', false, 0, '00801828', 'FreeDiams::CA_HCDPD::DIN', 44478);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Almagel Plus Sus', 'suspension', 'A02AF02', false, 0, '00815527', 'FreeDiams::CA_HCDPD::DIN', 44552);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lung Diffusion Test Mixture Gas', 'gas', 'V03AN', false, 0, '00823066', 'FreeDiams::CA_HCDPD::DIN', 44612);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jaa Prednisone Tab 5mg Usp', 'tablet', 'H02AB07', false, 0, '00868442', 'FreeDiams::CA_HCDPD::DIN', 44807);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antiseptic Swabs 4mg/Ml', 'pad', 'D08AJ51', false, 0, '00873381', 'FreeDiams::CA_HCDPD::DIN', 44888);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Softcide Handwash', 'liquid', 'D08AE05', false, 0, '00877220', 'FreeDiams::CA_HCDPD::DIN', 45065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Trihexyphenidyl Elx 0.4mg/Ml', 'elixir', 'N04AA01', false, 0, '00885398', 'FreeDiams::CA_HCDPD::DIN', 45323);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Prochlorazine Tab 10mg', 'tablet', 'N05AB04', false, 0, '00886432', 'FreeDiams::CA_HCDPD::DIN', 45324);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Prochlorazine Tab 5mg', 'tablet', 'N05AB04', false, 0, '00886440', 'FreeDiams::CA_HCDPD::DIN', 45325);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germinal Liq', 'liquid', 'V07AV', false, 0, '00890359', 'FreeDiams::CA_HCDPD::DIN', 45490);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen U.S.P.', 'gas', 'V03AN01', false, 0, '00896683', 'FreeDiams::CA_HCDPD::DIN', 45814);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Sodium 5000unit/500ml In Sodium Chloride 0.9%', 'solution', 'B01AB01', false, 0, '00622354', 'FreeDiams::CA_HCDPD::DIN', 45892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stud 100', 'spray, metered dose', 'D04AB01', false, 0, '01901532', 'FreeDiams::CA_HCDPD::DIN', 46020);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro Detergent Liq', 'liquid', 'V07AV', false, 0, '01906771', 'FreeDiams::CA_HCDPD::DIN', 46352);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Helium-Oxygen Mix Gas', 'gas', 'V03AN', false, 0, '01906801', 'FreeDiams::CA_HCDPD::DIN', 46353);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pharmalgen Yellow Hornet Venom', 'powder for solution', 'V01AA07', false, 0, '01948938', 'FreeDiams::CA_HCDPD::DIN', 46470);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pharmalgen White Faced Hornet Venom Protein', 'powder for solution', 'V01AA07', false, 0, '01948997', 'FreeDiams::CA_HCDPD::DIN', 46471);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Menomune-A/C/Y/W-135', 'kit', 'J07AH04', false, 0, '01959018', 'FreeDiams::CA_HCDPD::DIN', 46485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zocor', 'tablet', 'C10AA01', false, 0, '00884359', 'FreeDiams::CA_HCDPD::DIN', 46718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Motrin Ib Gelcaps', 'tablet', 'M01AE01', false, 0, '01983873', 'FreeDiams::CA_HCDPD::DIN', 46758);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reactine 20mg Tablet', 'tablet', 'R06AE07', false, 0, '01900978', 'FreeDiams::CA_HCDPD::DIN', 46803);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imovax Rabies Rabies Vaccine Inactivated (Dco)', 'powder for solution', 'J07BG01', false, 0, '01908286', 'FreeDiams::CA_HCDPD::DIN', 46832);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Urocit K Srt 540mg', 'tablet (extended-release)', 'A12BA02', false, 0, '01914022', 'FreeDiams::CA_HCDPD::DIN', 46885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Liposyn Ii Inj 10%', 'emulsion', 'B05BA02', false, 0, '00818712', 'FreeDiams::CA_HCDPD::DIN', 47094);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ibuprofen', 'tablet', 'M01AE01', false, 0, '00836133', 'FreeDiams::CA_HCDPD::DIN', 47112);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ibuprofen', 'tablet', 'M01AE01', false, 0, '00839264', 'FreeDiams::CA_HCDPD::DIN', 47123);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aminosyn Ii With Electrolytes In Dextrose Injection With Calcium', 'solution', 'B05BA10', false, 0, '00851574', 'FreeDiams::CA_HCDPD::DIN', 47126);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benadryl Allergy Sinus Caplets', 'tablet', 'N02BE51', false, 0, '02229367', 'FreeDiams::CA_HCDPD::DIN', 47167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antiseptic Cleanser Solution', 'solution', 'D08AC02', false, 0, '02229377', 'FreeDiams::CA_HCDPD::DIN', 47178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clotrimazole Vaginal Cream Usp 2%', 'cream', 'G01AF02', false, 0, '02229379', 'FreeDiams::CA_HCDPD::DIN', 47180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clotrimazole Cream Usp 1%', 'cream', 'D01AC01', false, 0, '02229380', 'FreeDiams::CA_HCDPD::DIN', 47181);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naropin Inj 2mg/Ml', 'solution', 'N01BB09', false, 0, '02229411', 'FreeDiams::CA_HCDPD::DIN', 47216);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naropin Inj 5mg/Ml', 'solution', 'N01BB09', false, 0, '02229415', 'FreeDiams::CA_HCDPD::DIN', 47220);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naropin Inj 10mg/Ml', 'solution', 'N01BB09', false, 0, '02229418', 'FreeDiams::CA_HCDPD::DIN', 47225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mentholatum Natural Ice Lipbalm', 'ointment', 'D02BA30', false, 0, '02229419', 'FreeDiams::CA_HCDPD::DIN', 47227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nimbex 2mg/Ml', 'liquid', 'M03AC11', false, 0, '02229422', 'FreeDiams::CA_HCDPD::DIN', 47231);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advance 12a', 'liquid', 'V07AV', false, 0, '02229425', 'FreeDiams::CA_HCDPD::DIN', 47240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phoslo Tablets', 'tablet', 'V03AE', false, 0, '02229437', 'FreeDiams::CA_HCDPD::DIN', 47284);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Gentamicin', 'liquid', 'S01AA11', false, 0, '02229440', 'FreeDiams::CA_HCDPD::DIN', 47318);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Gentamicin', 'solution', 'S02AA14', false, 0, '02229441', 'FreeDiams::CA_HCDPD::DIN', 47319);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dobutamine 12.5mg/Ml', 'solution', 'C01CA07', false, 0, '02229451', 'FreeDiams::CA_HCDPD::DIN', 47337);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mefenamic', 'capsule', 'M01AG01', false, 0, '02229452', 'FreeDiams::CA_HCDPD::DIN', 47338);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pantoloc', 'tablet (enteric-coated)', 'A02BC02', false, 0, '02229453', 'FreeDiams::CA_HCDPD::DIN', 47339);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Atenolol - 50mg', 'tablet', 'C07AB03', false, 0, '02229467', 'FreeDiams::CA_HCDPD::DIN', 47357);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Atenolol - 100mg', 'tablet', 'C07AB03', false, 0, '02229468', 'FreeDiams::CA_HCDPD::DIN', 47358);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Visine Contact Lens', 'drops', 'S01XA20', false, 0, '02229483', 'FreeDiams::CA_HCDPD::DIN', 47379);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy Formula', 'tablet', 'R06AA02', false, 0, '02229492', 'FreeDiams::CA_HCDPD::DIN', 47391);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Peri-Wash Ii Antiseptic Cleanser', 'liquid', 'D08AJ08', false, 0, '02229501', 'FreeDiams::CA_HCDPD::DIN', 47404);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Innohep - 20000anti-Xa Iu/Ml', 'liquid', 'B01AB10', false, 0, '02229515', 'FreeDiams::CA_HCDPD::DIN', 47420);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glycon', 'tablet', 'A10BA02', false, 0, '02229516', 'FreeDiams::CA_HCDPD::DIN', 47421);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Metformin (850mg)', 'tablet', 'A10BA02', false, 0, '02229517', 'FreeDiams::CA_HCDPD::DIN', 47422);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Gliclazide', 'tablet', 'A10BB09', false, 0, '02229519', 'FreeDiams::CA_HCDPD::DIN', 47424);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ciproflox', 'tablet', 'J01MA02', false, 0, '02229521', 'FreeDiams::CA_HCDPD::DIN', 47426);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ciproflox', 'tablet', 'J01MA02', false, 0, '02229522', 'FreeDiams::CA_HCDPD::DIN', 47427);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ciproflox', 'tablet', 'J01MA02', false, 0, '02229523', 'FreeDiams::CA_HCDPD::DIN', 47428);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Norflox - 400mg', 'tablet', 'J01MA06', false, 0, '02229524', 'FreeDiams::CA_HCDPD::DIN', 47429);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diltiaz Cd - Cap 300mg', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02229526', 'FreeDiams::CA_HCDPD::DIN', 47431);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Tylenol Cold & Stuffy Nose', 'suspension', 'N02BE51', false, 0, '02229538', 'FreeDiams::CA_HCDPD::DIN', 47448);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triamcinolone Acetonide Injectable Suspension Usp', 'suspension', 'H02AB08', false, 0, '02229540', 'FreeDiams::CA_HCDPD::DIN', 47450);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triamcinolone Acetonide Injectable Suspension Usp', 'suspension', 'H02AB08', false, 0, '02229550', 'FreeDiams::CA_HCDPD::DIN', 47461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diarr-Eze', 'tablet', 'A07DA03', false, 0, '02229552', 'FreeDiams::CA_HCDPD::DIN', 47464);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pilocarpine 4%', 'solution', 'S01EB01', false, 0, '02229554', 'FreeDiams::CA_HCDPD::DIN', 47466);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pilocarpine 2%', 'solution', 'S01EB01', false, 0, '02229555', 'FreeDiams::CA_HCDPD::DIN', 47467);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pilocarpine 1%', 'solution', 'S01EB01', false, 0, '02229556', 'FreeDiams::CA_HCDPD::DIN', 47468);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tomudex', 'powder for solution', 'L01BA03', false, 0, '02229566', 'FreeDiams::CA_HCDPD::DIN', 47482);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Mefenamic 250 Mg', 'capsule', 'M01AG01', false, 0, '02229569', 'FreeDiams::CA_HCDPD::DIN', 47492);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artificial Tears - Liq 1.4%', 'solution', 'S01XA20', false, 0, '02229570', 'FreeDiams::CA_HCDPD::DIN', 47493);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chapstick Lip Moisturizer', 'stick', 'D02BA30', false, 0, '02229613', 'FreeDiams::CA_HCDPD::DIN', 47540);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Valproic Acid E.C.', 'capsule (enteric-coated)', 'N03AG01', false, 0, '02229628', 'FreeDiams::CA_HCDPD::DIN', 47553);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artificial Tears Extra', 'solution', 'S01XA20', false, 0, '02229632', 'FreeDiams::CA_HCDPD::DIN', 47557);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zofran', 'liquid', 'A04AA01', false, 0, '02229639', 'FreeDiams::CA_HCDPD::DIN', 47565);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glutacide Concentrate 10% W/V', 'liquid', 'V07AV', false, 0, '02229641', 'FreeDiams::CA_HCDPD::DIN', 47571);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pronto Lice Killing Shampoo', 'shampoo', 'P03AC51', false, 0, '02229642', 'FreeDiams::CA_HCDPD::DIN', 47572);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitrazadon    - 5mg', 'tablet', 'N05CD02', false, 0, '02229654', 'FreeDiams::CA_HCDPD::DIN', 47629);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitrazadon - 10mg', 'tablet', 'N05CD02', false, 0, '02229655', 'FreeDiams::CA_HCDPD::DIN', 47630);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Metformin', 'tablet', 'A10BA02', false, 0, '02229656', 'FreeDiams::CA_HCDPD::DIN', 47631);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pepto-Bismol Extra Strength', 'liquid', 'A07BB', false, 0, '02229668', 'FreeDiams::CA_HCDPD::DIN', 47656);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophene 80mg Comprimes A Croquer', 'tablet', 'N02BE01', false, 0, '02229674', 'FreeDiams::CA_HCDPD::DIN', 47718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sucrets For Kids Cherry Flavour Lozenge', 'lozenge', 'R02AD04', false, 0, '02229682', 'FreeDiams::CA_HCDPD::DIN', 47738);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vaqta', 'suspension', 'J07BC02', false, 0, '02229702', 'FreeDiams::CA_HCDPD::DIN', 47865);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humalog', 'solution', 'A10AB04', false, 0, '02229704', 'FreeDiams::CA_HCDPD::DIN', 47871);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humalog   (Cartridge/Kwikpen)', 'solution', 'A10AB04', false, 0, '02229705', 'FreeDiams::CA_HCDPD::DIN', 47872);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cimetidine', 'tablet', 'A02BA01', false, 0, '02229717', 'FreeDiams::CA_HCDPD::DIN', 47892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cimetidine', 'tablet', 'A02BA01', false, 0, '02229718', 'FreeDiams::CA_HCDPD::DIN', 47893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cimetidine', 'tablet', 'A02BA01', false, 0, '02229719', 'FreeDiams::CA_HCDPD::DIN', 47894);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cimetidine', 'tablet', 'A02BA01', false, 0, '02229720', 'FreeDiams::CA_HCDPD::DIN', 47895);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cimetidine', 'tablet', 'A02BA01', false, 0, '02229721', 'FreeDiams::CA_HCDPD::DIN', 47896);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nutropin Aq - Sc 5mg/Ml', 'liquid', 'H01AC01', false, 0, '02229722', 'FreeDiams::CA_HCDPD::DIN', 47897);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Orphenadrine Citrate Injection, Usp', 'liquid', 'M03BC01', false, 0, '02229731', 'FreeDiams::CA_HCDPD::DIN', 47910);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pronal Capsules', 'capsule', 'N02BA71', false, 0, '02229733', 'FreeDiams::CA_HCDPD::DIN', 47953);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pronal - C1/2 Capsules', 'capsule', 'N02AA79', false, 0, '02229734', 'FreeDiams::CA_HCDPD::DIN', 47954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pronal C1/4 Capsules', 'capsule', 'N02BA71', false, 0, '02229735', 'FreeDiams::CA_HCDPD::DIN', 47955);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pronal Tablets', 'tablet', 'N02BA71', false, 0, '02229736', 'FreeDiams::CA_HCDPD::DIN', 47956);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soflax Ex 5', 'tablet', 'A06AB02', false, 0, '02229742', 'FreeDiams::CA_HCDPD::DIN', 47962);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soflax Ex 10', 'suppository', 'A06AB02', false, 0, '02229743', 'FreeDiams::CA_HCDPD::DIN', 47963);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soflax C', 'capsule', 'A06AA02', false, 0, '02229744', 'FreeDiams::CA_HCDPD::DIN', 47964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soflax Pediatric Drops', 'drops', 'A06AA02', false, 0, '02229745', 'FreeDiams::CA_HCDPD::DIN', 47965);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Innohep', 'solution', 'B01AB10', false, 0, '02229755', 'FreeDiams::CA_HCDPD::DIN', 47983);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Temazepam', 'capsule', 'N05CD07', false, 0, '02229756', 'FreeDiams::CA_HCDPD::DIN', 47984);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Temazepam', 'capsule', 'N05CD07', false, 0, '02229758', 'FreeDiams::CA_HCDPD::DIN', 47986);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Temazepam-15', 'capsule', 'N05CD07', false, 0, '02229760', 'FreeDiams::CA_HCDPD::DIN', 47988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Temazepam-30', 'capsule', 'N05CD07', false, 0, '02229761', 'FreeDiams::CA_HCDPD::DIN', 47989);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nortriptyline-10', 'capsule', 'N06AA10', false, 0, '02229763', 'FreeDiams::CA_HCDPD::DIN', 47991);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nortriptyline-25', 'capsule', 'N06AA10', false, 0, '02229764', 'FreeDiams::CA_HCDPD::DIN', 47992);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Benzydamine  -  Oral Rinse', 'kit', 'A01AD02', false, 0, '02229777', 'FreeDiams::CA_HCDPD::DIN', 48059);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Sotalol', 'tablet', 'C07AA07', false, 0, '02229778', 'FreeDiams::CA_HCDPD::DIN', 48060);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Sotalol', 'tablet', 'C07AA07', false, 0, '02229779', 'FreeDiams::CA_HCDPD::DIN', 48061);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Diltiazem Cd', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02229781', 'FreeDiams::CA_HCDPD::DIN', 48067);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Diltiazem Cd', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02229782', 'FreeDiams::CA_HCDPD::DIN', 48071);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Diltiazem Cd', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02229783', 'FreeDiams::CA_HCDPD::DIN', 48076);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Diltiazem Cd', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02229784', 'FreeDiams::CA_HCDPD::DIN', 48077);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Metformin 850 Mg Tablets', 'tablet', 'A10BA02', false, 0, '02229785', 'FreeDiams::CA_HCDPD::DIN', 48078);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avalanche', 'liquid', 'V07AV', false, 0, '02229786', 'FreeDiams::CA_HCDPD::DIN', 48111);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Body Series Hand & Body Lotion Spf 8 Moisturizing Formula', 'lotion', 'D02BA30', false, 0, '02229798', 'FreeDiams::CA_HCDPD::DIN', 48123);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Benzydamine  -  Oral Rinse', 'kit', 'A01AD02', false, 0, '02229799', 'FreeDiams::CA_HCDPD::DIN', 48124);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sucrets Extra Strength Cherry Lozenges', 'lozenge', 'R02AA12', false, 0, '01951734', 'FreeDiams::CA_HCDPD::DIN', 48138);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aspergum Orange 325 Mg', 'gum', 'N02BA01', false, 0, '01912917', 'FreeDiams::CA_HCDPD::DIN', 48139);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aspergum 325 Mg (Cherry)', 'gum', 'N02BA01', false, 0, '01912925', 'FreeDiams::CA_HCDPD::DIN', 48140);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Chloral Hydrate Capsules 500mg', 'capsule', 'N05CC01', false, 0, '00811882', 'FreeDiams::CA_HCDPD::DIN', 48143);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Alprazolam', 'tablet', 'N05BA12', false, 0, '02229813', 'FreeDiams::CA_HCDPD::DIN', 48166);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Alprazolam', 'tablet', 'N05BA12', false, 0, '02229814', 'FreeDiams::CA_HCDPD::DIN', 48167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solarcaine Medicated First Aid Lotion', 'lotion', 'D04AB01', false, 0, '02229827', 'FreeDiams::CA_HCDPD::DIN', 48182);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arthrotec 75', 'tablet', 'M01AB55', false, 0, '02229837', 'FreeDiams::CA_HCDPD::DIN', 48191);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hyoscine Butylbromide Injection Sandoz Standard', 'solution', 'A03BB01', false, 0, '02229868', 'FreeDiams::CA_HCDPD::DIN', 48226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Acetaminophen Caplets 325mg', 'tablet', 'N02BE01', false, 0, '02229873', 'FreeDiams::CA_HCDPD::DIN', 48231);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bellergal Spacetabs', 'tablet (extended-release)', 'A03ED', false, 0, '00176141', 'FreeDiams::CA_HCDPD::DIN', 48361);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandomigran', 'tablet', 'N02CX01', false, 0, '00329320', 'FreeDiams::CA_HCDPD::DIN', 48362);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Baclofen', 'tablet', 'M03BX01', false, 0, '02229936', 'FreeDiams::CA_HCDPD::DIN', 48389);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Baclofen', 'tablet', 'M03BX01', false, 0, '02229937', 'FreeDiams::CA_HCDPD::DIN', 48390);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sleep-Eze D Extra Strength Capsules', 'capsule', 'R06AA02', false, 0, '02229958', 'FreeDiams::CA_HCDPD::DIN', 48412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sleep-Eze D Extra Strength Caplets', 'tablet', 'R06AA02', false, 0, '02229959', 'FreeDiams::CA_HCDPD::DIN', 48413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sleep-Eze D Caplets', 'tablet', 'R06AA02', false, 0, '02229960', 'FreeDiams::CA_HCDPD::DIN', 48414);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aspirin With Stomach Guard Extra Strength - Tab', 'tablet', 'N02BA51', false, 0, '02229967', 'FreeDiams::CA_HCDPD::DIN', 48421);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Acetaminophen Caplets 500mg', 'tablet', 'N02BE01', false, 0, '02229977', 'FreeDiams::CA_HCDPD::DIN', 48431);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aspirin With Stomach Guard', 'tablet', 'N02BA51', false, 0, '02229980', 'FreeDiams::CA_HCDPD::DIN', 48434);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Metformin', 'tablet', 'A10BA02', false, 0, '02229994', 'FreeDiams::CA_HCDPD::DIN', 48453);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Viokase Tabs', 'tablet', 'A09AA02', false, 0, '02230019', 'FreeDiams::CA_HCDPD::DIN', 48551);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hyzaar 50/12.5mg', 'tablet', 'C09DA01', false, 0, '02230047', 'FreeDiams::CA_HCDPD::DIN', 48580);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte Sodium Bicarbonate Liquid Concentrate', 'liquid', 'B05ZA', false, 0, '02230083', 'FreeDiams::CA_HCDPD::DIN', 48615);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Theophylline Sr', 'tablet (extended-release)', 'R03DA04', false, 0, '02230085', 'FreeDiams::CA_HCDPD::DIN', 48617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Theophylline Sr', 'tablet (extended-release)', 'R03DA04', false, 0, '02230086', 'FreeDiams::CA_HCDPD::DIN', 48618);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Theophylline Sr', 'tablet (extended-release)', 'R03DA04', false, 0, '02230087', 'FreeDiams::CA_HCDPD::DIN', 48619);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Flutamide', 'tablet', 'L02BB01', false, 0, '02230089', 'FreeDiams::CA_HCDPD::DIN', 48621);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pentoxifylline Sr', 'tablet (extended-release)', 'C04AD03', false, 0, '02230090', 'FreeDiams::CA_HCDPD::DIN', 48622);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Temazepam', 'capsule', 'N05CD07', false, 0, '02230095', 'FreeDiams::CA_HCDPD::DIN', 48627);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Temazepam', 'capsule', 'N05CD07', false, 0, '02230102', 'FreeDiams::CA_HCDPD::DIN', 48634);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Flutamide', 'tablet', 'L02BB01', false, 0, '02230104', 'FreeDiams::CA_HCDPD::DIN', 48636);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doxorubicin Hydrochloride Injection', 'solution', 'L01DB01', false, 0, '02230108', 'FreeDiams::CA_HCDPD::DIN', 48640);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Gemfibrozil', 'tablet', 'C10AB04', false, 0, '02230183', 'FreeDiams::CA_HCDPD::DIN', 48859);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Vancomycin Hydrochloride, Usp - 500mg/Vial (10ml)', 'powder for solution', 'J01XA01', false, 0, '02230191', 'FreeDiams::CA_HCDPD::DIN', 48884);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Vancomycin Hydrochloride, Usp  - 1g/Vial (20ml)', 'powder for solution', 'J01XA01', false, 0, '02230192', 'FreeDiams::CA_HCDPD::DIN', 48885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Ketorolac - Tab 10mg', 'tablet', 'M01AB15', false, 0, '02230201', 'FreeDiams::CA_HCDPD::DIN', 48899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Tryptophan', 'tablet', 'N06AX02', false, 0, '02230202', 'FreeDiams::CA_HCDPD::DIN', 48900);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Captopril - Tab  12.5mg', 'tablet', 'C09AA01', false, 0, '02230203', 'FreeDiams::CA_HCDPD::DIN', 48901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Captopril - Tab  25mg', 'tablet', 'C09AA01', false, 0, '02230204', 'FreeDiams::CA_HCDPD::DIN', 48902);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Captopril - Tab  50mg', 'tablet', 'C09AA01', false, 0, '02230205', 'FreeDiams::CA_HCDPD::DIN', 48903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Captopril - Tab 100mg', 'tablet', 'C09AA01', false, 0, '02230206', 'FreeDiams::CA_HCDPD::DIN', 48904);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lupron Depot', 'powder for suspension, sustained-release', 'L02AE02', false, 0, '02230248', 'FreeDiams::CA_HCDPD::DIN', 48922);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pilocarpine 6%', 'solution', 'S01EB01', false, 0, '02230239', 'FreeDiams::CA_HCDPD::DIN', 48923);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Flunarizine - Cap 5mg', 'capsule', 'N07CA03', false, 0, '02230220', 'FreeDiams::CA_HCDPD::DIN', 48929);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Amoxicillin', 'capsule', 'J01CA04', false, 0, '02230243', 'FreeDiams::CA_HCDPD::DIN', 48975);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Amoxicillin', 'capsule', 'J01CA04', false, 0, '02230244', 'FreeDiams::CA_HCDPD::DIN', 48976);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Amoxicillin', 'powder for suspension', 'J01CA04', false, 0, '02230245', 'FreeDiams::CA_HCDPD::DIN', 48977);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Amoxicillin', 'powder for solution', 'J01CA04', false, 0, '02230246', 'FreeDiams::CA_HCDPD::DIN', 48978);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Peract 20 Liquid Sterilant', 'solution', 'V07AV', false, 0, '02230250', 'FreeDiams::CA_HCDPD::DIN', 48981);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibiotic Ointment Usp', 'ointment', 'D06AX30', false, 0, '02230251', 'FreeDiams::CA_HCDPD::DIN', 48982);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Clopamine Tab 10mg', 'tablet', 'N06AA04', false, 0, '02230256', 'FreeDiams::CA_HCDPD::DIN', 48987);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Barri-Care Moisture Barrier', 'ointment', 'D08AE05', false, 0, '02230257', 'FreeDiams::CA_HCDPD::DIN', 48988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun/Soleil', 'stick', 'D02BA30', false, 0, '02230260', 'FreeDiams::CA_HCDPD::DIN', 48991);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cefaclor', 'capsule', 'J01DC04', false, 0, '02230263', 'FreeDiams::CA_HCDPD::DIN', 48998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cefaclor', 'capsule', 'J01DC04', false, 0, '02230264', 'FreeDiams::CA_HCDPD::DIN', 48999);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bengay Muscle Pain No Odour', 'cream', 'M02AC', false, 0, '02230266', 'FreeDiams::CA_HCDPD::DIN', 49001);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diltiazem Hydrochloride Injection', 'solution', 'C08DB01', false, 0, '02230274', 'FreeDiams::CA_HCDPD::DIN', 49026);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Light Mineral Oil', 'liquid', 'D02AC', false, 0, '02230275', 'FreeDiams::CA_HCDPD::DIN', 49031);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trazorel', 'tablet', 'N06AX05', false, 0, '02230284', 'FreeDiams::CA_HCDPD::DIN', 49041);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trazorel', 'tablet', 'N06AX05', false, 0, '02230285', 'FreeDiams::CA_HCDPD::DIN', 49042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trazorel', 'tablet', 'N06AX05', false, 0, '02230286', 'FreeDiams::CA_HCDPD::DIN', 49043);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zantac  - Tab 75mg', 'tablet', 'A02BA02', false, 0, '02230287', 'FreeDiams::CA_HCDPD::DIN', 49044);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Codeine Contin 50mg Controlled Release Tab', 'tablet (extended-release)', 'R05DA04', false, 0, '02230302', 'FreeDiams::CA_HCDPD::DIN', 49057);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micatin Powder Spray     - Unscented 2%', 'aerosol', 'D01AC02', false, 0, '02230304', 'FreeDiams::CA_HCDPD::DIN', 49064);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gemzar  (200mg/Vial)', 'powder for solution', 'L01BC05', false, 0, '02230308', 'FreeDiams::CA_HCDPD::DIN', 49068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gemzar  (1gm/Vial)', 'powder for solution', 'L01BC05', false, 0, '02230309', 'FreeDiams::CA_HCDPD::DIN', 49070);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Methylphenidate', 'tablet', 'N06BA04', false, 0, '02230321', 'FreeDiams::CA_HCDPD::DIN', 49089);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Methylphenidate', 'tablet', 'N06BA04', false, 0, '02230322', 'FreeDiams::CA_HCDPD::DIN', 49090);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Mexiletine  Cap 100mg', 'capsule', 'C01BB02', false, 0, '02230359', 'FreeDiams::CA_HCDPD::DIN', 49155);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Mexiletine Cap 200mg', 'capsule', 'C01BB02', false, 0, '02230360', 'FreeDiams::CA_HCDPD::DIN', 49157);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norventyl', 'capsule', 'N06AA10', false, 0, '02230361', 'FreeDiams::CA_HCDPD::DIN', 49159);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norventyl', 'capsule', 'N06AA10', false, 0, '02230362', 'FreeDiams::CA_HCDPD::DIN', 49161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clonapam', 'tablet', 'N03AE01', false, 0, '02230366', 'FreeDiams::CA_HCDPD::DIN', 49164);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clonapam', 'tablet', 'N03AE01', false, 0, '02230368', 'FreeDiams::CA_HCDPD::DIN', 49166);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clonapam', 'tablet', 'N03AE01', false, 0, '02230369', 'FreeDiams::CA_HCDPD::DIN', 49167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Cortimyxin', 'solution', 'S02CA03', false, 0, '02230386', 'FreeDiams::CA_HCDPD::DIN', 49184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('E-San', 'solution', 'V07AV', false, 0, '02230389', 'FreeDiams::CA_HCDPD::DIN', 49187);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Oxybutynin', 'tablet', 'G04BD04', false, 0, '02230394', 'FreeDiams::CA_HCDPD::DIN', 49219);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Winrho Sdf', 'kit', 'J06BB01', false, 0, '02230397', 'FreeDiams::CA_HCDPD::DIN', 49231);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy Tablets Extra Strength', 'tablet', 'R06AA02', false, 0, '02230398', 'FreeDiams::CA_HCDPD::DIN', 49235);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Pentoxifylline-Sr 400 Mg', 'tablet (extended-release)', 'C04AD03', false, 0, '02230401', 'FreeDiams::CA_HCDPD::DIN', 49240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clopixol Tablets 10mg', 'tablet', 'N05AF05', false, 0, '02230402', 'FreeDiams::CA_HCDPD::DIN', 49241);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clopixol Tablets 25mg', 'tablet', 'N05AF05', false, 0, '02230403', 'FreeDiams::CA_HCDPD::DIN', 49242);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clopixol-Acuphase 50mg/Ml', 'solution', 'N05AF05', false, 0, '02230405', 'FreeDiams::CA_HCDPD::DIN', 49244);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clopixol Depot 200mg/Ml', 'solution', 'N05AF05', false, 0, '02230406', 'FreeDiams::CA_HCDPD::DIN', 49245);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultiva', 'powder for solution', 'N01AH06', false, 0, '02230409', 'FreeDiams::CA_HCDPD::DIN', 49266);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultiva', 'powder for solution', 'N01AH06', false, 0, '02230410', 'FreeDiams::CA_HCDPD::DIN', 49270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultiva', 'powder for solution', 'N01AH06', false, 0, '02230411', 'FreeDiams::CA_HCDPD::DIN', 49272);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hemabate', 'solution', 'G02AD04', false, 0, '02230417', 'FreeDiams::CA_HCDPD::DIN', 49287);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imitrex Nasal Spray', 'spray', 'N02CC01', false, 0, '02230418', 'FreeDiams::CA_HCDPD::DIN', 49288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imitrex Nasal Spray', 'spray', 'N02CC01', false, 0, '02230420', 'FreeDiams::CA_HCDPD::DIN', 49290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Metoclopramide', 'tablet', 'A03FA01', false, 0, '02230431', 'FreeDiams::CA_HCDPD::DIN', 49332);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Metoclopramide', 'tablet', 'A03FA01', false, 0, '02230432', 'FreeDiams::CA_HCDPD::DIN', 49335);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Metoclopramide', 'liquid', 'A03FA01', false, 0, '02230433', 'FreeDiams::CA_HCDPD::DIN', 49340);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acet 120', 'suppository', 'N02BE01', false, 0, '02230434', 'FreeDiams::CA_HCDPD::DIN', 49357);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acet 160', 'suppository', 'N02BE01', false, 0, '02230435', 'FreeDiams::CA_HCDPD::DIN', 49359);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acet 325', 'suppository', 'N02BE01', false, 0, '02230436', 'FreeDiams::CA_HCDPD::DIN', 49360);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acet 650', 'suppository', 'N02BE01', false, 0, '02230437', 'FreeDiams::CA_HCDPD::DIN', 49361);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mitomycin For Injection', 'powder for solution', 'L01DC03', false, 0, '02230450', 'FreeDiams::CA_HCDPD::DIN', 49399);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mitomycin For Injection', 'powder for solution', 'L01DC03', false, 0, '02230451', 'FreeDiams::CA_HCDPD::DIN', 49400);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Bromocriptine', 'capsule', 'G02CB01', false, 0, '02230454', 'FreeDiams::CA_HCDPD::DIN', 49403);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hemorrhoidal Relief Ointment', 'ointment', 'C05AX03', false, 0, '02230466', 'FreeDiams::CA_HCDPD::DIN', 49424);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Restroom Cleaner And Disinfectant', 'liquid', 'V07AV', false, 0, '02230469', 'FreeDiams::CA_HCDPD::DIN', 49430);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Gemfibrozil', 'tablet', 'C10AB04', false, 0, '02230476', 'FreeDiams::CA_HCDPD::DIN', 49439);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Metformin Tab 850mg', 'tablet', 'A10BA02', false, 0, '02230475', 'FreeDiams::CA_HCDPD::DIN', 49444);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sleep Aid', 'tablet', 'R06AA02', false, 0, '02230485', 'FreeDiams::CA_HCDPD::DIN', 49476);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hemosol Lo', 'solution', 'B05ZA', false, 0, '02230504', 'FreeDiams::CA_HCDPD::DIN', 49558);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hemosol Lg4', 'solution', 'B05ZA', false, 0, '02230505', 'FreeDiams::CA_HCDPD::DIN', 49559);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hemosol Lg2', 'solution', 'B05ZA', false, 0, '02230506', 'FreeDiams::CA_HCDPD::DIN', 49560);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ranitidine', 'tablet', 'A02BA02', false, 0, '02230507', 'FreeDiams::CA_HCDPD::DIN', 49561);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Canesten Combi-Pak Cream 1', 'cream', 'G01AF02', false, 0, '02230509', 'FreeDiams::CA_HCDPD::DIN', 49563);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Quat Plus Germicidal Detergent', 'liquid', 'V07AV', false, 0, '02230516', 'FreeDiams::CA_HCDPD::DIN', 49585);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro Fil Ultra Germicidal Detergent', 'liquid', 'V07AV', false, 0, '02230517', 'FreeDiams::CA_HCDPD::DIN', 49586);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro Fil Ultra Plus Germicidal Detergent', 'liquid', 'V07AV', false, 0, '02230518', 'FreeDiams::CA_HCDPD::DIN', 49587);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methoxacet', 'tablet', 'M03BA53', false, 0, '02230521', 'FreeDiams::CA_HCDPD::DIN', 49590);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clindamycin Injection Usp', 'liquid', 'J01FF01', false, 0, '02230535', 'FreeDiams::CA_HCDPD::DIN', 49605);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Renu Fresh Multi-Purpose Solution', 'solution', 'S01XA20', false, 0, '02230538', 'FreeDiams::CA_HCDPD::DIN', 49610);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clindamycin Injection Usp', 'liquid', 'J01FF01', false, 0, '02230540', 'FreeDiams::CA_HCDPD::DIN', 49612);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advil Gel Caplets', 'tablet', 'M01AE01', false, 0, '02230541', 'FreeDiams::CA_HCDPD::DIN', 49613);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imodium Quick Dissolve', 'tablet', 'A07DA03', false, 0, '02230542', 'FreeDiams::CA_HCDPD::DIN', 49614);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alkazyme', 'powder', 'V07AV', false, 0, '02230568', 'FreeDiams::CA_HCDPD::DIN', 49650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ametop Gel 4%', 'gel', 'D04AB06', false, 0, '02230575', 'FreeDiams::CA_HCDPD::DIN', 49664);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Twinrix', 'suspension', 'J07BC20', false, 0, '02230578', 'FreeDiams::CA_HCDPD::DIN', 49687);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gamastan S/D', 'solution', 'J06BA01', false, 0, '02230579', 'FreeDiams::CA_HCDPD::DIN', 49688);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Gemfibrozil', 'tablet', 'C10AB04', false, 0, '02230580', 'FreeDiams::CA_HCDPD::DIN', 49689);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Bromazepam', 'tablet', 'N05BA08', false, 0, '02230584', 'FreeDiams::CA_HCDPD::DIN', 49693);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Bromazepam', 'tablet', 'N05BA08', false, 0, '02230585', 'FreeDiams::CA_HCDPD::DIN', 49694);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neostigmine Omega', 'liquid', 'N07AA01', false, 0, '02230592', 'FreeDiams::CA_HCDPD::DIN', 49701);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neostigmine Omega', 'liquid', 'N07AA01', false, 0, '02230593', 'FreeDiams::CA_HCDPD::DIN', 49702);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pediapred', 'liquid', 'H02AB06', false, 0, '02230619', 'FreeDiams::CA_HCDPD::DIN', 49795);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Opticrom', 'solution', 'S01GX01', false, 0, '02230621', 'FreeDiams::CA_HCDPD::DIN', 49797);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Selegiline', 'tablet', 'N04BD01', false, 0, '02230641', 'FreeDiams::CA_HCDPD::DIN', 49813);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tobramycin Injection, Usp', 'solution', 'J01GB01', false, 0, '02230639', 'FreeDiams::CA_HCDPD::DIN', 49816);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tobramycin Injection, Usp', 'solution', 'J01GB01', false, 0, '02230640', 'FreeDiams::CA_HCDPD::DIN', 49817);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermatop Emollient Cream', 'cream', 'D07AC18', false, 0, '02230642', 'FreeDiams::CA_HCDPD::DIN', 49818);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Immune Serum Globulin (Human)', 'solution', 'J06BA01', false, 0, '02230647', 'FreeDiams::CA_HCDPD::DIN', 49876);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Budesonide Aq', 'spray, metered dose', 'R01AD05', false, 0, '02230648', 'FreeDiams::CA_HCDPD::DIN', 49895);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rylosol', 'tablet', 'C07AA07', false, 0, '02230649', 'FreeDiams::CA_HCDPD::DIN', 49903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rylosol', 'tablet', 'C07AA07', false, 0, '02230650', 'FreeDiams::CA_HCDPD::DIN', 49907);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rylosol', 'tablet', 'C07AA07', false, 0, '02230651', 'FreeDiams::CA_HCDPD::DIN', 49910);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tenoxicam Tablets', 'tablet', 'M01AC02', false, 0, '02230661', 'FreeDiams::CA_HCDPD::DIN', 49920);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dicetel', 'tablet', 'A03AX04', false, 0, '02230684', 'FreeDiams::CA_HCDPD::DIN', 49943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Basix Neutral Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02230693', 'FreeDiams::CA_HCDPD::DIN', 49954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cerezyme', 'powder for solution', 'A16AB02', false, 0, '02230694', 'FreeDiams::CA_HCDPD::DIN', 49955);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hypertet S/D', 'solution', 'J06BB02', false, 0, '02230697', 'FreeDiams::CA_HCDPD::DIN', 49957);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hyperrab S/D', 'solution', 'J06BB05', false, 0, '02230700', 'FreeDiams::CA_HCDPD::DIN', 49960);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Haloperidol-La', 'liquid', 'N05AD01', false, 0, '02230707', 'FreeDiams::CA_HCDPD::DIN', 49965);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Haloperidol-La', 'liquid', 'N05AD01', false, 0, '02230708', 'FreeDiams::CA_HCDPD::DIN', 49967);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermaflex Hc 1% Cream', 'cream', 'D07XA01', false, 0, '00681989', 'FreeDiams::CA_HCDPD::DIN', 49970);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lipitor', 'tablet', 'C10AA05', false, 0, '02230711', 'FreeDiams::CA_HCDPD::DIN', 49973);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lipitor', 'tablet', 'C10AA05', false, 0, '02230713', 'FreeDiams::CA_HCDPD::DIN', 49974);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lipitor', 'tablet', 'C10AA05', false, 0, '02230714', 'FreeDiams::CA_HCDPD::DIN', 49975);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Selegiline', 'tablet', 'N04BD01', false, 0, '02230717', 'FreeDiams::CA_HCDPD::DIN', 49977);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mitomycin For Injection Usp', 'powder for solution', 'L01DC03', false, 0, '02230729', 'FreeDiams::CA_HCDPD::DIN', 49991);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Ketotifen Tab 1mg', 'tablet', 'R06AX17', false, 0, '02230730', 'FreeDiams::CA_HCDPD::DIN', 49992);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trinipatch 0.2', 'patch', 'C01DA02', false, 0, '02230732', 'FreeDiams::CA_HCDPD::DIN', 49993);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trinipatch 0.4', 'patch', 'C01DA02', false, 0, '02230733', 'FreeDiams::CA_HCDPD::DIN', 49995);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trinipatch 0.6', 'patch', 'C01DA02', false, 0, '02230734', 'FreeDiams::CA_HCDPD::DIN', 49996);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Minocycline', 'capsule', 'J01AA08', false, 0, '02230735', 'FreeDiams::CA_HCDPD::DIN', 49998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Minocycline', 'capsule', 'J01AA08', false, 0, '02230736', 'FreeDiams::CA_HCDPD::DIN', 49999);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Losec 10 Mg', 'tablet (delayed-release)', 'A02BC01', false, 0, '02230737', 'FreeDiams::CA_HCDPD::DIN', 50000);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hyperhep B S/D', 'solution', 'J06BB04', false, 0, '02230738', 'FreeDiams::CA_HCDPD::DIN', 50001);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Le Baume Ehrlich', 'cream', 'M02AB', false, 0, '02230766', 'FreeDiams::CA_HCDPD::DIN', 50027);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dalmacol', 'liquid', 'R05DA20', false, 0, '02230769', 'FreeDiams::CA_HCDPD::DIN', 50030);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Valproic Acid', 'capsule', 'N03AG01', false, 0, '02230768', 'FreeDiams::CA_HCDPD::DIN', 50031);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylene Blue Injection Usp', 'liquid', 'V03AB17', false, 0, '02230770', 'FreeDiams::CA_HCDPD::DIN', 50032);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tazorac', 'gel', 'D05AX05', false, 0, '02230784', 'FreeDiams::CA_HCDPD::DIN', 50053);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tazorac', 'gel', 'D05AX05', false, 0, '02230785', 'FreeDiams::CA_HCDPD::DIN', 50054);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceramide Time Complex Moisture Cream Spf 15', 'cream', 'D02BA02', false, 0, '02230786', 'FreeDiams::CA_HCDPD::DIN', 50055);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children Feverhalt Drops 80mg/Ml', 'solution', 'N02BE01', false, 0, '02230787', 'FreeDiams::CA_HCDPD::DIN', 50056);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Saniquat', 'liquid', 'V07AV', false, 0, '02230792', 'FreeDiams::CA_HCDPD::DIN', 50059);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quaternion', 'liquid', 'V07AV', false, 0, '02230791', 'FreeDiams::CA_HCDPD::DIN', 50061);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle & Back Pain Relief Caplets', 'tablet', 'M03BA53', false, 0, '02230790', 'FreeDiams::CA_HCDPD::DIN', 50062);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Oxybutynin', 'tablet', 'G04BD04', false, 0, '02230800', 'FreeDiams::CA_HCDPD::DIN', 50065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Metoprolol-L', 'tablet', 'C07AB02', false, 0, '02230803', 'FreeDiams::CA_HCDPD::DIN', 50067);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Metoprolol-L', 'tablet', 'C07AB02', false, 0, '02230804', 'FreeDiams::CA_HCDPD::DIN', 50068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Terazosin', 'tablet', 'G04CA03', false, 0, '02230805', 'FreeDiams::CA_HCDPD::DIN', 50069);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Terazosin', 'tablet', 'G04CA03', false, 0, '02230806', 'FreeDiams::CA_HCDPD::DIN', 50070);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Terazosin', 'tablet', 'G04CA03', false, 0, '02230807', 'FreeDiams::CA_HCDPD::DIN', 50071);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Terazosin', 'tablet', 'G04CA03', false, 0, '02230808', 'FreeDiams::CA_HCDPD::DIN', 50072);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('After Sun Soothing Spray', 'kit', 'D04AB01', false, 0, '02147149', 'FreeDiams::CA_HCDPD::DIN', 50081);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soothing Foot Spray  -  Liquid', 'liquid', 'D08AE20', false, 0, '02155052', 'FreeDiams::CA_HCDPD::DIN', 50083);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('After Sport Body Wash With Triclosan', 'liquid', 'D08AE04', false, 0, '02148196', 'FreeDiams::CA_HCDPD::DIN', 50085);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nutrineal Pd4', 'liquid', 'B05ZA', false, 0, '02230810', 'FreeDiams::CA_HCDPD::DIN', 50094);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Tiaprofenic', 'tablet', 'M01AE11', false, 0, '02230827', 'FreeDiams::CA_HCDPD::DIN', 50097);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Tiaprofenic', 'tablet', 'M01AE11', false, 0, '02230828', 'FreeDiams::CA_HCDPD::DIN', 50098);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polysporin Antibiotic Cream', 'cream', 'D06AX30', false, 0, '02230844', 'FreeDiams::CA_HCDPD::DIN', 50105);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylac', 'tablet', 'N05AH01', false, 0, '02230837', 'FreeDiams::CA_HCDPD::DIN', 50115);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylac', 'tablet', 'N05AH01', false, 0, '02230838', 'FreeDiams::CA_HCDPD::DIN', 50116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylac', 'tablet', 'N05AH01', false, 0, '02230839', 'FreeDiams::CA_HCDPD::DIN', 50117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylac', 'tablet', 'N05AH01', false, 0, '02230840', 'FreeDiams::CA_HCDPD::DIN', 50120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flolan', 'powder for solution', 'B01AC09', false, 0, '02230845', 'FreeDiams::CA_HCDPD::DIN', 50121);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flolan', 'powder for solution', 'B01AC09', false, 0, '02230848', 'FreeDiams::CA_HCDPD::DIN', 50122);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Diluent For Flolan Injection', 'liquid', 'V07AB', false, 0, '02230857', 'FreeDiams::CA_HCDPD::DIN', 50130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Lotion Ecran Solaire 15', 'lotion', 'D02BA30', false, 0, '02230859', 'FreeDiams::CA_HCDPD::DIN', 50132);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Honey Bee Venom Multidose 13.0 Ml (1300mcg)', 'powder for solution', 'V01AA07', false, 0, '02230860', 'FreeDiams::CA_HCDPD::DIN', 50133);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Lotion Ecran Solaire 30', 'lotion', 'D02BA30', false, 0, '02230861', 'FreeDiams::CA_HCDPD::DIN', 50134);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mixed Vespid Venom Protein Multidose 13.0 Ml (3900 Mcg)', 'powder for solution', 'V01AA07', false, 0, '02230862', 'FreeDiams::CA_HCDPD::DIN', 50135);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Yellow Jacket Venom Protein Multidose 13.0 Ml (1300 Mcg)', 'powder for solution', 'V01AA07', false, 0, '02230863', 'FreeDiams::CA_HCDPD::DIN', 50137);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Wasp Venom Protein Multidose 13.0 Ml (1300 Mcg)', 'powder for solution', 'V01AA07', false, 0, '02230864', 'FreeDiams::CA_HCDPD::DIN', 50138);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flutamide', 'tablet', 'L02BB01', false, 0, '02230875', 'FreeDiams::CA_HCDPD::DIN', 50149);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sereine Wetting & Soaking Solution', 'solution', 'S01XA20', false, 0, '02230877', 'FreeDiams::CA_HCDPD::DIN', 50153);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sereine Contact Lens Cleaner', 'solution', 'S01XA20', false, 0, '02230878', 'FreeDiams::CA_HCDPD::DIN', 50154);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Amoxi Sugar Free', 'powder for suspension', 'J01CA04', false, 0, '02230879', 'FreeDiams::CA_HCDPD::DIN', 50155);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Amoxi Sugar Free', 'powder for suspension', 'J01CA04', false, 0, '02230880', 'FreeDiams::CA_HCDPD::DIN', 50157);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Foradil Dry Powder Capsules For Inhalation', 'capsule', 'R03AC13', false, 0, '02230898', 'FreeDiams::CA_HCDPD::DIN', 50160);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Gentamicin', 'ointment', 'S01AA11', false, 0, '02230888', 'FreeDiams::CA_HCDPD::DIN', 50166);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Gentamicin Otic Drops 0.3%', 'drops', 'S02AA14', false, 0, '02230889', 'FreeDiams::CA_HCDPD::DIN', 50167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('C.E.S. Tablets', 'tablet', 'G03CA57', false, 0, '02230891', 'FreeDiams::CA_HCDPD::DIN', 50169);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('C.E.S. Tablets', 'tablet', 'G03CA57', false, 0, '02230892', 'FreeDiams::CA_HCDPD::DIN', 50170);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topamax 25mg', 'tablet', 'N03AX11', false, 0, '02230893', 'FreeDiams::CA_HCDPD::DIN', 50171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topamax 100mg', 'tablet', 'N03AX11', false, 0, '02230894', 'FreeDiams::CA_HCDPD::DIN', 50172);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topamax 200mg', 'tablet', 'N03AX11', false, 0, '02230896', 'FreeDiams::CA_HCDPD::DIN', 50174);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biltricide', 'tablet', 'P02BA01', false, 0, '02230897', 'FreeDiams::CA_HCDPD::DIN', 50175);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Junior Strength Acetaminophen Tablets', 'tablet', 'N02BE01', false, 0, '02230934', 'FreeDiams::CA_HCDPD::DIN', 50212);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckley''S Night Time Mixture', 'syrup', 'R06AA52', false, 0, '02230939', 'FreeDiams::CA_HCDPD::DIN', 50217);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Buspirone', 'tablet', 'N05BE01', false, 0, '02230941', 'FreeDiams::CA_HCDPD::DIN', 50219);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Buspirone', 'tablet', 'N05BE01', false, 0, '02230942', 'FreeDiams::CA_HCDPD::DIN', 50220);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quadracel', 'suspension', 'J07CA02', false, 0, '02230946', 'FreeDiams::CA_HCDPD::DIN', 50224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robaxisal Extra Strength', 'tablet', 'M03BA53', false, 0, '02230949', 'FreeDiams::CA_HCDPD::DIN', 50227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Clonazepam', 'tablet', 'N03AE01', false, 0, '02230950', 'FreeDiams::CA_HCDPD::DIN', 50228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Clonazepam', 'tablet', 'N03AE01', false, 0, '02230951', 'FreeDiams::CA_HCDPD::DIN', 50229);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elizabeth Arden Intervene Daily Moisture Lotion Spf 15 Oil Free', 'lotion', 'D02BA30', false, 0, '02230954', 'FreeDiams::CA_HCDPD::DIN', 50232);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Thermosept Ed', 'liquid', 'V07AV', false, 0, '02230955', 'FreeDiams::CA_HCDPD::DIN', 50234);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen U.S.P.', 'gas', 'V03AN01', false, 0, '02230956', 'FreeDiams::CA_HCDPD::DIN', 50235);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('One Touch Topical Anesthetic Gel', 'gel', 'D04AB30', false, 0, '02230958', 'FreeDiams::CA_HCDPD::DIN', 50238);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cerebyx', 'liquid', 'N03AB05', false, 0, '02230988', 'FreeDiams::CA_HCDPD::DIN', 50269);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diltiaz Cd', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02230997', 'FreeDiams::CA_HCDPD::DIN', 50278);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diltiaz Cd', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02230998', 'FreeDiams::CA_HCDPD::DIN', 50279);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diltiaz Cd', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02230999', 'FreeDiams::CA_HCDPD::DIN', 50280);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Refresh Tears', 'drops', 'S01XA20', false, 0, '02231008', 'FreeDiams::CA_HCDPD::DIN', 50289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Feverhalt   (160mg Chewable Tablets)', 'tablet', 'N02BE01', false, 0, '02231011', 'FreeDiams::CA_HCDPD::DIN', 50292);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Furantoin', 'capsule', 'J01XE01', false, 0, '02231015', 'FreeDiams::CA_HCDPD::DIN', 50295);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Furantoin', 'capsule', 'J01XE01', false, 0, '02231016', 'FreeDiams::CA_HCDPD::DIN', 50297);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Valproic Acid', 'capsule', 'N03AG01', false, 0, '02231030', 'FreeDiams::CA_HCDPD::DIN', 50311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Valproic Acid E.C.', 'capsule (enteric-coated)', 'N03AG01', false, 0, '02231031', 'FreeDiams::CA_HCDPD::DIN', 50312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bustab', 'tablet', 'N05BE01', false, 0, '02231034', 'FreeDiams::CA_HCDPD::DIN', 50317);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bustab', 'tablet', 'N05BE01', false, 0, '02231035', 'FreeDiams::CA_HCDPD::DIN', 50318);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Selegiline', 'tablet', 'N04BD01', false, 0, '02231036', 'FreeDiams::CA_HCDPD::DIN', 50319);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cervidil', 'insert', 'G02AD02', false, 0, '02231047', 'FreeDiams::CA_HCDPD::DIN', 50327);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Diltiaz-Cd Capsules 120mg', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02231052', 'FreeDiams::CA_HCDPD::DIN', 50333);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Diltiaz-Cd Capsules 180mg', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02231053', 'FreeDiams::CA_HCDPD::DIN', 50334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Diltiaz-Cd Capsules 240mg', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02231054', 'FreeDiams::CA_HCDPD::DIN', 50335);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diltiazem-Cd 300mg Capsules', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02231057', 'FreeDiams::CA_HCDPD::DIN', 50338);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Havrix 720 Junior', 'suspension', 'J07BC02', false, 0, '02231056', 'FreeDiams::CA_HCDPD::DIN', 50339);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Tiaprofenic', 'tablet', 'M01AE11', false, 0, '02231060', 'FreeDiams::CA_HCDPD::DIN', 50342);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Ketoconazole', 'tablet', 'J02AB02', false, 0, '02231061', 'FreeDiams::CA_HCDPD::DIN', 50343);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Oxybutynin', 'syrup', 'G04BD04', false, 0, '02231089', 'FreeDiams::CA_HCDPD::DIN', 50373);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Peptic Guard', 'tablet', 'A02BA03', false, 0, '02231104', 'FreeDiams::CA_HCDPD::DIN', 50389);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-Zyme Tab 50mg', 'tablet', 'A09AA02', false, 0, '00837008', 'FreeDiams::CA_HCDPD::DIN', 50394);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polytopic Cream', 'cream', 'D06AX30', false, 0, '00422908', 'FreeDiams::CA_HCDPD::DIN', 50407);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hycamtin', 'powder for solution', 'L01XX17', false, 0, '02231116', 'FreeDiams::CA_HCDPD::DIN', 50424);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Famotidine', 'tablet', 'A02BA03', false, 0, '02231119', 'FreeDiams::CA_HCDPD::DIN', 50426);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Metoprolol-L', 'tablet', 'C07AB02', false, 0, '02231121', 'FreeDiams::CA_HCDPD::DIN', 50428);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Metoprolol-L', 'tablet', 'C07AB02', false, 0, '02231122', 'FreeDiams::CA_HCDPD::DIN', 50429);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Serevent Diskus (50mcg/Dose)', 'powder', 'R03AC12', false, 0, '02231129', 'FreeDiams::CA_HCDPD::DIN', 50436);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ipratropium', 'solution', 'R03BB01', false, 0, '02231135', 'FreeDiams::CA_HCDPD::DIN', 50442);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ipratropium          (20 Ml Bottle)', 'solution', 'R03BB01', false, 0, '02231136', 'FreeDiams::CA_HCDPD::DIN', 50443);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zithromax 600mg', 'tablet', 'J01FA10', false, 0, '02231143', 'FreeDiams::CA_HCDPD::DIN', 50450);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidodan Endotracheal Non-Aerosol Spray', 'liquid', 'N01BB02', false, 0, '02231147', 'FreeDiams::CA_HCDPD::DIN', 50454);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tiazac', 'capsule (extended release)', 'C08DB01', false, 0, '02231150', 'FreeDiams::CA_HCDPD::DIN', 50458);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tiazac', 'capsule (extended release)', 'C08DB01', false, 0, '02231151', 'FreeDiams::CA_HCDPD::DIN', 50459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tiazac', 'capsule (extended release)', 'C08DB01', false, 0, '02231152', 'FreeDiams::CA_HCDPD::DIN', 50460);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tiazac', 'capsule (extended release)', 'C08DB01', false, 0, '02231154', 'FreeDiams::CA_HCDPD::DIN', 50461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tiazac', 'capsule (extended release)', 'C08DB01', false, 0, '02231155', 'FreeDiams::CA_HCDPD::DIN', 50462);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fragmin 25000iu(Anti-Xa)/Ml', 'solution', 'B01AB04', false, 0, '02231171', 'FreeDiams::CA_HCDPD::DIN', 50478);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robaxacet Extra Strength', 'tablet', 'M03BA53', false, 0, '02231176', 'FreeDiams::CA_HCDPD::DIN', 50484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Sotalol Tab 80mg', 'tablet', 'C07AA07', false, 0, '02231181', 'FreeDiams::CA_HCDPD::DIN', 50489);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Sotalol Tab 160mg', 'tablet', 'C07AA07', false, 0, '02231182', 'FreeDiams::CA_HCDPD::DIN', 50490);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Indapamide Tab 2.5 Mg', 'tablet', 'C03BA11', false, 0, '02231184', 'FreeDiams::CA_HCDPD::DIN', 50491);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acyclovir Sodium For Injection', 'powder for solution', 'J05AB01', false, 0, '02231190', 'FreeDiams::CA_HCDPD::DIN', 50497);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Fluvoxamine 50 Mg Tab', 'tablet', 'N06AB08', false, 0, '02231192', 'FreeDiams::CA_HCDPD::DIN', 50499);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Fluvoxamine 100 Mg Tab', 'tablet', 'N06AB08', false, 0, '02231193', 'FreeDiams::CA_HCDPD::DIN', 50500);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ioterge', 'liquid', 'V07AV', false, 0, '02231200', 'FreeDiams::CA_HCDPD::DIN', 50507);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Mefenamic Acid', 'capsule', 'M01AG01', false, 0, '02231208', 'FreeDiams::CA_HCDPD::DIN', 50515);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydroxyzine Hydrochloride Injection, Usp', 'liquid', 'N05BB01', false, 0, '02231209', 'FreeDiams::CA_HCDPD::DIN', 50516);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun Therapy - Suntan Spf 30', 'cream', 'D02BA30', false, 0, '02231225', 'FreeDiams::CA_HCDPD::DIN', 50532);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Menstrual Caplets', 'tablet', 'N02BE51', false, 0, '02231239', 'FreeDiams::CA_HCDPD::DIN', 50547);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ipratropium       (1ml Unit Dose)', 'solution', 'R03BB01', false, 0, '02231244', 'FreeDiams::CA_HCDPD::DIN', 50551);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ipratropium        (2ml Unit Dose)', 'solution', 'R03BB01', false, 0, '02231245', 'FreeDiams::CA_HCDPD::DIN', 50552);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pneumo 23', 'liquid', 'J07AL02', false, 0, '02231259', 'FreeDiams::CA_HCDPD::DIN', 50566);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Inactivated Poliomyelitis Vaccine (Diploid Cell Origin) - Ipv', 'solution', 'J07BF03', false, 0, '02231267', 'FreeDiams::CA_HCDPD::DIN', 50574);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multi-Purpose Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02231276', 'FreeDiams::CA_HCDPD::DIN', 50583);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Cimetidine', 'tablet', 'A02BA01', false, 0, '02231287', 'FreeDiams::CA_HCDPD::DIN', 50597);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Cimetidine', 'tablet', 'A02BA01', false, 0, '02231288', 'FreeDiams::CA_HCDPD::DIN', 50598);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Genteal', 'solution', 'S01XA20', false, 0, '02231289', 'FreeDiams::CA_HCDPD::DIN', 50599);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Cimetidine', 'tablet', 'A02BA01', false, 0, '02231290', 'FreeDiams::CA_HCDPD::DIN', 50600);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Care Spf 15 With Vitamin E', 'stick', 'D02BA30', false, 0, '02231298', 'FreeDiams::CA_HCDPD::DIN', 50605);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Dm', 'suspension', 'R05DA09', false, 0, '02231313', 'FreeDiams::CA_HCDPD::DIN', 50620);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized Mite Dermatophagoides Farinae', 'liquid', 'V01AA07', false, 0, '02231321', 'FreeDiams::CA_HCDPD::DIN', 50628);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized Mite Dermatophagoides Pteronyssinus', 'liquid', 'V01AA07', false, 0, '02231324', 'FreeDiams::CA_HCDPD::DIN', 50631);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Naproxen Sr', 'tablet (extended-release)', 'M01AE02', false, 0, '02231327', 'FreeDiams::CA_HCDPD::DIN', 50634);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Fluoxetine Oral Solution', 'solution', 'N06AB03', false, 0, '02231328', 'FreeDiams::CA_HCDPD::DIN', 50635);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Fluvoxamine Tablets', 'tablet', 'N06AB08', false, 0, '02231329', 'FreeDiams::CA_HCDPD::DIN', 50637);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Fluvoxamine Tablets', 'tablet', 'N06AB08', false, 0, '02231330', 'FreeDiams::CA_HCDPD::DIN', 50638);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Degraisseur-Desinfectant', 'liquid', 'V07AV', false, 0, '02231332', 'FreeDiams::CA_HCDPD::DIN', 50646);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pentacel', 'kit', 'J07CA06', false, 0, '02231343', 'FreeDiams::CA_HCDPD::DIN', 50651);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('T36 Disinfex', 'liquid', 'V07AV', false, 0, '02231344', 'FreeDiams::CA_HCDPD::DIN', 50653);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sporanox Oral Solution 10mg/Ml', 'solution', 'J02AC02', false, 0, '02231347', 'FreeDiams::CA_HCDPD::DIN', 50656);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kwellada-P Lotion', 'lotion', 'P03AC04', false, 0, '02231348', 'FreeDiams::CA_HCDPD::DIN', 50657);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Cyclobenzaprine', 'tablet', 'M03BX08', false, 0, '02231353', 'FreeDiams::CA_HCDPD::DIN', 50662);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tavist Tablets 1mg', 'tablet', 'R06AA04', false, 0, '00035971', 'FreeDiams::CA_HCDPD::DIN', 50687);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anzemet', 'tablet', 'A04AA04', false, 0, '02231379', 'FreeDiams::CA_HCDPD::DIN', 50690);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Femara 2.5mg', 'tablet', 'L02BG04', false, 0, '02231384', 'FreeDiams::CA_HCDPD::DIN', 50695);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cromolyn Nasal Spray', 'kit', 'R01AC01', false, 0, '02231390', 'FreeDiams::CA_HCDPD::DIN', 50704);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Control', 'tablet', 'A02BA03', false, 0, '02231400', 'FreeDiams::CA_HCDPD::DIN', 50715);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Dm 12 Hour Syrup', 'syrup (extended-release)', 'R05DA09', false, 0, '02231404', 'FreeDiams::CA_HCDPD::DIN', 50719);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daunorubicin Hydrochloride For Injection', 'powder for solution', 'L01DB02', false, 0, '02231420', 'FreeDiams::CA_HCDPD::DIN', 50738);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cromolyn Sterules', 'solution', 'R03BC01', false, 0, '02231431', 'FreeDiams::CA_HCDPD::DIN', 50747);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Cefaclor Capsules 250mg', 'capsule', 'J01DC04', false, 0, '02231432', 'FreeDiams::CA_HCDPD::DIN', 50748);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Cefaclor', 'capsule', 'J01DC04', false, 0, '02231433', 'FreeDiams::CA_HCDPD::DIN', 50749);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Lovastatin Tablets', 'tablet', 'C10AA02', false, 0, '02231434', 'FreeDiams::CA_HCDPD::DIN', 50750);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitrolingual Pumpspray', 'metered-dose pump', 'C01DA02', false, 0, '02231441', 'FreeDiams::CA_HCDPD::DIN', 50758);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mavik (0.5mg)', 'capsule', 'C09AA10', false, 0, '02231457', 'FreeDiams::CA_HCDPD::DIN', 50773);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mavik (1mg)', 'capsule', 'C09AA10', false, 0, '02231459', 'FreeDiams::CA_HCDPD::DIN', 50775);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mavik (2mg)', 'capsule', 'C09AA10', false, 0, '02231460', 'FreeDiams::CA_HCDPD::DIN', 50776);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allegra 12 Hour', 'tablet', 'R06AX26', false, 0, '02231462', 'FreeDiams::CA_HCDPD::DIN', 50779);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gonal-F', 'powder for solution', 'G03GA05', false, 0, '02231465', 'FreeDiams::CA_HCDPD::DIN', 50782);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gammagard S/D  (Iv)', 'powder for solution', 'J06BA02', false, 0, '02231468', 'FreeDiams::CA_HCDPD::DIN', 50792);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oesclim', 'patch', 'G03CA03', false, 0, '02243724', 'FreeDiams::CA_HCDPD::DIN', 67656);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gammagard S/D  (Iv)', 'powder for solution', 'J06BA02', false, 0, '02231469', 'FreeDiams::CA_HCDPD::DIN', 50793);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gammagard S/D  (Iv)', 'powder for solution', 'J06BA02', false, 0, '02231470', 'FreeDiams::CA_HCDPD::DIN', 50794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gammagard S/D  (Iv)', 'powder for solution', 'J06BA02', false, 0, '02231471', 'FreeDiams::CA_HCDPD::DIN', 50795);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diltiazem-Cd 120mg Capsules', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02231472', 'FreeDiams::CA_HCDPD::DIN', 50796);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diltiazem-Cd 180mg Capsules', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02231474', 'FreeDiams::CA_HCDPD::DIN', 50798);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diltiazem-Cd 240mg Capsules', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02231475', 'FreeDiams::CA_HCDPD::DIN', 50799);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Domperidone 10 Mg Tablets', 'tablet', 'A03FA03', false, 0, '02231477', 'FreeDiams::CA_HCDPD::DIN', 50801);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Innohep', 'solution', 'B01AB10', false, 0, '02231478', 'FreeDiams::CA_HCDPD::DIN', 50802);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kwellada-P Creme Rinse', 'liquid', 'P03AC04', false, 0, '02231480', 'FreeDiams::CA_HCDPD::DIN', 50804);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prospray', 'solution', 'V07AV', false, 0, '02231483', 'FreeDiams::CA_HCDPD::DIN', 50814);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Salvent Sterules', 'solution', 'R03AC02', false, 0, '02231488', 'FreeDiams::CA_HCDPD::DIN', 50819);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Valproic', 'capsule (enteric-coated)', 'N03AG01', false, 0, '02231489', 'FreeDiams::CA_HCDPD::DIN', 50820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Azathioprine', 'tablet', 'L04AX01', false, 0, '02231491', 'FreeDiams::CA_HCDPD::DIN', 50821);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Buspirone', 'tablet', 'N05BE01', false, 0, '02231492', 'FreeDiams::CA_HCDPD::DIN', 50822);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xalatan', 'solution', 'S01EE01', false, 0, '02231493', 'FreeDiams::CA_HCDPD::DIN', 50823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ipravent Sterules', 'solution', 'R03BB01', false, 0, '02231494', 'FreeDiams::CA_HCDPD::DIN', 50824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diclofenac', 'tablet', 'M01AB05', false, 0, '02231502', 'FreeDiams::CA_HCDPD::DIN', 50842);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diclofenac', 'tablet', 'M01AB05', false, 0, '02231503', 'FreeDiams::CA_HCDPD::DIN', 50843);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diclofenac-Sr', 'tablet (extended-release)', 'M01AB05', false, 0, '02231504', 'FreeDiams::CA_HCDPD::DIN', 50844);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diclofenac-Sr', 'tablet (extended-release)', 'M01AB05', false, 0, '02231505', 'FreeDiams::CA_HCDPD::DIN', 50845);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diclofenac', 'suppository', 'M01AB05', false, 0, '02231506', 'FreeDiams::CA_HCDPD::DIN', 50847);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diclofenac', 'suppository', 'M01AB05', false, 0, '02231508', 'FreeDiams::CA_HCDPD::DIN', 50848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Climara 50', 'patch', 'G03CA03', false, 0, '02231509', 'FreeDiams::CA_HCDPD::DIN', 50849);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Climara 100', 'patch', 'G03CA03', false, 0, '02231510', 'FreeDiams::CA_HCDPD::DIN', 50850);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Grenadier', 'liquid', 'V07AV', false, 0, '02231522', 'FreeDiams::CA_HCDPD::DIN', 50866);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vivotif L', 'powder', 'J07AP01', false, 0, '02231523', 'FreeDiams::CA_HCDPD::DIN', 50867);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pursue Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02231526', 'FreeDiams::CA_HCDPD::DIN', 50870);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ofloxacin Tablets', 'tablet', 'J01MA01', false, 0, '02231529', 'FreeDiams::CA_HCDPD::DIN', 50873);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ofloxacin Tablets', 'tablet', 'J01MA01', false, 0, '02231531', 'FreeDiams::CA_HCDPD::DIN', 50874);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ofloxacin Tablets', 'tablet', 'J01MA01', false, 0, '02231532', 'FreeDiams::CA_HCDPD::DIN', 50875);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Miconazole Nitrate Vaginal Cream Usp, 2%', 'cream', 'G01AF04', false, 0, '02231533', 'FreeDiams::CA_HCDPD::DIN', 50876);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pindolol', 'tablet', 'C07AA03', false, 0, '02231536', 'FreeDiams::CA_HCDPD::DIN', 50877);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pindolol', 'tablet', 'C07AA03', false, 0, '02231537', 'FreeDiams::CA_HCDPD::DIN', 50879);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pindolol', 'tablet', 'C07AA03', false, 0, '02231539', 'FreeDiams::CA_HCDPD::DIN', 50882);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Carbamazepine', 'tablet (chewable)', 'N03AF01', false, 0, '02231540', 'FreeDiams::CA_HCDPD::DIN', 50883);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Carbamazepine', 'tablet (chewable)', 'N03AF01', false, 0, '02231542', 'FreeDiams::CA_HCDPD::DIN', 50885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Carbamazepine-Cr', 'tablet (extended-release)', 'N03AF01', false, 0, '02231543', 'FreeDiams::CA_HCDPD::DIN', 50886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Carbamazepine-Cr', 'tablet (extended-release)', 'N03AF01', false, 0, '02231544', 'FreeDiams::CA_HCDPD::DIN', 50887);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Control', 'tablet', 'A02BA03', false, 0, '02231567', 'FreeDiams::CA_HCDPD::DIN', 50911);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abelcet', 'suspension', 'J02AA01', false, 0, '02231590', 'FreeDiams::CA_HCDPD::DIN', 50926);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kid''S Spf 30', 'lotion', 'D02BA30', false, 0, '02231574', 'FreeDiams::CA_HCDPD::DIN', 50939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bikini Zone', 'cream', 'D04AB01', false, 0, '02231578', 'FreeDiams::CA_HCDPD::DIN', 50944);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-Safe Lotion', 'lotion', 'D08AE04', false, 0, '02231580', 'FreeDiams::CA_HCDPD::DIN', 50946);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eprex Sterile Solution 1000iu/0.5ml', 'solution', 'B03XA01', false, 0, '02231583', 'FreeDiams::CA_HCDPD::DIN', 50949);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eprex Sterile Solution 2000iu/0.5ml', 'solution', 'B03XA01', false, 0, '02231584', 'FreeDiams::CA_HCDPD::DIN', 50950);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eprex Sterile Solution 3000iu/0.3ml', 'solution', 'B03XA01', false, 0, '02231585', 'FreeDiams::CA_HCDPD::DIN', 50951);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eprex Sterile Solution 4000iu/0.4ml', 'solution', 'B03XA01', false, 0, '02231586', 'FreeDiams::CA_HCDPD::DIN', 50952);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eprex Sterile Solution 10000iu/1.0ml', 'solution', 'B03XA01', false, 0, '02231587', 'FreeDiams::CA_HCDPD::DIN', 50953);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Differin', 'cream', 'D10AD03', false, 0, '02231592', 'FreeDiams::CA_HCDPD::DIN', 50959);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Duratocin Injection', 'liquid', 'H01BB03', false, 0, '02231593', 'FreeDiams::CA_HCDPD::DIN', 50960);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hygenipak Instafoam Anti-Microbial Foaming Skin Cleanser', 'liquid', 'D08AE04', false, 0, '02231594', 'FreeDiams::CA_HCDPD::DIN', 50961);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cetirizine', 'tablet', 'R06AE07', false, 0, '02231603', 'FreeDiams::CA_HCDPD::DIN', 50975);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Camptosar Injection', 'solution', 'L01XX19', false, 0, '02231622', 'FreeDiams::CA_HCDPD::DIN', 50993);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soft Care Antiseptic Skin Cleanser', 'liquid', 'D08AE05', false, 0, '02231636', 'FreeDiams::CA_HCDPD::DIN', 51009);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Pindolol', 'tablet', 'C07AA03', false, 0, '02231650', 'FreeDiams::CA_HCDPD::DIN', 51024);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intron A', 'kit', 'L03AB05', false, 0, '02231651', 'FreeDiams::CA_HCDPD::DIN', 51025);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Diclofenac', 'tablet', 'M01AB05', false, 0, '02231662', 'FreeDiams::CA_HCDPD::DIN', 51037);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Diclofenac', 'tablet', 'M01AB05', false, 0, '02231663', 'FreeDiams::CA_HCDPD::DIN', 51039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Diclofenac-Sr', 'tablet (extended-release)', 'M01AB05', false, 0, '02231664', 'FreeDiams::CA_HCDPD::DIN', 51040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Clomipramine', 'tablet', 'N06AA04', false, 0, '02231667', 'FreeDiams::CA_HCDPD::DIN', 51042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Clomipramine', 'tablet', 'N06AA04', false, 0, '02231669', 'FreeDiams::CA_HCDPD::DIN', 51044);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Cromolyn Plastic Ampules', 'solution', 'R03BC01', false, 0, '02231671', 'FreeDiams::CA_HCDPD::DIN', 51046);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Protamine Sulfate Injection Usp', 'solution', 'V03AB14', false, 0, '02231674', 'FreeDiams::CA_HCDPD::DIN', 51049);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Combivent Udv', 'solution', 'R03AK04', false, 0, '02231675', 'FreeDiams::CA_HCDPD::DIN', 51050);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Covera-Hs', 'tablet (extended-release)', 'C08DA01', false, 0, '02231676', 'FreeDiams::CA_HCDPD::DIN', 51052);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Covera-Hs', 'tablet (extended-release)', 'C08DA01', false, 0, '02231677', 'FreeDiams::CA_HCDPD::DIN', 51053);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Salvent Sterules', 'solution', 'R03AC02', false, 0, '02231678', 'FreeDiams::CA_HCDPD::DIN', 51054);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ketotifen', 'syrup', 'R06AX17', false, 0, '02231679', 'FreeDiams::CA_HCDPD::DIN', 51055);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ketotifen', 'tablet', 'R06AX17', false, 0, '02231680', 'FreeDiams::CA_HCDPD::DIN', 51056);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Trazodone', 'tablet', 'N06AX05', false, 0, '02231683', 'FreeDiams::CA_HCDPD::DIN', 51060);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Trazodone', 'tablet', 'N06AX05', false, 0, '02231684', 'FreeDiams::CA_HCDPD::DIN', 51061);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Trazodone', 'tablet', 'N06AX05', false, 0, '02231685', 'FreeDiams::CA_HCDPD::DIN', 51062);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Labetalol Hydrochloride Injection Usp', 'liquid', 'C07AG01', false, 0, '02231689', 'FreeDiams::CA_HCDPD::DIN', 51066);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cefaclor', 'capsule', 'J01DC04', false, 0, '02231691', 'FreeDiams::CA_HCDPD::DIN', 51068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cefaclor', 'capsule', 'J01DC04', false, 0, '02231693', 'FreeDiams::CA_HCDPD::DIN', 51070);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Bromocriptine', 'tablet', 'G02CB01', false, 0, '02231702', 'FreeDiams::CA_HCDPD::DIN', 51080);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Atenolol', 'tablet', 'C07AB03', false, 0, '02231731', 'FreeDiams::CA_HCDPD::DIN', 51110);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Atenolol', 'tablet', 'C07AB03', false, 0, '02231733', 'FreeDiams::CA_HCDPD::DIN', 51112);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fenofibrate Micro', 'capsule', 'C10AB05', false, 0, '02231780', 'FreeDiams::CA_HCDPD::DIN', 51210);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Nortriptyline 10mg', 'capsule', 'N06AA10', false, 0, '02231781', 'FreeDiams::CA_HCDPD::DIN', 51213);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Nortriptyline', 'capsule', 'N06AA10', false, 0, '02231782', 'FreeDiams::CA_HCDPD::DIN', 51214);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Salbutamol Plastic Ampules 1 Mg/Ml', 'solution', 'R03AC02', false, 0, '02231783', 'FreeDiams::CA_HCDPD::DIN', 51215);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Salbutamol Plastic Ampules  2 Mg/Ml', 'solution', 'R03AC02', false, 0, '02231784', 'FreeDiams::CA_HCDPD::DIN', 51216);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Ipratropium Plastic Ampules 250 Mcg/Ml', 'solution', 'R03BB01', false, 0, '02231785', 'FreeDiams::CA_HCDPD::DIN', 51217);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Indomethacin', 'suppository', 'M01AB01', false, 0, '02231799', 'FreeDiams::CA_HCDPD::DIN', 51232);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Indomethacin', 'suppository', 'M01AB01', false, 0, '02231800', 'FreeDiams::CA_HCDPD::DIN', 51233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylprednisolone Sodium Succinate For Injection', 'powder for solution', 'H02AB04', false, 0, '02231893', 'FreeDiams::CA_HCDPD::DIN', 51346);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylprednisolone Sodium Succinate For Injection', 'powder for solution', 'H02AB04', false, 0, '02231894', 'FreeDiams::CA_HCDPD::DIN', 51347);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylprednisolone Sodium Succinate For Injection', 'powder for solution', 'H02AB04', false, 0, '02231895', 'FreeDiams::CA_HCDPD::DIN', 51348);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rhinocort Aqua', 'spray, metered dose', 'R01AD05', false, 0, '02231923', 'FreeDiams::CA_HCDPD::DIN', 51375);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isoflurane Usp', 'liquid', 'N01AB06', false, 0, '02231929', 'FreeDiams::CA_HCDPD::DIN', 51381);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxy.Ir', 'tablet', 'N02AA05', false, 0, '02231934', 'FreeDiams::CA_HCDPD::DIN', 51386);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Statex Suppositories 5mg', 'suppository', 'N02AA01', false, 0, '00632228', 'FreeDiams::CA_HCDPD::DIN', 51391);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Statex Suppositories 30mg', 'suppository', 'N02AA01', false, 0, '00639389', 'FreeDiams::CA_HCDPD::DIN', 51392);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cytogam', 'liquid', 'J06BB09', false, 0, '02231962', 'FreeDiams::CA_HCDPD::DIN', 51418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aricept', 'tablet', 'N06DA02', false, 0, '02232043', 'FreeDiams::CA_HCDPD::DIN', 51491);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aricept', 'tablet', 'N06DA02', false, 0, '02232044', 'FreeDiams::CA_HCDPD::DIN', 51492);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Moclobemide', 'tablet', 'N06AG02', false, 0, '02232148', 'FreeDiams::CA_HCDPD::DIN', 51594);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Moclobemide', 'tablet', 'N06AG02', false, 0, '02232150', 'FreeDiams::CA_HCDPD::DIN', 51595);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Clobetasol Cream', 'cream', 'D07AD01', false, 0, '02232191', 'FreeDiams::CA_HCDPD::DIN', 51610);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Clobetasol Ointment', 'ointment', 'D07AD01', false, 0, '02232193', 'FreeDiams::CA_HCDPD::DIN', 51611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Clobetasol Scalp Application', 'liquid', 'D07AD01', false, 0, '02232195', 'FreeDiams::CA_HCDPD::DIN', 51612);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Derm Creme De Jour', 'cream', 'D02BA30', false, 0, '02232205', 'FreeDiams::CA_HCDPD::DIN', 51733);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Advil', 'suspension', 'M01AE01', false, 0, '02232297', 'FreeDiams::CA_HCDPD::DIN', 51742);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Etodolac', 'capsule', 'M01AB08', false, 0, '02232317', 'FreeDiams::CA_HCDPD::DIN', 51745);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Etodolac', 'capsule', 'M01AB08', false, 0, '02232318', 'FreeDiams::CA_HCDPD::DIN', 51746);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exdol-8 Tablets', 'tablet', 'N02BE51', false, 0, '02232387', 'FreeDiams::CA_HCDPD::DIN', 51867);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exdol-15 Tablets', 'tablet', 'N02BE51', false, 0, '02232388', 'FreeDiams::CA_HCDPD::DIN', 51868);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exdol-30 Tablets', 'tablet', 'N02AA59', false, 0, '02232389', 'FreeDiams::CA_HCDPD::DIN', 51869);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sani Rinse', 'liquid', 'V07AV', false, 0, '02232453', 'FreeDiams::CA_HCDPD::DIN', 51889);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balminil Nasal Decongestant', 'spray', 'R01AA07', false, 0, '00791172', 'FreeDiams::CA_HCDPD::DIN', 51892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quaterg', 'liquid', 'V07AV', false, 0, '02232463', 'FreeDiams::CA_HCDPD::DIN', 51894);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Buspirone', 'tablet', 'N05BE01', false, 0, '02232564', 'FreeDiams::CA_HCDPD::DIN', 52040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Requip', 'tablet', 'N04BC04', false, 0, '02232565', 'FreeDiams::CA_HCDPD::DIN', 52041);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Requip', 'tablet', 'N04BC04', false, 0, '02232567', 'FreeDiams::CA_HCDPD::DIN', 52043);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Requip', 'tablet', 'N04BC04', false, 0, '02232568', 'FreeDiams::CA_HCDPD::DIN', 52044);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Requip', 'tablet', 'N04BC04', false, 0, '02232569', 'FreeDiams::CA_HCDPD::DIN', 52047);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Airomir', 'metered-dose (aerosol)', 'R03AC02', false, 0, '02232570', 'FreeDiams::CA_HCDPD::DIN', 52048);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Procet-30', 'tablet', 'N02AA59', false, 0, '02232658', 'FreeDiams::CA_HCDPD::DIN', 52221);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylprednisolone Sodium Succinate For Injection, Usp', 'powder for solution', 'H02AB04', false, 0, '02232748', 'FreeDiams::CA_HCDPD::DIN', 52240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylprednisolone Sodium Succinate For Injection, Usp', 'powder for solution', 'H02AB04', false, 0, '02232750', 'FreeDiams::CA_HCDPD::DIN', 52242);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cyproterone', 'tablet', 'G03HA01', false, 0, '02232872', 'FreeDiams::CA_HCDPD::DIN', 52361);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Methotrimeprazine', 'tablet', 'N05AA02', false, 0, '02232903', 'FreeDiams::CA_HCDPD::DIN', 52422);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Methotrimeprazine', 'tablet', 'N05AA02', false, 0, '02232904', 'FreeDiams::CA_HCDPD::DIN', 52423);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Methotrimeprazine', 'tablet', 'N05AA02', false, 0, '02232905', 'FreeDiams::CA_HCDPD::DIN', 52424);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stool Softener', 'capsule', 'A06AA02', false, 0, '02232969', 'FreeDiams::CA_HCDPD::DIN', 52463);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Salbutamol Respirator Solution', 'solution', 'R03AC02', false, 0, '02232987', 'FreeDiams::CA_HCDPD::DIN', 52472);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Enalapril', 'tablet', 'C09AA02', false, 0, '02233005', 'FreeDiams::CA_HCDPD::DIN', 52490);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Enalapril', 'tablet', 'C09AA02', false, 0, '02233006', 'FreeDiams::CA_HCDPD::DIN', 52491);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Enalapril', 'tablet', 'C09AA02', false, 0, '02233007', 'FreeDiams::CA_HCDPD::DIN', 52492);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Retavase', 'powder for solution', 'B01AD07', false, 0, '02233013', 'FreeDiams::CA_HCDPD::DIN', 52499);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balminil Dm + Decongestant + Expectorant Extra Strength', 'syrup', 'R05FA02', false, 0, '02233026', 'FreeDiams::CA_HCDPD::DIN', 52513);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balminil Dm + Expectorant Extra Strength', 'syrup', 'R05FA02', false, 0, '02233027', 'FreeDiams::CA_HCDPD::DIN', 52514);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Terazosin', 'tablet', 'G04CA03', false, 0, '02233047', 'FreeDiams::CA_HCDPD::DIN', 52538);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Terazosin', 'tablet', 'G04CA03', false, 0, '02233048', 'FreeDiams::CA_HCDPD::DIN', 52543);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Terazosin', 'tablet', 'G04CA03', false, 0, '02233049', 'FreeDiams::CA_HCDPD::DIN', 52544);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Terazosin 10 Mg Tablets', 'tablet', 'G04CA03', false, 0, '02233050', 'FreeDiams::CA_HCDPD::DIN', 52545);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('V-Cide', 'solution', 'V07AV', false, 0, '02233054', 'FreeDiams::CA_HCDPD::DIN', 52647);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Patanol Ophthalmic Solution', 'liquid', 'S01GX09', false, 0, '02233143', 'FreeDiams::CA_HCDPD::DIN', 53275);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tisseel Kit Vh 1.0', 'kit', 'B02BD20', false, 0, '02233273', 'FreeDiams::CA_HCDPD::DIN', 53282);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tisseel Kit Vh 5.0', 'kit', 'B02BD20', false, 0, '02233275', 'FreeDiams::CA_HCDPD::DIN', 53284);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('President''S Choice Sunscreen Lotion Spf 8', 'lotion', 'D02BA30', false, 0, '02233494', 'FreeDiams::CA_HCDPD::DIN', 53416);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('President''S Choice Sunblock Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02233498', 'FreeDiams::CA_HCDPD::DIN', 53417);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('President''S Choice Sunless Tanning Cream Spf 15', 'cream', 'D02BA30', false, 0, '02233499', 'FreeDiams::CA_HCDPD::DIN', 53419);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('President''S Choice Sport Sunblock Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02233507', 'FreeDiams::CA_HCDPD::DIN', 53421);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('President''S Choice Sunblock Spray Spf 30', 'spray', 'D02BA30', false, 0, '02233510', 'FreeDiams::CA_HCDPD::DIN', 53422);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('President''S Choice Sunblock Spray For Children Spf 30', 'spray', 'D02BA30', false, 0, '02233511', 'FreeDiams::CA_HCDPD::DIN', 53423);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('President''S Choice Sunblock Lotion For Children Spf 30', 'lotion', 'D02BA30', false, 0, '02233512', 'FreeDiams::CA_HCDPD::DIN', 53424);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('President''S Choice Sunblock Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02233513', 'FreeDiams::CA_HCDPD::DIN', 53425);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('President''S Choice Sunblock Lotion For Babies Spf 45', 'lotion', 'D02BA30', false, 0, '02233514', 'FreeDiams::CA_HCDPD::DIN', 53426);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diane-35', 'tablet', 'G03HB01', false, 0, '02233542', 'FreeDiams::CA_HCDPD::DIN', 53444);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lubriderm Uv Spf 15', 'lotion', 'D02BA30', false, 0, '02233568', 'FreeDiams::CA_HCDPD::DIN', 53823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra-Q128', 'liquid', 'V07AV', false, 0, '02233687', 'FreeDiams::CA_HCDPD::DIN', 53825);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avon Foot Works Therapeutic Cracked Heel Relief Cream', 'cream', 'D04AB01', false, 0, '02233718', 'FreeDiams::CA_HCDPD::DIN', 53831);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synthroid - Tab 137mcg', 'tablet', 'H03AA01', false, 0, '02233852', 'FreeDiams::CA_HCDPD::DIN', 53868);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Clonazepam', 'tablet', 'N03AE01', false, 0, '02233960', 'FreeDiams::CA_HCDPD::DIN', 53892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Nitrazepam', 'tablet', 'N05CD02', false, 0, '02234003', 'FreeDiams::CA_HCDPD::DIN', 53893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Nitrazepam', 'tablet', 'N05CD02', false, 0, '02234007', 'FreeDiams::CA_HCDPD::DIN', 53896);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Clonazepam', 'tablet', 'N03AE01', false, 0, '02233982', 'FreeDiams::CA_HCDPD::DIN', 54229);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Clonazepam', 'tablet', 'N03AE01', false, 0, '02233985', 'FreeDiams::CA_HCDPD::DIN', 54230);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proctodan-Hc Ointment', 'ointment', 'C05AA01', false, 0, '02234466', 'FreeDiams::CA_HCDPD::DIN', 55837);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atgam', 'solution', 'L04AA03', false, 0, '02234470', 'FreeDiams::CA_HCDPD::DIN', 55838);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Terazosin Tablets', 'tablet', 'G04CA03', false, 0, '02234502', 'FreeDiams::CA_HCDPD::DIN', 55839);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Terazosin Tablets', 'tablet', 'G04CA03', false, 0, '02234503', 'FreeDiams::CA_HCDPD::DIN', 55840);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Terazosin Tablets', 'tablet', 'G04CA03', false, 0, '02234504', 'FreeDiams::CA_HCDPD::DIN', 55841);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Terazosin Tablets', 'tablet', 'G04CA03', false, 0, '02234505', 'FreeDiams::CA_HCDPD::DIN', 55842);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('282 Tablets', 'tablet', 'N02BA51', false, 0, '02234510', 'FreeDiams::CA_HCDPD::DIN', 55849);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Glyburide', 'tablet', 'A10BB01', false, 0, '02234514', 'FreeDiams::CA_HCDPD::DIN', 55852);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Methylphenidate', 'tablet', 'N06BA04', false, 0, '02234749', 'FreeDiams::CA_HCDPD::DIN', 55866);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cefadroxil', 'capsule', 'J01DB05', false, 0, '02235134', 'FreeDiams::CA_HCDPD::DIN', 56852);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract, Standardized Cat Pelt', 'liquid', 'V01AA11', false, 0, '02235299', 'FreeDiams::CA_HCDPD::DIN', 57341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Liquid Pedvaxhib', 'suspension', 'J07AG01', false, 0, '02235721', 'FreeDiams::CA_HCDPD::DIN', 59709);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Nifedipine', 'capsule', 'C08CA05', false, 0, '02235897', 'FreeDiams::CA_HCDPD::DIN', 59718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Nifedipine', 'capsule', 'C08CA05', false, 0, '02235898', 'FreeDiams::CA_HCDPD::DIN', 59719);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Betaxolol', 'solution', 'S01ED02', false, 0, '02235971', 'FreeDiams::CA_HCDPD::DIN', 59722);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epi Wash', 'lotion', 'D08AE05', false, 0, '02236105', 'FreeDiams::CA_HCDPD::DIN', 59731);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avon Footworks Antifungal Foot Spray', 'liquid', 'D01AE18', false, 0, '02236168', 'FreeDiams::CA_HCDPD::DIN', 59733);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soft Care Antibacterial Hand Soap', 'liquid', 'D08AE04', false, 0, '02236170', 'FreeDiams::CA_HCDPD::DIN', 59735);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atracurium Besylate Injection', 'solution', 'M03AC04', false, 0, '02236319', 'FreeDiams::CA_HCDPD::DIN', 59791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clean & Clear Persa-Gel 5', 'lotion', 'D10AE01', false, 0, '02236396', 'FreeDiams::CA_HCDPD::DIN', 59870);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anodan-Hc 10mg Suppositories', 'suppository', 'C05AA01', false, 0, '02236399', 'FreeDiams::CA_HCDPD::DIN', 59873);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Domperidone', 'tablet', 'A03FA03', false, 0, '02236466', 'FreeDiams::CA_HCDPD::DIN', 59887);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Cyclobenzaprine', 'tablet', 'M03BX08', false, 0, '02236506', 'FreeDiams::CA_HCDPD::DIN', 59925);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Baclofen', 'tablet', 'M03BX01', false, 0, '02236507', 'FreeDiams::CA_HCDPD::DIN', 59927);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Baclofen', 'tablet', 'M03BX01', false, 0, '02236508', 'FreeDiams::CA_HCDPD::DIN', 59928);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Glyburide', 'tablet', 'A10BB01', false, 0, '02236548', 'FreeDiams::CA_HCDPD::DIN', 59930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Activated Charcoal', 'capsule', 'A07BA01', false, 0, '02236563', 'FreeDiams::CA_HCDPD::DIN', 59931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lovenox With Preservative 300mg/3ml', 'solution', 'B01AB05', false, 0, '02236564', 'FreeDiams::CA_HCDPD::DIN', 59932);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('A+D Diaper Rash Ointment', 'ointment', 'D02AC', false, 0, '02236577', 'FreeDiams::CA_HCDPD::DIN', 59943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Strepsils', 'lozenge', 'R02AA03', false, 0, '02236583', 'FreeDiams::CA_HCDPD::DIN', 59951);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accolate Tab 20 Mg', 'tablet', 'R03DC01', false, 0, '02236606', 'FreeDiams::CA_HCDPD::DIN', 59964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dextrose 10% Inj 10gm/100ml Usp', 'solution', 'B05BA03', false, 0, '00060364', 'FreeDiams::CA_HCDPD::DIN', 59976);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluide Hydratant Quotidien Spf 15', 'lotion', 'D02BA30', false, 0, '02236713', 'FreeDiams::CA_HCDPD::DIN', 60001);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Time Repair Am Spf 15', 'cream', 'D02BA30', false, 0, '02236719', 'FreeDiams::CA_HCDPD::DIN', 60006);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Acetaminophen Suspension', 'suspension', 'N02BE01', false, 0, '02236728', 'FreeDiams::CA_HCDPD::DIN', 60014);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Glyburide', 'tablet', 'A10BB01', false, 0, '02236734', 'FreeDiams::CA_HCDPD::DIN', 60020);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluvoxamine-50', 'tablet', 'N06AB08', false, 0, '02236753', 'FreeDiams::CA_HCDPD::DIN', 60040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluvoxamine-100', 'tablet', 'N06AB08', false, 0, '02236754', 'FreeDiams::CA_HCDPD::DIN', 60041);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atracurium Besylate Injection', 'liquid', 'M03AC04', false, 0, '02236759', 'FreeDiams::CA_HCDPD::DIN', 60046);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Orciprenaline Syrup', 'syrup', 'R03CB03', false, 0, '02236783', 'FreeDiams::CA_HCDPD::DIN', 60071);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Viractin Gel', 'gel', 'D04AB06', false, 0, '02236790', 'FreeDiams::CA_HCDPD::DIN', 60078);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acne Vanishing Treatment', 'lotion', 'D10AE01', false, 0, '02236796', 'FreeDiams::CA_HCDPD::DIN', 60085);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acne Vanishing Treatment Cover-Up', 'cream', 'D10AE01', false, 0, '02236797', 'FreeDiams::CA_HCDPD::DIN', 60086);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Valproic Acid', 'syrup', 'N03AG01', false, 0, '02236807', 'FreeDiams::CA_HCDPD::DIN', 60096);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diovan 80mg', 'capsule', 'C09CA03', false, 0, '02236808', 'FreeDiams::CA_HCDPD::DIN', 60097);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diovan 160mg', 'capsule', 'C09CA03', false, 0, '02236809', 'FreeDiams::CA_HCDPD::DIN', 60098);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Azathioprine', 'tablet', 'L04AX01', false, 0, '02236819', 'FreeDiams::CA_HCDPD::DIN', 60109);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Opti-Free Express', 'solution', 'S01XA20', false, 0, '02236833', 'FreeDiams::CA_HCDPD::DIN', 60122);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levaquin 5mg/Ml', 'solution', 'J01MA12', false, 0, '02236839', 'FreeDiams::CA_HCDPD::DIN', 60128);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levaquin', 'tablet', 'J01MA12', false, 0, '02236841', 'FreeDiams::CA_HCDPD::DIN', 60130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levaquin 500mg', 'tablet', 'J01MA12', false, 0, '02236842', 'FreeDiams::CA_HCDPD::DIN', 60131);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Ticlopidine', 'tablet', 'B01AC05', false, 0, '02236848', 'FreeDiams::CA_HCDPD::DIN', 60138);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balminil Dm Children', 'syrup', 'R05DA09', false, 0, '02236850', 'FreeDiams::CA_HCDPD::DIN', 60140);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Domperidone-10', 'tablet', 'A03FA03', false, 0, '02236857', 'FreeDiams::CA_HCDPD::DIN', 60147);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Agrylin', 'capsule', 'L01XX35', false, 0, '02236859', 'FreeDiams::CA_HCDPD::DIN', 60149);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Drx Germicidal Detergent', 'liquid', 'V07AV', false, 0, '02236868', 'FreeDiams::CA_HCDPD::DIN', 60158);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methoxacet-C 1/8', 'tablet', 'M03BA53', false, 0, '02236872', 'FreeDiams::CA_HCDPD::DIN', 60162);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Primene 10%', 'liquid', 'B05BA01', false, 0, '02236875', 'FreeDiams::CA_HCDPD::DIN', 60165);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alphagan', 'liquid', 'S01EA05', false, 0, '02236876', 'FreeDiams::CA_HCDPD::DIN', 60166);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lovenox', 'solution', 'B01AB05', false, 0, '02236883', 'FreeDiams::CA_HCDPD::DIN', 60174);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Propofol Injection', 'emulsion', 'N01AX10', false, 0, '02236887', 'FreeDiams::CA_HCDPD::DIN', 60178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fraxiparine', 'solution', 'B01AB06', false, 0, '02236913', 'FreeDiams::CA_HCDPD::DIN', 60205);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balminil Dm + Decongestant + Expectorant', 'syrup', 'R05FA02', false, 0, '02236915', 'FreeDiams::CA_HCDPD::DIN', 60207);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acyclovir Sodium Injection', 'solution', 'J05AB01', false, 0, '02236916', 'FreeDiams::CA_HCDPD::DIN', 60208);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ozonol Antibiotics Plus', 'ointment', 'D06AX55', false, 0, '02236917', 'FreeDiams::CA_HCDPD::DIN', 60209);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acyclovir Sodium Injection', 'solution', 'J05AB01', false, 0, '02236926', 'FreeDiams::CA_HCDPD::DIN', 60218);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Salbutamol Respirator Solution', 'solution', 'R03AC02', false, 0, '02236931', 'FreeDiams::CA_HCDPD::DIN', 60224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Salbutamol Respirator Solution', 'solution', 'R03AC02', false, 0, '02236932', 'FreeDiams::CA_HCDPD::DIN', 60225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Salbutamol Respirator Solution', 'solution', 'R03AC02', false, 0, '02236933', 'FreeDiams::CA_HCDPD::DIN', 60226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Ipratropium', 'solution', 'R03BB01', false, 0, '02236934', 'FreeDiams::CA_HCDPD::DIN', 60227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Trazodone', 'tablet', 'N06AX05', false, 0, '02236941', 'FreeDiams::CA_HCDPD::DIN', 60234);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Trazodone', 'tablet', 'N06AX05', false, 0, '02236942', 'FreeDiams::CA_HCDPD::DIN', 60235);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Loxapine', 'tablet', 'N05AH01', false, 0, '02236943', 'FreeDiams::CA_HCDPD::DIN', 60236);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Loxapine', 'tablet', 'N05AH01', false, 0, '02236944', 'FreeDiams::CA_HCDPD::DIN', 60237);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Loxapine', 'tablet', 'N05AH01', false, 0, '02236945', 'FreeDiams::CA_HCDPD::DIN', 60238);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Loxapine', 'tablet', 'N05AH01', false, 0, '02236946', 'FreeDiams::CA_HCDPD::DIN', 60239);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Clonazepam-R', 'tablet', 'N03AE01', false, 0, '02236948', 'FreeDiams::CA_HCDPD::DIN', 60241);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Bromocriptine', 'capsule', 'G02CB01', false, 0, '02236949', 'FreeDiams::CA_HCDPD::DIN', 60242);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperdal Oral Solution', 'solution', 'N05AX08', false, 0, '02236950', 'FreeDiams::CA_HCDPD::DIN', 60243);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Seroquel Tab 25mg', 'tablet', 'N05AH04', false, 0, '02236951', 'FreeDiams::CA_HCDPD::DIN', 60245);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Seroquel Tab 100mg', 'tablet', 'N05AH04', false, 0, '02236952', 'FreeDiams::CA_HCDPD::DIN', 60246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Seroquel Tab 200mg', 'tablet', 'N05AH04', false, 0, '02236953', 'FreeDiams::CA_HCDPD::DIN', 60247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Band-Aid Brand Adhesive Bandages Plus Antibiotic', 'kit', 'D06AX30', false, 0, '02236954', 'FreeDiams::CA_HCDPD::DIN', 60248);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flavoxate', 'tablet', 'G04BD02', false, 0, '02236956', 'FreeDiams::CA_HCDPD::DIN', 60251);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Tryptophan', 'tablet', 'N06AX02', false, 0, '02236957', 'FreeDiams::CA_HCDPD::DIN', 60252);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Baclofen', 'tablet', 'M03BX01', false, 0, '02236963', 'FreeDiams::CA_HCDPD::DIN', 60258);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Baclofen', 'tablet', 'M03BX01', false, 0, '02236964', 'FreeDiams::CA_HCDPD::DIN', 60259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alesse 21', 'tablet', 'G03AA07', false, 0, '02236974', 'FreeDiams::CA_HCDPD::DIN', 60269);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alesse 28', 'tablet', 'G03AA07', false, 0, '02236975', 'FreeDiams::CA_HCDPD::DIN', 60270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Fluconazole', 'tablet', 'J02AC01', false, 0, '02236978', 'FreeDiams::CA_HCDPD::DIN', 60273);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Fluconazole', 'tablet', 'J02AC01', false, 0, '02236979', 'FreeDiams::CA_HCDPD::DIN', 60274);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gold Bond Medicated Cream 28g', 'cream', 'D04AB07', false, 0, '02236991', 'FreeDiams::CA_HCDPD::DIN', 60289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lyderm Ointment 0.05%', 'ointment', 'D07AC08', false, 0, '02236996', 'FreeDiams::CA_HCDPD::DIN', 60294);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lyderm Gel 0.05%', 'gel', 'D07AC08', false, 0, '02236997', 'FreeDiams::CA_HCDPD::DIN', 60295);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kinesys Spf 30 Sun Stick', 'stick', 'D02BA30', false, 0, '02237002', 'FreeDiams::CA_HCDPD::DIN', 60302);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Lithium Carbonate', 'capsule', 'N05AN01', false, 0, '02237006', 'FreeDiams::CA_HCDPD::DIN', 60306);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Lithium Carbonate', 'capsule', 'N05AN01', false, 0, '02237007', 'FreeDiams::CA_HCDPD::DIN', 60307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Lithium Carbonate', 'capsule', 'N05AN01', false, 0, '02237008', 'FreeDiams::CA_HCDPD::DIN', 60308);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ketoprofen Suppositories', 'suppository', 'M01AE03', false, 0, '02237011', 'FreeDiams::CA_HCDPD::DIN', 60312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Block Up Oil Free 30 Spf', 'lotion', 'D02BA30', false, 0, '02237024', 'FreeDiams::CA_HCDPD::DIN', 60325);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Block Up! Baby Spf 30 Sunblock With Aloe', 'kit', 'D02BA30', false, 0, '02237025', 'FreeDiams::CA_HCDPD::DIN', 60326);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Block Up! Sport Spf 30 Sunblock With Aloe', 'kit', 'D02BA30', false, 0, '02237026', 'FreeDiams::CA_HCDPD::DIN', 60327);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Block Up! Sunblock Spf 30 With Aloe', 'kit', 'D02BA30', false, 0, '02237027', 'FreeDiams::CA_HCDPD::DIN', 60328);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Dexamethasone', 'tablet', 'H02AB02', false, 0, '02237044', 'FreeDiams::CA_HCDPD::DIN', 60347);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Dexamethasone', 'tablet', 'H02AB02', false, 0, '02237045', 'FreeDiams::CA_HCDPD::DIN', 60348);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Dexamethasone', 'tablet', 'H02AB02', false, 0, '02237046', 'FreeDiams::CA_HCDPD::DIN', 60349);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Bethanechol Chloride', 'tablet', 'N07AB02', false, 0, '02237047', 'FreeDiams::CA_HCDPD::DIN', 60350);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Bethanechol Chloride', 'tablet', 'N07AB02', false, 0, '02237048', 'FreeDiams::CA_HCDPD::DIN', 60351);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Bethanechol Chloride', 'tablet', 'N07AB02', false, 0, '02237049', 'FreeDiams::CA_HCDPD::DIN', 60352);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Moclobemide', 'tablet', 'N06AG02', false, 0, '02237111', 'FreeDiams::CA_HCDPD::DIN', 60425);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Moclobemide', 'tablet', 'N06AG02', false, 0, '02237112', 'FreeDiams::CA_HCDPD::DIN', 60426);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro*Fil #14 H.D. Germicidal Cleaner', 'liquid', 'V07AV', false, 0, '02237118', 'FreeDiams::CA_HCDPD::DIN', 60432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Septefx (18.5%)', 'liquid', 'V07AV', false, 0, '02237130', 'FreeDiams::CA_HCDPD::DIN', 60445);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Septefx (70.5%)', 'liquid', 'V07AV', false, 0, '02237131', 'FreeDiams::CA_HCDPD::DIN', 60446);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Ipratropium - 1ml Polyneb', 'solution', 'R03BB01', false, 0, '02237134', 'FreeDiams::CA_HCDPD::DIN', 60449);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Ipratropium - 2ml Polyneb', 'solution', 'R03BB01', false, 0, '02237135', 'FreeDiams::CA_HCDPD::DIN', 60450);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefazolin For Injection, Usp', 'powder for solution', 'J01DB04', false, 0, '02237137', 'FreeDiams::CA_HCDPD::DIN', 60452);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefazolin For Injection, Usp', 'powder for solution', 'J01DB04', false, 0, '02237138', 'FreeDiams::CA_HCDPD::DIN', 60453);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefazolin For Injection, Usp', 'powder for solution', 'J01DB04', false, 0, '02237140', 'FreeDiams::CA_HCDPD::DIN', 60455);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefazolin For Injection, Usp', 'powder for solution', 'J01DB04', false, 0, '02237141', 'FreeDiams::CA_HCDPD::DIN', 60456);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mirapex', 'tablet', 'N04BC05', false, 0, '02237145', 'FreeDiams::CA_HCDPD::DIN', 60463);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mirapex', 'tablet', 'N04BC05', false, 0, '02237146', 'FreeDiams::CA_HCDPD::DIN', 60464);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mirapex', 'tablet', 'N04BC05', false, 0, '02237147', 'FreeDiams::CA_HCDPD::DIN', 60465);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ulcidine', 'tablet', 'A02BA03', false, 0, '02237148', 'FreeDiams::CA_HCDPD::DIN', 60466);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ulcidine', 'tablet', 'A02BA03', false, 0, '02237149', 'FreeDiams::CA_HCDPD::DIN', 60467);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Nytol Quickgels', 'capsule', 'R06AA02', false, 0, '02237169', 'FreeDiams::CA_HCDPD::DIN', 60487);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lotion Ecran Solaire Extreme Spf 30 / Sunscreen Lotion Extreme', 'lotion', 'D02BA30', false, 0, '02237179', 'FreeDiams::CA_HCDPD::DIN', 60497);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Idoxuridine', 'liquid', 'D06BB01', false, 0, '02237187', 'FreeDiams::CA_HCDPD::DIN', 60505);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxeze Turbuhaler 12mcg/Aem', 'kit', 'R03AC13', false, 0, '02237224', 'FreeDiams::CA_HCDPD::DIN', 60542);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxeze Turbuhaler 6 Mcg/Aem', 'kit', 'R03AC13', false, 0, '02237225', 'FreeDiams::CA_HCDPD::DIN', 60543);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Control', 'tablet', 'A02BA03', false, 0, '02237223', 'FreeDiams::CA_HCDPD::DIN', 60544);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polysporin Triple Antibiotic Ointment', 'ointment', 'D06AX30', false, 0, '02237226', 'FreeDiams::CA_HCDPD::DIN', 60545);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polysporin Antibiotic Ointment', 'ointment', 'D06AX30', false, 0, '02237227', 'FreeDiams::CA_HCDPD::DIN', 60546);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ketoconazole', 'tablet', 'J02AB02', false, 0, '02237235', 'FreeDiams::CA_HCDPD::DIN', 60554);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flovent Diskus', 'powder', 'R03BA05', false, 0, '02237244', 'FreeDiams::CA_HCDPD::DIN', 60564);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flovent Diskus', 'powder', 'R03BA05', false, 0, '02237245', 'FreeDiams::CA_HCDPD::DIN', 60565);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flovent Diskus', 'powder', 'R03BA05', false, 0, '02237246', 'FreeDiams::CA_HCDPD::DIN', 60566);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flovent Diskus', 'powder', 'R03BA05', false, 0, '02237247', 'FreeDiams::CA_HCDPD::DIN', 60567);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Tryptophan', 'tablet', 'N06AX02', false, 0, '02237250', 'FreeDiams::CA_HCDPD::DIN', 60571);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Effexor Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02237279', 'FreeDiams::CA_HCDPD::DIN', 60600);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Effexor Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02237280', 'FreeDiams::CA_HCDPD::DIN', 60601);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Effexor Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02237282', 'FreeDiams::CA_HCDPD::DIN', 60603);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imodium Advanced Multi-Symptom Chewable Tablets', 'tablet (chewable)', 'A07DA53', false, 0, '02237297', 'FreeDiams::CA_HCDPD::DIN', 60618);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pursue Disinfectant/Deodorizer Spray', 'aerosol', 'V07AV', false, 0, '02237306', 'FreeDiams::CA_HCDPD::DIN', 60627);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Minocycline', 'capsule', 'J01AA08', false, 0, '02237313', 'FreeDiams::CA_HCDPD::DIN', 60635);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Minocycline', 'capsule', 'J01AA08', false, 0, '02237314', 'FreeDiams::CA_HCDPD::DIN', 60636);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pepto-Bismol Chewables', 'tablet', 'A02AX', false, 0, '02237315', 'FreeDiams::CA_HCDPD::DIN', 60637);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rebif', 'solution', 'L03AB07', false, 0, '02237319', 'FreeDiams::CA_HCDPD::DIN', 60641);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rebif', 'solution', 'L03AB07', false, 0, '02237320', 'FreeDiams::CA_HCDPD::DIN', 60642);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imogam Rabies Pasteurized', 'solution', 'J06BB05', false, 0, '02237328', 'FreeDiams::CA_HCDPD::DIN', 60651);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Trazodone', 'tablet', 'N06AX05', false, 0, '02237339', 'FreeDiams::CA_HCDPD::DIN', 60663);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Emadine', 'liquid', 'S01GX06', false, 0, '02237355', 'FreeDiams::CA_HCDPD::DIN', 60678);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accuretic 10/12.5 Mg', 'tablet', 'C09BA06', false, 0, '02237367', 'FreeDiams::CA_HCDPD::DIN', 60690);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accuretic 20/12.5 Mg', 'tablet', 'C09BA06', false, 0, '02237368', 'FreeDiams::CA_HCDPD::DIN', 60691);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accuretic 20/25 Mg', 'tablet', 'C09BA06', false, 0, '02237369', 'FreeDiams::CA_HCDPD::DIN', 60692);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Fluconazole', 'tablet', 'J02AC01', false, 0, '02237370', 'FreeDiams::CA_HCDPD::DIN', 60693);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Fluconazole', 'tablet', 'J02AC01', false, 0, '02237371', 'FreeDiams::CA_HCDPD::DIN', 60694);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nortriptyline', 'capsule', 'N06AA10', false, 0, '02237376', 'FreeDiams::CA_HCDPD::DIN', 60699);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nortriptyline', 'capsule', 'N06AA10', false, 0, '02237377', 'FreeDiams::CA_HCDPD::DIN', 60700);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Infant''S Acetaminophen Suspension (80mg/1ml Cherry And Grape Flavours)', 'suspension', 'N02BE01', false, 0, '02237390', 'FreeDiams::CA_HCDPD::DIN', 60714);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asept', 'liquid', 'D08AE04', false, 0, '02237406', 'FreeDiams::CA_HCDPD::DIN', 60734);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bacti-Foam', 'spray', 'D08AE04', false, 0, '02237409', 'FreeDiams::CA_HCDPD::DIN', 60738);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen', 'tablet', 'N02BE01', false, 0, '02237418', 'FreeDiams::CA_HCDPD::DIN', 60748);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Acetaminophen', 'tablet', 'N02BE01', false, 0, '02237419', 'FreeDiams::CA_HCDPD::DIN', 60749);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen, Caffeine & 8mg Codeine Phosphate', 'tablet', 'N02BE51', false, 0, '02237420', 'FreeDiams::CA_HCDPD::DIN', 60750);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin For Children Dm 12 Hour Syrup', 'syrup (extended-release)', 'R05DA09', false, 0, '02237429', 'FreeDiams::CA_HCDPD::DIN', 60760);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('D-Forte', 'capsule', 'A11CC01', false, 0, '02237450', 'FreeDiams::CA_HCDPD::DIN', 60784);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Peridex Oral Rinse', 'kit', 'A01AB03', false, 0, '02237452', 'FreeDiams::CA_HCDPD::DIN', 60786);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Tamoxifen', 'tablet', 'L02BA01', false, 0, '02237459', 'FreeDiams::CA_HCDPD::DIN', 60793);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Tamoxifen', 'tablet', 'L02BA01', false, 0, '02237460', 'FreeDiams::CA_HCDPD::DIN', 60794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Terazosin-1', 'tablet', 'G04CA03', false, 0, '02237476', 'FreeDiams::CA_HCDPD::DIN', 60810);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Terazosin-2', 'tablet', 'G04CA03', false, 0, '02237477', 'FreeDiams::CA_HCDPD::DIN', 60811);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Terazosin-5', 'tablet', 'G04CA03', false, 0, '02237478', 'FreeDiams::CA_HCDPD::DIN', 60812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Terazosin-10', 'tablet', 'G04CA03', false, 0, '02237479', 'FreeDiams::CA_HCDPD::DIN', 60813);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Allergy Sinus Nighttime Caplet', 'tablet', 'N02BE51', false, 0, '02237483', 'FreeDiams::CA_HCDPD::DIN', 60817);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cellcept', 'tablet', 'L04AA06', false, 0, '02237484', 'FreeDiams::CA_HCDPD::DIN', 60818);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cefaclor', 'powder', 'J01DC04', false, 0, '02237500', 'FreeDiams::CA_HCDPD::DIN', 60834);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cefaclor', 'powder', 'J01DC04', false, 0, '02237501', 'FreeDiams::CA_HCDPD::DIN', 60835);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cefaclor', 'powder', 'J01DC04', false, 0, '02237502', 'FreeDiams::CA_HCDPD::DIN', 60836);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cipro Oral Suspension 10%', 'suspension', 'J01MA02', false, 0, '02237514', 'FreeDiams::CA_HCDPD::DIN', 60849);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gold Bond Medicated Lotion (Regular Strength)', 'lotion', 'D02AA', false, 0, '02237526', 'FreeDiams::CA_HCDPD::DIN', 60861);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Formula 410', 'liquid', 'V07AV', false, 0, '02237530', 'FreeDiams::CA_HCDPD::DIN', 60867);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bum-Butt-R', 'cream', 'D02AC', false, 0, '02237532', 'FreeDiams::CA_HCDPD::DIN', 60869);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Loxapine', 'tablet', 'N05AH01', false, 0, '02237534', 'FreeDiams::CA_HCDPD::DIN', 60871);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Loxapine', 'tablet', 'N05AH01', false, 0, '02237535', 'FreeDiams::CA_HCDPD::DIN', 60872);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Loxapine', 'tablet', 'N05AH01', false, 0, '02237536', 'FreeDiams::CA_HCDPD::DIN', 60873);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Loxapine', 'tablet', 'N05AH01', false, 0, '02237537', 'FreeDiams::CA_HCDPD::DIN', 60874);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Twinrix Junior', 'suspension', 'J07BC20', false, 0, '02237548', 'FreeDiams::CA_HCDPD::DIN', 60885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Treatment Spf 15', 'stick', 'D02BA30', false, 0, '02237553', 'FreeDiams::CA_HCDPD::DIN', 60890);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Orotol Plus', 'liquid', 'V07AV', false, 0, '02237557', 'FreeDiams::CA_HCDPD::DIN', 60895);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Ticlopidine 250 Mg', 'tablet', 'B01AC05', false, 0, '02237560', 'FreeDiams::CA_HCDPD::DIN', 60898);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophene 160mg Comprimes A Croquer', 'tablet', 'N02BE01', false, 0, '02237562', 'FreeDiams::CA_HCDPD::DIN', 60900);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gold Bond Extra Strength Medicated Body Lotion', 'lotion', 'D02AA', false, 0, '02237563', 'FreeDiams::CA_HCDPD::DIN', 60901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Azeo Pangen Extra Strength', 'tablet', 'A09AA02', false, 0, '02237574', 'FreeDiams::CA_HCDPD::DIN', 60913);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle And Back Pain Relief', 'tablet', 'M03BA53', false, 0, '02237577', 'FreeDiams::CA_HCDPD::DIN', 60916);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spasmhalt-8', 'tablet', 'M03BA53', false, 0, '02237578', 'FreeDiams::CA_HCDPD::DIN', 60917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle And Back Pain Relief', 'tablet', 'M03BA53', false, 0, '02237579', 'FreeDiams::CA_HCDPD::DIN', 60918);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spasmhalt-Asa-8', 'tablet', 'M03BA53', false, 0, '02237580', 'FreeDiams::CA_HCDPD::DIN', 60919);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermatone Skin Protector - Pommade', 'ointment', 'D02BA30', false, 0, '02237589', 'FreeDiams::CA_HCDPD::DIN', 60920);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tamoxifen', 'tablet', 'L02BA01', false, 0, '02237596', 'FreeDiams::CA_HCDPD::DIN', 60935);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tamoxifen', 'tablet', 'L02BA01', false, 0, '02237597', 'FreeDiams::CA_HCDPD::DIN', 60936);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Atenolol', 'tablet', 'C07AB03', false, 0, '02237600', 'FreeDiams::CA_HCDPD::DIN', 60939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Atenolol', 'tablet', 'C07AB03', false, 0, '02237601', 'FreeDiams::CA_HCDPD::DIN', 60940);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('United C-64', 'solution', 'V07AV', false, 0, '02237617', 'FreeDiams::CA_HCDPD::DIN', 60956);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adalat Xl - Srt 20mg', 'tablet (extended-release)', 'C08CA05', false, 0, '02237618', 'FreeDiams::CA_HCDPD::DIN', 60957);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Agarol Plain', 'emulsion', 'A06AA51', false, 0, '02237625', 'FreeDiams::CA_HCDPD::DIN', 60965);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Loxapine', 'tablet', 'N05AH01', false, 0, '02237651', 'FreeDiams::CA_HCDPD::DIN', 60994);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Loxapine', 'tablet', 'N05AH01', false, 0, '02237652', 'FreeDiams::CA_HCDPD::DIN', 60995);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Loxapine', 'tablet', 'N05AH01', false, 0, '02237653', 'FreeDiams::CA_HCDPD::DIN', 60996);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Loxapine', 'tablet', 'N05AH01', false, 0, '02237654', 'FreeDiams::CA_HCDPD::DIN', 60997);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neoral 10mg', 'capsule', 'L04AD01', false, 0, '02237671', 'FreeDiams::CA_HCDPD::DIN', 61016);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hard Surface Disinfectant Solution (Hsd)', 'liquid', 'V07AV', false, 0, '02237675', 'FreeDiams::CA_HCDPD::DIN', 61020);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Norfloxacin', 'tablet', 'J01MA06', false, 0, '02237682', 'FreeDiams::CA_HCDPD::DIN', 61027);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('3129 Quat-10', 'liquid', 'V07AV', false, 0, '02237685', 'FreeDiams::CA_HCDPD::DIN', 61030);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soft Care Food Industry Sanitizing Hand Soap', 'liquid', 'D08AE05', false, 0, '02237696', 'FreeDiams::CA_HCDPD::DIN', 61042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Strength Phazyme 180mg Softgels', 'capsule', 'A03AX13', false, 0, '02237698', 'FreeDiams::CA_HCDPD::DIN', 61044);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ticlopidine Tablets', 'tablet', 'B01AC05', false, 0, '02237701', 'FreeDiams::CA_HCDPD::DIN', 61047);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Acebutolol', 'tablet', 'C07AB04', false, 0, '02237721', 'FreeDiams::CA_HCDPD::DIN', 61075);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Acebutolol', 'tablet', 'C07AB04', false, 0, '02237722', 'FreeDiams::CA_HCDPD::DIN', 61076);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Acebutolol', 'tablet', 'C07AB04', false, 0, '02237723', 'FreeDiams::CA_HCDPD::DIN', 61077);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aspirin 81mg', 'tablet (enteric-coated)', 'N02BA01', false, 0, '02237726', 'FreeDiams::CA_HCDPD::DIN', 61080);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefaclor Capsules', 'capsule', 'J01DC04', false, 0, '02237729', 'FreeDiams::CA_HCDPD::DIN', 61083);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefaclor Capsules', 'capsule', 'J01DC04', false, 0, '02237730', 'FreeDiams::CA_HCDPD::DIN', 61084);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Claritin', 'tablet', 'R06AX13', false, 0, '02237734', 'FreeDiams::CA_HCDPD::DIN', 61088);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mitomycin For Injection Usp', 'powder for solution', 'L01DC03', false, 0, '02237745', 'FreeDiams::CA_HCDPD::DIN', 61099);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluorescein Sodium & Benoxinate Hydrochloride Ophtalmic Solution, Usp', 'solution', 'S01JA51', false, 0, '02237775', 'FreeDiams::CA_HCDPD::DIN', 61132);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dormiphen Comprime', 'tablet', 'R06AA02', false, 0, '02237788', 'FreeDiams::CA_HCDPD::DIN', 61145);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dormiphen Extra-Fort Comprime', 'tablet', 'R06AA02', false, 0, '02237789', 'FreeDiams::CA_HCDPD::DIN', 61146);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Verapamil Sr', 'tablet (extended-release)', 'C08DA01', false, 0, '02237791', 'FreeDiams::CA_HCDPD::DIN', 61148);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avaxim', 'suspension', 'J07BC02', false, 0, '02237792', 'FreeDiams::CA_HCDPD::DIN', 61149);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antithrombin Iii Immuno', 'kit', 'B01AB02', false, 0, '02237810', 'FreeDiams::CA_HCDPD::DIN', 61169);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antithrombin Iii Immuno', 'kit', 'B01AB02', false, 0, '02237811', 'FreeDiams::CA_HCDPD::DIN', 61170);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antithrombin Iii Immuno', 'powder for solution', 'B01AB02', false, 0, '02237812', 'FreeDiams::CA_HCDPD::DIN', 61171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02237813', 'FreeDiams::CA_HCDPD::DIN', 61172);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02237814', 'FreeDiams::CA_HCDPD::DIN', 61173);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Erwinase', 'powder for solution', 'L01XX02', false, 0, '02237815', 'FreeDiams::CA_HCDPD::DIN', 61174);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutra San-Det 256', 'liquid', 'V07AV', false, 0, '02237818', 'FreeDiams::CA_HCDPD::DIN', 61177);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('San-Det Gp', 'liquid', 'V07AV', false, 0, '02237819', 'FreeDiams::CA_HCDPD::DIN', 61178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amerge', 'tablet', 'N02CC02', false, 0, '02237820', 'FreeDiams::CA_HCDPD::DIN', 61179);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amerge', 'tablet', 'N02CC02', false, 0, '02237821', 'FreeDiams::CA_HCDPD::DIN', 61180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Wellbutrin Sr', 'tablet (extended-release)', 'N06AX12', false, 0, '02237825', 'FreeDiams::CA_HCDPD::DIN', 61184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Mefenamic Acid', 'capsule', 'M01AG01', false, 0, '02237826', 'FreeDiams::CA_HCDPD::DIN', 61185);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Reducer', 'tablet', 'A02BA02', false, 0, '02237829', 'FreeDiams::CA_HCDPD::DIN', 61188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Valproic', 'capsule', 'N03AG01', false, 0, '02237830', 'FreeDiams::CA_HCDPD::DIN', 61189);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Betaject', 'suspension', 'H02AB01', false, 0, '02237835', 'FreeDiams::CA_HCDPD::DIN', 61194);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen Usp', 'gas', 'V03AN01', false, 0, '02237847', 'FreeDiams::CA_HCDPD::DIN', 61206);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Octostim Spray', 'spray', 'H01BA02', false, 0, '02237860', 'FreeDiams::CA_HCDPD::DIN', 61220);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Dipivefrin', 'drops', 'S01EA02', false, 0, '02237868', 'FreeDiams::CA_HCDPD::DIN', 61228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rejuva Moisturizing Day Cream Spf 30', 'cream', 'D02BA30', false, 0, '02237874', 'FreeDiams::CA_HCDPD::DIN', 61235);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Acebutolol (Type S)', 'tablet', 'C07AB04', false, 0, '02237885', 'FreeDiams::CA_HCDPD::DIN', 61246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Acebutolol (Type S)', 'tablet', 'C07AB04', false, 0, '02237886', 'FreeDiams::CA_HCDPD::DIN', 61247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Acebutolol (Type S)', 'tablet', 'C07AB04', false, 0, '02237887', 'FreeDiams::CA_HCDPD::DIN', 61248);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Carbamazepine Cr 200 Mg', 'tablet (extended-release)', 'N03AF01', false, 0, '02237907', 'FreeDiams::CA_HCDPD::DIN', 61270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Carbamazepine Cr 400 Mg', 'tablet (extended-release)', 'N03AF01', false, 0, '02237908', 'FreeDiams::CA_HCDPD::DIN', 61271);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Ketorolac', 'tablet', 'M01AB15', false, 0, '02237910', 'FreeDiams::CA_HCDPD::DIN', 61273);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Verapamil', 'tablet', 'C08DA01', false, 0, '02237921', 'FreeDiams::CA_HCDPD::DIN', 61286);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Verapamil', 'tablet', 'C08DA01', false, 0, '02237922', 'FreeDiams::CA_HCDPD::DIN', 61287);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avapro', 'tablet', 'C09CA04', false, 0, '02237923', 'FreeDiams::CA_HCDPD::DIN', 61288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avapro', 'tablet', 'C09CA04', false, 0, '02237924', 'FreeDiams::CA_HCDPD::DIN', 61289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avapro', 'tablet', 'C09CA04', false, 0, '02237925', 'FreeDiams::CA_HCDPD::DIN', 61290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vapophene', 'liquid', 'V07AV', false, 0, '02237927', 'FreeDiams::CA_HCDPD::DIN', 61292);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Sunscreen', 'cream', 'D02BA30', false, 0, '02237930', 'FreeDiams::CA_HCDPD::DIN', 61295);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Spf 30', 'lotion', 'D02BA30', false, 0, '02237931', 'FreeDiams::CA_HCDPD::DIN', 61296);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Luxiva Preventage Hand Treatment For Dry Skin Spf 15', 'cream', 'D02BA30', false, 0, '02237933', 'FreeDiams::CA_HCDPD::DIN', 61299);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lait Auto-Bronzant Spf 6', 'emulsion', 'D02BA30', false, 0, '02237948', 'FreeDiams::CA_HCDPD::DIN', 61313);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clean & Clear Foaming Facial Cleanser', 'liquid', 'D08AE04', false, 0, '02237962', 'FreeDiams::CA_HCDPD::DIN', 61329);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Saizen', 'powder for solution', 'H01AC01', false, 0, '02237971', 'FreeDiams::CA_HCDPD::DIN', 61332);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sparkle Q-San', 'liquid', 'V07AV', false, 0, '02237982', 'FreeDiams::CA_HCDPD::DIN', 61358);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Levobunolol', 'liquid', 'S01ED03', false, 0, '02237991', 'FreeDiams::CA_HCDPD::DIN', 61367);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle And Back Pain Relief', 'tablet', 'M03BA53', false, 0, '02237995', 'FreeDiams::CA_HCDPD::DIN', 61372);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('L668 Ora Soft 3', 'liquid', 'D08AE04', false, 0, '02238001', 'FreeDiams::CA_HCDPD::DIN', 61379);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Future E Spf 15', 'cream', 'D02BA30', false, 0, '02238002', 'FreeDiams::CA_HCDPD::DIN', 61380);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rectogel Hc', 'ointment', 'C05AA01', false, 0, '00662461', 'FreeDiams::CA_HCDPD::DIN', 61410);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Agri Health Guard', 'liquid', 'V07AV', false, 0, '02238045', 'FreeDiams::CA_HCDPD::DIN', 61429);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Pindolol', 'tablet', 'C07AA03', false, 0, '02238046', 'FreeDiams::CA_HCDPD::DIN', 61430);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Pindolol', 'tablet', 'C07AA03', false, 0, '02238047', 'FreeDiams::CA_HCDPD::DIN', 61431);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Valproic', 'capsule', 'N03AG01', false, 0, '02238048', 'FreeDiams::CA_HCDPD::DIN', 61432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Loperamide', 'tablet', 'A07DA03', false, 0, '02238052', 'FreeDiams::CA_HCDPD::DIN', 61436);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Salonpas Gel-Patch', 'plaster', 'M02AC', false, 0, '02238054', 'FreeDiams::CA_HCDPD::DIN', 61438);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mi-Kleen Disinfectant Pine Cream Cleanser', 'cream', 'V07AV', false, 0, '02238084', 'FreeDiams::CA_HCDPD::DIN', 61471);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Scrub ''N Swipes', 'pad', 'V07AV', false, 0, '02238086', 'FreeDiams::CA_HCDPD::DIN', 61475);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avs Virucidal Extra', 'powder', 'V07AV', false, 0, '02238094', 'FreeDiams::CA_HCDPD::DIN', 61485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tarka', 'tablet (extended-release)', 'C09BB10', false, 0, '02238097', 'FreeDiams::CA_HCDPD::DIN', 61488);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Selegiline', 'tablet', 'N04BD01', false, 0, '02238102', 'FreeDiams::CA_HCDPD::DIN', 61495);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Gliclazide', 'tablet', 'A10BB09', false, 0, '02238103', 'FreeDiams::CA_HCDPD::DIN', 61497);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Malarone', 'tablet', 'P01BB51', false, 0, '02238151', 'FreeDiams::CA_HCDPD::DIN', 61542);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Esoterica Unscented', 'cream', 'D11AX11', false, 0, '02238153', 'FreeDiams::CA_HCDPD::DIN', 61543);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Esoterica Sunscreen Fade Cream', 'cream', 'D11AX11', false, 0, '02238152', 'FreeDiams::CA_HCDPD::DIN', 61544);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Codulax Tablets', 'tablet', 'A06AB02', false, 0, '02238155', 'FreeDiams::CA_HCDPD::DIN', 61546);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diastat', 'gel', 'N05BA01', false, 0, '02238162', 'FreeDiams::CA_HCDPD::DIN', 61553);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Amoxicillin', 'capsule', 'J01CA04', false, 0, '02238171', 'FreeDiams::CA_HCDPD::DIN', 61562);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Amoxicillin', 'capsule', 'J01CA04', false, 0, '02238172', 'FreeDiams::CA_HCDPD::DIN', 61563);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methoxisal', 'tablet', 'M03BA53', false, 0, '00868868', 'FreeDiams::CA_HCDPD::DIN', 61576);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bromocriptine', 'tablet', 'G02CB01', false, 0, '02238192', 'FreeDiams::CA_HCDPD::DIN', 61585);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bromocriptine', 'capsule', 'G02CB01', false, 0, '02238193', 'FreeDiams::CA_HCDPD::DIN', 61586);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Nizatidine', 'capsule', 'A02BA04', false, 0, '02238194', 'FreeDiams::CA_HCDPD::DIN', 61587);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Nizatidine', 'capsule', 'A02BA04', false, 0, '02238195', 'FreeDiams::CA_HCDPD::DIN', 61588);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Sucralfate', 'tablet', 'A02BX02', false, 0, '02238209', 'FreeDiams::CA_HCDPD::DIN', 61602);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Valproic Acid', 'syrup', 'N03AG01', false, 0, '02238210', 'FreeDiams::CA_HCDPD::DIN', 61603);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Loperamide', 'tablet', 'A07DA03', false, 0, '02238211', 'FreeDiams::CA_HCDPD::DIN', 61604);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Propecia', 'tablet', 'D11AX10', false, 0, '02238213', 'FreeDiams::CA_HCDPD::DIN', 61606);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Singulair', 'tablet (chewable)', 'R03DC03', false, 0, '02238216', 'FreeDiams::CA_HCDPD::DIN', 61609);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Singulair', 'tablet', 'R03DC03', false, 0, '02238217', 'FreeDiams::CA_HCDPD::DIN', 61610);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Carbamazepine Cr', 'tablet (extended-release)', 'N03AF01', false, 0, '02238222', 'FreeDiams::CA_HCDPD::DIN', 61615);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Carbamazepine Cr', 'tablet (extended-release)', 'N03AF01', false, 0, '02238223', 'FreeDiams::CA_HCDPD::DIN', 61616);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vionex Antimicrobial Liquid Soap', 'liquid', 'D08AE05', false, 0, '02238251', 'FreeDiams::CA_HCDPD::DIN', 61646);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vionex Antimicrobial Skinwipe Towelette', 'wipe', 'D08AE05', false, 0, '02238252', 'FreeDiams::CA_HCDPD::DIN', 61647);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Verapamil Sr', 'tablet (extended-release)', 'C08DA01', false, 0, '02238276', 'FreeDiams::CA_HCDPD::DIN', 61673);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Sertraline', 'capsule', 'N06AB06', false, 0, '02238280', 'FreeDiams::CA_HCDPD::DIN', 61676);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Sertraline', 'capsule', 'N06AB06', false, 0, '02238281', 'FreeDiams::CA_HCDPD::DIN', 61677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Sertraline', 'capsule', 'N06AB06', false, 0, '02238282', 'FreeDiams::CA_HCDPD::DIN', 61678);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sirop Docusate De Sodium U.S.P. 4mg/Ml', 'syrup', 'A06AA02', false, 0, '02238283', 'FreeDiams::CA_HCDPD::DIN', 61679);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Health Saver Disinfectant Ii', 'liquid', 'V07AV', false, 0, '02238284', 'FreeDiams::CA_HCDPD::DIN', 61680);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simply Botanical Sensation Soothing Skin', 'liquid', 'D08AE04', false, 0, '02238288', 'FreeDiams::CA_HCDPD::DIN', 61685);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Tylenol', 'tablet', 'N02BE01', false, 0, '02238295', 'FreeDiams::CA_HCDPD::DIN', 61697);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actifed Tablets', 'tablet', 'R01BA52', false, 0, '02238302', 'FreeDiams::CA_HCDPD::DIN', 61704);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Domperidone', 'tablet', 'A03FA03', false, 0, '02238315', 'FreeDiams::CA_HCDPD::DIN', 61717);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Atenolol', 'tablet', 'C07AB03', false, 0, '02238316', 'FreeDiams::CA_HCDPD::DIN', 61718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Atenolol', 'tablet', 'C07AB03', false, 0, '02238318', 'FreeDiams::CA_HCDPD::DIN', 61719);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Selegiline', 'tablet', 'N04BD01', false, 0, '02238319', 'FreeDiams::CA_HCDPD::DIN', 61721);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Sotalol - 80 Mg', 'tablet', 'C07AA07', false, 0, '02238326', 'FreeDiams::CA_HCDPD::DIN', 61729);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Sotalol - 160 Mg', 'tablet', 'C07AA07', false, 0, '02238327', 'FreeDiams::CA_HCDPD::DIN', 61730);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Clobazam', 'tablet', 'N05BA09', false, 0, '02238334', 'FreeDiams::CA_HCDPD::DIN', 61740);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reactine', 'syrup', 'R06AE07', false, 0, '02238337', 'FreeDiams::CA_HCDPD::DIN', 61744);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Selegiline', 'tablet', 'N04BD01', false, 0, '02238340', 'FreeDiams::CA_HCDPD::DIN', 61747);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Domperidone', 'tablet', 'A03FA03', false, 0, '02238341', 'FreeDiams::CA_HCDPD::DIN', 61748);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rescriptor', 'tablet', 'J05AG02', false, 0, '02238348', 'FreeDiams::CA_HCDPD::DIN', 61760);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hands On Defense', 'liquid', 'D08AE04', false, 0, '02238350', 'FreeDiams::CA_HCDPD::DIN', 61762);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Valproic Syrup', 'syrup', 'N03AG01', false, 0, '02238370', 'FreeDiams::CA_HCDPD::DIN', 61782);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tub Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02238372', 'FreeDiams::CA_HCDPD::DIN', 61784);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caelyx', 'suspension', 'L01DB01', false, 0, '02238389', 'FreeDiams::CA_HCDPD::DIN', 61804);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenylephrine Hydrochloride Injection Usp, 1%', 'liquid', 'C01CA06', false, 0, '02238400', 'FreeDiams::CA_HCDPD::DIN', 61817);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Methoprazine', 'tablet', 'N05AA02', false, 0, '02238403', 'FreeDiams::CA_HCDPD::DIN', 61820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Methoprazine', 'tablet', 'N05AA02', false, 0, '02238404', 'FreeDiams::CA_HCDPD::DIN', 61821);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Methoprazine', 'tablet', 'N05AA02', false, 0, '02238405', 'FreeDiams::CA_HCDPD::DIN', 61822);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Methoprazine', 'tablet', 'N05AA02', false, 0, '02238406', 'FreeDiams::CA_HCDPD::DIN', 61823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermazinc Spray', 'spray', 'D11AX12', false, 0, '02238407', 'FreeDiams::CA_HCDPD::DIN', 61824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen (Compressed)', 'gas', 'V03AN01', false, 0, '02238428', 'FreeDiams::CA_HCDPD::DIN', 61847);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Noriquat', 'liquid', 'V07AV', false, 0, '02238440', 'FreeDiams::CA_HCDPD::DIN', 61859);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyban', 'tablet (extended-release)', 'N06AX12', false, 0, '02238441', 'FreeDiams::CA_HCDPD::DIN', 61860);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xeloda', 'tablet', 'L01BC06', false, 0, '02238453', 'FreeDiams::CA_HCDPD::DIN', 61873);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xeloda', 'tablet', 'L01BC06', false, 0, '02238454', 'FreeDiams::CA_HCDPD::DIN', 61874);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nasonex', 'spray, metered dose', 'R01AD09', false, 0, '02238465', 'FreeDiams::CA_HCDPD::DIN', 61885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutrogena Moisture Spf 15', 'cream', 'D02BA30', false, 0, '02238466', 'FreeDiams::CA_HCDPD::DIN', 61886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Standardized Grass Pollen - Meadow Fescue (100000 Bau/Ml)', 'liquid', 'V01AA02', false, 0, '02238472', 'FreeDiams::CA_HCDPD::DIN', 61892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Standardized Grass Pollen - Meadow Fescue (10000 Bau/Ml)', 'liquid', 'V01AA02', false, 0, '02238473', 'FreeDiams::CA_HCDPD::DIN', 61893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutrogena Healthy Skin Face Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02238476', 'FreeDiams::CA_HCDPD::DIN', 61896);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Standardized Grass Pollen - Kentucky Bluegrass (100000 Bau/Ml)', 'liquid', 'V01AA02', false, 0, '02238480', 'FreeDiams::CA_HCDPD::DIN', 61900);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Standardized Grass Pollen - Kentucky Bluegrass (10000 Bau/Ml)', 'liquid', 'V01AA02', false, 0, '02238481', 'FreeDiams::CA_HCDPD::DIN', 61901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Standardized Grass Pollen - Orchard Grass (100000 Bau/Ml)', 'liquid', 'V01AA02', false, 0, '02238485', 'FreeDiams::CA_HCDPD::DIN', 61905);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Standardized Grass Pollen - Orchard Grass (10000 Bau/Ml)', 'liquid', 'V01AA02', false, 0, '02238486', 'FreeDiams::CA_HCDPD::DIN', 61906);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Standardized Grass Pollen - Redtop (100,000 Bau/Ml)', 'liquid', 'V01AA02', false, 0, '02238489', 'FreeDiams::CA_HCDPD::DIN', 61909);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Standardized Grass Pollen - Redtop (10,000 Bau/Ml)', 'liquid', 'V01AA02', false, 0, '02238490', 'FreeDiams::CA_HCDPD::DIN', 61910);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Standardized Grass Pollen - Sweet Vernalgrass (100,000 Bau/Ml)', 'liquid', 'V01AA02', false, 0, '02238493', 'FreeDiams::CA_HCDPD::DIN', 61913);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Standardized Grass Pollen - Sweet Vernalgrass (10,000 Bau/Ml)', 'liquid', 'V01AA02', false, 0, '02238494', 'FreeDiams::CA_HCDPD::DIN', 61914);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Standardized Grass Pollen - Timothy (100000 Bau/Ml)', 'liquid', 'V01AA02', false, 0, '02238497', 'FreeDiams::CA_HCDPD::DIN', 61918);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Standardized Grass Pollen - Timothy (10000 Bau/Ml)', 'liquid', 'V01AA02', false, 0, '02238498', 'FreeDiams::CA_HCDPD::DIN', 61919);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Standardized Grass Pollen - Perennial Ryegrass (100000 Bau/Ml)', 'liquid', 'V01AA02', false, 0, '02238501', 'FreeDiams::CA_HCDPD::DIN', 61922);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Standardized Grass Pollen - Perennial Ryegrass (10000 Bau/Ml)', 'liquid', 'V01AA02', false, 0, '02238502', 'FreeDiams::CA_HCDPD::DIN', 61923);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hands On Antiseptic', 'liquid', 'D08AJ01', false, 0, '02238517', 'FreeDiams::CA_HCDPD::DIN', 61938);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hp-Pac', 'kit', 'A02BD07', false, 0, '02238525', 'FreeDiams::CA_HCDPD::DIN', 61948);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cystadane', 'powder for solution', 'A16AA06', false, 0, '02238526', 'FreeDiams::CA_HCDPD::DIN', 61949);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Strepsils Sore Throat Blocked Nose', 'lozenge', 'R02AA03', false, 0, '02238543', 'FreeDiams::CA_HCDPD::DIN', 61969);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asaphen E.C.', 'tablet (delayed-release)', 'N02BA01', false, 0, '02238545', 'FreeDiams::CA_HCDPD::DIN', 61971);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valproic-250', 'capsule', 'N03AG01', false, 0, '02238546', 'FreeDiams::CA_HCDPD::DIN', 61972);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Captopril', 'tablet', 'C09AA01', false, 0, '02238551', 'FreeDiams::CA_HCDPD::DIN', 61977);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Captopril', 'tablet', 'C09AA01', false, 0, '02238552', 'FreeDiams::CA_HCDPD::DIN', 61978);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Captopril', 'tablet', 'C09AA01', false, 0, '02238553', 'FreeDiams::CA_HCDPD::DIN', 61979);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Captopril', 'tablet', 'C09AA01', false, 0, '02238554', 'FreeDiams::CA_HCDPD::DIN', 61980);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Captopril', 'tablet', 'C09AA01', false, 0, '02238555', 'FreeDiams::CA_HCDPD::DIN', 61982);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Captopril', 'tablet', 'C09AA01', false, 0, '02238556', 'FreeDiams::CA_HCDPD::DIN', 61983);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Captopril', 'tablet', 'C09AA01', false, 0, '02238557', 'FreeDiams::CA_HCDPD::DIN', 61984);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Captopril', 'tablet', 'C09AA01', false, 0, '02238558', 'FreeDiams::CA_HCDPD::DIN', 61985);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Flutamide', 'tablet', 'L02BB01', false, 0, '02238560', 'FreeDiams::CA_HCDPD::DIN', 61987);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fluorometholone', 'suspension', 'S01BA07', false, 0, '02238568', 'FreeDiams::CA_HCDPD::DIN', 61995);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Beclomethasone 50 Mcg/Metered Nasal Spray', 'suspension', 'R01AD01', false, 0, '02238577', 'FreeDiams::CA_HCDPD::DIN', 62003);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fucidin H', 'cream', 'D07CA01', false, 0, '02238578', 'FreeDiams::CA_HCDPD::DIN', 62005);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Ranitidine 75mg', 'tablet', 'A02BA02', false, 0, '02238579', 'FreeDiams::CA_HCDPD::DIN', 62006);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muse', 'suppository', 'G04BE01', false, 0, '02238593', 'FreeDiams::CA_HCDPD::DIN', 62021);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muse', 'suppository', 'G04BE01', false, 0, '02238594', 'FreeDiams::CA_HCDPD::DIN', 62022);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muse', 'suppository', 'G04BE01', false, 0, '02238595', 'FreeDiams::CA_HCDPD::DIN', 62023);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Zopiclone', 'tablet', 'N05CF01', false, 0, '02238596', 'FreeDiams::CA_HCDPD::DIN', 62024);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Viracept -250mg', 'tablet', 'J05AE04', false, 0, '02238617', 'FreeDiams::CA_HCDPD::DIN', 62045);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Viracept -50mg', 'powder', 'J05AE04', false, 0, '02238618', 'FreeDiams::CA_HCDPD::DIN', 62046);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Deosan', 'liquid', 'V07AV', false, 0, '02238620', 'FreeDiams::CA_HCDPD::DIN', 62048);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Infants'' Motrin Suspension Drops', 'suspension', 'M01AE01', false, 0, '02238626', 'FreeDiams::CA_HCDPD::DIN', 62054);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Cyclobenzaprine', 'tablet', 'M03BX08', false, 0, '02238633', 'FreeDiams::CA_HCDPD::DIN', 62061);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Sotalol', 'tablet', 'C07AA07', false, 0, '02238634', 'FreeDiams::CA_HCDPD::DIN', 62062);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Sotalol', 'tablet', 'C07AA07', false, 0, '02238635', 'FreeDiams::CA_HCDPD::DIN', 62063);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Bromocriptine', 'tablet', 'G02CB01', false, 0, '02238636', 'FreeDiams::CA_HCDPD::DIN', 62064);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Bromocriptine', 'capsule', 'G02CB01', false, 0, '02238637', 'FreeDiams::CA_HCDPD::DIN', 62065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Nabumetone', 'tablet', 'M01AX01', false, 0, '02238639', 'FreeDiams::CA_HCDPD::DIN', 62067);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sleep-Eze D Extra Strength Gelcaps', 'capsule', 'R06AA02', false, 0, '02238644', 'FreeDiams::CA_HCDPD::DIN', 62073);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('292 Tablets', 'tablet', 'N02AA59', false, 0, '02238645', 'FreeDiams::CA_HCDPD::DIN', 62074);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('282 Mep', 'tablet', 'N02BA71', false, 0, '02238646', 'FreeDiams::CA_HCDPD::DIN', 62075);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cepacol Sore Throat Spray', 'spray', 'R02AD04', false, 0, '02238651', 'FreeDiams::CA_HCDPD::DIN', 62080);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zomig Tab 2.5 Mg', 'tablet', 'N02CC03', false, 0, '02238660', 'FreeDiams::CA_HCDPD::DIN', 62089);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('C-2 Buffered With Codeine', 'tablet', 'N02BA51', false, 0, '02238670', 'FreeDiams::CA_HCDPD::DIN', 62101);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intron A', 'solution', 'L03AB05', false, 0, '02238674', 'FreeDiams::CA_HCDPD::DIN', 62105);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intron A', 'solution', 'L03AB05', false, 0, '02238675', 'FreeDiams::CA_HCDPD::DIN', 62106);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bacti-Stat Ae', 'liquid', 'D08AE04', false, 0, '02238676', 'FreeDiams::CA_HCDPD::DIN', 62107);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Plavix', 'tablet', 'B01AC04', false, 0, '02238682', 'FreeDiams::CA_HCDPD::DIN', 62114);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lamisil Spray', 'spray', 'D01AE15', false, 0, '02238703', 'FreeDiams::CA_HCDPD::DIN', 62135);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estrogel', 'gel', 'G03CA03', false, 0, '02238704', 'FreeDiams::CA_HCDPD::DIN', 62136);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Viramune', 'tablet', 'J05AG01', false, 0, '02238748', 'FreeDiams::CA_HCDPD::DIN', 62181);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen', 'gas', 'V03AN01', false, 0, '02238755', 'FreeDiams::CA_HCDPD::DIN', 62190);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Sotalol', 'tablet', 'C07AA07', false, 0, '02238768', 'FreeDiams::CA_HCDPD::DIN', 62204);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Sotalol', 'tablet', 'C07AA07', false, 0, '02238769', 'FreeDiams::CA_HCDPD::DIN', 62205);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Timolol', 'liquid', 'S01ED01', false, 0, '02238770', 'FreeDiams::CA_HCDPD::DIN', 62206);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Timolol', 'liquid', 'S01ED01', false, 0, '02238771', 'FreeDiams::CA_HCDPD::DIN', 62207);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Beclomethasone Nasal Spray', 'suspension', 'R01AD01', false, 0, '02238796', 'FreeDiams::CA_HCDPD::DIN', 62232);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Valproic Acid Syrup', 'syrup', 'N03AG01', false, 0, '02238817', 'FreeDiams::CA_HCDPD::DIN', 62254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clavulin 875', 'tablet', 'J01CR02', false, 0, '02238829', 'FreeDiams::CA_HCDPD::DIN', 62267);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clavulin 400', 'powder for solution', 'J01CR02', false, 0, '02238830', 'FreeDiams::CA_HCDPD::DIN', 62268);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clavulin 200', 'powder for solution', 'J01CR02', false, 0, '02238831', 'FreeDiams::CA_HCDPD::DIN', 62269);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Denavir', 'cream', 'D06BB06', false, 0, '02238848', 'FreeDiams::CA_HCDPD::DIN', 62288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyprexa 15mg', 'tablet', 'N05AH03', false, 0, '02238850', 'FreeDiams::CA_HCDPD::DIN', 62290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyprexa 20mg', 'tablet', 'N05AH03', false, 0, '02238851', 'FreeDiams::CA_HCDPD::DIN', 62291);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Otrivin Allergy And Cold Decongestant Nasal Spray', 'spray', 'R01AA07', false, 0, '02238867', 'FreeDiams::CA_HCDPD::DIN', 62307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Azopt', 'suspension', 'S01EC04', false, 0, '02238873', 'FreeDiams::CA_HCDPD::DIN', 62313);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol Arthritis Pain', 'tablet (extended-release)', 'N02BE01', false, 0, '02238885', 'FreeDiams::CA_HCDPD::DIN', 62325);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hot Lemon Relief For Symptoms Of Cold And Flu Extra Strength', 'powder', 'N02BE51', false, 0, '02238890', 'FreeDiams::CA_HCDPD::DIN', 62330);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benztropine Omega', 'liquid', 'N04AC01', false, 0, '02238903', 'FreeDiams::CA_HCDPD::DIN', 62344);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creme De Jour Au Retinol', 'cream', 'D02BA30', false, 0, '02238915', 'FreeDiams::CA_HCDPD::DIN', 62357);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pd-450 Liq 4.5%', 'liquid', 'V07AV', false, 0, '00653101', 'FreeDiams::CA_HCDPD::DIN', 62389);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ld-160', 'liquid', 'V07AV', false, 0, '00676063', 'FreeDiams::CA_HCDPD::DIN', 62391);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Detergent Sanitizer D10 Conc.', 'liquid', 'V07AV', false, 0, '02238968', 'FreeDiams::CA_HCDPD::DIN', 62416);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Detergent Sanitizer D10', 'liquid', 'V07AV', false, 0, '02238969', 'FreeDiams::CA_HCDPD::DIN', 62417);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Disinfectant Cleaner Rx2', 'liquid', 'V07AV', false, 0, '02238970', 'FreeDiams::CA_HCDPD::DIN', 62418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Disinfectant Cleaner R2', 'liquid', 'V07AV', false, 0, '02238971', 'FreeDiams::CA_HCDPD::DIN', 62419);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexidin 2 Solution', 'liquid', 'D08AC02', false, 0, '02238982', 'FreeDiams::CA_HCDPD::DIN', 62430);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Urso', 'tablet', 'A05AA02', false, 0, '02238984', 'FreeDiams::CA_HCDPD::DIN', 62432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gliadel Wafer', 'wafer', 'L01AD01', false, 0, '02238985', 'FreeDiams::CA_HCDPD::DIN', 62433);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rho-Nitro Pumpspray', 'metered-dose pump', 'C01DA02', false, 0, '02238998', 'FreeDiams::CA_HCDPD::DIN', 62447);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creon 5 Minimicrospheres', 'capsule', 'A09AA02', false, 0, '02239007', 'FreeDiams::CA_HCDPD::DIN', 62457);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creon 20 Minimicrospheres', 'capsule', 'A09AA02', false, 0, '02239008', 'FreeDiams::CA_HCDPD::DIN', 62458);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Handclens', 'spray', 'D08AJ01', false, 0, '02239010', 'FreeDiams::CA_HCDPD::DIN', 62461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Sport Spray Spf 30', 'spray', 'D02BA30', false, 0, '02239012', 'FreeDiams::CA_HCDPD::DIN', 62463);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ombrelle Vapo Sport Spf 15', 'lotion', 'D02BA30', false, 0, '02239016', 'FreeDiams::CA_HCDPD::DIN', 62467);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Clonazepam', 'tablet', 'N03AE01', false, 0, '02239024', 'FreeDiams::CA_HCDPD::DIN', 62475);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Clonazepam', 'tablet', 'N03AE01', false, 0, '02239025', 'FreeDiams::CA_HCDPD::DIN', 62476);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Evista (60mg)', 'tablet', 'G03XC01', false, 0, '02239028', 'FreeDiams::CA_HCDPD::DIN', 62480);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nadryl 25mg', 'tablet', 'R06AA02', false, 0, '02239029', 'FreeDiams::CA_HCDPD::DIN', 62481);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nadryl 50mg', 'tablet', 'R06AA02', false, 0, '02239030', 'FreeDiams::CA_HCDPD::DIN', 62482);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Relaxophen Caplets', 'tablet', 'M03BA53', false, 0, '02239031', 'FreeDiams::CA_HCDPD::DIN', 62483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Benzydamine Oral Rinse', 'liquid', 'A01AD02', false, 0, '02239044', 'FreeDiams::CA_HCDPD::DIN', 62497);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flutamide', 'tablet', 'L02BB01', false, 0, '02239045', 'FreeDiams::CA_HCDPD::DIN', 62498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Serostim', 'powder for solution', 'H01AC01', false, 0, '02239046', 'FreeDiams::CA_HCDPD::DIN', 62499);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Serostim', 'powder for solution', 'H01AC01', false, 0, '02239047', 'FreeDiams::CA_HCDPD::DIN', 62500);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Relievol Pms Extra Strength Caplets', 'tablet', 'N02BE51', false, 0, '02239060', 'FreeDiams::CA_HCDPD::DIN', 62514);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Detrol', 'tablet', 'G04BD07', false, 0, '02239064', 'FreeDiams::CA_HCDPD::DIN', 62518);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Detrol', 'tablet', 'G04BD07', false, 0, '02239065', 'FreeDiams::CA_HCDPD::DIN', 62519);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desoxi Cream 0.05%', 'cream', 'D07AC03', false, 0, '02239068', 'FreeDiams::CA_HCDPD::DIN', 62520);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fungicure Gel', 'gel', 'D01AE18', false, 0, '02239066', 'FreeDiams::CA_HCDPD::DIN', 62521);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desoxi Cream 0.25%', 'cream', 'D07AC03', false, 0, '02239069', 'FreeDiams::CA_HCDPD::DIN', 62523);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Virocidin-X', 'spray', 'V07AV', false, 0, '02239070', 'FreeDiams::CA_HCDPD::DIN', 62524);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Metformin', 'tablet', 'A10BA02', false, 0, '02239081', 'FreeDiams::CA_HCDPD::DIN', 62536);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('White Petroleum Jelly U.S.P.', 'paste', 'D02AC', false, 0, '02239087', 'FreeDiams::CA_HCDPD::DIN', 62542);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atacand', 'tablet', 'C09CA06', false, 0, '02239090', 'FreeDiams::CA_HCDPD::DIN', 62546);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atacand Tab 8mg', 'tablet', 'C09CA06', false, 0, '02239091', 'FreeDiams::CA_HCDPD::DIN', 62547);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atacand Tab 16 Mg', 'tablet', 'C09CA06', false, 0, '02239092', 'FreeDiams::CA_HCDPD::DIN', 62548);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylac', 'solution', 'N05AH01', false, 0, '02239101', 'FreeDiams::CA_HCDPD::DIN', 62556);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hot Lemon Relief - Extra Strength', 'powder', 'N02BE51', false, 0, '02239121', 'FreeDiams::CA_HCDPD::DIN', 62576);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Ipratropium Solution', 'solution', 'R03BB01', false, 0, '02239131', 'FreeDiams::CA_HCDPD::DIN', 62586);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benadryl Extra Strength Caplets', 'tablet', 'R06AA02', false, 0, '02239138', 'FreeDiams::CA_HCDPD::DIN', 62594);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Muscle & Back Pain Relief', 'tablet', 'M03BA53', false, 0, '02239141', 'FreeDiams::CA_HCDPD::DIN', 62597);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actonel', 'tablet', 'M05BA07', false, 0, '02239146', 'FreeDiams::CA_HCDPD::DIN', 62602);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actifed Plus Caplets', 'tablet', 'N02BE51', false, 0, '02239154', 'FreeDiams::CA_HCDPD::DIN', 62610);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polysporin Plus Pain Relief Ear Drops', 'drops', 'S02AA30', false, 0, '02239155', 'FreeDiams::CA_HCDPD::DIN', 62611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polysporin Eye And Ear Drops Sterile', 'drops', 'S03AA30', false, 0, '02239156', 'FreeDiams::CA_HCDPD::DIN', 62612);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polysporin Sterile Ophthalmic Ointment', 'ointment', 'S01AA30', false, 0, '02239157', 'FreeDiams::CA_HCDPD::DIN', 62613);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sudafed Cold And Cough Extra Strength Caplets', 'tablet', 'N02BE51', false, 0, '02239158', 'FreeDiams::CA_HCDPD::DIN', 62614);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sudafed Head Cold & Sinus Extra Strength Tablets', 'tablet', 'N02BE51', false, 0, '02239159', 'FreeDiams::CA_HCDPD::DIN', 62615);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zanaflex', 'tablet', 'M03BX02', false, 0, '02239170', 'FreeDiams::CA_HCDPD::DIN', 62626);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heptovir', 'tablet', 'J05AF05', false, 0, '02239193', 'FreeDiams::CA_HCDPD::DIN', 62649);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heptovir', 'solution', 'J05AF05', false, 0, '02239194', 'FreeDiams::CA_HCDPD::DIN', 62650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polysporin Plus Pain Relief', 'cream', 'D06AX30', false, 0, '02239201', 'FreeDiams::CA_HCDPD::DIN', 62658);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Priorix', 'kit', 'J07BD52', false, 0, '02239208', 'FreeDiams::CA_HCDPD::DIN', 62666);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Combivir', 'tablet', 'J05AR01', false, 0, '02239213', 'FreeDiams::CA_HCDPD::DIN', 62673);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glycon 850mg', 'tablet', 'A10BA02', false, 0, '02239214', 'FreeDiams::CA_HCDPD::DIN', 62674);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Furosemide Tablets', 'tablet', 'C03CA01', false, 0, '02239224', 'FreeDiams::CA_HCDPD::DIN', 62684);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Furosemide Tablets', 'tablet', 'C03CA01', false, 0, '02239225', 'FreeDiams::CA_HCDPD::DIN', 62685);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Surgical Scrub And Handwash', 'liquid', 'D08AE05', false, 0, '02239237', 'FreeDiams::CA_HCDPD::DIN', 62698);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Minocycline', 'capsule', 'J01AA08', false, 0, '02239238', 'FreeDiams::CA_HCDPD::DIN', 62699);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Minocycline', 'capsule', 'J01AA08', false, 0, '02239239', 'FreeDiams::CA_HCDPD::DIN', 62700);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germxtra', 'liquid', 'V07AV', false, 0, '02239248', 'FreeDiams::CA_HCDPD::DIN', 62709);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Endure 200', 'liquid', 'D08AE04', false, 0, '02239250', 'FreeDiams::CA_HCDPD::DIN', 62713);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Endure 400 Scrub-Stat 4', 'liquid', 'D08AC02', false, 0, '02239252', 'FreeDiams::CA_HCDPD::DIN', 62715);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jaa Pyral 125 Tablet 125mg', 'tablet', 'P02CC01', false, 0, '00786055', 'FreeDiams::CA_HCDPD::DIN', 62729);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lemonex', 'liquid', 'V07AV', false, 0, '02239266', 'FreeDiams::CA_HCDPD::DIN', 62730);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mavik (4mg)', 'capsule', 'C09AA10', false, 0, '02239267', 'FreeDiams::CA_HCDPD::DIN', 62731);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutrogena Anti-Wrinkle Cream Spf 15', 'cream', 'D02BA30', false, 0, '02239268', 'FreeDiams::CA_HCDPD::DIN', 62732);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Head & Shoulders Dandruff Shampoo', 'shampoo', 'D11AX12', false, 0, '02239278', 'FreeDiams::CA_HCDPD::DIN', 62742);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oil Of Olay Protective Renewal Lotion', 'lotion', 'D02BA30', false, 0, '02239279', 'FreeDiams::CA_HCDPD::DIN', 62743);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Envirosystems Ethylene Oxide Sterilant', 'gas', 'V07AV', false, 0, '02239281', 'FreeDiams::CA_HCDPD::DIN', 62746);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Flunisolide Nasal Spray', 'metered-dose pump', 'R01AD04', false, 0, '02239288', 'FreeDiams::CA_HCDPD::DIN', 62753);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ovol-180 Mg Ultra Strength Capsules', 'capsule', 'A03AX13', false, 0, '02239298', 'FreeDiams::CA_HCDPD::DIN', 62764);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ecocare 250', 'liquid', 'D08AE04', false, 0, '02239311', 'FreeDiams::CA_HCDPD::DIN', 62780);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ecocare 360', 'liquid', 'D08AJ01', false, 0, '02239318', 'FreeDiams::CA_HCDPD::DIN', 62787);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandostatin Lar 10mg', 'powder', 'H01CB02', false, 0, '02239323', 'FreeDiams::CA_HCDPD::DIN', 62792);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandostatin Lar 20mg', 'powder', 'H01CB02', false, 0, '02239324', 'FreeDiams::CA_HCDPD::DIN', 62793);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandostatin Lar 30mg', 'powder', 'H01CB02', false, 0, '02239325', 'FreeDiams::CA_HCDPD::DIN', 62794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tryptan Tab 250mg', 'tablet', 'N06AX02', false, 0, '02239326', 'FreeDiams::CA_HCDPD::DIN', 62795);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tryptan Tab 750mg', 'tablet', 'N06AX02', false, 0, '02239327', 'FreeDiams::CA_HCDPD::DIN', 62796);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vagin-X', 'cream', 'D04AA04', false, 0, '02239338', 'FreeDiams::CA_HCDPD::DIN', 62807);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diclofenac-K', 'tablet', 'M01AB05', false, 0, '02239355', 'FreeDiams::CA_HCDPD::DIN', 62824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Salbutamol', 'solution', 'R03AC02', false, 0, '02239365', 'FreeDiams::CA_HCDPD::DIN', 62834);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Salbutamol', 'solution', 'R03AC02', false, 0, '02239366', 'FreeDiams::CA_HCDPD::DIN', 62835);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Sumatriptan', 'tablet', 'N02CC01', false, 0, '02239367', 'FreeDiams::CA_HCDPD::DIN', 62836);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zofran Odt', 'tablet (orally disintegrating)', 'A04AA01', false, 0, '02239372', 'FreeDiams::CA_HCDPD::DIN', 62841);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zofran Odt', 'tablet (orally disintegrating)', 'A04AA01', false, 0, '02239373', 'FreeDiams::CA_HCDPD::DIN', 62842);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rodan & Fields/Proactiv Solution:Repairing Lotion', 'lotion', 'D10AE01', false, 0, '02239396', 'FreeDiams::CA_HCDPD::DIN', 62868);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rodan & Fields/Proactiv Solution:Renewing Cleanser', 'lotion', 'D10AE01', false, 0, '02239398', 'FreeDiams::CA_HCDPD::DIN', 62870);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tek-Trol Disinfectant-Cleaner-Concentrate', 'liquid', 'V07AV', false, 0, '02239409', 'FreeDiams::CA_HCDPD::DIN', 62881);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract-Standardized Cat Hair', 'liquid', 'V01AA11', false, 0, '02239410', 'FreeDiams::CA_HCDPD::DIN', 62882);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Beauticontrol Cell Block C', 'cream', 'D02BA30', false, 0, '02239413', 'FreeDiams::CA_HCDPD::DIN', 62885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Canesten External Cream Refill', 'cream', 'D01AC01', false, 0, '02239432', 'FreeDiams::CA_HCDPD::DIN', 62905);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate 2151', 'solution', 'B05ZA', false, 0, '02239486', 'FreeDiams::CA_HCDPD::DIN', 62960);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate 2198', 'solution', 'B05ZA', false, 0, '02239490', 'FreeDiams::CA_HCDPD::DIN', 62964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate 2156', 'solution', 'B05ZA', false, 0, '02239491', 'FreeDiams::CA_HCDPD::DIN', 62965);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Absorbine Jr Antifungal Liquid', 'liquid', 'D01AE18', false, 0, '02239497', 'FreeDiams::CA_HCDPD::DIN', 62971);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aldara 5% Cream', 'cream', 'D06BB10', false, 0, '02239505', 'FreeDiams::CA_HCDPD::DIN', 62979);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Activated Charcoal Powder', 'powder for solution', 'A07BA01', false, 0, '02239507', 'FreeDiams::CA_HCDPD::DIN', 62983);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soft Care 2% Chg Antimicrobial Skin Cleanser', 'liquid', 'D08AC02', false, 0, '02239513', 'FreeDiams::CA_HCDPD::DIN', 62989);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Divalproex 125mg', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02239517', 'FreeDiams::CA_HCDPD::DIN', 62993);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Divalproex 250mg', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02239518', 'FreeDiams::CA_HCDPD::DIN', 62994);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Divalproex 500mg', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02239519', 'FreeDiams::CA_HCDPD::DIN', 62995);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Dexamethasone Tablet 4mg', 'tablet', 'H02AB02', false, 0, '02239534', 'FreeDiams::CA_HCDPD::DIN', 63010);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Loperamide Caplets 2mg', 'tablet', 'A07DA03', false, 0, '02239535', 'FreeDiams::CA_HCDPD::DIN', 63011);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Piroxicam', 'capsule', 'M01AC01', false, 0, '02239536', 'FreeDiams::CA_HCDPD::DIN', 63012);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Benzydamine', 'liquid', 'A01AD02', false, 0, '02239537', 'FreeDiams::CA_HCDPD::DIN', 63013);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simply Sleep', 'tablet', 'R06AA02', false, 0, '02239548', 'FreeDiams::CA_HCDPD::DIN', 63024);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Link Anti-Bac 128', 'liquid', 'V07AV', false, 0, '02239564', 'FreeDiams::CA_HCDPD::DIN', 63042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Tobramycin 0.3% Ophthalmic Solution', 'liquid', 'S01AA12', false, 0, '02239577', 'FreeDiams::CA_HCDPD::DIN', 63055);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Melaleuca Shampooing Antipelliculaire Pellicules Grasses, Cuir Chevelu Gras-Rene Furterer', 'shampoo', 'D11AX12', false, 0, '02239597', 'FreeDiams::CA_HCDPD::DIN', 63067);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Monistat 1 Combination Pack', 'kit', 'G01AF04', false, 0, '02239600', 'FreeDiams::CA_HCDPD::DIN', 63070);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Monistat 1 Vaginal Ovule', 'suppository', 'G01AF04', false, 0, '02239601', 'FreeDiams::CA_HCDPD::DIN', 63071);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Celexa 20 Mg', 'tablet', 'N06AB04', false, 0, '02239607', 'FreeDiams::CA_HCDPD::DIN', 63077);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Celexa 40 Mg', 'tablet', 'N06AB04', false, 0, '02239608', 'FreeDiams::CA_HCDPD::DIN', 63078);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Panto Iv', 'powder for solution', 'A02BC02', false, 0, '02239616', 'FreeDiams::CA_HCDPD::DIN', 63087);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Indapamide', 'tablet', 'C03BA11', false, 0, '02239619', 'FreeDiams::CA_HCDPD::DIN', 63090);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Indapamide', 'tablet', 'C03BA11', false, 0, '02239620', 'FreeDiams::CA_HCDPD::DIN', 63091);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ipratropium', 'liquid', 'R03BB01', false, 0, '02239627', 'FreeDiams::CA_HCDPD::DIN', 63098);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nursing Cream', 'cream', 'D02AC', false, 0, '02239629', 'FreeDiams::CA_HCDPD::DIN', 63100);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tobi', 'solution', 'J01GB01', false, 0, '02239630', 'FreeDiams::CA_HCDPD::DIN', 63101);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aloe Kote Spf 25', 'ointment', 'D02BA30', false, 0, '02239631', 'FreeDiams::CA_HCDPD::DIN', 63102);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluphenazine Omega', 'liquid', 'N05AB02', false, 0, '02239636', 'FreeDiams::CA_HCDPD::DIN', 63107);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Haloperidol-La Omega', 'liquid', 'N05AD01', false, 0, '02239639', 'FreeDiams::CA_HCDPD::DIN', 63111);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Haloperidol-La Omega', 'liquid', 'N05AD01', false, 0, '02239640', 'FreeDiams::CA_HCDPD::DIN', 63112);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Androderm', 'patch', 'G03BA03', false, 0, '02239653', 'FreeDiams::CA_HCDPD::DIN', 63125);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Conjugated Estrogens C.S.D.', 'tablet', 'G03CA57', false, 0, '02239654', 'FreeDiams::CA_HCDPD::DIN', 63126);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Conjugated Estrogens C.S.D.', 'tablet', 'G03CA57', false, 0, '02239655', 'FreeDiams::CA_HCDPD::DIN', 63127);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Provocholine', 'powder for solution', 'V04CX', false, 0, '02239656', 'FreeDiams::CA_HCDPD::DIN', 63128);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Docusate Sodium', 'capsule', 'A06AA02', false, 0, '02239658', 'FreeDiams::CA_HCDPD::DIN', 63130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Niastase', 'powder for solution', 'B02BD08', false, 0, '02239659', 'FreeDiams::CA_HCDPD::DIN', 63131);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Niastase', 'powder for solution', 'B02BD08', false, 0, '02239660', 'FreeDiams::CA_HCDPD::DIN', 63132);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Niastase', 'powder for solution', 'B02BD08', false, 0, '02239661', 'FreeDiams::CA_HCDPD::DIN', 63133);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alertec', 'tablet', 'N06BA07', false, 0, '02239665', 'FreeDiams::CA_HCDPD::DIN', 63139);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Cold Cough And Fever', 'liquid', 'N02BE51', false, 0, '02239666', 'FreeDiams::CA_HCDPD::DIN', 63140);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Minocycline Capsules', 'capsule', 'J01AA08', false, 0, '02239667', 'FreeDiams::CA_HCDPD::DIN', 63141);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Minocycline Capsules', 'capsule', 'J01AA08', false, 0, '02239668', 'FreeDiams::CA_HCDPD::DIN', 63142);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Divalproex', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02239698', 'FreeDiams::CA_HCDPD::DIN', 63179);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Divalproex', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02239699', 'FreeDiams::CA_HCDPD::DIN', 63180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Divalproex', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02239700', 'FreeDiams::CA_HCDPD::DIN', 63181);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Divalproex', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02239701', 'FreeDiams::CA_HCDPD::DIN', 63182);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Divalproex', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02239702', 'FreeDiams::CA_HCDPD::DIN', 63183);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Divalproex', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02239703', 'FreeDiams::CA_HCDPD::DIN', 63184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Denti-Care Topical Anesthetic Gel', 'gel', 'A01AD11', false, 0, '02239705', 'FreeDiams::CA_HCDPD::DIN', 63187);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Valproic', 'capsule', 'N03AG01', false, 0, '02239714', 'FreeDiams::CA_HCDPD::DIN', 63196);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neurontin 600mg', 'tablet', 'N03AX12', false, 0, '02239717', 'FreeDiams::CA_HCDPD::DIN', 63199);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neurontin 800mg', 'tablet', 'N03AX12', false, 0, '02239718', 'FreeDiams::CA_HCDPD::DIN', 63200);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Virocid', 'liquid', 'V07AV', false, 0, '02239726', 'FreeDiams::CA_HCDPD::DIN', 63207);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cidex Opa Solution', 'solution', 'V07AV', false, 0, '02239732', 'FreeDiams::CA_HCDPD::DIN', 63214);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle And Back Pain Relief Extra Strength', 'tablet', 'M03BA53', false, 0, '02239741', 'FreeDiams::CA_HCDPD::DIN', 63223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle And Back Pain Relief Extra Strength', 'tablet', 'M03BA53', false, 0, '02239742', 'FreeDiams::CA_HCDPD::DIN', 63224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Ticlopidine', 'tablet', 'B01AC05', false, 0, '02239744', 'FreeDiams::CA_HCDPD::DIN', 63226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Moclobemide', 'tablet', 'N06AG02', false, 0, '02239746', 'FreeDiams::CA_HCDPD::DIN', 63228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Moclobemide', 'tablet', 'N06AG02', false, 0, '02239747', 'FreeDiams::CA_HCDPD::DIN', 63229);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Moclobemide', 'tablet', 'N06AG02', false, 0, '02239748', 'FreeDiams::CA_HCDPD::DIN', 63230);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diclofenac K', 'tablet', 'M01AB05', false, 0, '02239753', 'FreeDiams::CA_HCDPD::DIN', 63235);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bactroban Cream', 'cream', 'D06AX09', false, 0, '02239757', 'FreeDiams::CA_HCDPD::DIN', 63239);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Viagra', 'tablet', 'G04BE03', false, 0, '02239766', 'FreeDiams::CA_HCDPD::DIN', 63248);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Viagra', 'tablet', 'G04BE03', false, 0, '02239767', 'FreeDiams::CA_HCDPD::DIN', 63249);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Viagra', 'tablet', 'G04BE03', false, 0, '02239768', 'FreeDiams::CA_HCDPD::DIN', 63250);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Virox 5 Rtu', 'liquid', 'V07AV', false, 0, '02239775', 'FreeDiams::CA_HCDPD::DIN', 63257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Ice Natural Sunscreen Spf 15', 'stick', 'D02BA30', false, 0, '02239780', 'FreeDiams::CA_HCDPD::DIN', 63261);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pine Quat', 'liquid', 'V07AV', false, 0, '02239779', 'FreeDiams::CA_HCDPD::DIN', 63262);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro Spf 15 Sport Lotion', 'lotion', 'D02BA30', false, 0, '02239781', 'FreeDiams::CA_HCDPD::DIN', 63263);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro Spf 30 Sport Lotion', 'lotion', 'D02BA30', false, 0, '02239782', 'FreeDiams::CA_HCDPD::DIN', 63264);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Multi-Symptom Pms Relief', 'tablet', 'N02BE51', false, 0, '02239813', 'FreeDiams::CA_HCDPD::DIN', 63299);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluoxetine Capsules', 'capsule', 'N06AB03', false, 0, '02239817', 'FreeDiams::CA_HCDPD::DIN', 63304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluoxetine Capsules', 'capsule', 'N06AB03', false, 0, '02239818', 'FreeDiams::CA_HCDPD::DIN', 63305);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Virox 5', 'liquid', 'V07AV', false, 0, '02239828', 'FreeDiams::CA_HCDPD::DIN', 63315);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pimozide', 'tablet', 'N05AG02', false, 0, '02239829', 'FreeDiams::CA_HCDPD::DIN', 63316);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pimozide', 'tablet', 'N05AG02', false, 0, '02239830', 'FreeDiams::CA_HCDPD::DIN', 63317);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Infergen', 'solution', 'L03AB09', false, 0, '02239832', 'FreeDiams::CA_HCDPD::DIN', 63319);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lupron Depot', 'powder for suspension, sustained-release', 'L02AE02', false, 0, '02239833', 'FreeDiams::CA_HCDPD::DIN', 63320);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lupron Depot', 'powder for suspension, sustained-release', 'L02AE02', false, 0, '02239834', 'FreeDiams::CA_HCDPD::DIN', 63321);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Amiodarone', 'tablet', 'C01BD01', false, 0, '02239835', 'FreeDiams::CA_HCDPD::DIN', 63322);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allegra-D', 'tablet (extended-release)', 'R01BA52', false, 0, '02239853', 'FreeDiams::CA_HCDPD::DIN', 63341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Blistex Herbal Answer Lipbalm Spf 15', 'ointment', 'D02BA30', false, 0, '02239854', 'FreeDiams::CA_HCDPD::DIN', 63342);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Block-Up Kids Spf 30 Bug Repelling', 'lotion', 'D02BA30', false, 0, '02239858', 'FreeDiams::CA_HCDPD::DIN', 63346);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Block-Up Sport 15', 'lotion', 'D02BA30', false, 0, '02239859', 'FreeDiams::CA_HCDPD::DIN', 63347);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Block-Up Oil Free 45 Spf', 'lotion', 'D02BA30', false, 0, '02239860', 'FreeDiams::CA_HCDPD::DIN', 63348);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Block-Up Sport 30 Bug Repelling', 'lotion', 'D02BA30', false, 0, '02239861', 'FreeDiams::CA_HCDPD::DIN', 63349);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Block-Up Oil Free 15 Spf', 'lotion', 'D02BA30', false, 0, '02239862', 'FreeDiams::CA_HCDPD::DIN', 63350);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Block-Up Regular Spf 45', 'lotion', 'D02BA30', false, 0, '02239863', 'FreeDiams::CA_HCDPD::DIN', 63351);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Feno-Micro', 'capsule', 'C10AB05', false, 0, '02239864', 'FreeDiams::CA_HCDPD::DIN', 63352);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sustiva 50mg', 'capsule', 'J05AG03', false, 0, '02239886', 'FreeDiams::CA_HCDPD::DIN', 63374);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sustiva 200mg', 'capsule', 'J05AG03', false, 0, '02239888', 'FreeDiams::CA_HCDPD::DIN', 63376);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Terbinafine', 'tablet', 'D01BA02', false, 0, '02239893', 'FreeDiams::CA_HCDPD::DIN', 63385);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topamax', 'capsule', 'N03AX11', false, 0, '02239907', 'FreeDiams::CA_HCDPD::DIN', 63399);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topamax', 'capsule', 'N03AX11', false, 0, '02239908', 'FreeDiams::CA_HCDPD::DIN', 63400);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epaxal', 'liquid', 'J07BC02', false, 0, '02239910', 'FreeDiams::CA_HCDPD::DIN', 63411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Sucralfate', 'tablet', 'A02BX02', false, 0, '02239912', 'FreeDiams::CA_HCDPD::DIN', 63412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Indapamide Tablets 1.25mg', 'tablet', 'C03BA11', false, 0, '02239913', 'FreeDiams::CA_HCDPD::DIN', 63413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Indapamide Tablets 2.5mg', 'tablet', 'C03BA11', false, 0, '02239917', 'FreeDiams::CA_HCDPD::DIN', 63417);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Loxapine Tablets 5mg', 'tablet', 'N05AH01', false, 0, '02239918', 'FreeDiams::CA_HCDPD::DIN', 63418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Loxapine Tablets 10mg', 'tablet', 'N05AH01', false, 0, '02239919', 'FreeDiams::CA_HCDPD::DIN', 63419);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Loxapine Tablets 25mg', 'tablet', 'N05AH01', false, 0, '02239920', 'FreeDiams::CA_HCDPD::DIN', 63420);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Loxapine Tablets 50mg', 'tablet', 'N05AH01', false, 0, '02239921', 'FreeDiams::CA_HCDPD::DIN', 63421);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gluconorm 0.5mg', 'tablet', 'A10BX02', false, 0, '02239924', 'FreeDiams::CA_HCDPD::DIN', 63424);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gluconorm 1.0mg', 'tablet', 'A10BX02', false, 0, '02239925', 'FreeDiams::CA_HCDPD::DIN', 63425);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gluconorm 2.0mg', 'tablet', 'A10BX02', false, 0, '02239926', 'FreeDiams::CA_HCDPD::DIN', 63426);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Celebrex 100mg', 'capsule', 'M01AH01', false, 0, '02239941', 'FreeDiams::CA_HCDPD::DIN', 63442);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Celebrex 200mg', 'capsule', 'M01AH01', false, 0, '02239942', 'FreeDiams::CA_HCDPD::DIN', 63443);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ketorolac Tromethamine Injection Usp', 'liquid', 'M01AB15', false, 0, '02239944', 'FreeDiams::CA_HCDPD::DIN', 63447);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Gemfibrozil', 'capsule', 'C10AB04', false, 0, '02239951', 'FreeDiams::CA_HCDPD::DIN', 63454);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zithromax For Intravenous Injection', 'powder for solution', 'J01FA10', false, 0, '02239952', 'FreeDiams::CA_HCDPD::DIN', 63455);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Fluvoxamine', 'tablet', 'N06AB08', false, 0, '02239953', 'FreeDiams::CA_HCDPD::DIN', 63456);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Fluvoxamine', 'tablet', 'N06AB08', false, 0, '02239954', 'FreeDiams::CA_HCDPD::DIN', 63457);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crčme Analgésique Extra-Puissante Sans Odeur', 'cream', 'M02AC', false, 0, '02239967', 'FreeDiams::CA_HCDPD::DIN', 63472);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minocycline', 'capsule', 'J01AA08', false, 0, '02239982', 'FreeDiams::CA_HCDPD::DIN', 63489);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trelstar', 'powder for suspension, sustained-release', 'L02AE04', false, 0, '02240000', 'FreeDiams::CA_HCDPD::DIN', 63507);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Luxiva Preventage Firming Defense Creme Spf 15', 'cream', 'D02BA30', false, 0, '02240008', 'FreeDiams::CA_HCDPD::DIN', 63515);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Luxiva Preventage Firming Defense Creme For Dry Skin Spf 15', 'cream', 'D02BA30', false, 0, '02240009', 'FreeDiams::CA_HCDPD::DIN', 63516);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Skinvisible Antiseptic Skin Cleanser', 'lotion', 'D08AE04', false, 0, '02240020', 'FreeDiams::CA_HCDPD::DIN', 63527);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gastrocalm Comprimes (Chewable Tablets)', 'tablet', 'A02AF02', false, 0, '02240024', 'FreeDiams::CA_HCDPD::DIN', 63534);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Indapamide', 'tablet', 'C03BA11', false, 0, '02240067', 'FreeDiams::CA_HCDPD::DIN', 63577);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Amiodarone', 'tablet', 'C01BD01', false, 0, '02240071', 'FreeDiams::CA_HCDPD::DIN', 63581);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rivasol-Hc Suppositories', 'suppository', 'C05AA01', false, 0, '02240112', 'FreeDiams::CA_HCDPD::DIN', 63617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aveeno Anti-Itch Cream', 'cream', 'D04AB07', false, 0, '02240104', 'FreeDiams::CA_HCDPD::DIN', 63619);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aveeno Anti-Itch Lotion', 'lotion', 'D04AB07', false, 0, '02240105', 'FreeDiams::CA_HCDPD::DIN', 63620);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cosopt  -(2%/0.5% Oph Dps)', 'solution', 'S01ED51', false, 0, '02240113', 'FreeDiams::CA_HCDPD::DIN', 63627);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fraxiparine Forte', 'solution', 'B01AB06', false, 0, '02240114', 'FreeDiams::CA_HCDPD::DIN', 63628);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lamictal', 'tablet', 'N03AX09', false, 0, '02240115', 'FreeDiams::CA_HCDPD::DIN', 63629);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxy.Ir', 'tablet', 'N02AA05', false, 0, '02240131', 'FreeDiams::CA_HCDPD::DIN', 63645);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxy.Ir', 'tablet', 'N02AA05', false, 0, '02240132', 'FreeDiams::CA_HCDPD::DIN', 63646);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Provon Medicated Lotion Soap With Triclosan', 'liquid', 'D08AE04', false, 0, '02240142', 'FreeDiams::CA_HCDPD::DIN', 63657);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cellex-C Suncare Spf 30', 'lotion', 'D02BA30', false, 0, '02240147', 'FreeDiams::CA_HCDPD::DIN', 63661);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cellex-C Suncare Spf 32', 'lotion', 'D02BA30', false, 0, '02240148', 'FreeDiams::CA_HCDPD::DIN', 63662);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Psoriasin Gel', 'gel', 'D05AA', false, 0, '02240152', 'FreeDiams::CA_HCDPD::DIN', 63668);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Henry Schein Surface Disinfectant', 'liquid', 'V07AV', false, 0, '02240189', 'FreeDiams::CA_HCDPD::DIN', 63709);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coumadin Tab 3mg', 'tablet', 'B01AA03', false, 0, '02240205', 'FreeDiams::CA_HCDPD::DIN', 63731);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coumadin Tab 6 Mg', 'tablet', 'B01AA03', false, 0, '02240206', 'FreeDiams::CA_HCDPD::DIN', 63732);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Fenofibrate Micro', 'capsule', 'C10AB05', false, 0, '02240210', 'FreeDiams::CA_HCDPD::DIN', 63736);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dinate', 'tablet', 'R06AA02', false, 0, '02240216', 'FreeDiams::CA_HCDPD::DIN', 63745);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stemgen', 'kit', 'L03AA12', false, 0, '02240229', 'FreeDiams::CA_HCDPD::DIN', 63758);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adacel', 'suspension', 'J07AJ52', false, 0, '02240255', 'FreeDiams::CA_HCDPD::DIN', 63789);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aller-Relief', 'tablet', 'R06AE07', false, 0, '02240265', 'FreeDiams::CA_HCDPD::DIN', 63802);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy-Relief', 'tablet', 'R06AE07', false, 0, '02240266', 'FreeDiams::CA_HCDPD::DIN', 63803);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topactin Emollient Cream 0.05%', 'cream', 'D07AC08', false, 0, '02240269', 'FreeDiams::CA_HCDPD::DIN', 63806);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Midazolam Injection', 'solution', 'N05CD08', false, 0, '02240285', 'FreeDiams::CA_HCDPD::DIN', 63823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Midazolam Injection', 'solution', 'N05CD08', false, 0, '02240286', 'FreeDiams::CA_HCDPD::DIN', 63824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humalog Mix 25  (Cartridge/Kwikpen)', 'suspension', 'A10AD04', false, 0, '02240294', 'FreeDiams::CA_HCDPD::DIN', 63832);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humalog Mix 50  (Cartridge/Kwikpen)', 'suspension', 'A10AD04', false, 0, '02240297', 'FreeDiams::CA_HCDPD::DIN', 63835);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Altace Plus Felodipine 5mg + 5mg', 'tablet', 'C09BB05', false, 0, '02240306', 'FreeDiams::CA_HCDPD::DIN', 63844);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Altace Plus Felodipine 2.5mg + 2.5mg', 'tablet', 'C09BB05', false, 0, '02240307', 'FreeDiams::CA_HCDPD::DIN', 63845);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Verapamil Sr 240mg Tablets', 'tablet (extended-release)', 'C08DA01', false, 0, '02240321', 'FreeDiams::CA_HCDPD::DIN', 63861);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lines', 'liquid', 'V07AV', false, 0, '02240323', 'FreeDiams::CA_HCDPD::DIN', 63862);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xenical 120mg Capsule', 'capsule', 'A08AB01', false, 0, '02240325', 'FreeDiams::CA_HCDPD::DIN', 63865);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('One-Alpha', 'drops', 'A11CC03', false, 0, '02240329', 'FreeDiams::CA_HCDPD::DIN', 63869);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Bezafibrate', 'tablet', 'C10AB02', false, 0, '02240331', 'FreeDiams::CA_HCDPD::DIN', 63870);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zocor', 'tablet', 'C10AA01', false, 0, '02240332', 'FreeDiams::CA_HCDPD::DIN', 63871);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Tryptophan', 'tablet', 'N06AX02', false, 0, '02240333', 'FreeDiams::CA_HCDPD::DIN', 63872);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Tryptophan', 'capsule', 'N06AX02', false, 0, '02240334', 'FreeDiams::CA_HCDPD::DIN', 63873);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Fenofibrate Micro', 'capsule', 'C10AB05', false, 0, '02240337', 'FreeDiams::CA_HCDPD::DIN', 63876);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Divalproex-125', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02240341', 'FreeDiams::CA_HCDPD::DIN', 63881);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Divalproex-250', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02240342', 'FreeDiams::CA_HCDPD::DIN', 63882);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Divalproex-500', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02240343', 'FreeDiams::CA_HCDPD::DIN', 63883);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sialor', 'tablet', 'A16AX02', false, 0, '02240344', 'FreeDiams::CA_HCDPD::DIN', 63884);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cellcept I.V.', 'powder for solution', 'L04AA06', false, 0, '02240347', 'FreeDiams::CA_HCDPD::DIN', 63885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Terbinafine', 'tablet', 'D01BA02', false, 0, '02240346', 'FreeDiams::CA_HCDPD::DIN', 63887);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Indapamide', 'tablet', 'C03BA11', false, 0, '02240349', 'FreeDiams::CA_HCDPD::DIN', 63891);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Integrilin', 'solution', 'B01AC16', false, 0, '02240351', 'FreeDiams::CA_HCDPD::DIN', 63892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Indapamide', 'tablet', 'C03BA11', false, 0, '02240350', 'FreeDiams::CA_HCDPD::DIN', 63893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Integrilin', 'solution', 'B01AC16', false, 0, '02240352', 'FreeDiams::CA_HCDPD::DIN', 63894);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soluprep', 'solution', 'D08AC52', false, 0, '02240356', 'FreeDiams::CA_HCDPD::DIN', 63898);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ziagen', 'tablet', 'J05AF06', false, 0, '02240357', 'FreeDiams::CA_HCDPD::DIN', 63899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ziagen', 'solution', 'J05AF06', false, 0, '02240358', 'FreeDiams::CA_HCDPD::DIN', 63900);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pamprin Pms Caplets', 'tablet', 'N02BE51', false, 0, '02240359', 'FreeDiams::CA_HCDPD::DIN', 63901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Feno-Micro-200', 'capsule', 'C10AB05', false, 0, '02240360', 'FreeDiams::CA_HCDPD::DIN', 63903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hyperox', 'liquid', 'V07AV', false, 0, '02240361', 'FreeDiams::CA_HCDPD::DIN', 63904);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Polytrimethoprim', 'liquid', 'S01AA30', false, 0, '02240363', 'FreeDiams::CA_HCDPD::DIN', 63906);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Endure 250 Foaming Healthcare Personnel Hand Wash', 'liquid', 'D08AE04', false, 0, '02240389', 'FreeDiams::CA_HCDPD::DIN', 63917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Famotidine Tablets', 'tablet', 'A02BA03', false, 0, '02240414', 'FreeDiams::CA_HCDPD::DIN', 63963);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Endure 420 Cida-Stat', 'liquid', 'D08AC02', false, 0, '02240416', 'FreeDiams::CA_HCDPD::DIN', 63965);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teveten', 'tablet', 'C09CA02', false, 0, '02240432', 'FreeDiams::CA_HCDPD::DIN', 63981);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Perichlor', 'liquid', 'A01AB03', false, 0, '02240433', 'FreeDiams::CA_HCDPD::DIN', 63982);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fentanyl Citrate Injection Usp', 'liquid', 'N01AH01', false, 0, '02240434', 'FreeDiams::CA_HCDPD::DIN', 63983);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Tryptophan', 'tablet', 'N06AX02', false, 0, '02240445', 'FreeDiams::CA_HCDPD::DIN', 63994);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Softchews Cough And Cold', 'tablet', 'R05DA20', false, 0, '02240448', 'FreeDiams::CA_HCDPD::DIN', 63999);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Softchews Cold And Allergy', 'tablet', 'R01BA52', false, 0, '02240450', 'FreeDiams::CA_HCDPD::DIN', 64001);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Moclobemide', 'tablet', 'N06AG02', false, 0, '02240456', 'FreeDiams::CA_HCDPD::DIN', 64019);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Nizatidine', 'capsule', 'A02BA04', false, 0, '02240457', 'FreeDiams::CA_HCDPD::DIN', 64020);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Nizatidine', 'capsule', 'A02BA04', false, 0, '02240458', 'FreeDiams::CA_HCDPD::DIN', 64021);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bismuth + Antacid (Chewable Tablets)', 'tablet', 'A02AX', false, 0, '02240473', 'FreeDiams::CA_HCDPD::DIN', 64038);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Sertraline', 'capsule', 'N06AB06', false, 0, '02240481', 'FreeDiams::CA_HCDPD::DIN', 64051);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Sertraline', 'capsule', 'N06AB06', false, 0, '02240484', 'FreeDiams::CA_HCDPD::DIN', 64054);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Sertraline', 'capsule', 'N06AB06', false, 0, '02240485', 'FreeDiams::CA_HCDPD::DIN', 64055);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Doxazosin', 'tablet', 'C02CA04', false, 0, '02240498', 'FreeDiams::CA_HCDPD::DIN', 64067);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Doxazosin', 'tablet', 'C02CA04', false, 0, '02240499', 'FreeDiams::CA_HCDPD::DIN', 64068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Doxazosin', 'tablet', 'C02CA04', false, 0, '02240500', 'FreeDiams::CA_HCDPD::DIN', 64069);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Ipratropium', 'liquid', 'R01AX03', false, 0, '02240508', 'FreeDiams::CA_HCDPD::DIN', 64077);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Sport Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02240511', 'FreeDiams::CA_HCDPD::DIN', 64081);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maxalt Rpd', 'wafer', 'N02CC04', false, 0, '02240518', 'FreeDiams::CA_HCDPD::DIN', 64089);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maxalt Rpd', 'wafer', 'N02CC04', false, 0, '02240519', 'FreeDiams::CA_HCDPD::DIN', 64090);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maxalt', 'tablet', 'N02CC04', false, 0, '02240520', 'FreeDiams::CA_HCDPD::DIN', 64091);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maxalt', 'tablet', 'N02CC04', false, 0, '02240521', 'FreeDiams::CA_HCDPD::DIN', 64092);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Denti-Care Chlorhexidine Gluconate Oral Rinse 0.12%', 'kit', 'A01AB03', false, 0, '02240526', 'FreeDiams::CA_HCDPD::DIN', 64096);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Junior Strength Motrin Caplets', 'tablet', 'M01AE01', false, 0, '02240527', 'FreeDiams::CA_HCDPD::DIN', 64097);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flexacreme Extra-Puissante', 'cream', 'M02AC', false, 0, '02240530', 'FreeDiams::CA_HCDPD::DIN', 64100);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sebamed Diaper Rash Cream', 'cream', 'D02AC', false, 0, '02240541', 'FreeDiams::CA_HCDPD::DIN', 64111);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Oxybutynin', 'tablet', 'G04BD04', false, 0, '02240549', 'FreeDiams::CA_HCDPD::DIN', 64119);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Oxybutynin', 'tablet', 'G04BD04', false, 0, '02240550', 'FreeDiams::CA_HCDPD::DIN', 64120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperdal', 'tablet', 'N05AX08', false, 0, '02240551', 'FreeDiams::CA_HCDPD::DIN', 64121);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperdal', 'tablet', 'N05AX08', false, 0, '02240552', 'FreeDiams::CA_HCDPD::DIN', 64122);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medicament Pour Les Sinus, Regulier', 'tablet', 'N02BE51', false, 0, '02240562', 'FreeDiams::CA_HCDPD::DIN', 64134);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medicament Pour Les Sinus, Extra-Fort', 'tablet', 'N02BE51', false, 0, '02240563', 'FreeDiams::CA_HCDPD::DIN', 64135);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polysporin Complete', 'ointment', 'D06AX30', false, 0, '02240568', 'FreeDiams::CA_HCDPD::DIN', 64139);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marcelle True Radiance Spf 15 Fps', 'lotion', 'D02BA30', false, 0, '02240579', 'FreeDiams::CA_HCDPD::DIN', 64150);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Doxazosin', 'tablet', 'C02CA04', false, 0, '02240588', 'FreeDiams::CA_HCDPD::DIN', 64159);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Doxazosin', 'tablet', 'C02CA04', false, 0, '02240589', 'FreeDiams::CA_HCDPD::DIN', 64160);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Doxazosin', 'tablet', 'C02CA04', false, 0, '02240590', 'FreeDiams::CA_HCDPD::DIN', 64161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Busulfex', 'solution', 'L01AB01', false, 0, '02240602', 'FreeDiams::CA_HCDPD::DIN', 64173);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Amiodarone', 'tablet', 'C01BD01', false, 0, '02240604', 'FreeDiams::CA_HCDPD::DIN', 64175);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Zopiclone', 'tablet', 'N05CF01', false, 0, '02240606', 'FreeDiams::CA_HCDPD::DIN', 64177);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Protamine Sulfate Injection Usp', 'liquid', 'V03AB14', false, 0, '02240618', 'FreeDiams::CA_HCDPD::DIN', 64191);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen Usp', 'gas', 'V03AN01', false, 0, '02240621', 'FreeDiams::CA_HCDPD::DIN', 64194);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutrogena T/Gel Therapeutic Shampoo', 'shampoo', 'D05AA', false, 0, '02240645', 'FreeDiams::CA_HCDPD::DIN', 64224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Kids Spf 30', 'lotion', 'D02BA30', false, 0, '02240646', 'FreeDiams::CA_HCDPD::DIN', 64225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexidin 0.5 Solution', 'liquid', 'D08AC52', false, 0, '02240680', 'FreeDiams::CA_HCDPD::DIN', 64263);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fluvoxamine', 'tablet', 'N06AB08', false, 0, '02240682', 'FreeDiams::CA_HCDPD::DIN', 64266);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fluvoxamine', 'tablet', 'N06AB08', false, 0, '02240683', 'FreeDiams::CA_HCDPD::DIN', 64267);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Dexamethasone Tablets, Usp', 'tablet', 'H02AB02', false, 0, '02240684', 'FreeDiams::CA_HCDPD::DIN', 64268);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Dexamethasone Tablets, Usp', 'tablet', 'H02AB02', false, 0, '02240687', 'FreeDiams::CA_HCDPD::DIN', 64271);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Herceptin', 'powder for solution', 'L01XC03', false, 0, '02240692', 'FreeDiams::CA_HCDPD::DIN', 64277);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intron A', 'liquid', 'L03AB05', false, 0, '02240693', 'FreeDiams::CA_HCDPD::DIN', 64280);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intron A', 'liquid', 'L03AB05', false, 0, '02240694', 'FreeDiams::CA_HCDPD::DIN', 64281);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intron A', 'liquid', 'L03AB05', false, 0, '02240695', 'FreeDiams::CA_HCDPD::DIN', 64282);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Softlips Sweet', 'ointment', 'D02BA30', false, 0, '02240701', 'FreeDiams::CA_HCDPD::DIN', 64289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aggrastat', 'solution', 'B01AC17', false, 0, '02240706', 'FreeDiams::CA_HCDPD::DIN', 64293);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imunovir', 'tablet', 'J05AX05', false, 0, '02240713', 'FreeDiams::CA_HCDPD::DIN', 64296);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tub Purge', 'liquid', 'V07AV', false, 0, '02240711', 'FreeDiams::CA_HCDPD::DIN', 64299);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eprex Sterile Solution 40000iu/Ml', 'solution', 'B03XA01', false, 0, '02240722', 'FreeDiams::CA_HCDPD::DIN', 64311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avon Sun Lip Balm Spf 15', 'stick', 'D02BA30', false, 0, '02240745', 'FreeDiams::CA_HCDPD::DIN', 64334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Suprefact Depot 3 Months', 'implant', 'L02AE01', false, 0, '02240749', 'FreeDiams::CA_HCDPD::DIN', 64338);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teint Diorlift', 'emulsion', 'D02BA02', false, 0, '02240752', 'FreeDiams::CA_HCDPD::DIN', 64341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Misoprostol Tablets', 'tablet', 'A02BB01', false, 0, '02240754', 'FreeDiams::CA_HCDPD::DIN', 64343);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Misoprostol Tablets', 'tablet', 'A02BB01', false, 0, '02240755', 'FreeDiams::CA_HCDPD::DIN', 64344);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen U.S.P.', 'gas', 'V03AN01', false, 0, '02240757', 'FreeDiams::CA_HCDPD::DIN', 64346);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micardis 40mg Tab', 'tablet', 'C09CA07', false, 0, '02240769', 'FreeDiams::CA_HCDPD::DIN', 64358);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micardis 80mg Tab', 'tablet', 'C09CA07', false, 0, '02240770', 'FreeDiams::CA_HCDPD::DIN', 64359);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefoxitin For Injection, Usp', 'powder for solution', 'J01DC01', false, 0, '02240773', 'FreeDiams::CA_HCDPD::DIN', 64362);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cefadroxil', 'capsule', 'J01DB05', false, 0, '02240774', 'FreeDiams::CA_HCDPD::DIN', 64363);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Miacalcin Nasal Spray 200 Iu', 'spray', 'H05BA01', false, 0, '02240775', 'FreeDiams::CA_HCDPD::DIN', 64365);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen Usp', 'gas', 'V03AN01', false, 0, '02240782', 'FreeDiams::CA_HCDPD::DIN', 64373);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Naproxen', 'tablet', 'M01AE02', false, 0, '02240786', 'FreeDiams::CA_HCDPD::DIN', 64377);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Naproxen', 'tablet', 'M01AE02', false, 0, '02240787', 'FreeDiams::CA_HCDPD::DIN', 64378);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Naproxen', 'tablet', 'M01AE02', false, 0, '02240788', 'FreeDiams::CA_HCDPD::DIN', 64379);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterigel', 'liquid', 'D08AC52', false, 0, '02240800', 'FreeDiams::CA_HCDPD::DIN', 64391);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Nonspil Acetaminophen Syrup 160mg/5ml', 'syrup', 'N02BE01', false, 0, '02240803', 'FreeDiams::CA_HCDPD::DIN', 64394);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extraneal', 'solution', 'B05D', false, 0, '02240806', 'FreeDiams::CA_HCDPD::DIN', 64397);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Terbinafine', 'tablet', 'D01BA02', false, 0, '02240807', 'FreeDiams::CA_HCDPD::DIN', 64398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Zopiclone', 'tablet', 'N05CF01', false, 0, '02240823', 'FreeDiams::CA_HCDPD::DIN', 64414);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Naproxen Sodium', 'tablet', 'M01AE02', false, 0, '02240827', 'FreeDiams::CA_HCDPD::DIN', 64418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Naproxen Sodium Ds', 'tablet', 'M01AE02', false, 0, '02240828', 'FreeDiams::CA_HCDPD::DIN', 64419);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advair 100 Diskus', 'powder', 'R03AK06', false, 0, '02240835', 'FreeDiams::CA_HCDPD::DIN', 64426);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advair 250 Diskus', 'powder', 'R03AK06', false, 0, '02240836', 'FreeDiams::CA_HCDPD::DIN', 64427);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advair 500 Diskus', 'powder', 'R03AK06', false, 0, '02240837', 'FreeDiams::CA_HCDPD::DIN', 64428);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Zide 50/25mg Tablets', 'tablet', 'C03EA01', false, 0, '02240846', 'FreeDiams::CA_HCDPD::DIN', 64437);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proctodan-Hc Suppositories', 'suppository', 'C05AA01', false, 0, '02240851', 'FreeDiams::CA_HCDPD::DIN', 64442);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Nabumetone 500mg', 'tablet', 'M01AX01', false, 0, '02240867', 'FreeDiams::CA_HCDPD::DIN', 64458);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Nabumetone 750mg', 'tablet', 'M01AX01', false, 0, '02240868', 'FreeDiams::CA_HCDPD::DIN', 64459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Thuroclens Antimicrobial Cationic Cleanser', 'liquid', 'D08AJ01', false, 0, '02240869', 'FreeDiams::CA_HCDPD::DIN', 64460);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Savall', 'solution', 'V07AV', false, 0, '02240870', 'FreeDiams::CA_HCDPD::DIN', 64461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Paroxetine', 'tablet', 'N06AB05', false, 0, '02240907', 'FreeDiams::CA_HCDPD::DIN', 64498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Paroxetine', 'tablet', 'N06AB05', false, 0, '02240908', 'FreeDiams::CA_HCDPD::DIN', 64499);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Paroxetine', 'tablet', 'N06AB05', false, 0, '02240909', 'FreeDiams::CA_HCDPD::DIN', 64500);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cetirizine', 'tablet', 'R06AE07', false, 0, '02240910', 'FreeDiams::CA_HCDPD::DIN', 64501);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Regular Multi-Tar Plus Shampoo', 'shampoo', 'D05AA', false, 0, '02240942', 'FreeDiams::CA_HCDPD::DIN', 64533);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tarka', 'tablet (extended-release)', 'C09BB10', false, 0, '02240946', 'FreeDiams::CA_HCDPD::DIN', 64537);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doxazosin-1', 'tablet', 'C02CA04', false, 0, '02240978', 'FreeDiams::CA_HCDPD::DIN', 64570);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doxazosin-2', 'tablet', 'C02CA04', false, 0, '02240979', 'FreeDiams::CA_HCDPD::DIN', 64571);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doxazosin-4', 'tablet', 'C02CA04', false, 0, '02240980', 'FreeDiams::CA_HCDPD::DIN', 64572);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zap Topical Anesthetic Spray', 'spray', 'D04AB30', false, 0, '02240984', 'FreeDiams::CA_HCDPD::DIN', 64576);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Refludan', 'powder for solution', 'B01AE02', false, 0, '02240996', 'FreeDiams::CA_HCDPD::DIN', 64588);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Budesonide Aq', 'spray, metered dose', 'R01AD05', false, 0, '02241003', 'FreeDiams::CA_HCDPD::DIN', 64595);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hyzaar Ds 100/25 Mg', 'tablet', 'C09DA01', false, 0, '02241007', 'FreeDiams::CA_HCDPD::DIN', 64599);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crinone', 'gel', 'G03DA04', false, 0, '02241013', 'FreeDiams::CA_HCDPD::DIN', 64606);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Tryptophan', 'capsule', 'N06AX02', false, 0, '02241023', 'FreeDiams::CA_HCDPD::DIN', 64617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Naproxen Ec', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02241024', 'FreeDiams::CA_HCDPD::DIN', 64618);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Varilrix', 'powder for solution', 'J07BK01', false, 0, '02241047', 'FreeDiams::CA_HCDPD::DIN', 64641);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Burn Cream', 'cream', 'D04AB01', false, 0, '02241051', 'FreeDiams::CA_HCDPD::DIN', 64645);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hyperquat', 'liquid', 'V07AV', false, 0, '02241052', 'FreeDiams::CA_HCDPD::DIN', 64646);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Counteract Acetaminophen E-S', 'tablet', 'N02BE01', false, 0, '02241058', 'FreeDiams::CA_HCDPD::DIN', 64652);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Counteract Kids Acetaminophen', 'liquid', 'N02BE01', false, 0, '02241059', 'FreeDiams::CA_HCDPD::DIN', 64653);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gadovist 1.0', 'solution', 'V08CA09', false, 0, '02241089', 'FreeDiams::CA_HCDPD::DIN', 64684);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('The Magic Bullet', 'suppository', 'A06AB02', false, 0, '02241091', 'FreeDiams::CA_HCDPD::DIN', 64686);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Temodal', 'capsule', 'L01AX03', false, 0, '02241093', 'FreeDiams::CA_HCDPD::DIN', 64696);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Temodal', 'capsule', 'L01AX03', false, 0, '02241094', 'FreeDiams::CA_HCDPD::DIN', 64697);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Temodal', 'capsule', 'L01AX03', false, 0, '02241095', 'FreeDiams::CA_HCDPD::DIN', 64698);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Temodal', 'capsule', 'L01AX03', false, 0, '02241096', 'FreeDiams::CA_HCDPD::DIN', 64699);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunright Spf 15', 'cream', 'D02BA30', false, 0, '02241098', 'FreeDiams::CA_HCDPD::DIN', 64701);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunright Spf 30', 'cream', 'D02BA30', false, 0, '02241099', 'FreeDiams::CA_HCDPD::DIN', 64702);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bod San 2.5', 'liquid', 'V07AV', false, 0, '02241100', 'FreeDiams::CA_HCDPD::DIN', 64703);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avandia', 'tablet', 'A10BG02', false, 0, '02241112', 'FreeDiams::CA_HCDPD::DIN', 64716);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avandia', 'tablet', 'A10BG02', false, 0, '02241113', 'FreeDiams::CA_HCDPD::DIN', 64717);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avandia', 'tablet', 'A10BG02', false, 0, '02241114', 'FreeDiams::CA_HCDPD::DIN', 64718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 15 Spray-On Sunscreen', 'liquid', 'D02BA30', false, 0, '02241130', 'FreeDiams::CA_HCDPD::DIN', 64736);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30+ Spray-On Sunscreen', 'liquid', 'D02BA30', false, 0, '02241131', 'FreeDiams::CA_HCDPD::DIN', 64737);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30+ Sunscreen', 'cream', 'D02BA30', false, 0, '02241132', 'FreeDiams::CA_HCDPD::DIN', 64738);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kids Spf 30+ Sunscreen', 'cream', 'D02BA30', false, 0, '02241133', 'FreeDiams::CA_HCDPD::DIN', 64739);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kids Spf 30+ Spray-On Sunscreen', 'liquid', 'D02BA30', false, 0, '02241134', 'FreeDiams::CA_HCDPD::DIN', 64740);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Depocyt', 'suspension', 'L01BC01', false, 0, '02241150', 'FreeDiams::CA_HCDPD::DIN', 64756);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dihydroergotamine Mesylate Injection Usp', 'liquid', 'N02CA01', false, 0, '02241163', 'FreeDiams::CA_HCDPD::DIN', 64769);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Redi-Pro Detergent & Disinfectant', 'powder', 'V07AV', false, 0, '02241164', 'FreeDiams::CA_HCDPD::DIN', 64770);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Redi-Pro Spray Disinfectant Cleaner', 'powder', 'V07AV', false, 0, '02241165', 'FreeDiams::CA_HCDPD::DIN', 64771);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jack & Jill Bedtime', 'liquid', 'R06AA02', false, 0, '02241167', 'FreeDiams::CA_HCDPD::DIN', 64773);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Etoposide Injection, Usp', 'solution', 'L01CB01', false, 0, '02241182', 'FreeDiams::CA_HCDPD::DIN', 64788);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Hydroxyzin 10mg Capsules', 'capsule', 'N05BB01', false, 0, '02241192', 'FreeDiams::CA_HCDPD::DIN', 64798);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Hydroxyzin 25mg Capsules', 'capsule', 'N05BB01', false, 0, '02241193', 'FreeDiams::CA_HCDPD::DIN', 64799);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Hydroxyzin 50mg Capsules', 'capsule', 'N05BB01', false, 0, '02241194', 'FreeDiams::CA_HCDPD::DIN', 64800);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen-Odan Tablets 325mg', 'tablet', 'N02BE01', false, 0, '02241200', 'FreeDiams::CA_HCDPD::DIN', 64806);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen-Odan Tablets 500mg', 'tablet', 'N02BE01', false, 0, '02241201', 'FreeDiams::CA_HCDPD::DIN', 64807);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tobramycin Injection Usp', 'liquid', 'J01GB01', false, 0, '02241209', 'FreeDiams::CA_HCDPD::DIN', 64815);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tobramycin Injection Usp', 'liquid', 'J01GB01', false, 0, '02241210', 'FreeDiams::CA_HCDPD::DIN', 64816);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibacterial Liquid Soap', 'gel', 'D08AE04', false, 0, '02241223', 'FreeDiams::CA_HCDPD::DIN', 64830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylprednisolone Sodium Succinate For Injection', 'powder for solution', 'H02AB04', false, 0, '02241229', 'FreeDiams::CA_HCDPD::DIN', 64837);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Satinique Dandruff Control Hair Cleanser', 'shampoo', 'D11AX12', false, 0, '02241236', 'FreeDiams::CA_HCDPD::DIN', 64845);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diltiaz Injectable', 'liquid', 'C08DB01', false, 0, '02241253', 'FreeDiams::CA_HCDPD::DIN', 64862);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Percept', 'liquid', 'V07AV', false, 0, '02241255', 'FreeDiams::CA_HCDPD::DIN', 64864);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Butcher''S Per Diem', 'liquid', 'V07AV', false, 0, '02241256', 'FreeDiams::CA_HCDPD::DIN', 64865);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Percept Rtu', 'liquid', 'V07AV', false, 0, '02241257', 'FreeDiams::CA_HCDPD::DIN', 64866);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lucidity Light-Diffusing Makeup Spf 8', 'liquid', 'D02BA02', false, 0, '02241267', 'FreeDiams::CA_HCDPD::DIN', 64877);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dormex Regulier Comprime', 'tablet', 'R06AA02', false, 0, '02241269', 'FreeDiams::CA_HCDPD::DIN', 64879);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dormex Extra Fort Caplet', 'tablet', 'R06AA02', false, 0, '02241270', 'FreeDiams::CA_HCDPD::DIN', 64880);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reversa Uv Creme Contour Des Yeux', 'cream', 'D02BA30', false, 0, '02241273', 'FreeDiams::CA_HCDPD::DIN', 64883);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ombrelle - Lotion Extreme Spf 30', 'lotion', 'D02BA30', false, 0, '02241277', 'FreeDiams::CA_HCDPD::DIN', 64887);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Oxybutynin 5 Mg Tablets', 'tablet', 'G04BD04', false, 0, '02241285', 'FreeDiams::CA_HCDPD::DIN', 64895);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sertraline-25', 'capsule', 'N06AB06', false, 0, '02241302', 'FreeDiams::CA_HCDPD::DIN', 64918);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sertraline-50', 'capsule', 'N06AB06', false, 0, '02241303', 'FreeDiams::CA_HCDPD::DIN', 64919);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sertraline-100', 'capsule', 'N06AB06', false, 0, '02241304', 'FreeDiams::CA_HCDPD::DIN', 64920);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isoflurane Usp', 'liquid', 'N01AB06', false, 0, '02241315', 'FreeDiams::CA_HCDPD::DIN', 64934);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Virex Rtu Disinfectant Deodorizing Cleaner', 'liquid', 'V07AV', false, 0, '02241318', 'FreeDiams::CA_HCDPD::DIN', 64939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vagifem', 'vaginal tablet', 'G03CA03', false, 0, '02241332', 'FreeDiams::CA_HCDPD::DIN', 64959);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Formula Hh', 'tablet', 'A11JB', false, 0, '02241346', 'FreeDiams::CA_HCDPD::DIN', 64976);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Fluvoxamine', 'tablet', 'N06AB08', false, 0, '02241347', 'FreeDiams::CA_HCDPD::DIN', 64977);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Fluvoxamine', 'tablet', 'N06AB08', false, 0, '02241348', 'FreeDiams::CA_HCDPD::DIN', 64978);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ifex (Ifosfamide) 3 G/Vial', 'powder for solution', 'L01AA06', false, 0, '02241356', 'FreeDiams::CA_HCDPD::DIN', 64988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ifex (Ifosfamide) 1 G/Vial', 'powder for solution', 'L01AA06', false, 0, '02241357', 'FreeDiams::CA_HCDPD::DIN', 64989);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Junior Strength Tylenol', 'tablet', 'N02BE01', false, 0, '02241361', 'FreeDiams::CA_HCDPD::DIN', 64993);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02241371', 'FreeDiams::CA_HCDPD::DIN', 65003);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02241374', 'FreeDiams::CA_HCDPD::DIN', 65006);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metadol', 'liquid', 'N07BC02', false, 0, '02241377', 'FreeDiams::CA_HCDPD::DIN', 65010);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Chest Congestion Relief', 'syrup', 'R05CA03', false, 0, '02241379', 'FreeDiams::CA_HCDPD::DIN', 65015);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('West Antiseptic Soap', 'liquid', 'D08AE04', false, 0, '02241393', 'FreeDiams::CA_HCDPD::DIN', 65029);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alocril', 'liquid', 'S01GX04', false, 0, '02241407', 'FreeDiams::CA_HCDPD::DIN', 65043);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Uromitexan', 'solution', 'V03AF01', false, 0, '02241411', 'FreeDiams::CA_HCDPD::DIN', 65047);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hot Lemon Cough And Colds Relief Dm', 'powder for solution', 'R05DA20', false, 0, '02241424', 'FreeDiams::CA_HCDPD::DIN', 65060);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dacarbazine For Injection Bp', 'powder for solution', 'L01AX04', false, 0, '02241445', 'FreeDiams::CA_HCDPD::DIN', 65081);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Laura Line Antibacterial Soap', 'liquid', 'D08AE04', false, 0, '02241457', 'FreeDiams::CA_HCDPD::DIN', 65095);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lotion Calamine Avec Antihistaminique', 'suspension', 'D04AA32', false, 0, '02241462', 'FreeDiams::CA_HCDPD::DIN', 65100);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tamiflu Capsule 75mg', 'capsule', 'J05AH02', false, 0, '02241472', 'FreeDiams::CA_HCDPD::DIN', 65111);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zenapax 5mg/Ml', 'liquid', 'L04AC01', false, 0, '02241473', 'FreeDiams::CA_HCDPD::DIN', 65112);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norvir Sec', 'capsule', 'J05AE03', false, 0, '02241480', 'FreeDiams::CA_HCDPD::DIN', 65120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Norfloxacin', 'tablet', 'J01MA06', false, 0, '02241483', 'FreeDiams::CA_HCDPD::DIN', 65123);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Expectorant (Regular Strength) Cough Syrup', 'syrup', 'R05CA03', false, 0, '02241488', 'FreeDiams::CA_HCDPD::DIN', 65128);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm-Decongestant-Expectorant (Extra Strength) Syrup', 'syrup', 'R05FA02', false, 0, '02241489', 'FreeDiams::CA_HCDPD::DIN', 65129);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm-Decongestant-Expectorant Syrup', 'syrup', 'R05FA02', false, 0, '02241490', 'FreeDiams::CA_HCDPD::DIN', 65130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm-Expectorant Syrup', 'syrup', 'R05FA02', false, 0, '02241491', 'FreeDiams::CA_HCDPD::DIN', 65131);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm-Decongestant Children''S Syrup', 'syrup', 'R05DA20', false, 0, '02241492', 'FreeDiams::CA_HCDPD::DIN', 65132);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm-Decongestant Syrup', 'syrup', 'R05DA20', false, 0, '02241493', 'FreeDiams::CA_HCDPD::DIN', 65133);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm Children''S Cough Syrup', 'syrup', 'R05DA09', false, 0, '02241494', 'FreeDiams::CA_HCDPD::DIN', 65134);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm Cough Syrup', 'syrup', 'R05DA09', false, 0, '02241495', 'FreeDiams::CA_HCDPD::DIN', 65135);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jean Murrat Shampooing Anti-Pelliculaire', 'shampoo', 'D11AX12', false, 0, '02241496', 'FreeDiams::CA_HCDPD::DIN', 65136);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ventolin Hfa', 'metered-dose (aerosol)', 'R03AC02', false, 0, '02241497', 'FreeDiams::CA_HCDPD::DIN', 65137);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin B12', 'liquid', 'B03BA01', false, 0, '02241500', 'FreeDiams::CA_HCDPD::DIN', 65140);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Virex Ii 256 One-Step Disinfectant Cleaner And Deodorant', 'liquid', 'V07AV', false, 0, '02241502', 'FreeDiams::CA_HCDPD::DIN', 65142);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Propofol Injection', 'emulsion', 'N01AX10', false, 0, '02241504', 'FreeDiams::CA_HCDPD::DIN', 65144);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Claritin Kids', 'syrup', 'R06AX13', false, 0, '02241523', 'FreeDiams::CA_HCDPD::DIN', 65175);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vecuronium Bromide For Injection', 'powder for solution', 'M03AC03', false, 0, '02241524', 'FreeDiams::CA_HCDPD::DIN', 65176);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vecuronium Bromide For Injection', 'powder for solution', 'M03AC03', false, 0, '02241525', 'FreeDiams::CA_HCDPD::DIN', 65177);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Flu Daytime', 'tablet', 'N02BE51', false, 0, '02241526', 'FreeDiams::CA_HCDPD::DIN', 65178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germi-Stat Prep Gel', 'liquid', 'D08AC52', false, 0, '02241528', 'FreeDiams::CA_HCDPD::DIN', 65180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Nauseant', 'tablet', 'R06AA02', false, 0, '02241532', 'FreeDiams::CA_HCDPD::DIN', 65184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marcelle Sheer Tint Fluid Moisturizer Spf 15 / Fluide Hydratant Teinté Translucide Fps 15', 'lotion', 'D02BA02', false, 0, '02241537', 'FreeDiams::CA_HCDPD::DIN', 65189);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arjo General Purpose Disinfectant', 'liquid', 'V07AV', false, 0, '02241539', 'FreeDiams::CA_HCDPD::DIN', 65191);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arjo Disinfectant Cleanser Iv', 'liquid', 'V07AV', false, 0, '02241540', 'FreeDiams::CA_HCDPD::DIN', 65192);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hertel Pro', 'liquid', 'V07AV', false, 0, '02241553', 'FreeDiams::CA_HCDPD::DIN', 65206);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Levobunolol Ophthalmic Solution Usp 0.5%', 'liquid', 'S01ED03', false, 0, '02241574', 'FreeDiams::CA_HCDPD::DIN', 65228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Levobunolol Ophthalmic Solution Usp 0.25%', 'liquid', 'S01ED03', false, 0, '02241575', 'FreeDiams::CA_HCDPD::DIN', 65229);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taski Disinfectant Cleaner R2a', 'liquid', 'V07AV', false, 0, '02241584', 'FreeDiams::CA_HCDPD::DIN', 65240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckley''S Complete Extra Strength Cough, Cold And Flu Night', 'tablet', 'N02BE51', false, 0, '02241592', 'FreeDiams::CA_HCDPD::DIN', 65249);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckley''S Complete Extra Strength Cough, Cold & Flu Day', 'tablet', 'N02BE51', false, 0, '02241593', 'FreeDiams::CA_HCDPD::DIN', 65250);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mirapex', 'tablet', 'N04BC05', false, 0, '02241594', 'FreeDiams::CA_HCDPD::DIN', 65251);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Scheinpharm Ranitidine 150 Mg', 'tablet', 'A02BA02', false, 0, '02241598', 'FreeDiams::CA_HCDPD::DIN', 65255);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Scheinpharm Ranitidine 300 Mg', 'tablet', 'A02BA02', false, 0, '02241599', 'FreeDiams::CA_HCDPD::DIN', 65256);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desferrioxamine Mesilate For Injection', 'powder for solution', 'V03AC01', false, 0, '02241600', 'FreeDiams::CA_HCDPD::DIN', 65257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lipidil Supra 100 Mg', 'tablet', 'C10AB05', false, 0, '02241601', 'FreeDiams::CA_HCDPD::DIN', 65258);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lipidil Supra 160 Mg', 'tablet', 'C10AB05', false, 0, '02241602', 'FreeDiams::CA_HCDPD::DIN', 65259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Gemfibrozil', 'capsule', 'C10AB04', false, 0, '02241608', 'FreeDiams::CA_HCDPD::DIN', 65265);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crew Neutral Na Non-Acid Bowl & Bathroom Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02241613', 'FreeDiams::CA_HCDPD::DIN', 65270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ambisome', 'powder for solution', 'J02AA01', false, 0, '02241630', 'FreeDiams::CA_HCDPD::DIN', 65288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefuroxime For Injection, Usp', 'powder for solution', 'J01DC02', false, 0, '02241638', 'FreeDiams::CA_HCDPD::DIN', 65298);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefuroxime For Injection, Usp', 'powder for solution', 'J01DC02', false, 0, '02241639', 'FreeDiams::CA_HCDPD::DIN', 65299);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefuroxime For Injection, Usp', 'powder for solution', 'J01DC02', false, 0, '02241640', 'FreeDiams::CA_HCDPD::DIN', 65300);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micrell Antibacterial Lotion Soap With Chloroxylenol', 'liquid', 'D08AE05', false, 0, '02241648', 'FreeDiams::CA_HCDPD::DIN', 65308);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Futurist Time-Resisting Makeup Spf 15', 'liquid', 'D02BA02', false, 0, '02241672', 'FreeDiams::CA_HCDPD::DIN', 65332);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Plan B', 'tablet', 'G03AD01', false, 0, '02241674', 'FreeDiams::CA_HCDPD::DIN', 65334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Chloride Injection', 'liquid', 'B05XA01', false, 0, '02241676', 'FreeDiams::CA_HCDPD::DIN', 65336);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Chloride Injection', 'liquid', 'B05XA01', false, 0, '02241677', 'FreeDiams::CA_HCDPD::DIN', 65337);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Chloride Injection', 'liquid', 'B05XA01', false, 0, '02241679', 'FreeDiams::CA_HCDPD::DIN', 65339);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alprostadil Injection, Usp', 'liquid', 'C01EA01', false, 0, '02241680', 'FreeDiams::CA_HCDPD::DIN', 65340);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Gemfibrozil', 'capsule', 'C10AB04', false, 0, '02241704', 'FreeDiams::CA_HCDPD::DIN', 65364);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Clindamycin', 'capsule', 'J01FF01', false, 0, '02241709', 'FreeDiams::CA_HCDPD::DIN', 65371);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Clindamycin', 'capsule', 'J01FF01', false, 0, '02241710', 'FreeDiams::CA_HCDPD::DIN', 65372);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Levobunolol', 'liquid', 'S01ED03', false, 0, '02241715', 'FreeDiams::CA_HCDPD::DIN', 65378);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Levobunolol', 'liquid', 'S01ED03', false, 0, '02241716', 'FreeDiams::CA_HCDPD::DIN', 65379);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nasal Decongestant Spray With Moisturizers', 'liquid', 'R01AA07', false, 0, '02241736', 'FreeDiams::CA_HCDPD::DIN', 65399);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amphotec 100 Mg', 'powder for suspension', 'J02AA01', false, 0, '02241749', 'FreeDiams::CA_HCDPD::DIN', 65412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amphotec 50 Mg', 'powder for suspension', 'J02AA01', false, 0, '02241750', 'FreeDiams::CA_HCDPD::DIN', 65413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cerezyme 400 Units', 'powder for solution', 'A16AB02', false, 0, '02241751', 'FreeDiams::CA_HCDPD::DIN', 65414);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Tobramycin 0.3%', 'solution', 'S01AA12', false, 0, '02241755', 'FreeDiams::CA_HCDPD::DIN', 65418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Performance Sunscreen Cream', 'cream', 'D02BA30', false, 0, '02241760', 'FreeDiams::CA_HCDPD::DIN', 65423);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Performance Sunscreen Spray', 'liquid', 'D02BA30', false, 0, '02241761', 'FreeDiams::CA_HCDPD::DIN', 65424);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 15 Performance Bodycare Sunscreen Spray', 'liquid', 'D02BA30', false, 0, '02241762', 'FreeDiams::CA_HCDPD::DIN', 65425);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Kids Spray-On Sunscreen', 'liquid', 'D02BA30', false, 0, '02241763', 'FreeDiams::CA_HCDPD::DIN', 65426);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Kids Cream Sunscreen', 'cream', 'D02BA30', false, 0, '02241764', 'FreeDiams::CA_HCDPD::DIN', 65427);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gas-X Super Extra Strength', 'capsule', 'A03AX13', false, 0, '02241766', 'FreeDiams::CA_HCDPD::DIN', 65429);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advil Liqui-Gels', 'capsule', 'M01AE01', false, 0, '02241769', 'FreeDiams::CA_HCDPD::DIN', 65432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Procytox Tab 25mg', 'tablet', 'L01AA01', false, 0, '02241795', 'FreeDiams::CA_HCDPD::DIN', 65460);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Procytox Tab 50mg', 'tablet', 'L01AA01', false, 0, '02241796', 'FreeDiams::CA_HCDPD::DIN', 65461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Procytox 200mg/Vial', 'powder for solution', 'L01AA01', false, 0, '02241797', 'FreeDiams::CA_HCDPD::DIN', 65462);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Procytox 500mg/Vial', 'powder for solution', 'L01AA01', false, 0, '02241798', 'FreeDiams::CA_HCDPD::DIN', 65463);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Procytox 1000mg/Vial', 'powder for solution', 'L01AA01', false, 0, '02241799', 'FreeDiams::CA_HCDPD::DIN', 65464);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Procytox 2000mg/Vial', 'powder for solution', 'L01AA01', false, 0, '02241800', 'FreeDiams::CA_HCDPD::DIN', 65465);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pantoloc', 'tablet (enteric-coated)', 'A02BC02', false, 0, '02241804', 'FreeDiams::CA_HCDPD::DIN', 65469);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vancomycin Hydrochloride For Injection, Usp', 'powder for solution', 'J01XA01', false, 0, '02241807', 'FreeDiams::CA_HCDPD::DIN', 65472);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun Defense Spf 30', 'lotion', 'D02BA30', false, 0, '02241810', 'FreeDiams::CA_HCDPD::DIN', 65475);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avalide 150/12.5 Mg', 'tablet', 'C09DA04', false, 0, '02241818', 'FreeDiams::CA_HCDPD::DIN', 65483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avalide 300/12.5 Mg', 'tablet', 'C09DA04', false, 0, '02241819', 'FreeDiams::CA_HCDPD::DIN', 65484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Vancomycin 500 Mg', 'powder for solution', 'J01XA01', false, 0, '02241820', 'FreeDiams::CA_HCDPD::DIN', 65485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Vancomycin 1 G', 'powder for solution', 'J01XA01', false, 0, '02241821', 'FreeDiams::CA_HCDPD::DIN', 65486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estalis 140/50 Mcg', 'patch', 'G03FA01', false, 0, '02241835', 'FreeDiams::CA_HCDPD::DIN', 65502);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estalis 250/50 Mcg', 'patch', 'G03FA01', false, 0, '02241837', 'FreeDiams::CA_HCDPD::DIN', 65503);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gamut', 'liquid', 'V07AV', false, 0, '02241875', 'FreeDiams::CA_HCDPD::DIN', 65545);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Carbamazepine Cr', 'tablet (extended-release)', 'N03AF01', false, 0, '02241882', 'FreeDiams::CA_HCDPD::DIN', 65552);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Carbamazepine Cr', 'tablet (extended-release)', 'N03AF01', false, 0, '02241883', 'FreeDiams::CA_HCDPD::DIN', 65553);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desoxi Gel 0.05%', 'gel', 'D07AC03', false, 0, '02241887', 'FreeDiams::CA_HCDPD::DIN', 65557);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arava 10mg', 'tablet', 'L04AA13', false, 0, '02241888', 'FreeDiams::CA_HCDPD::DIN', 65558);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arava 20 Mg', 'tablet', 'L04AA13', false, 0, '02241889', 'FreeDiams::CA_HCDPD::DIN', 65559);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arava 100 Mg', 'tablet', 'L04AA13', false, 0, '02241890', 'FreeDiams::CA_HCDPD::DIN', 65560);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Fluconazole-150', 'capsule', 'J02AC01', false, 0, '02241895', 'FreeDiams::CA_HCDPD::DIN', 65565);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diovan-Hct 80mg/12.5mg', 'tablet', 'C09DA03', false, 0, '02241900', 'FreeDiams::CA_HCDPD::DIN', 65570);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diovan-Hct 160mg/12.5mg', 'tablet', 'C09DA03', false, 0, '02241901', 'FreeDiams::CA_HCDPD::DIN', 65571);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marcaine Spinal 7.5 Mg/Ml', 'solution', 'N01BB01', false, 0, '02241914', 'FreeDiams::CA_HCDPD::DIN', 65584);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marcaine E 2.5 Mg/Ml', 'solution', 'N01BB51', false, 0, '02241915', 'FreeDiams::CA_HCDPD::DIN', 65585);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marcaine E 5.0 Mg/Ml', 'solution', 'N01BB51', false, 0, '02241916', 'FreeDiams::CA_HCDPD::DIN', 65586);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marcaine 7.5 Mg/Ml', 'solution', 'N01BB01', false, 0, '02241917', 'FreeDiams::CA_HCDPD::DIN', 65587);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marcaine 2.5 Mg/Ml', 'solution', 'N01BB01', false, 0, '02241918', 'FreeDiams::CA_HCDPD::DIN', 65588);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marcaine 5 Mg/Ml', 'solution', 'N01BB01', false, 0, '02241919', 'FreeDiams::CA_HCDPD::DIN', 65589);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rituxan', 'solution', 'L01XC02', false, 0, '02241927', 'FreeDiams::CA_HCDPD::DIN', 65597);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fluphenazine Decanoate', 'liquid', 'N05AB02', false, 0, '02241928', 'FreeDiams::CA_HCDPD::DIN', 65598);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Blistex Complete Moisture Lipbalm Spf 15', 'stick', 'D02BA30', false, 0, '02241931', 'FreeDiams::CA_HCDPD::DIN', 65601);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Viokase', 'tablet', 'A09AA02', false, 0, '02241933', 'FreeDiams::CA_HCDPD::DIN', 65603);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Envy Foaming Disinfectant Cleaner', 'aerosol', 'V07AV', false, 0, '02241958', 'FreeDiams::CA_HCDPD::DIN', 65628);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neocitran Extra Strength Daytime Total Plus Mucus Relief', 'powder for solution', 'N02BE51', false, 0, '02241963', 'FreeDiams::CA_HCDPD::DIN', 65633);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Family Medic First-Aid Treatment Lotion', 'liquid', 'D04AB01', false, 0, '02241966', 'FreeDiams::CA_HCDPD::DIN', 65636);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Family Medic First-Aid Treatment Liquid', 'liquid', 'D04AB01', false, 0, '02241967', 'FreeDiams::CA_HCDPD::DIN', 65637);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norwegian Formula Lip Moisturizer Spf 15', 'stick', 'D02BA30', false, 0, '02241969', 'FreeDiams::CA_HCDPD::DIN', 65639);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hospital Dis 256', 'liquid', 'V07AV', false, 0, '02241973', 'FreeDiams::CA_HCDPD::DIN', 65643);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lemon Dis', 'liquid', 'V07AV', false, 0, '02241975', 'FreeDiams::CA_HCDPD::DIN', 65645);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Talwin 30 Mg/Ml', 'solution', 'N02AD01', false, 0, '02241976', 'FreeDiams::CA_HCDPD::DIN', 65646);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pontocaine 5 Mg/Ml', 'solution', 'S01HA03', false, 0, '02241977', 'FreeDiams::CA_HCDPD::DIN', 65647);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pontocaine', 'powder for solution', 'N01BA03', false, 0, '02241978', 'FreeDiams::CA_HCDPD::DIN', 65648);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novocain 20 Mg/Ml', 'solution', 'N01BA02', false, 0, '02241979', 'FreeDiams::CA_HCDPD::DIN', 65649);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neo-Synephrine 10 Mg/Ml', 'solution', 'C01CA06', false, 0, '02241980', 'FreeDiams::CA_HCDPD::DIN', 65650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levophed 1.0 Mg/Ml', 'solution', 'C01CA03', false, 0, '02241981', 'FreeDiams::CA_HCDPD::DIN', 65651);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Betaxin', 'solution', 'A11DA01', false, 0, '02241983', 'FreeDiams::CA_HCDPD::DIN', 65653);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy Sinus Headache Caplets', 'tablet', 'N02BE51', false, 0, '02241995', 'FreeDiams::CA_HCDPD::DIN', 65665);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbocaine 1%', 'solution', 'N01BB03', false, 0, '02241999', 'FreeDiams::CA_HCDPD::DIN', 65669);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbocaine 1%', 'solution', 'N01BB03', false, 0, '02242000', 'FreeDiams::CA_HCDPD::DIN', 65670);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbocaine 2%', 'solution', 'N01BB03', false, 0, '02242001', 'FreeDiams::CA_HCDPD::DIN', 65671);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Demerol 50 Mg/Ml   (Multiple Dose With Metacresol As Preservative)', 'solution', 'N02AB02', false, 0, '02242002', 'FreeDiams::CA_HCDPD::DIN', 65672);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Demerol 50 Mg/Ml   (Single Use, Preservative Free)', 'solution', 'N02AB02', false, 0, '02242003', 'FreeDiams::CA_HCDPD::DIN', 65673);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Demerol 75 Mg/Ml', 'solution', 'N02AB02', false, 0, '02242004', 'FreeDiams::CA_HCDPD::DIN', 65674);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Demerol 100 Mg/Ml', 'solution', 'N02AB02', false, 0, '02242005', 'FreeDiams::CA_HCDPD::DIN', 65675);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Demerol 100 Mg/Ml', 'solution', 'N02AB02', false, 0, '02242006', 'FreeDiams::CA_HCDPD::DIN', 65676);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dobutamine Injection Usp', 'liquid', 'C01CA07', false, 0, '02242010', 'FreeDiams::CA_HCDPD::DIN', 65680);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Qvar 50 Mcg', 'metered-dose (aerosol)', 'R03BA01', false, 0, '02242029', 'FreeDiams::CA_HCDPD::DIN', 65700);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Qvar 100 Mcg', 'metered-dose (aerosol)', 'R03BA01', false, 0, '02242030', 'FreeDiams::CA_HCDPD::DIN', 65701);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Deferoxamine', 'powder for solution', 'V03AC01', false, 0, '02242055', 'FreeDiams::CA_HCDPD::DIN', 65727);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chemsan Fp 17 No Rinse Sanitizer', 'liquid', 'V07AV', false, 0, '02242063', 'FreeDiams::CA_HCDPD::DIN', 65736);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vortex', 'liquid', 'V07AV', false, 0, '02242065', 'FreeDiams::CA_HCDPD::DIN', 65738);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trileptal 150 Mg', 'tablet', 'N03AF02', false, 0, '02242067', 'FreeDiams::CA_HCDPD::DIN', 65740);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trileptal 300 Mg', 'tablet', 'N03AF02', false, 0, '02242068', 'FreeDiams::CA_HCDPD::DIN', 65741);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trileptal 600 Mg', 'tablet', 'N03AF02', false, 0, '02242069', 'FreeDiams::CA_HCDPD::DIN', 65742);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Clonazepam', 'tablet', 'N03AE01', false, 0, '02242077', 'FreeDiams::CA_HCDPD::DIN', 65751);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Clonazepam 2 Mg', 'tablet', 'N03AE01', false, 0, '02242078', 'FreeDiams::CA_HCDPD::DIN', 65752);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Cyclobenzaprine', 'tablet', 'M03BX08', false, 0, '02242079', 'FreeDiams::CA_HCDPD::DIN', 65753);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Minocycline 50 Mg', 'capsule', 'J01AA08', false, 0, '02242080', 'FreeDiams::CA_HCDPD::DIN', 65754);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Minocycline', 'capsule', 'J01AA08', false, 0, '02242081', 'FreeDiams::CA_HCDPD::DIN', 65755);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Preservative-Free Thera Tears Lubricant Eye Drops', 'drops', 'S01XA20', false, 0, '02242082', 'FreeDiams::CA_HCDPD::DIN', 65756);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Atenolol 100 Mg', 'tablet', 'C07AB03', false, 0, '02242093', 'FreeDiams::CA_HCDPD::DIN', 65768);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Atenolol 50 Mg', 'tablet', 'C07AB03', false, 0, '02242094', 'FreeDiams::CA_HCDPD::DIN', 65769);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Glyburide', 'tablet', 'A10BB01', false, 0, '02242095', 'FreeDiams::CA_HCDPD::DIN', 65770);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Glyburide', 'tablet', 'A10BB01', false, 0, '02242096', 'FreeDiams::CA_HCDPD::DIN', 65771);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Oxybutynin', 'tablet', 'G04BD04', false, 0, '02242109', 'FreeDiams::CA_HCDPD::DIN', 65784);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exelon 1.5 Mg', 'capsule', 'N06DA03', false, 0, '02242115', 'FreeDiams::CA_HCDPD::DIN', 65791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exelon', 'capsule', 'N06DA03', false, 0, '02242116', 'FreeDiams::CA_HCDPD::DIN', 65792);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exelon', 'capsule', 'N06DA03', false, 0, '02242117', 'FreeDiams::CA_HCDPD::DIN', 65793);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exelon', 'capsule', 'N06DA03', false, 0, '02242118', 'FreeDiams::CA_HCDPD::DIN', 65794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aggrenox', 'kit', 'B01AC30', false, 0, '02242119', 'FreeDiams::CA_HCDPD::DIN', 65795);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isovue Multipack-370', 'liquid', 'V08AB04', false, 0, '02242121', 'FreeDiams::CA_HCDPD::DIN', 65799);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isovue Multipack-300', 'liquid', 'V08AB04', false, 0, '02242122', 'FreeDiams::CA_HCDPD::DIN', 65800);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02242123', 'FreeDiams::CA_HCDPD::DIN', 65801);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02242124', 'FreeDiams::CA_HCDPD::DIN', 65802);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Indapamide 2.5 Mg', 'tablet', 'C03BA11', false, 0, '02242125', 'FreeDiams::CA_HCDPD::DIN', 65803);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Gemfibrozil', 'tablet', 'C10AB04', false, 0, '02242126', 'FreeDiams::CA_HCDPD::DIN', 65804);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clean & Clear Continuous Control', 'lotion', 'D10AE01', false, 0, '02242134', 'FreeDiams::CA_HCDPD::DIN', 65812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ephedrine V With Guaifenesin', 'tablet', 'R05CA10', false, 0, '02242144', 'FreeDiams::CA_HCDPD::DIN', 65822);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cellcept', 'powder for suspension', 'L04AA06', false, 0, '02242145', 'FreeDiams::CA_HCDPD::DIN', 65823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Salofalk Suppositories 1000 Mg', 'suppository', 'A07EC02', false, 0, '02242146', 'FreeDiams::CA_HCDPD::DIN', 65824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Steriflo', 'gas', 'V07AV', false, 0, '02242147', 'FreeDiams::CA_HCDPD::DIN', 65825);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Buspirone 10 Mg', 'tablet', 'N05BE01', false, 0, '02242149', 'FreeDiams::CA_HCDPD::DIN', 65827);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Baclofen 10 Mg', 'tablet', 'M03BX01', false, 0, '02242150', 'FreeDiams::CA_HCDPD::DIN', 65828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Baclofen 20 Mg', 'tablet', 'M03BX01', false, 0, '02242151', 'FreeDiams::CA_HCDPD::DIN', 65829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Sotalol', 'tablet', 'C07AA07', false, 0, '02242156', 'FreeDiams::CA_HCDPD::DIN', 65834);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Sotalol', 'tablet', 'C07AA07', false, 0, '02242157', 'FreeDiams::CA_HCDPD::DIN', 65835);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arjo All-Purpose Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02242161', 'FreeDiams::CA_HCDPD::DIN', 65839);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kadian Capsules', 'capsule (sustained-release)', 'N02AA01', false, 0, '02242163', 'FreeDiams::CA_HCDPD::DIN', 65841);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vestec 625 (Neutral Disinfectant/Cleaner)', 'liquid', 'V07AV', false, 0, '02242167', 'FreeDiams::CA_HCDPD::DIN', 65845);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vestec 220 (Disinfectant No Rinse Sanitizer)', 'liquid', 'V07AV', false, 0, '02242168', 'FreeDiams::CA_HCDPD::DIN', 65846);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Laura Line Antibacterial 1% Liquid Soap', 'liquid', 'D08AE04', false, 0, '02242174', 'FreeDiams::CA_HCDPD::DIN', 65853);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Fluoxetine 10mg', 'capsule', 'N06AB03', false, 0, '02242177', 'FreeDiams::CA_HCDPD::DIN', 65856);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Fluoxetine 20mg', 'capsule', 'N06AB03', false, 0, '02242178', 'FreeDiams::CA_HCDPD::DIN', 65857);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle & Back Pain Relief - 8', 'tablet', 'M03BA53', false, 0, '02242180', 'FreeDiams::CA_HCDPD::DIN', 65859);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maux De Gorge Et De La Toux Extra-Fort', 'powder for solution', 'N02BE51', false, 0, '02242194', 'FreeDiams::CA_HCDPD::DIN', 65873);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caviwipes', 'pad', 'V07AV', false, 0, '02242209', 'FreeDiams::CA_HCDPD::DIN', 65889);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sudafed Sinus Advance', 'tablet', 'M01AE51', false, 0, '02242217', 'FreeDiams::CA_HCDPD::DIN', 65897);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dormer 211 Spf 30', 'cream', 'D02BA30', false, 0, '02242226', 'FreeDiams::CA_HCDPD::DIN', 65907);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Dipivefrin', 'liquid', 'S01EA02', false, 0, '02242232', 'FreeDiams::CA_HCDPD::DIN', 65914);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Applaud', 'liquid', 'D08AE04', false, 0, '02242248', 'FreeDiams::CA_HCDPD::DIN', 65934);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acclaim', 'liquid', 'D08AE04', false, 0, '02242260', 'FreeDiams::CA_HCDPD::DIN', 65951);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fresh Power Gold', 'liquid', 'D08AE04', false, 0, '02242263', 'FreeDiams::CA_HCDPD::DIN', 65956);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Timolol Maleate-Ex', 'solution', 'S01ED01', false, 0, '02242275', 'FreeDiams::CA_HCDPD::DIN', 65975);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Timolol Maleate-Ex', 'solution', 'S01ED01', false, 0, '02242276', 'FreeDiams::CA_HCDPD::DIN', 65976);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Entrophen', 'tablet (delayed-release)', 'B01AC06', false, 0, '02242281', 'FreeDiams::CA_HCDPD::DIN', 65982);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zep Natural', 'liquid', 'V07AV', false, 0, '02242292', 'FreeDiams::CA_HCDPD::DIN', 65998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Grasp', 'liquid', 'D08AE05', false, 0, '02242293', 'FreeDiams::CA_HCDPD::DIN', 65999);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Toloxin', 'solution', 'C01AA05', false, 0, '02242320', 'FreeDiams::CA_HCDPD::DIN', 66031);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lanoxin', 'tablet', 'C01AA05', false, 0, '02242321', 'FreeDiams::CA_HCDPD::DIN', 66032);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lanoxin', 'tablet', 'C01AA05', false, 0, '02242322', 'FreeDiams::CA_HCDPD::DIN', 66033);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lanoxin', 'tablet', 'C01AA05', false, 0, '02242323', 'FreeDiams::CA_HCDPD::DIN', 66034);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zaditor    (With Preservative)', 'solution', 'S01GX08', false, 0, '02242324', 'FreeDiams::CA_HCDPD::DIN', 66035);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amiodarone Hydrochloride For Injection', 'liquid', 'C01BD01', false, 0, '02242325', 'FreeDiams::CA_HCDPD::DIN', 66036);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Chlorhexidine Oral Rinse', 'liquid', 'A01AB03', false, 0, '02242329', 'FreeDiams::CA_HCDPD::DIN', 66040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Episoft Foaming Antibacterial Lotion Soap', 'liquid', 'D08AE04', false, 0, '02242330', 'FreeDiams::CA_HCDPD::DIN', 66041);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Steroxal', 'gas', 'V07AV', false, 0, '02242359', 'FreeDiams::CA_HCDPD::DIN', 66070);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Haloperidol La Injectable', 'liquid', 'N05AD01', false, 0, '02242361', 'FreeDiams::CA_HCDPD::DIN', 66072);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Haloperidol La Injectable', 'liquid', 'N05AD01', false, 0, '02242362', 'FreeDiams::CA_HCDPD::DIN', 66074);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Motrin Suspension', 'suspension', 'M01AE01', false, 0, '02242365', 'FreeDiams::CA_HCDPD::DIN', 66076);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Visudyne', 'powder for solution', 'S01LA01', false, 0, '02242367', 'FreeDiams::CA_HCDPD::DIN', 66078);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisture Eyes', 'drops', 'S01XA20', false, 0, '02242370', 'FreeDiams::CA_HCDPD::DIN', 66081);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hair Regrowth Treatment', 'solution', 'D11AX01', false, 0, '02242377', 'FreeDiams::CA_HCDPD::DIN', 66088);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jaa Prednisone Tab 1mg Usp', 'tablet', 'H02AB07', false, 0, '00868426', 'FreeDiams::CA_HCDPD::DIN', 66101);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutrogena Day Moisture Spf 15', 'cream', 'D02BA30', false, 0, '02242394', 'FreeDiams::CA_HCDPD::DIN', 66106);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trianal Cľ', 'capsule', 'N02BA71', false, 0, '02242406', 'FreeDiams::CA_HCDPD::DIN', 66118);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Clindamycin', 'capsule', 'J01FF01', false, 0, '02242409', 'FreeDiams::CA_HCDPD::DIN', 66121);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Clindamycin', 'capsule', 'J01FF01', false, 0, '02242410', 'FreeDiams::CA_HCDPD::DIN', 66122);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Luxiva Changing Skin Treatment Spf 15', 'cream', 'D02BA30', false, 0, '02242412', 'FreeDiams::CA_HCDPD::DIN', 66124);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Power Flush 3000', 'liquid', 'V07AV', false, 0, '02242414', 'FreeDiams::CA_HCDPD::DIN', 66126);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stoko Estesol Gold Antibacterial Hand Wash', 'liquid', 'D08AE04', false, 0, '02242426', 'FreeDiams::CA_HCDPD::DIN', 66138);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Puregon', 'solution', 'G03GA06', false, 0, '02242439', 'FreeDiams::CA_HCDPD::DIN', 66152);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Puregon', 'solution', 'G03GA06', false, 0, '02242441', 'FreeDiams::CA_HCDPD::DIN', 66154);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ranitidine 150 Mg', 'tablet', 'A02BA02', false, 0, '02242453', 'FreeDiams::CA_HCDPD::DIN', 66172);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ranitidine 300 Mg', 'tablet', 'A02BA02', false, 0, '02242454', 'FreeDiams::CA_HCDPD::DIN', 66173);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enz All', 'liquid', 'V07AV', false, 0, '02242455', 'FreeDiams::CA_HCDPD::DIN', 66174);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Acyclovir', 'tablet', 'J05AB01', false, 0, '02242463', 'FreeDiams::CA_HCDPD::DIN', 66188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Acyclovir', 'tablet', 'J05AB01', false, 0, '02242464', 'FreeDiams::CA_HCDPD::DIN', 66189);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desmopressin Spray', 'spray, metered dose', 'H01BA02', false, 0, '02242465', 'FreeDiams::CA_HCDPD::DIN', 66190);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valtaxin', 'solution', 'L01DB09', false, 0, '02242466', 'FreeDiams::CA_HCDPD::DIN', 66191);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rivacocet', 'tablet', 'N02BE51', false, 0, '02242468', 'FreeDiams::CA_HCDPD::DIN', 66193);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Corvert Injection', 'solution', 'C01BD05', false, 0, '02242470', 'FreeDiams::CA_HCDPD::DIN', 66196);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atridox', 'gel (controlled-release)', 'A01AB22', false, 0, '02242473', 'FreeDiams::CA_HCDPD::DIN', 66197);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dostinex', 'tablet', 'G02CB03', false, 0, '02242471', 'FreeDiams::CA_HCDPD::DIN', 66198);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Amiodarone', 'tablet', 'C01BD01', false, 0, '02242472', 'FreeDiams::CA_HCDPD::DIN', 66199);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benefect Botanical Disinfectant', 'spray', 'V07AV', false, 0, '02242474', 'FreeDiams::CA_HCDPD::DIN', 66200);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Zopiclone', 'tablet', 'N05CF01', false, 0, '02242480', 'FreeDiams::CA_HCDPD::DIN', 66207);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Zopiclone', 'tablet', 'N05CF01', false, 0, '02242481', 'FreeDiams::CA_HCDPD::DIN', 66208);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sulfate Injection Usp', 'liquid', 'N02AA01', false, 0, '02242484', 'FreeDiams::CA_HCDPD::DIN', 66221);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Cortimyxin', 'ointment', 'S01CA03', false, 0, '02242485', 'FreeDiams::CA_HCDPD::DIN', 66223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('One-Alpha', 'liquid', 'A11CC03', false, 0, '02242502', 'FreeDiams::CA_HCDPD::DIN', 66245);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Terbinafine', 'tablet', 'D01BA02', false, 0, '02242503', 'FreeDiams::CA_HCDPD::DIN', 66246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Butorphanol', 'liquid', 'N02AF01', false, 0, '02242504', 'FreeDiams::CA_HCDPD::DIN', 66247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naprelan', 'tablet (extended-release)', 'M01AE02', false, 0, '02242505', 'FreeDiams::CA_HCDPD::DIN', 66249);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naprelan', 'tablet (extended-release)', 'M01AE02', false, 0, '02242506', 'FreeDiams::CA_HCDPD::DIN', 66250);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen Usp', 'gas', 'V03AN01', false, 0, '02242508', 'FreeDiams::CA_HCDPD::DIN', 66253);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solu-I.V. Chg', 'solution', 'D08AC02', false, 0, '02242513', 'FreeDiams::CA_HCDPD::DIN', 66260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actonel', 'tablet', 'M05BA07', false, 0, '02242518', 'FreeDiams::CA_HCDPD::DIN', 66266);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Sertraline', 'capsule', 'N06AB06', false, 0, '02242519', 'FreeDiams::CA_HCDPD::DIN', 66267);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Sertraline', 'capsule', 'N06AB06', false, 0, '02242520', 'FreeDiams::CA_HCDPD::DIN', 66268);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Sertraline', 'capsule', 'N06AB06', false, 0, '02242521', 'FreeDiams::CA_HCDPD::DIN', 66269);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advil Pediatric Drops', 'suspension', 'M01AE01', false, 0, '02242522', 'FreeDiams::CA_HCDPD::DIN', 66270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Proctomyxin Hc', 'ointment', 'C05AA01', false, 0, '02242527', 'FreeDiams::CA_HCDPD::DIN', 66275);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Proctomyxin Hc Suppositories', 'suppository', 'C05AA51', false, 0, '02242528', 'FreeDiams::CA_HCDPD::DIN', 66276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multi-12/K1 Pediatric', 'liquid', 'B05XC', false, 0, '02242529', 'FreeDiams::CA_HCDPD::DIN', 66277);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Femhrt', 'tablet', 'G03FA01', false, 0, '02242531', 'FreeDiams::CA_HCDPD::DIN', 66279);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen Usp', 'gas', 'V03AN01', false, 0, '02242532', 'FreeDiams::CA_HCDPD::DIN', 66280);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen Usp', 'gas', 'V03AN01', false, 0, '02242542', 'FreeDiams::CA_HCDPD::DIN', 66284);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra-Strength Bismuth', 'suspension', 'A07BB', false, 0, '02242537', 'FreeDiams::CA_HCDPD::DIN', 66286);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diltiazem Cd', 'capsule (extended release)', 'C08DB01', false, 0, '02242538', 'FreeDiams::CA_HCDPD::DIN', 66289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diltiazem Cd', 'capsule (extended release)', 'C08DB01', false, 0, '02242539', 'FreeDiams::CA_HCDPD::DIN', 66290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diltiazem Cd', 'capsule (extended release)', 'C08DB01', false, 0, '02242540', 'FreeDiams::CA_HCDPD::DIN', 66291);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diltiazem Cd', 'capsule (extended release)', 'C08DB01', false, 0, '02242541', 'FreeDiams::CA_HCDPD::DIN', 66292);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate 2126', 'solution', 'B05ZA', false, 0, '02242547', 'FreeDiams::CA_HCDPD::DIN', 66299);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Beaucoup', 'liquid', 'V07AV', false, 0, '02242569', 'FreeDiams::CA_HCDPD::DIN', 66340);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluphenazine Omega', 'liquid', 'N05AB02', false, 0, '02242570', 'FreeDiams::CA_HCDPD::DIN', 66341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actos (15mg)', 'tablet', 'A10BG03', false, 0, '02242572', 'FreeDiams::CA_HCDPD::DIN', 66344);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actos (30mg)', 'tablet', 'A10BG03', false, 0, '02242573', 'FreeDiams::CA_HCDPD::DIN', 66345);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actos (45mg)', 'tablet', 'A10BG03', false, 0, '02242574', 'FreeDiams::CA_HCDPD::DIN', 66346);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Banana Boat Sunscreen Oil Spray Huile Écran Solaire En Vaporisateur Spf Fps 4', 'spray', 'D02BA30', false, 0, '02242583', 'FreeDiams::CA_HCDPD::DIN', 66357);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jack & Jill Cough And Cold', 'liquid', 'R05DA20', false, 0, '02242588', 'FreeDiams::CA_HCDPD::DIN', 66361);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Metformin', 'tablet', 'A10BA02', false, 0, '02242589', 'FreeDiams::CA_HCDPD::DIN', 66363);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ndc Apple Orchard Neutral Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02242603', 'FreeDiams::CA_HCDPD::DIN', 66379);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sani-Cloth Plus Germicidal Disposable Cloth', 'wipe', 'V07AV', false, 0, '02242608', 'FreeDiams::CA_HCDPD::DIN', 66387);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Motrin Ib', 'tablet', 'M01AE01', false, 0, '02242632', 'FreeDiams::CA_HCDPD::DIN', 66413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gentamicin Injection Usp', 'solution', 'J01GB03', false, 0, '02242652', 'FreeDiams::CA_HCDPD::DIN', 66434);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Super Strength Motrin Ib', 'tablet', 'M01AE01', false, 0, '02242658', 'FreeDiams::CA_HCDPD::DIN', 66438);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Cefuroxime', 'tablet', 'J01DC02', false, 0, '02242656', 'FreeDiams::CA_HCDPD::DIN', 66439);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Cefuroxime', 'tablet', 'J01DC02', false, 0, '02242657', 'FreeDiams::CA_HCDPD::DIN', 66440);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized Grass Pollen - Bermuda', 'liquid', 'V01AA02', false, 0, '02242663', 'FreeDiams::CA_HCDPD::DIN', 66452);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized Grass Pollen - Timothy', 'liquid', 'V01AA02', false, 0, '02242664', 'FreeDiams::CA_HCDPD::DIN', 66453);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized Grass Pollen - Kentucky Blue/June', 'liquid', 'V01AA02', false, 0, '02242666', 'FreeDiams::CA_HCDPD::DIN', 66455);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized Grass Pollen - Sweet Vernal', 'liquid', 'V01AA02', false, 0, '02242668', 'FreeDiams::CA_HCDPD::DIN', 66457);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized Grass Pollen - Red Top', 'liquid', 'V01AA02', false, 0, '02242670', 'FreeDiams::CA_HCDPD::DIN', 66459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized Grass Pollen - Meadow Fescue', 'liquid', 'V01AA02', false, 0, '02242672', 'FreeDiams::CA_HCDPD::DIN', 66461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized Grass Pollen - Orchard', 'liquid', 'V01AA02', false, 0, '02242674', 'FreeDiams::CA_HCDPD::DIN', 66463);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized Grass Pollen - Perennial Rye', 'liquid', 'V01AA02', false, 0, '02242676', 'FreeDiams::CA_HCDPD::DIN', 66465);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Warfarin', 'tablet', 'B01AA03', false, 0, '02242680', 'FreeDiams::CA_HCDPD::DIN', 66470);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Warfarin', 'tablet', 'B01AA03', false, 0, '02242681', 'FreeDiams::CA_HCDPD::DIN', 66471);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Warfarin', 'tablet', 'B01AA03', false, 0, '02242682', 'FreeDiams::CA_HCDPD::DIN', 66472);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Warfarin', 'tablet', 'B01AA03', false, 0, '02242683', 'FreeDiams::CA_HCDPD::DIN', 66473);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Warfarin', 'tablet', 'B01AA03', false, 0, '02242684', 'FreeDiams::CA_HCDPD::DIN', 66474);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Warfarin', 'tablet', 'B01AA03', false, 0, '02242685', 'FreeDiams::CA_HCDPD::DIN', 66475);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Warfarin', 'tablet', 'B01AA03', false, 0, '02242686', 'FreeDiams::CA_HCDPD::DIN', 66476);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Warfarin', 'tablet', 'B01AA03', false, 0, '02242687', 'FreeDiams::CA_HCDPD::DIN', 66477);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lovenox Hp', 'solution', 'B01AB05', false, 0, '02242692', 'FreeDiams::CA_HCDPD::DIN', 66484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Warfarin', 'tablet', 'B01AA03', false, 0, '02242697', 'FreeDiams::CA_HCDPD::DIN', 66492);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zinc Zap Spray', 'spray', 'D11AX12', false, 0, '02242702', 'FreeDiams::CA_HCDPD::DIN', 66499);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aromasin', 'tablet', 'L02BG06', false, 0, '02242705', 'FreeDiams::CA_HCDPD::DIN', 66502);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy Canada Allergen Extract - Alum Precipitated', 'liquid', 'V01AA02', false, 0, '02242713', 'FreeDiams::CA_HCDPD::DIN', 66518);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy Canada Allergen Extract', 'liquid', 'V01AA20', false, 0, '02242716', 'FreeDiams::CA_HCDPD::DIN', 66519);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy Canada Allergen Extract - Alum Precipitated', 'liquid', 'V01AA02', false, 0, '02242714', 'FreeDiams::CA_HCDPD::DIN', 66520);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy Canada Allergen Extract - Alum Precipitated', 'liquid', 'V01AA02', false, 0, '02242715', 'FreeDiams::CA_HCDPD::DIN', 66521);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy Canada Allergen Extract - Diagnostic', 'liquid', 'V04CL', false, 0, '02242717', 'FreeDiams::CA_HCDPD::DIN', 66522);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Metformin', 'tablet', 'A10BA02', false, 0, '02242726', 'FreeDiams::CA_HCDPD::DIN', 66533);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Typherix', 'liquid', 'J07AP03', false, 0, '02242727', 'FreeDiams::CA_HCDPD::DIN', 66534);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Doxazosin', 'tablet', 'C02CA04', false, 0, '02242728', 'FreeDiams::CA_HCDPD::DIN', 66535);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Doxazosin', 'tablet', 'C02CA04', false, 0, '02242729', 'FreeDiams::CA_HCDPD::DIN', 66536);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Doxazosin', 'tablet', 'C02CA04', false, 0, '02242730', 'FreeDiams::CA_HCDPD::DIN', 66537);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Terbinafine', 'tablet', 'D01BA02', false, 0, '02242735', 'FreeDiams::CA_HCDPD::DIN', 66543);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Capex', 'shampoo', 'D07AC04', false, 0, '02242738', 'FreeDiams::CA_HCDPD::DIN', 66546);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zep Micronex', 'liquid', 'V07AV', false, 0, '02242749', 'FreeDiams::CA_HCDPD::DIN', 66562);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rilutek', 'tablet', 'N07XX02', false, 0, '02242763', 'FreeDiams::CA_HCDPD::DIN', 66576);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Visine Advance Allergy', 'drops', 'S01GA51', false, 0, '02242764', 'FreeDiams::CA_HCDPD::DIN', 66582);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Metformin', 'tablet', 'A10BA02', false, 0, '02242783', 'FreeDiams::CA_HCDPD::DIN', 66606);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Acyclovir', 'tablet', 'J05AB01', false, 0, '02242784', 'FreeDiams::CA_HCDPD::DIN', 66607);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mobicox', 'tablet', 'M01AC06', false, 0, '02242785', 'FreeDiams::CA_HCDPD::DIN', 66608);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mobicox', 'tablet', 'M01AC06', false, 0, '02242786', 'FreeDiams::CA_HCDPD::DIN', 66609);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Captopril', 'tablet', 'C09AA01', false, 0, '02242788', 'FreeDiams::CA_HCDPD::DIN', 66611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Captopril', 'tablet', 'C09AA01', false, 0, '02242789', 'FreeDiams::CA_HCDPD::DIN', 66612);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Captopril', 'tablet', 'C09AA01', false, 0, '02242790', 'FreeDiams::CA_HCDPD::DIN', 66613);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Captopril', 'tablet', 'C09AA01', false, 0, '02242791', 'FreeDiams::CA_HCDPD::DIN', 66614);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metformin', 'tablet', 'A10BA02', false, 0, '02242793', 'FreeDiams::CA_HCDPD::DIN', 66616);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metformin', 'tablet', 'A10BA02', false, 0, '02242794', 'FreeDiams::CA_HCDPD::DIN', 66617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Anuzinc Hc Plus Suppositories', 'suppository', 'C05AA51', false, 0, '02242797', 'FreeDiams::CA_HCDPD::DIN', 66620);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Anuzinc Hc Suppositories', 'suppository', 'C05AA51', false, 0, '02242798', 'FreeDiams::CA_HCDPD::DIN', 66621);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Scopolamine Hydrobromide Injection', 'liquid', 'N05CM05', false, 0, '02242810', 'FreeDiams::CA_HCDPD::DIN', 66635);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Scopolamine Hydrobromide Injection', 'liquid', 'N05CM05', false, 0, '02242811', 'FreeDiams::CA_HCDPD::DIN', 66636);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lactulose', 'liquid', 'A06AD11', false, 0, '02242814', 'FreeDiams::CA_HCDPD::DIN', 66642);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simulect', 'powder for solution', 'L04AC02', false, 0, '02242815', 'FreeDiams::CA_HCDPD::DIN', 66643);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allegra 24 Hour (120mg)', 'tablet', 'R06AX26', false, 0, '02242819', 'FreeDiams::CA_HCDPD::DIN', 66647);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Cyclosporine', 'capsule', 'L04AD01', false, 0, '02242821', 'FreeDiams::CA_HCDPD::DIN', 66649);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Swish Miracle Detergent Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02242836', 'FreeDiams::CA_HCDPD::DIN', 66666);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lithium Carbonate', 'capsule', 'N05AN01', false, 0, '02242837', 'FreeDiams::CA_HCDPD::DIN', 66667);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lithium Carbonate', 'capsule', 'N05AN01', false, 0, '02242838', 'FreeDiams::CA_HCDPD::DIN', 66668);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Digisan E Foam Hand Sanitizer', 'liquid', 'D08AJ01', false, 0, '02242842', 'FreeDiams::CA_HCDPD::DIN', 66672);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Digiclean E Hand Soap', 'liquid', 'D08AE04', false, 0, '02242844', 'FreeDiams::CA_HCDPD::DIN', 66674);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Digiclean Antibacterial Foam Hand Soap', 'liquid', 'D08AE04', false, 0, '02242846', 'FreeDiams::CA_HCDPD::DIN', 66676);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Digiclean E Foam Hand Soap', 'liquid', 'D08AE05', false, 0, '02242847', 'FreeDiams::CA_HCDPD::DIN', 66677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylac', 'tablet', 'N05AH01', false, 0, '02242868', 'FreeDiams::CA_HCDPD::DIN', 66699);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Spray Spf 30', 'spray', 'D02BA30', false, 0, '02242875', 'FreeDiams::CA_HCDPD::DIN', 66706);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Premplus', 'kit', 'G03FA12', false, 0, '02242878', 'FreeDiams::CA_HCDPD::DIN', 66710);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Premplus', 'kit', 'G03FA12', false, 0, '02242879', 'FreeDiams::CA_HCDPD::DIN', 66711);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Expectorant (Extra Strength) Syrup', 'syrup', 'R05CA03', false, 0, '02242892', 'FreeDiams::CA_HCDPD::DIN', 66724);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diurex Water Caplets', 'tablet', 'C03BD', false, 0, '02242893', 'FreeDiams::CA_HCDPD::DIN', 66725);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enbrel', 'kit', 'L04AB01', false, 0, '02242903', 'FreeDiams::CA_HCDPD::DIN', 66735);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Midazolam Injection', 'liquid', 'N05CD08', false, 0, '02242904', 'FreeDiams::CA_HCDPD::DIN', 66736);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Midazolam Injection', 'liquid', 'N05CD08', false, 0, '02242905', 'FreeDiams::CA_HCDPD::DIN', 66737);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Azathioprine', 'tablet', 'L04AX01', false, 0, '02242907', 'FreeDiams::CA_HCDPD::DIN', 66740);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Etodolac 200 Mg', 'capsule', 'M01AB08', false, 0, '02242914', 'FreeDiams::CA_HCDPD::DIN', 66748);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Etodolac', 'capsule', 'M01AB08', false, 0, '02242915', 'FreeDiams::CA_HCDPD::DIN', 66749);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fumalyse Ii', 'liquid', 'V07AV', false, 0, '02242918', 'FreeDiams::CA_HCDPD::DIN', 66752);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rosasol', 'cream', 'D06BX01', false, 0, '02242919', 'FreeDiams::CA_HCDPD::DIN', 66753);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Hydroxyurea', 'capsule', 'L01XX05', false, 0, '02242920', 'FreeDiams::CA_HCDPD::DIN', 66754);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Warfarin', 'tablet', 'B01AA03', false, 0, '02242924', 'FreeDiams::CA_HCDPD::DIN', 66762);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Warfarin', 'tablet', 'B01AA03', false, 0, '02242925', 'FreeDiams::CA_HCDPD::DIN', 66763);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Warfarin', 'tablet', 'B01AA03', false, 0, '02242926', 'FreeDiams::CA_HCDPD::DIN', 66764);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Warfarin', 'tablet', 'B01AA03', false, 0, '02242927', 'FreeDiams::CA_HCDPD::DIN', 66765);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Warfarin', 'tablet', 'B01AA03', false, 0, '02242928', 'FreeDiams::CA_HCDPD::DIN', 66766);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Warfarin', 'tablet', 'B01AA03', false, 0, '02242929', 'FreeDiams::CA_HCDPD::DIN', 66767);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Metformin', 'tablet', 'A10BA02', false, 0, '02242931', 'FreeDiams::CA_HCDPD::DIN', 66769);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lustra', 'cream', 'D11AX11', false, 0, '02242933', 'FreeDiams::CA_HCDPD::DIN', 66771);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lustra-Af', 'cream', 'D11AX11', false, 0, '02242934', 'FreeDiams::CA_HCDPD::DIN', 66772);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Ranitidine Solution', 'solution', 'A02BA02', false, 0, '02242940', 'FreeDiams::CA_HCDPD::DIN', 66779);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydrotherapy Cleaner And Disinfectant', 'liquid', 'V07AV', false, 0, '02242952', 'FreeDiams::CA_HCDPD::DIN', 66791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methoxacet Extra Strength', 'tablet', 'M03BA53', false, 0, '02242960', 'FreeDiams::CA_HCDPD::DIN', 66799);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ephedrine Sulfate Injection', 'liquid', 'R03CA02', false, 0, '02242961', 'FreeDiams::CA_HCDPD::DIN', 66800);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avelox', 'tablet', 'J01MA14', false, 0, '02242965', 'FreeDiams::CA_HCDPD::DIN', 66804);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Unitron Peg', 'powder for solution', 'L03AB10', false, 0, '02242966', 'FreeDiams::CA_HCDPD::DIN', 66805);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Unitron Peg', 'powder for solution', 'L03AB10', false, 0, '02242967', 'FreeDiams::CA_HCDPD::DIN', 66806);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Unitron Peg', 'powder for solution', 'L03AB10', false, 0, '02242968', 'FreeDiams::CA_HCDPD::DIN', 66807);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Unitron Peg', 'powder for solution', 'L03AB10', false, 0, '02242969', 'FreeDiams::CA_HCDPD::DIN', 66808);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clindasol', 'cream', 'D10AF01', false, 0, '02242970', 'FreeDiams::CA_HCDPD::DIN', 66809);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amikacin Sulfate Injection Usp', 'liquid', 'J01GB06', false, 0, '02242971', 'FreeDiams::CA_HCDPD::DIN', 66810);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Propofol Injection', 'emulsion', 'N01AX10', false, 0, '02242973', 'FreeDiams::CA_HCDPD::DIN', 66813);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Metformin', 'tablet', 'A10BA02', false, 0, '02242974', 'FreeDiams::CA_HCDPD::DIN', 66814);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Genteal Gel', 'gel', 'S01XA20', false, 0, '02242977', 'FreeDiams::CA_HCDPD::DIN', 66817);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methoxisal Extra Strength', 'tablet', 'M03BA53', false, 0, '02242978', 'FreeDiams::CA_HCDPD::DIN', 66818);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rogitine', 'solution', 'C04AB01', false, 0, '02242979', 'FreeDiams::CA_HCDPD::DIN', 66819);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antizol', 'liquid', 'V03AB34', false, 0, '02242980', 'FreeDiams::CA_HCDPD::DIN', 66820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydroval Cream 0.2%', 'cream', 'D07AA02', false, 0, '02242984', 'FreeDiams::CA_HCDPD::DIN', 66824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydroval Ointment 0.2%', 'ointment', 'D07AA02', false, 0, '02242985', 'FreeDiams::CA_HCDPD::DIN', 66825);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Optimark', 'solution', 'V08CA06', false, 0, '02242986', 'FreeDiams::CA_HCDPD::DIN', 66826);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diamicron Mr', 'tablet (extended-release)', 'A10BB09', false, 0, '02242987', 'FreeDiams::CA_HCDPD::DIN', 66827);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Sport Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02242988', 'FreeDiams::CA_HCDPD::DIN', 66828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balminil Night-Time', 'syrup', 'R05FA02', false, 0, '02242999', 'FreeDiams::CA_HCDPD::DIN', 66839);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balminil Cough And Flu', 'syrup', 'N02BE51', false, 0, '02243000', 'FreeDiams::CA_HCDPD::DIN', 66840);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlorhexidine And Isopropyl Alcohol Swabsticks', 'swab', 'D08AC52', false, 0, '02243002', 'FreeDiams::CA_HCDPD::DIN', 66842);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlorhexidine And Isopropyl Alcohol Prep Pads', 'pad', 'D08AC52', false, 0, '02243003', 'FreeDiams::CA_HCDPD::DIN', 66843);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mirena', 'insert (extended-release)', 'G02BA03', false, 0, '02243005', 'FreeDiams::CA_HCDPD::DIN', 66845);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Sinus Relief', 'tablet', 'N02BE51', false, 0, '02243006', 'FreeDiams::CA_HCDPD::DIN', 66847);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Seequin 4 Ids', 'gel', 'D11AX11', false, 0, '02243007', 'FreeDiams::CA_HCDPD::DIN', 66848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Visine Advance True Tears', 'drops', 'S01XA20', false, 0, '02243009', 'FreeDiams::CA_HCDPD::DIN', 66850);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm Expectorant (Extra Strength) Syrup', 'syrup', 'R05FA02', false, 0, '02243010', 'FreeDiams::CA_HCDPD::DIN', 66851);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Temazepam', 'capsule', 'N05CD07', false, 0, '02243023', 'FreeDiams::CA_HCDPD::DIN', 66885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Temazepam', 'capsule', 'N05CD07', false, 0, '02243024', 'FreeDiams::CA_HCDPD::DIN', 66886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Brimonidine', 'liquid', 'S01EA05', false, 0, '02243026', 'FreeDiams::CA_HCDPD::DIN', 66888);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Gel Spf 30', 'gel', 'D02BA30', false, 0, '02243030', 'FreeDiams::CA_HCDPD::DIN', 66892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Ranitidine', 'tablet', 'A02BA02', false, 0, '02243038', 'FreeDiams::CA_HCDPD::DIN', 66900);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Ranitidine', 'tablet', 'A02BA02', false, 0, '02243039', 'FreeDiams::CA_HCDPD::DIN', 66901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zomig Rapimelt', 'tablet (orally disintegrating)', 'N02CC03', false, 0, '02243045', 'FreeDiams::CA_HCDPD::DIN', 66907);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle & Back Pain Relief-8', 'tablet', 'M03BA53', false, 0, '02243047', 'FreeDiams::CA_HCDPD::DIN', 66910);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clindets', 'pad', 'D10AF01', false, 0, '02243050', 'FreeDiams::CA_HCDPD::DIN', 66912);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle & Back Pain Relief Extra Strength', 'tablet', 'M03BA53', false, 0, '02243051', 'FreeDiams::CA_HCDPD::DIN', 66913);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pepcid Complete', 'tablet (chewable)', 'A02BA53', false, 0, '02243053', 'FreeDiams::CA_HCDPD::DIN', 66915);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle & Back Pain Relief', 'tablet', 'M03BA53', false, 0, '02243054', 'FreeDiams::CA_HCDPD::DIN', 66916);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle & Back Pain Relief', 'tablet', 'M03BA53', false, 0, '02243055', 'FreeDiams::CA_HCDPD::DIN', 66917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Cough And Congestion', 'syrup', 'R05DA20', false, 0, '02243062', 'FreeDiams::CA_HCDPD::DIN', 66928);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Covan Syrup', 'syrup', 'R05DA20', false, 0, '02243063', 'FreeDiams::CA_HCDPD::DIN', 66929);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tinactin Pump Spray', 'spray', 'D01AE18', false, 0, '02243064', 'FreeDiams::CA_HCDPD::DIN', 66930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citroquat', 'liquid', 'V07AV', false, 0, '02243065', 'FreeDiams::CA_HCDPD::DIN', 66931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen Usp', 'gas', 'V03AN01', false, 0, '02243073', 'FreeDiams::CA_HCDPD::DIN', 66939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Assure', 'liquid', 'V07AV', false, 0, '02243074', 'FreeDiams::CA_HCDPD::DIN', 66940);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sporox Ii', 'liquid', 'V07AV', false, 0, '02243075', 'FreeDiams::CA_HCDPD::DIN', 66941);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humatrope', 'kit', 'H01AC01', false, 0, '02243077', 'FreeDiams::CA_HCDPD::DIN', 66943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humatrope', 'kit', 'H01AC01', false, 0, '02243078', 'FreeDiams::CA_HCDPD::DIN', 66944);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humatrope', 'kit', 'H01AC01', false, 0, '02243079', 'FreeDiams::CA_HCDPD::DIN', 66945);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimetapp Cough & Congestion Liquid', 'liquid', 'R05FA02', false, 0, '02243080', 'FreeDiams::CA_HCDPD::DIN', 66947);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimetapp Daytime Cold Extra Strength Caplets', 'tablet', 'N02BE51', false, 0, '02243083', 'FreeDiams::CA_HCDPD::DIN', 66950);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cimetidine Oral Solution', 'liquid', 'A02BA01', false, 0, '02243085', 'FreeDiams::CA_HCDPD::DIN', 66952);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyprexa Zydis', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02243086', 'FreeDiams::CA_HCDPD::DIN', 66953);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyprexa Zydis', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02243087', 'FreeDiams::CA_HCDPD::DIN', 66954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyprexa Zydis', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02243088', 'FreeDiams::CA_HCDPD::DIN', 66955);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyprexa Zydis', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02243089', 'FreeDiams::CA_HCDPD::DIN', 66956);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimetapp Nighttime Cold Extra Strength Caplets', 'tablet', 'N02BE51', false, 0, '02243091', 'FreeDiams::CA_HCDPD::DIN', 66958);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prismasol O', 'solution', 'B05ZA', false, 0, '02243095', 'FreeDiams::CA_HCDPD::DIN', 66962);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lipitor', 'tablet', 'C10AA05', false, 0, '02243097', 'FreeDiams::CA_HCDPD::DIN', 66964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetylcysteine Solution', 'solution', 'R05CB01', false, 0, '02243098', 'FreeDiams::CA_HCDPD::DIN', 66965);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asa Daily Low Dose', 'tablet (enteric-coated)', 'B01AC06', false, 0, '02243101', 'FreeDiams::CA_HCDPD::DIN', 66968);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Waterbabies Spray Spf-45', 'lotion', 'D02BA30', false, 0, '02243107', 'FreeDiams::CA_HCDPD::DIN', 66974);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Total Cold And Flu', 'syrup', 'N02BE51', false, 0, '02243114', 'FreeDiams::CA_HCDPD::DIN', 66983);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ventolin Diskus', 'powder', 'R03AC02', false, 0, '02243115', 'FreeDiams::CA_HCDPD::DIN', 66984);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trimethoprim Tablets', 'tablet', 'J01EA01', false, 0, '02243116', 'FreeDiams::CA_HCDPD::DIN', 66985);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trimethoprim Tablets', 'tablet', 'J01EA01', false, 0, '02243117', 'FreeDiams::CA_HCDPD::DIN', 66986);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clean Gear Ii', 'liquid', 'V07AV', false, 0, '02243125', 'FreeDiams::CA_HCDPD::DIN', 66995);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Lovastatin', 'tablet', 'C10AA02', false, 0, '02243127', 'FreeDiams::CA_HCDPD::DIN', 66997);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Lovastatin', 'tablet', 'C10AA02', false, 0, '02243129', 'FreeDiams::CA_HCDPD::DIN', 66999);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prograf', 'capsule', 'L04AD02', false, 0, '02243144', 'FreeDiams::CA_HCDPD::DIN', 67015);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clindoxyl Gel', 'gel', 'D10AF51', false, 0, '02243158', 'FreeDiams::CA_HCDPD::DIN', 67033);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pediacel', 'suspension', 'J07CA06', false, 0, '02243167', 'FreeDiams::CA_HCDPD::DIN', 67042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutral Germicidal Cleaner', 'liquid', 'V07AV', false, 0, '02243172', 'FreeDiams::CA_HCDPD::DIN', 67048);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Definity', 'suspension', 'V08DA04', false, 0, '02243173', 'FreeDiams::CA_HCDPD::DIN', 67049);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mannitol Injection', 'solution', 'B05BC01', false, 0, '02243176', 'FreeDiams::CA_HCDPD::DIN', 67055);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Feno-Micro Capsules', 'capsule', 'C10AB05', false, 0, '02243180', 'FreeDiams::CA_HCDPD::DIN', 67060);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Helixate Fs', 'powder for solution', 'B02BD02', false, 0, '02243186', 'FreeDiams::CA_HCDPD::DIN', 67066);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Helixate Fs', 'powder for solution', 'B02BD02', false, 0, '02243187', 'FreeDiams::CA_HCDPD::DIN', 67067);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Helixate Fs', 'powder for solution', 'B02BD02', false, 0, '02243188', 'FreeDiams::CA_HCDPD::DIN', 67068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Moclobemide', 'tablet', 'N06AG02', false, 0, '02243218', 'FreeDiams::CA_HCDPD::DIN', 67101);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Moclobemide', 'tablet', 'N06AG02', false, 0, '02243219', 'FreeDiams::CA_HCDPD::DIN', 67102);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Daytime Cold Relief', 'tablet', 'N02BE51', false, 0, '02243221', 'FreeDiams::CA_HCDPD::DIN', 67104);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Forward Dc Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02243228', 'FreeDiams::CA_HCDPD::DIN', 67114);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Ranitidine', 'tablet', 'A02BA02', false, 0, '02243229', 'FreeDiams::CA_HCDPD::DIN', 67115);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Ranitidine', 'tablet', 'A02BA02', false, 0, '02243230', 'FreeDiams::CA_HCDPD::DIN', 67116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimethyl Sulfoxide Irrigation Usp', 'solution', 'G04BX13', false, 0, '02243231', 'FreeDiams::CA_HCDPD::DIN', 67117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citriquat', 'liquid', 'V07AV', false, 0, '02243233', 'FreeDiams::CA_HCDPD::DIN', 67119);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rapamune Oral Solution', 'solution', 'L04AA10', false, 0, '02243237', 'FreeDiams::CA_HCDPD::DIN', 67127);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Weiman Germicidal Solution', 'solution', 'V07AV', false, 0, '02243238', 'FreeDiams::CA_HCDPD::DIN', 67128);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diazepam Autoinjector', 'liquid', 'N05BA01', false, 0, '02243240', 'FreeDiams::CA_HCDPD::DIN', 67132);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eprex Sterile Solution', 'solution', 'B03XA01', false, 0, '02243239', 'FreeDiams::CA_HCDPD::DIN', 67133);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Super Germiphene', 'liquid', 'V07AV', false, 0, '02243241', 'FreeDiams::CA_HCDPD::DIN', 67134);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Midazolam Injectable 1 Mg/Ml', 'liquid', 'N05CD08', false, 0, '02243253', 'FreeDiams::CA_HCDPD::DIN', 67147);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Midazolam Injectable 5 Mg/Ml', 'liquid', 'N05CD08', false, 0, '02243254', 'FreeDiams::CA_HCDPD::DIN', 67148);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solagé', 'solution', 'D11AX56', false, 0, '02243257', 'FreeDiams::CA_HCDPD::DIN', 67151);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lorazepam Injection Usp', 'liquid', 'N05BA06', false, 0, '02243278', 'FreeDiams::CA_HCDPD::DIN', 67176);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('No-Mix Terg-O-Cide', 'liquid', 'V07AV', false, 0, '02243284', 'FreeDiams::CA_HCDPD::DIN', 67182);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibacterial Lotion Soap', 'lotion', 'D08AE05', false, 0, '02243290', 'FreeDiams::CA_HCDPD::DIN', 67188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glucagon', 'kit', 'H04AA01', false, 0, '02243297', 'FreeDiams::CA_HCDPD::DIN', 67195);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Naproxen Ec', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02243312', 'FreeDiams::CA_HCDPD::DIN', 67215);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Naproxen Ec', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02243313', 'FreeDiams::CA_HCDPD::DIN', 67216);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Naproxen Ec', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02243314', 'FreeDiams::CA_HCDPD::DIN', 67217);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Propafenone', 'tablet', 'C01BC03', false, 0, '02243324', 'FreeDiams::CA_HCDPD::DIN', 67227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Propafenone', 'tablet', 'C01BC03', false, 0, '02243325', 'FreeDiams::CA_HCDPD::DIN', 67228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ticlopidine', 'tablet', 'B01AC05', false, 0, '02243327', 'FreeDiams::CA_HCDPD::DIN', 67230);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cetaphil Daily Facial Moisturizer Spf 15', 'lotion', 'D02BA30', false, 0, '02243329', 'FreeDiams::CA_HCDPD::DIN', 67232);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ferrlecit', 'liquid', 'B03AC07', false, 0, '02243333', 'FreeDiams::CA_HCDPD::DIN', 67236);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Diltiazem Cd', 'capsule (extended release)', 'C08DB01', false, 0, '02243338', 'FreeDiams::CA_HCDPD::DIN', 67243);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Diltiazem Cd', 'capsule (extended release)', 'C08DB01', false, 0, '02243339', 'FreeDiams::CA_HCDPD::DIN', 67244);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Diltiazem Cd', 'capsule (extended release)', 'C08DB01', false, 0, '02243340', 'FreeDiams::CA_HCDPD::DIN', 67245);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Diltiazem Cd', 'capsule (extended release)', 'C08DB01', false, 0, '02243341', 'FreeDiams::CA_HCDPD::DIN', 67246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Varizig', 'kit', 'J06BB03', false, 0, '02243342', 'FreeDiams::CA_HCDPD::DIN', 67247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Moclobemide Tablets 150mg', 'tablet', 'N06AG02', false, 0, '02243348', 'FreeDiams::CA_HCDPD::DIN', 67255);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Moclobemide Tablets 300mg', 'tablet', 'N06AG02', false, 0, '02243349', 'FreeDiams::CA_HCDPD::DIN', 67256);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Amoxi Clav 250/125', 'tablet', 'J01CR02', false, 0, '02243350', 'FreeDiams::CA_HCDPD::DIN', 67257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Amoxi Clav 500/125', 'tablet', 'J01CR02', false, 0, '02243351', 'FreeDiams::CA_HCDPD::DIN', 67258);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Lamotrigine', 'tablet', 'N03AX09', false, 0, '02243352', 'FreeDiams::CA_HCDPD::DIN', 67259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Lamotrigine', 'tablet', 'N03AX09', false, 0, '02243353', 'FreeDiams::CA_HCDPD::DIN', 67260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Azathioprine-50', 'tablet', 'L04AX01', false, 0, '02243371', 'FreeDiams::CA_HCDPD::DIN', 67279);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kleenex Antibacterial Skin Cleanser', 'solution', 'D08AE04', false, 0, '02243381', 'FreeDiams::CA_HCDPD::DIN', 67289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bobbi Brown Moisture Rich Foundation Spf 15', 'emulsion', 'D02BA02', false, 0, '02243385', 'FreeDiams::CA_HCDPD::DIN', 67293);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zep Tranquil Meadows', 'liquid', 'D08AE04', false, 0, '02243395', 'FreeDiams::CA_HCDPD::DIN', 67303);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zep Morning Snow', 'liquid', 'D08AE04', false, 0, '02243396', 'FreeDiams::CA_HCDPD::DIN', 67304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zep Evening Calm', 'liquid', 'D08AE04', false, 0, '02243397', 'FreeDiams::CA_HCDPD::DIN', 67305);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zep Citrus Blast', 'liquid', 'D08AE04', false, 0, '02243398', 'FreeDiams::CA_HCDPD::DIN', 67306);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zep Summer Rain', 'liquid', 'D08AE04', false, 0, '02243399', 'FreeDiams::CA_HCDPD::DIN', 67307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eprex Sterile Solution 5000iu/0.5ml', 'solution', 'B03XA01', false, 0, '02243400', 'FreeDiams::CA_HCDPD::DIN', 67308);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eprex Sterile Solution 6000 Iu/0.6 Ml', 'solution', 'B03XA01', false, 0, '02243401', 'FreeDiams::CA_HCDPD::DIN', 67309);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eprex Sterile Solution 8000 Iu/0.8 Ml', 'solution', 'B03XA01', false, 0, '02243403', 'FreeDiams::CA_HCDPD::DIN', 67311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spectrol', 'liquid', 'V07AV', false, 0, '02243416', 'FreeDiams::CA_HCDPD::DIN', 67324);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Chloride In Lactated Ringer''S Injection', 'liquid', 'B05BB01', false, 0, '02243421', 'FreeDiams::CA_HCDPD::DIN', 67329);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Zopiclone', 'tablet', 'N05CF01', false, 0, '02243426', 'FreeDiams::CA_HCDPD::DIN', 67334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Naproxen Ec', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02243431', 'FreeDiams::CA_HCDPD::DIN', 67340);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Naproxen Ec', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02243432', 'FreeDiams::CA_HCDPD::DIN', 67341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diclo Rapide 50 Mg Tablets', 'tablet', 'M01AB05', false, 0, '02243433', 'FreeDiams::CA_HCDPD::DIN', 67343);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Adenosine', 'solution', 'C01EB10', false, 0, '02243435', 'FreeDiams::CA_HCDPD::DIN', 67346);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Gabapentin', 'capsule', 'N03AX12', false, 0, '02243446', 'FreeDiams::CA_HCDPD::DIN', 67356);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Gabapentin', 'capsule', 'N03AX12', false, 0, '02243447', 'FreeDiams::CA_HCDPD::DIN', 67357);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Gabapentin', 'capsule', 'N03AX12', false, 0, '02243448', 'FreeDiams::CA_HCDPD::DIN', 67358);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Deferoxamine', 'powder for solution', 'V03AC01', false, 0, '02243450', 'FreeDiams::CA_HCDPD::DIN', 67360);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hospital Disinfectant Spray', 'liquid', 'V07AV', false, 0, '02243456', 'FreeDiams::CA_HCDPD::DIN', 67366);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hospital Disinfectant Wipes', 'wipe', 'V07AV', false, 0, '02243457', 'FreeDiams::CA_HCDPD::DIN', 67367);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isocare M.V.R.', 'liquid', 'V07AV', false, 0, '02243462', 'FreeDiams::CA_HCDPD::DIN', 67373);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kimcare Antibacterial - Antibacterial Skin Cleanser', 'lotion', 'D08AE05', false, 0, '02243463', 'FreeDiams::CA_HCDPD::DIN', 67374);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Ofloxacin', 'tablet', 'J01MA01', false, 0, '02243474', 'FreeDiams::CA_HCDPD::DIN', 67385);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Ofloxacin', 'tablet', 'J01MA01', false, 0, '02243475', 'FreeDiams::CA_HCDPD::DIN', 67386);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Ofloxacin', 'tablet', 'J01MA01', false, 0, '02243476', 'FreeDiams::CA_HCDPD::DIN', 67387);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asepti-Wipe Ii Germicidal Disposal Wipe', 'wipe', 'V07AV', false, 0, '02243478', 'FreeDiams::CA_HCDPD::DIN', 67389);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Fluoxetine', 'capsule', 'N06AB03', false, 0, '02243486', 'FreeDiams::CA_HCDPD::DIN', 67397);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Fluoxetine', 'capsule', 'N06AB03', false, 0, '02243487', 'FreeDiams::CA_HCDPD::DIN', 67398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Swish Non Acid Bowl And Washroom Cleaner', 'liquid', 'V07AV', false, 0, '02243493', 'FreeDiams::CA_HCDPD::DIN', 67406);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maalox Extra Strength With Antigas Chewable Tablets', 'tablet', 'A02AF02', false, 0, '02243496', 'FreeDiams::CA_HCDPD::DIN', 67414);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pravastatin', 'tablet', 'C10AA03', false, 0, '02243506', 'FreeDiams::CA_HCDPD::DIN', 67424);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pravastatin', 'tablet', 'C10AA03', false, 0, '02243507', 'FreeDiams::CA_HCDPD::DIN', 67425);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pravastatin', 'tablet', 'C10AA03', false, 0, '02243508', 'FreeDiams::CA_HCDPD::DIN', 67426);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quat-10', 'liquid', 'V07AV', false, 0, '02243517', 'FreeDiams::CA_HCDPD::DIN', 67435);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Terazosin', 'tablet', 'G04CA03', false, 0, '02243518', 'FreeDiams::CA_HCDPD::DIN', 67437);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Terazosin', 'tablet', 'G04CA03', false, 0, '02243519', 'FreeDiams::CA_HCDPD::DIN', 67438);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Terazosin', 'tablet', 'G04CA03', false, 0, '02243520', 'FreeDiams::CA_HCDPD::DIN', 67439);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Terazosin', 'tablet', 'G04CA03', false, 0, '02243521', 'FreeDiams::CA_HCDPD::DIN', 67440);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Thiamine Hcl Injection, Usp (100mg/Ml)', 'liquid', 'A11DA01', false, 0, '02243525', 'FreeDiams::CA_HCDPD::DIN', 67443);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Labetalol Tablets', 'tablet', 'C07AG01', false, 0, '02243538', 'FreeDiams::CA_HCDPD::DIN', 67456);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Labetalol Tablets', 'tablet', 'C07AG01', false, 0, '02243539', 'FreeDiams::CA_HCDPD::DIN', 67457);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quat-Shot', 'solution', 'V07AV', false, 0, '02243546', 'FreeDiams::CA_HCDPD::DIN', 67464);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Fenofibrate Micronized', 'capsule', 'C10AB05', false, 0, '02243551', 'FreeDiams::CA_HCDPD::DIN', 67469);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Fenofibrate Micronized', 'capsule', 'C10AB05', false, 0, '02243552', 'FreeDiams::CA_HCDPD::DIN', 67470);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Orphenadrine', 'tablet (extended-release)', 'M03BC01', false, 0, '02243559', 'FreeDiams::CA_HCDPD::DIN', 67477);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorph Contin-Controlled Release Cap - 18mg', 'capsule (sustained-release)', 'N02AA03', false, 0, '02243562', 'FreeDiams::CA_HCDPD::DIN', 67480);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoclopramide Omega', 'liquid', 'A03FA01', false, 0, '02243563', 'FreeDiams::CA_HCDPD::DIN', 67481);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antiseptic Oral Rinse', 'liquid', 'R02AA06', false, 0, '02243571', 'FreeDiams::CA_HCDPD::DIN', 67489);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Ticlopidine', 'tablet', 'B01AC05', false, 0, '02243587', 'FreeDiams::CA_HCDPD::DIN', 67505);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Nitro Sublingual Spray', 'metered-dose (aerosol)', 'C01DA02', false, 0, '02243588', 'FreeDiams::CA_HCDPD::DIN', 67506);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutra-Stat 128', 'liquid', 'V07AV', false, 0, '02243594', 'FreeDiams::CA_HCDPD::DIN', 67512);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Singulair', 'tablet (chewable)', 'R03DC03', false, 0, '02243602', 'FreeDiams::CA_HCDPD::DIN', 67521);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Alpraz', 'tablet', 'N05BA12', false, 0, '02243611', 'FreeDiams::CA_HCDPD::DIN', 67530);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Alpraz Ts', 'tablet', 'N05BA12', false, 0, '02243612', 'FreeDiams::CA_HCDPD::DIN', 67531);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Normocarb 35', 'solution', 'B05ZA', false, 0, '02243623', 'FreeDiams::CA_HCDPD::DIN', 67542);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kaletra', 'solution', 'J05AE06', false, 0, '02243644', 'FreeDiams::CA_HCDPD::DIN', 67570);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Fluconazole-150', 'capsule', 'J02AC01', false, 0, '02243645', 'FreeDiams::CA_HCDPD::DIN', 67573);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ato Quat', 'liquid', 'V07AV', false, 0, '02243658', 'FreeDiams::CA_HCDPD::DIN', 67586);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinda-T', 'solution', 'D10AF01', false, 0, '02243659', 'FreeDiams::CA_HCDPD::DIN', 67589);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Streptomycin For Injection Usp', 'powder for solution', 'J01GA01', false, 0, '02243660', 'FreeDiams::CA_HCDPD::DIN', 67590);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Oxaprozin', 'tablet', 'M01AE12', false, 0, '02243661', 'FreeDiams::CA_HCDPD::DIN', 67591);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quat Ultra', 'solution', 'V07AV', false, 0, '02243667', 'FreeDiams::CA_HCDPD::DIN', 67597);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Recombivax Hb     -(Preservative Free)', 'solution', 'J07BC01', false, 0, '02243676', 'FreeDiams::CA_HCDPD::DIN', 67606);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quest 256 Neutral Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02243678', 'FreeDiams::CA_HCDPD::DIN', 67608);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('F.S. Prosan 512', 'liquid', 'V07AV', false, 0, '02243679', 'FreeDiams::CA_HCDPD::DIN', 67609);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyvoxam 600 Mg', 'tablet', 'J01XX08', false, 0, '02243684', 'FreeDiams::CA_HCDPD::DIN', 67614);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyvoxam 2 Mg/Ml', 'solution', 'J01XX08', false, 0, '02243685', 'FreeDiams::CA_HCDPD::DIN', 67615);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyvoxam', 'powder for suspension', 'J01XX08', false, 0, '02243686', 'FreeDiams::CA_HCDPD::DIN', 67616);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Claritin Eye Allergy Relief', 'drops', 'S01GA04', false, 0, '02243688', 'FreeDiams::CA_HCDPD::DIN', 67618);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Claritin Allergic Congestion Relief', 'solution', 'R01AA05', false, 0, '02243690', 'FreeDiams::CA_HCDPD::DIN', 67620);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asepticare Tb + Ii', 'liquid', 'V07AV', false, 0, '02243708', 'FreeDiams::CA_HCDPD::DIN', 67640);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Venofer', 'liquid', 'B03AC02', false, 0, '02243716', 'FreeDiams::CA_HCDPD::DIN', 67648);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crew Restroom Floor & Surface Non-Acid Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02243719', 'FreeDiams::CA_HCDPD::DIN', 67651);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crew Restroom Floor & Surface Sc Non-Acid Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02243720', 'FreeDiams::CA_HCDPD::DIN', 67652);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Botox Cosmetic', 'powder for solution', 'M03AX01', false, 0, '02243721', 'FreeDiams::CA_HCDPD::DIN', 67653);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Propafenone', 'tablet', 'C01BC03', false, 0, '02243727', 'FreeDiams::CA_HCDPD::DIN', 67659);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Propafenone', 'tablet', 'C01BC03', false, 0, '02243728', 'FreeDiams::CA_HCDPD::DIN', 67660);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phentolamine Mesylate Injection Sandoz Standard', 'solution', 'C04AB01', false, 0, '02243737', 'FreeDiams::CA_HCDPD::DIN', 67670);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Cold And Cough', 'syrup', 'R05DA20', false, 0, '02243739', 'FreeDiams::CA_HCDPD::DIN', 67672);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avaxim - Pediatric       -(Syringe)', 'suspension', 'J07BC02', false, 0, '02243741', 'FreeDiams::CA_HCDPD::DIN', 67674);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Gabapentin', 'capsule', 'N03AX12', false, 0, '02243743', 'FreeDiams::CA_HCDPD::DIN', 67676);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Gabapentin', 'capsule', 'N03AX12', false, 0, '02243744', 'FreeDiams::CA_HCDPD::DIN', 67677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Gabapentin', 'capsule', 'N03AX12', false, 0, '02243745', 'FreeDiams::CA_HCDPD::DIN', 67678);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Terazosin', 'tablet', 'G04CA03', false, 0, '02243746', 'FreeDiams::CA_HCDPD::DIN', 67679);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Terazosin', 'tablet', 'G04CA03', false, 0, '02243747', 'FreeDiams::CA_HCDPD::DIN', 67680);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Terazosin', 'tablet', 'G04CA03', false, 0, '02243748', 'FreeDiams::CA_HCDPD::DIN', 67681);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Terazosin', 'tablet', 'G04CA03', false, 0, '02243749', 'FreeDiams::CA_HCDPD::DIN', 67682);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf #30 Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02243751', 'FreeDiams::CA_HCDPD::DIN', 67685);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Comtan', 'tablet', 'N04BX02', false, 0, '02243763', 'FreeDiams::CA_HCDPD::DIN', 67698);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Aclavulanate', 'tablet', 'J01CR02', false, 0, '02243771', 'FreeDiams::CA_HCDPD::DIN', 67706);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Propafenone-150', 'tablet', 'C01BC03', false, 0, '02243783', 'FreeDiams::CA_HCDPD::DIN', 67721);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Propafenone-300', 'tablet', 'C01BC03', false, 0, '02243784', 'FreeDiams::CA_HCDPD::DIN', 67722);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ipra Sal Udv', 'solution', 'R03AK04', false, 0, '02243789', 'FreeDiams::CA_HCDPD::DIN', 67727);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pariet, Enteric-Coated Tablet 10mg', 'tablet (enteric-coated)', 'A02BC04', false, 0, '02243796', 'FreeDiams::CA_HCDPD::DIN', 67734);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pariet, Enteric-Coated Tablet 20mg', 'tablet (enteric-coated)', 'A02BC04', false, 0, '02243797', 'FreeDiams::CA_HCDPD::DIN', 67735);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('London Drugs Coated Daily Low-Dose Asa', 'tablet (enteric-coated)', 'N02BA01', false, 0, '02243800', 'FreeDiams::CA_HCDPD::DIN', 67738);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Equate Daily Low-Dose', 'tablet (enteric-coated)', 'N02BA01', false, 0, '02243801', 'FreeDiams::CA_HCDPD::DIN', 67739);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rexall Coated Daily Low Dose Asa', 'tablet (enteric-coated)', 'N02BA01', false, 0, '02243802', 'FreeDiams::CA_HCDPD::DIN', 67740);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lamictal', 'tablet', 'N03AX09', false, 0, '02243803', 'FreeDiams::CA_HCDPD::DIN', 67741);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Blistex Silk And Shine Lip Balm', 'stick', 'D02BA30', false, 0, '02243805', 'FreeDiams::CA_HCDPD::DIN', 67743);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Ticlopidine', 'tablet', 'B01AC05', false, 0, '02243808', 'FreeDiams::CA_HCDPD::DIN', 67746);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Menjugate', 'powder for suspension', 'J07AH', false, 0, '02243820', 'FreeDiams::CA_HCDPD::DIN', 67759);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravastatin-10', 'tablet', 'C10AA03', false, 0, '02243824', 'FreeDiams::CA_HCDPD::DIN', 67763);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravastatin-20', 'tablet', 'C10AA03', false, 0, '02243825', 'FreeDiams::CA_HCDPD::DIN', 67764);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravastatin-40', 'tablet', 'C10AA03', false, 0, '02243826', 'FreeDiams::CA_HCDPD::DIN', 67765);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ipravent Sterules', 'solution', 'R03BB01', false, 0, '02243827', 'FreeDiams::CA_HCDPD::DIN', 67766);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Salvent Sterules', 'solution', 'R03AC02', false, 0, '02243828', 'FreeDiams::CA_HCDPD::DIN', 67769);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coverage 256', 'liquid', 'V07AV', false, 0, '02243832', 'FreeDiams::CA_HCDPD::DIN', 67773);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Provocholine', 'powder for solution', 'V04CX', false, 0, '02243834', 'FreeDiams::CA_HCDPD::DIN', 67775);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Argatroban', 'solution', 'B01AE03', false, 0, '02243835', 'FreeDiams::CA_HCDPD::DIN', 67776);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Amiodarone', 'tablet', 'C01BD01', false, 0, '02243836', 'FreeDiams::CA_HCDPD::DIN', 67777);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vaniqa', 'cream', 'D11AX16', false, 0, '02243837', 'FreeDiams::CA_HCDPD::DIN', 67778);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bisacodyl Tablets 5mg', 'tablet', 'A06AB02', false, 0, '02243838', 'FreeDiams::CA_HCDPD::DIN', 67779);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trelstar', 'powder for suspension, sustained-release', 'L02AE04', false, 0, '02243856', 'FreeDiams::CA_HCDPD::DIN', 67797);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fucithalmic Viscous Eye Drops   -(Without Preservative)', 'drops', 'S01AA13', false, 0, '02243861', 'FreeDiams::CA_HCDPD::DIN', 67802);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fucithalmic Viscous Eye Drops   -(With Preservative)', 'drops', 'S01AA13', false, 0, '02243862', 'FreeDiams::CA_HCDPD::DIN', 67803);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Laundry Super Bleach', 'solution', 'V07AV', false, 0, '02243874', 'FreeDiams::CA_HCDPD::DIN', 67815);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chloroblich', 'solution', 'V07AV', false, 0, '02243877', 'FreeDiams::CA_HCDPD::DIN', 67818);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Serc', 'tablet', 'N07CA01', false, 0, '02243878', 'FreeDiams::CA_HCDPD::DIN', 67819);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Loratadine', 'tablet', 'R06AX13', false, 0, '02243880', 'FreeDiams::CA_HCDPD::DIN', 67821);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Strepsils Anaesthetic Formula', 'lozenge', 'R02AA12', false, 0, '02243888', 'FreeDiams::CA_HCDPD::DIN', 67829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tazorac', 'cream', 'D05AX05', false, 0, '02243894', 'FreeDiams::CA_HCDPD::DIN', 67835);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tazorac', 'cream', 'D05AX05', false, 0, '02243895', 'FreeDiams::CA_HCDPD::DIN', 67836);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exact Coated Daily Low-Dose Asa', 'tablet (enteric-coated)', 'N02BA01', false, 0, '02243896', 'FreeDiams::CA_HCDPD::DIN', 67838);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Global Clean Antimicrobial Lotion Soap', 'lotion', 'D08AE05', false, 0, '02243906', 'FreeDiams::CA_HCDPD::DIN', 67848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Remeron', 'tablet', 'N06AX11', false, 0, '02243910', 'FreeDiams::CA_HCDPD::DIN', 67852);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Retin-A Micro Tretinoin Microsphere Gel, 0.1%', 'gel', 'D10AD01', false, 0, '02243914', 'FreeDiams::CA_HCDPD::DIN', 67856);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aerius', 'tablet', 'R06AX27', false, 0, '02243919', 'FreeDiams::CA_HCDPD::DIN', 67861);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle And Back Pain Relief Extra Strength', 'tablet', 'M03BA53', false, 0, '02243928', 'FreeDiams::CA_HCDPD::DIN', 67870);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levulan Kerastick', 'powder for solution', 'L01XD04', false, 0, '02243933', 'FreeDiams::CA_HCDPD::DIN', 67875);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Midazolam Injection', 'solution', 'N05CD08', false, 0, '02243934', 'FreeDiams::CA_HCDPD::DIN', 67876);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Midazolam Injection', 'solution', 'N05CD08', false, 0, '02243935', 'FreeDiams::CA_HCDPD::DIN', 67877);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teveten', 'tablet', 'C09CA02', false, 0, '02243942', 'FreeDiams::CA_HCDPD::DIN', 67885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Puregon', 'solution', 'G03GA06', false, 0, '02243948', 'FreeDiams::CA_HCDPD::DIN', 67891);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Activated Charcoal Usp', 'powder', 'A07BA01', false, 0, '02243950', 'FreeDiams::CA_HCDPD::DIN', 67893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ditropan Xl  -(5mg)', 'tablet (extended-release)', 'G04BD04', false, 0, '02243960', 'FreeDiams::CA_HCDPD::DIN', 67903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ditropan Xl  -(10mg)', 'tablet (extended-release)', 'G04BD04', false, 0, '02243961', 'FreeDiams::CA_HCDPD::DIN', 67904);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baza Cleanse & Protect', 'lotion', 'D02AA', false, 0, '02243966', 'FreeDiams::CA_HCDPD::DIN', 67909);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimetapp Dm Cough & Cold', 'liquid', 'R05DA20', false, 0, '02243969', 'FreeDiams::CA_HCDPD::DIN', 67912);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Entrophen Chewable', 'tablet (chewable)', 'N02BA01', false, 0, '02243974', 'FreeDiams::CA_HCDPD::DIN', 67917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Codeine', 'tablet', 'R05DA04', false, 0, '02243978', 'FreeDiams::CA_HCDPD::DIN', 67922);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Codeine', 'tablet', 'R05DA04', false, 0, '02243979', 'FreeDiams::CA_HCDPD::DIN', 67923);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimetapp', 'liquid', 'R01BA53', false, 0, '02243980', 'FreeDiams::CA_HCDPD::DIN', 67924);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Amoxi Clav 125mg/31.25mg Per 5ml', 'powder for suspension', 'J01CR02', false, 0, '02243986', 'FreeDiams::CA_HCDPD::DIN', 67930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Amoxi Clav 250mg/62.5mg Per 5ml', 'powder for suspension', 'J01CR02', false, 0, '02243987', 'FreeDiams::CA_HCDPD::DIN', 67931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ketorolac Injectable', 'solution', 'M01AB15', false, 0, '02243989', 'FreeDiams::CA_HCDPD::DIN', 67933);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pegetron', 'kit', 'L03AB60', false, 0, '02246029', 'FreeDiams::CA_HCDPD::DIN', 70158);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estradot 37.5', 'patch', 'G03CA03', false, 0, '02243999', 'FreeDiams::CA_HCDPD::DIN', 67942);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estradot 50', 'patch', 'G03CA03', false, 0, '02244000', 'FreeDiams::CA_HCDPD::DIN', 67943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estradot 75', 'patch', 'G03CA03', false, 0, '02244001', 'FreeDiams::CA_HCDPD::DIN', 67944);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estradot 100', 'patch', 'G03CA03', false, 0, '02244002', 'FreeDiams::CA_HCDPD::DIN', 67945);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Monistat 3 Vaginal Cream', 'cream', 'G01AF04', false, 0, '02244005', 'FreeDiams::CA_HCDPD::DIN', 67948);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bobbi Brown Extra Moisturizing Balm Spf 25', 'cream', 'D02BA30', false, 0, '02244006', 'FreeDiams::CA_HCDPD::DIN', 67949);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balminil Codeine Night Time + Expectorant', 'liquid', 'R05FA02', false, 0, '02244010', 'FreeDiams::CA_HCDPD::DIN', 67953);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balminil Codeine + Decongestant + Expectorant', 'liquid', 'R05FA02', false, 0, '02244011', 'FreeDiams::CA_HCDPD::DIN', 67954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Clean Scope Disinfectant', 'liquid', 'V07AV', false, 0, '02244012', 'FreeDiams::CA_HCDPD::DIN', 67955);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Remicade', 'powder for solution', 'L04AB02', false, 0, '02244016', 'FreeDiams::CA_HCDPD::DIN', 67959);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atacand Plus', 'tablet', 'C09DA06', false, 0, '02244021', 'FreeDiams::CA_HCDPD::DIN', 67964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Misoprostol', 'tablet', 'A02BB01', false, 0, '02244022', 'FreeDiams::CA_HCDPD::DIN', 67965);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Misoprostol', 'tablet', 'A02BB01', false, 0, '02244023', 'FreeDiams::CA_HCDPD::DIN', 67966);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Blistex Fruit Smoothies Lip Balm', 'stick', 'D02BA30', false, 0, '02244044', 'FreeDiams::CA_HCDPD::DIN', 67987);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('G2', 'spray', 'V07AV', false, 0, '02244045', 'FreeDiams::CA_HCDPD::DIN', 67988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Keystone Antibacterial Foam Hand Soap', 'liquid', 'D08AE04', false, 0, '02244052', 'FreeDiams::CA_HCDPD::DIN', 67995);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimetapp-C', 'syrup', 'R05DA20', false, 0, '02244078', 'FreeDiams::CA_HCDPD::DIN', 68031);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimetane Expectorant C', 'syrup', 'R05FA02', false, 0, '02244079', 'FreeDiams::CA_HCDPD::DIN', 68034);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimetane Expectorant Dc', 'syrup', 'R05FA02', false, 0, '02244080', 'FreeDiams::CA_HCDPD::DIN', 68035);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prevnar', 'suspension', 'J07AL02', false, 0, '02244081', 'FreeDiams::CA_HCDPD::DIN', 68040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu Colour Skin Beneficial Tinted Moisturizer Spf 15', 'lotion', 'D02BA30', false, 0, '02244092', 'FreeDiams::CA_HCDPD::DIN', 68051);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Seroquel 300 Mg', 'tablet', 'N05AH04', false, 0, '02244107', 'FreeDiams::CA_HCDPD::DIN', 68066);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Misoprostol (0.1mg)', 'tablet', 'A02BB01', false, 0, '02244124', 'FreeDiams::CA_HCDPD::DIN', 68082);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Misoprostol (0.2mg)', 'tablet', 'A02BB01', false, 0, '02244125', 'FreeDiams::CA_HCDPD::DIN', 68083);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dovobet Ointment', 'ointment', 'D05AX52', false, 0, '02244126', 'FreeDiams::CA_HCDPD::DIN', 68084);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Divalproex (125mg)', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02244138', 'FreeDiams::CA_HCDPD::DIN', 68099);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Divalproex (250mg)', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02244139', 'FreeDiams::CA_HCDPD::DIN', 68100);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Divalproex (500mg)', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02244140', 'FreeDiams::CA_HCDPD::DIN', 68101);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Nighttime Cold Relief', 'tablet', 'N02BE51', false, 0, '02244142', 'FreeDiams::CA_HCDPD::DIN', 68103);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Allergy And Sinus Relief', 'tablet', 'N02BE51', false, 0, '02244143', 'FreeDiams::CA_HCDPD::DIN', 68104);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sufentanil Citrate Injection Usp', 'solution', 'N01AH03', false, 0, '02244147', 'FreeDiams::CA_HCDPD::DIN', 68108);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Protopic', 'ointment', 'D11AH01', false, 0, '02244148', 'FreeDiams::CA_HCDPD::DIN', 68109);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Protopic', 'ointment', 'D11AH01', false, 0, '02244149', 'FreeDiams::CA_HCDPD::DIN', 68110);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('La Mer The Spf 18 Fluid', 'liquid', 'D02BA30', false, 0, '02244156', 'FreeDiams::CA_HCDPD::DIN', 68117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinishield Health Care Personnel Handwash', 'liquid', 'D08AE04', false, 0, '02244159', 'FreeDiams::CA_HCDPD::DIN', 68120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Fluphenazine  Injectable', 'liquid', 'N05AB02', false, 0, '02244166', 'FreeDiams::CA_HCDPD::DIN', 68128);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maxi Quat', 'solution', 'V07AV', false, 0, '02244181', 'FreeDiams::CA_HCDPD::DIN', 68144);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sleep Aid Liquid Fastgels', 'capsule', 'R06AA02', false, 0, '02244203', 'FreeDiams::CA_HCDPD::DIN', 68166);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Strength Gas Relief', 'capsule', 'A03AX13', false, 0, '02244204', 'FreeDiams::CA_HCDPD::DIN', 68167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vinoxx', 'solution', 'V07AV', false, 0, '02244220', 'FreeDiams::CA_HCDPD::DIN', 68184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisturizer Maple Day Cream Spf 15', 'cream', 'D02BA30', false, 0, '02244222', 'FreeDiams::CA_HCDPD::DIN', 68186);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ab Handsoap', 'liquid', 'D08AE04', false, 0, '02244238', 'FreeDiams::CA_HCDPD::DIN', 68204);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coltalin Cold & Allergy Tablets', 'tablet', 'N02BE51', false, 0, '02244263', 'FreeDiams::CA_HCDPD::DIN', 68230);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Coltalin Fruit Flavor Chewable Cold Tablets', 'tablet', 'N02BE51', false, 0, '02244264', 'FreeDiams::CA_HCDPD::DIN', 68231);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cancidas', 'powder for solution', 'J02AX04', false, 0, '02244265', 'FreeDiams::CA_HCDPD::DIN', 68232);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cancidas', 'powder for solution', 'J02AX04', false, 0, '02244266', 'FreeDiams::CA_HCDPD::DIN', 68233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Head & Shoulders Dandruff Conditioner', 'lotion', 'D11AX12', false, 0, '02244286', 'FreeDiams::CA_HCDPD::DIN', 68253);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Safe 4 Hours Antibacterial Skin Protector', 'lotion', 'D08AE04', false, 0, '02244287', 'FreeDiams::CA_HCDPD::DIN', 68254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metadol-D', 'liquid', 'N07BC02', false, 0, '02244290', 'FreeDiams::CA_HCDPD::DIN', 68257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flovent Hfa', 'metered-dose (aerosol)', 'R03BA05', false, 0, '02244291', 'FreeDiams::CA_HCDPD::DIN', 68258);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flovent Hfa', 'metered-dose (aerosol)', 'R03BA05', false, 0, '02244292', 'FreeDiams::CA_HCDPD::DIN', 68259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flovent Hfa', 'metered-dose (aerosol)', 'R03BA05', false, 0, '02244293', 'FreeDiams::CA_HCDPD::DIN', 68260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Gabapentin Capsules', 'capsule', 'N03AX12', false, 0, '02244304', 'FreeDiams::CA_HCDPD::DIN', 68271);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Gabapentin Capsules', 'capsule', 'N03AX12', false, 0, '02244305', 'FreeDiams::CA_HCDPD::DIN', 68273);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Gabapentin Capsules', 'capsule', 'N03AX12', false, 0, '02244306', 'FreeDiams::CA_HCDPD::DIN', 68274);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Renagel', 'tablet', 'V03AE02', false, 0, '02244310', 'FreeDiams::CA_HCDPD::DIN', 68278);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aci Quat', 'liquid', 'V07AV', false, 0, '02244321', 'FreeDiams::CA_HCDPD::DIN', 68288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cyclosporine Oral Solution', 'solution', 'L04AD01', false, 0, '02244324', 'FreeDiams::CA_HCDPD::DIN', 68291);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taminol Caplets', 'tablet', 'N02BE01', false, 0, '02244331', 'FreeDiams::CA_HCDPD::DIN', 68299);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Viva Asa 325 Mg', 'tablet', 'N02BA01', false, 0, '02244333', 'FreeDiams::CA_HCDPD::DIN', 68301);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fightbac Rtu', 'liquid', 'V07AV', false, 0, '02244338', 'FreeDiams::CA_HCDPD::DIN', 68306);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fightbac 64', 'liquid', 'V07AV', false, 0, '02244341', 'FreeDiams::CA_HCDPD::DIN', 68309);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micardis Plus', 'tablet', 'C09DA07', false, 0, '02244344', 'FreeDiams::CA_HCDPD::DIN', 68312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Pravastatin Tablets', 'tablet', 'C10AA03', false, 0, '02244350', 'FreeDiams::CA_HCDPD::DIN', 68318);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Pravastatin Tablets', 'tablet', 'C10AA03', false, 0, '02244351', 'FreeDiams::CA_HCDPD::DIN', 68319);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Pravastatin Tablets', 'tablet', 'C10AA03', false, 0, '02244352', 'FreeDiams::CA_HCDPD::DIN', 68320);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novorapid', 'liquid', 'A10AB05', false, 0, '02244353', 'FreeDiams::CA_HCDPD::DIN', 68321);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Oil Free Faces Spf-30', 'lotion', 'D02BA30', false, 0, '02244357', 'FreeDiams::CA_HCDPD::DIN', 68325);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Noxzema Triple Clean Antibacterial Lathering Cleanser', 'lotion', 'D08AE04', false, 0, '02244362', 'FreeDiams::CA_HCDPD::DIN', 68330);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mefloquine', 'tablet', 'P01BC02', false, 0, '02244366', 'FreeDiams::CA_HCDPD::DIN', 68334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paclitaxel For Injection', 'solution', 'L01CD01', false, 0, '02244372', 'FreeDiams::CA_HCDPD::DIN', 68340);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Propofol', 'emulsion', 'N01AX10', false, 0, '02244379', 'FreeDiams::CA_HCDPD::DIN', 68347);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Sport Gel Spf-30', 'gel', 'D02BA30', false, 0, '02244387', 'FreeDiams::CA_HCDPD::DIN', 68355);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cefuroxime', 'tablet', 'J01DC02', false, 0, '02244393', 'FreeDiams::CA_HCDPD::DIN', 68362);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cefuroxime', 'tablet', 'J01DC02', false, 0, '02244394', 'FreeDiams::CA_HCDPD::DIN', 68363);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Carbamazepine Chewable Tablets 100mg', 'tablet (chewable)', 'N03AF01', false, 0, '02244403', 'FreeDiams::CA_HCDPD::DIN', 68372);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Carbamazepine Chewable Tablets 200mg', 'tablet (chewable)', 'N03AF01', false, 0, '02244404', 'FreeDiams::CA_HCDPD::DIN', 68373);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Florazole Er', 'tablet (extended-release)', 'J01XD01', false, 0, '02244405', 'FreeDiams::CA_HCDPD::DIN', 68374);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Water For Injection Usp', 'liquid', 'V07AB', false, 0, '02244412', 'FreeDiams::CA_HCDPD::DIN', 68381);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Warfarin', 'tablet', 'B01AA03', false, 0, '02244462', 'FreeDiams::CA_HCDPD::DIN', 68431);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Warfarin', 'tablet', 'B01AA03', false, 0, '02244463', 'FreeDiams::CA_HCDPD::DIN', 68432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Warfarin', 'tablet', 'B01AA03', false, 0, '02244464', 'FreeDiams::CA_HCDPD::DIN', 68433);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Warfarin', 'tablet', 'B01AA03', false, 0, '02244465', 'FreeDiams::CA_HCDPD::DIN', 68435);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Warfarin', 'tablet', 'B01AA03', false, 0, '02244466', 'FreeDiams::CA_HCDPD::DIN', 68436);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Warfarin', 'tablet', 'B01AA03', false, 0, '02244467', 'FreeDiams::CA_HCDPD::DIN', 68437);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Band-Aid Brand Antiseptic Wash', 'liquid', 'D04AB01', false, 0, '02244468', 'FreeDiams::CA_HCDPD::DIN', 68438);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Clobazam', 'tablet', 'N05BA09', false, 0, '02244474', 'FreeDiams::CA_HCDPD::DIN', 68447);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dipyridamole Injection, Usp', 'liquid', 'B01AC07', false, 0, '02244475', 'FreeDiams::CA_HCDPD::DIN', 68448);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Levocarbidopa', 'tablet', 'N04BA02', false, 0, '02244494', 'FreeDiams::CA_HCDPD::DIN', 68470);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Levocarbidopa', 'tablet', 'N04BA02', false, 0, '02244495', 'FreeDiams::CA_HCDPD::DIN', 68471);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Levocarbidopa', 'tablet', 'N04BA02', false, 0, '02244496', 'FreeDiams::CA_HCDPD::DIN', 68472);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Butorphanol', 'spray', 'N02AF01', false, 0, '02244508', 'FreeDiams::CA_HCDPD::DIN', 68484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Gabapentin', 'capsule', 'N03AX12', false, 0, '02244513', 'FreeDiams::CA_HCDPD::DIN', 68490);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Gabapentin', 'capsule', 'N03AX12', false, 0, '02244514', 'FreeDiams::CA_HCDPD::DIN', 68491);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Gabapentin', 'capsule', 'N03AX12', false, 0, '02244515', 'FreeDiams::CA_HCDPD::DIN', 68492);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Turbulence Cleaner And Disinfectant', 'liquid', 'V07AV', false, 0, '02244517', 'FreeDiams::CA_HCDPD::DIN', 68494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nexium - 20mg', 'tablet (delayed-release)', 'A02BC05', false, 0, '02244521', 'FreeDiams::CA_HCDPD::DIN', 68498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nexium - 40mg', 'tablet (delayed-release)', 'A02BC05', false, 0, '02244522', 'FreeDiams::CA_HCDPD::DIN', 68499);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Doxazosin', 'tablet', 'C02CA04', false, 0, '02244527', 'FreeDiams::CA_HCDPD::DIN', 68508);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Doxazosin', 'tablet', 'C02CA04', false, 0, '02244528', 'FreeDiams::CA_HCDPD::DIN', 68509);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Doxazosin', 'tablet', 'C02CA04', false, 0, '02244529', 'FreeDiams::CA_HCDPD::DIN', 68510);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maxilene 4', 'cream', 'D04AB01', false, 0, '02244533', 'FreeDiams::CA_HCDPD::DIN', 68513);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pamidronate Disodium For Injection', 'solution', 'M05BA03', false, 0, '02244550', 'FreeDiams::CA_HCDPD::DIN', 68533);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pamidronate Disodium For Injection', 'solution', 'M05BA03', false, 0, '02244551', 'FreeDiams::CA_HCDPD::DIN', 68534);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pamidronate Disodium For Injection', 'solution', 'M05BA03', false, 0, '02244552', 'FreeDiams::CA_HCDPD::DIN', 68535);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Nabumetone', 'tablet', 'M01AX01', false, 0, '02244563', 'FreeDiams::CA_HCDPD::DIN', 68548);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Myoflex Maximum Strength', 'cream', 'M02AC', false, 0, '02244573', 'FreeDiams::CA_HCDPD::DIN', 68558);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advil Extra Strength Caplets', 'tablet', 'M01AE01', false, 0, '02244577', 'FreeDiams::CA_HCDPD::DIN', 68562);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Wrinkle Defense', 'cream', 'D02BA30', false, 0, '02244585', 'FreeDiams::CA_HCDPD::DIN', 68570);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Lotion Spray Spf 30', 'lotion', 'D02BA30', false, 0, '02244589', 'FreeDiams::CA_HCDPD::DIN', 68574);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Videx Ec', 'capsule (enteric-coated)', 'J05AF02', false, 0, '02244596', 'FreeDiams::CA_HCDPD::DIN', 68582);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Videx Ec', 'capsule (enteric-coated)', 'J05AF02', false, 0, '02244597', 'FreeDiams::CA_HCDPD::DIN', 68583);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Videx Ec', 'capsule (enteric-coated)', 'J05AF02', false, 0, '02244598', 'FreeDiams::CA_HCDPD::DIN', 68584);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Videx Ec', 'capsule (enteric-coated)', 'J05AF02', false, 0, '02244599', 'FreeDiams::CA_HCDPD::DIN', 68585);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mary Kay Timewise Sunscreen Spf 15', 'lotion', 'D02BA30', false, 0, '02244607', 'FreeDiams::CA_HCDPD::DIN', 68594);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aveda Lip Saver Spf 15', 'stick', 'D02BA30', false, 0, '02244608', 'FreeDiams::CA_HCDPD::DIN', 68595);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gojo Antimicrobial Lotion Soap With Chloroxylenol', 'liquid', 'D08AE05', false, 0, '02244610', 'FreeDiams::CA_HCDPD::DIN', 68597);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Detrol La', 'capsule (sustained-release)', 'G04BD07', false, 0, '02244612', 'FreeDiams::CA_HCDPD::DIN', 68599);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Detrol La', 'capsule (sustained-release)', 'G04BD07', false, 0, '02244613', 'FreeDiams::CA_HCDPD::DIN', 68600);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mitoxantrone Injection Usp', 'solution', 'L01DB07', false, 0, '02244614', 'FreeDiams::CA_HCDPD::DIN', 68601);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Milrinone Lactate Injection', 'solution', 'C01CE02', false, 0, '02244622', 'FreeDiams::CA_HCDPD::DIN', 68609);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dentsply 2% Lidocaine With Epinephrine 1:100,000', 'solution', 'N01BB52', false, 0, '02244635', 'FreeDiams::CA_HCDPD::DIN', 68622);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clobazam Tablets', 'tablet', 'N05BA09', false, 0, '02244638', 'FreeDiams::CA_HCDPD::DIN', 68625);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biaxin', 'granules for suspension', 'J01FA09', false, 0, '02244641', 'FreeDiams::CA_HCDPD::DIN', 68628);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Aclavulanate 125 F', 'suspension', 'J01CR02', false, 0, '02244646', 'FreeDiams::CA_HCDPD::DIN', 68633);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Aclavulanate 250 F', 'suspension', 'J01CR02', false, 0, '02244647', 'FreeDiams::CA_HCDPD::DIN', 68634);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Refresh Liquigel', 'solution', 'S01XA20', false, 0, '02244650', 'FreeDiams::CA_HCDPD::DIN', 68637);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Nyquil Cough', 'liquid', 'R05DA20', false, 0, '02244662', 'FreeDiams::CA_HCDPD::DIN', 68650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trileptal Oral Suspension', 'suspension', 'N03AF02', false, 0, '02244673', 'FreeDiams::CA_HCDPD::DIN', 68661);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fortolin', 'tablet', 'N02BE01', false, 0, '02244676', 'FreeDiams::CA_HCDPD::DIN', 68664);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Floctafenine', 'tablet', 'N02BG04', false, 0, '02244680', 'FreeDiams::CA_HCDPD::DIN', 68668);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Floctafenine', 'tablet', 'N02BG04', false, 0, '02244681', 'FreeDiams::CA_HCDPD::DIN', 68669);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maalox Antacid With Anti-Gas', 'suspension', 'A02AF02', false, 0, '02244689', 'FreeDiams::CA_HCDPD::DIN', 68677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maalox Antacid With Anti-Gas Extra Strength', 'suspension', 'A02AF02', false, 0, '02244690', 'FreeDiams::CA_HCDPD::DIN', 68678);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multi-11', 'solution', 'B05XC', false, 0, '02244696', 'FreeDiams::CA_HCDPD::DIN', 68684);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Peroxigard', 'liquid', 'V07AV', false, 0, '02244709', 'FreeDiams::CA_HCDPD::DIN', 68698);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Medroxy Tablets', 'tablet', 'G03DA02', false, 0, '02244726', 'FreeDiams::CA_HCDPD::DIN', 68715);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Medroxy Tablets', 'tablet', 'G03DA02', false, 0, '02244727', 'FreeDiams::CA_HCDPD::DIN', 68716);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diltiazem Hydrochloride Injection', 'solution', 'C08DB01', false, 0, '02244728', 'FreeDiams::CA_HCDPD::DIN', 68717);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermatone', 'stick', 'D02BA30', false, 0, '02244754', 'FreeDiams::CA_HCDPD::DIN', 68743);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biaxin Xl', 'tablet (extended-release)', 'J01FA09', false, 0, '02244756', 'FreeDiams::CA_HCDPD::DIN', 68745);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trizivir', 'tablet', 'J05AR04', false, 0, '02244757', 'FreeDiams::CA_HCDPD::DIN', 68746);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Mometasone', 'ointment', 'D07AC13', false, 0, '02244769', 'FreeDiams::CA_HCDPD::DIN', 68758);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diovan 80mg Tablets', 'tablet', 'C09CA03', false, 0, '02244781', 'FreeDiams::CA_HCDPD::DIN', 68771);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diovan 160mg Tablets', 'tablet', 'C09CA03', false, 0, '02244782', 'FreeDiams::CA_HCDPD::DIN', 68772);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gonal-F', 'powder for solution', 'G03GA05', false, 0, '02244787', 'FreeDiams::CA_HCDPD::DIN', 68777);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Morphine Sr', 'tablet (extended-release)', 'N02AA01', false, 0, '02244790', 'FreeDiams::CA_HCDPD::DIN', 68780);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Morphine Sr', 'tablet (extended-release)', 'N02AA01', false, 0, '02244791', 'FreeDiams::CA_HCDPD::DIN', 68781);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Morphine Sr', 'tablet (extended-release)', 'N02AA01', false, 0, '02244792', 'FreeDiams::CA_HCDPD::DIN', 68782);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorphone Hp Forte Injection', 'solution', 'N02AA03', false, 0, '02244797', 'FreeDiams::CA_HCDPD::DIN', 68787);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Methotrexate Sodium', 'tablet', 'L01BA01', false, 0, '02244798', 'FreeDiams::CA_HCDPD::DIN', 68788);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Milrinone Injection', 'liquid', 'C01CE02', false, 0, '02244811', 'FreeDiams::CA_HCDPD::DIN', 68801);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Temazepam Capsules 15mg', 'capsule', 'N05CD07', false, 0, '02244814', 'FreeDiams::CA_HCDPD::DIN', 68804);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Temazepam Capsules 30mg', 'capsule', 'N05CD07', false, 0, '02244815', 'FreeDiams::CA_HCDPD::DIN', 68805);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Clomipramine Tablets 10mg', 'tablet', 'N06AA04', false, 0, '02244816', 'FreeDiams::CA_HCDPD::DIN', 68806);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Clomipramine Tablets 25mg', 'tablet', 'N06AA04', false, 0, '02244817', 'FreeDiams::CA_HCDPD::DIN', 68807);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Clomipramine Tablets 50mg', 'tablet', 'N06AA04', false, 0, '02244818', 'FreeDiams::CA_HCDPD::DIN', 68808);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tnkase', 'powder for solution', 'B01AD11', false, 0, '02244826', 'FreeDiams::CA_HCDPD::DIN', 68816);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Oil Free Lotion Spf 45', 'lotion', 'D02BA30', false, 0, '02244828', 'FreeDiams::CA_HCDPD::DIN', 68818);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Sertraline', 'capsule', 'N06AB06', false, 0, '02244838', 'FreeDiams::CA_HCDPD::DIN', 68828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Sertraline', 'capsule', 'N06AB06', false, 0, '02244839', 'FreeDiams::CA_HCDPD::DIN', 68829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Sertraline', 'capsule', 'N06AB06', false, 0, '02244840', 'FreeDiams::CA_HCDPD::DIN', 68830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Flavoxate', 'tablet', 'G04BD02', false, 0, '02244842', 'FreeDiams::CA_HCDPD::DIN', 68832);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Colistimethate For Injection U.S.P.', 'powder for solution', 'J01XB01', false, 0, '02244849', 'FreeDiams::CA_HCDPD::DIN', 68839);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Milrinone Lactate Injection', 'solution', 'C01CE02', false, 0, '02244854', 'FreeDiams::CA_HCDPD::DIN', 68844);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reversa Uv Creme Visage Et Cou Fps 15', 'cream', 'D02BA30', false, 0, '02244858', 'FreeDiams::CA_HCDPD::DIN', 68850);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multi-San Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02244869', 'FreeDiams::CA_HCDPD::DIN', 68862);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Famotidine Injectable     -(No Preservative)', 'solution', 'A02BA03', false, 0, '02244888', 'FreeDiams::CA_HCDPD::DIN', 68883);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imuran', 'powder for solution', 'L04AX01', false, 0, '02244895', 'FreeDiams::CA_HCDPD::DIN', 68893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dipyridamole For Injection', 'solution', 'B01AC07', false, 0, '02244909', 'FreeDiams::CA_HCDPD::DIN', 68907);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mesna For Injection', 'solution', 'V03AF01', false, 0, '02244931', 'FreeDiams::CA_HCDPD::DIN', 68929);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Endbac Ii Disinfectant Spray', 'aerosol', 'V07AV', false, 0, '02244932', 'FreeDiams::CA_HCDPD::DIN', 68930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stride Dc Floral Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02244933', 'FreeDiams::CA_HCDPD::DIN', 68931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hertel Plus Disinfectant', 'liquid', 'V07AV', false, 0, '02244935', 'FreeDiams::CA_HCDPD::DIN', 68933);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Liberator', 'tablet (extended-release)', 'R01BA52', false, 0, '02244941', 'FreeDiams::CA_HCDPD::DIN', 68939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ketorolac Tromethamine Injection, Usp', 'liquid', 'M01AB15', false, 0, '02244947', 'FreeDiams::CA_HCDPD::DIN', 68945);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Safetec Burn Spray', 'spray', 'D04AB01', false, 0, '02244949', 'FreeDiams::CA_HCDPD::DIN', 68947);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Safetec Burn Gel', 'gel', 'D04AB01', false, 0, '02244950', 'FreeDiams::CA_HCDPD::DIN', 68948);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Safetec Sting Relief', 'solution', 'D04AB01', false, 0, '02244951', 'FreeDiams::CA_HCDPD::DIN', 68949);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tracleer', 'tablet', 'C02KX01', false, 0, '02244981', 'FreeDiams::CA_HCDPD::DIN', 68979);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tracleer', 'tablet', 'C02KX01', false, 0, '02244982', 'FreeDiams::CA_HCDPD::DIN', 68980);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asa 81 Mg', 'tablet (enteric-coated)', 'N02BA01', false, 0, '02244993', 'FreeDiams::CA_HCDPD::DIN', 68992);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Famotidine Injectable     -(With Preservative, Benzyl Alcohol)', 'solution', 'A02BA03', false, 0, '02244998', 'FreeDiams::CA_HCDPD::DIN', 68997);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Pentasone', 'solution', 'S03CA06', false, 0, '02244999', 'FreeDiams::CA_HCDPD::DIN', 68998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Chewable Acetaminophen Tablet', 'tablet', 'N02BE01', false, 0, '02245010', 'FreeDiams::CA_HCDPD::DIN', 69009);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Myocet', 'liposomes', 'L01DB01', false, 0, '02245015', 'FreeDiams::CA_HCDPD::DIN', 69014);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinus Medication', 'tablet', 'N02BE51', false, 0, '02245016', 'FreeDiams::CA_HCDPD::DIN', 69017);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Sinus Relief Nighttime', 'tablet', 'N02BE51', false, 0, '02245017', 'FreeDiams::CA_HCDPD::DIN', 69018);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Provon Antimicrobial Lotion Soap With 0.3% Chloroxylenol', 'lotion', 'D08AE05', false, 0, '02245038', 'FreeDiams::CA_HCDPD::DIN', 69042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spritz', 'liquid', 'V07AV', false, 0, '02245056', 'FreeDiams::CA_HCDPD::DIN', 69060);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neisvac-C', 'suspension', 'J07AH07', false, 0, '02245057', 'FreeDiams::CA_HCDPD::DIN', 69061);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Omeprazole', 'capsule (delayed release)', 'A02BC01', false, 0, '02245058', 'FreeDiams::CA_HCDPD::DIN', 69062);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accel', 'liquid', 'V07AV', false, 0, '02245061', 'FreeDiams::CA_HCDPD::DIN', 69065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimetapp Extra Strength', 'liquid', 'R01BA53', false, 0, '02245075', 'FreeDiams::CA_HCDPD::DIN', 69079);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimetapp Extra Strength Dm Cough & Cold', 'liquid', 'R05DA20', false, 0, '02245076', 'FreeDiams::CA_HCDPD::DIN', 69080);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Zopiclone', 'tablet', 'N05CF01', false, 0, '02245077', 'FreeDiams::CA_HCDPD::DIN', 69081);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Docusate Sodium', 'capsule', 'A06AA02', false, 0, '02245079', 'FreeDiams::CA_HCDPD::DIN', 69083);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Docusate Calcium', 'capsule', 'A06AA02', false, 0, '02245080', 'FreeDiams::CA_HCDPD::DIN', 69084);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germi-Stat 2% Foaming Liquid', 'liquid', 'D08AC02', false, 0, '02245085', 'FreeDiams::CA_HCDPD::DIN', 69089);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soleil Protexion Sun Lip Stick Velvet Moisture Spf 20', 'stick', 'D02BA30', false, 0, '02245091', 'FreeDiams::CA_HCDPD::DIN', 69095);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Septic 885', 'liquid', 'V07AV', false, 0, '02245099', 'FreeDiams::CA_HCDPD::DIN', 69105);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advair 125', 'aerosol, metered dose', 'R03AK06', false, 0, '02245126', 'FreeDiams::CA_HCDPD::DIN', 69136);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advair 250', 'aerosol, metered dose', 'R03AK06', false, 0, '02245127', 'FreeDiams::CA_HCDPD::DIN', 69137);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gas Relief', 'capsule', 'A03AX13', false, 0, '02245144', 'FreeDiams::CA_HCDPD::DIN', 69154);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Strength Gas Relief', 'capsule', 'A03AX13', false, 0, '02245145', 'FreeDiams::CA_HCDPD::DIN', 69155);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Sertraline', 'capsule', 'N06AB06', false, 0, '02245159', 'FreeDiams::CA_HCDPD::DIN', 69170);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Sertraline', 'capsule', 'N06AB06', false, 0, '02245160', 'FreeDiams::CA_HCDPD::DIN', 69172);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Sertraline', 'capsule', 'N06AB06', false, 0, '02245161', 'FreeDiams::CA_HCDPD::DIN', 69174);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soothing Gel With Lidocaine', 'gel', 'D04AB01', false, 0, '02245174', 'FreeDiams::CA_HCDPD::DIN', 69189);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imodium Advanced Multi-Symptom Caplets', 'tablet', 'A07DA53', false, 0, '02245185', 'FreeDiams::CA_HCDPD::DIN', 69200);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lamotrigine', 'tablet', 'N03AX09', false, 0, '02245208', 'FreeDiams::CA_HCDPD::DIN', 69223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lamotrigine', 'tablet', 'N03AX09', false, 0, '02245209', 'FreeDiams::CA_HCDPD::DIN', 69224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lamotrigine', 'tablet', 'N03AX09', false, 0, '02245210', 'FreeDiams::CA_HCDPD::DIN', 69225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levocarb Cr', 'tablet (extended-release)', 'N04BA02', false, 0, '02245211', 'FreeDiams::CA_HCDPD::DIN', 69226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stool Softener', 'capsule', 'A06AA02', false, 0, '02245212', 'FreeDiams::CA_HCDPD::DIN', 69227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ascorbic Acid Injection Usp', 'solution', 'A11GA01', false, 0, '02245214', 'FreeDiams::CA_HCDPD::DIN', 69229);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pyridoxine Hydrochloride Injection Usp 100 Mg/Ml', 'solution', 'A11HA02', false, 0, '02245215', 'FreeDiams::CA_HCDPD::DIN', 69230);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Nitrazepam Tablets Bp', 'tablet', 'N05CD02', false, 0, '02245230', 'FreeDiams::CA_HCDPD::DIN', 69245);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Nitrazepam Tablets Bp', 'tablet', 'N05CD02', false, 0, '02245231', 'FreeDiams::CA_HCDPD::DIN', 69246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clindamycin', 'capsule', 'J01FF01', false, 0, '02245232', 'FreeDiams::CA_HCDPD::DIN', 69247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clindamycin', 'capsule', 'J01FF01', false, 0, '02245233', 'FreeDiams::CA_HCDPD::DIN', 69248);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exelon', 'solution', 'N06DA03', false, 0, '02245240', 'FreeDiams::CA_HCDPD::DIN', 69257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Gliclazide', 'tablet', 'A10BB09', false, 0, '02245247', 'FreeDiams::CA_HCDPD::DIN', 69269);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Indapamide 1.25 Mg Tablets', 'tablet', 'C03BA11', false, 0, '02245246', 'FreeDiams::CA_HCDPD::DIN', 69270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amiodarone Hydrochloride For Injection', 'solution', 'C01BD01', false, 0, '02245248', 'FreeDiams::CA_HCDPD::DIN', 69271);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Nausee Dimenhydrinate 50 Mg Usp', 'tablet', 'R06AA02', false, 0, '02245266', 'FreeDiams::CA_HCDPD::DIN', 69289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amaryl', 'tablet', 'A10BB12', false, 0, '02245272', 'FreeDiams::CA_HCDPD::DIN', 69295);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amaryl', 'tablet', 'A10BB12', false, 0, '02245273', 'FreeDiams::CA_HCDPD::DIN', 69296);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amaryl', 'tablet', 'A10BB12', false, 0, '02245274', 'FreeDiams::CA_HCDPD::DIN', 69297);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Morphine Sulfate Sr 15 Mg', 'tablet (extended-release)', 'N02AA01', false, 0, '02245284', 'FreeDiams::CA_HCDPD::DIN', 69308);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Morphine Sulfate Sr 30 Mg', 'tablet (extended-release)', 'N02AA01', false, 0, '02245285', 'FreeDiams::CA_HCDPD::DIN', 69309);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Morphine Sulfate Sr 60 Mg', 'tablet (extended-release)', 'N02AA01', false, 0, '02245286', 'FreeDiams::CA_HCDPD::DIN', 69310);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Morphine Sulfate Sr 100 Mg', 'tablet (extended-release)', 'N02AA01', false, 0, '02245287', 'FreeDiams::CA_HCDPD::DIN', 69311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Morphine Sulfate Sr 200 Mg', 'tablet (extended-release)', 'N02AA01', false, 0, '02245288', 'FreeDiams::CA_HCDPD::DIN', 69312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Fluconazole', 'tablet', 'J02AC01', false, 0, '02245292', 'FreeDiams::CA_HCDPD::DIN', 69316);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Fluconazole', 'tablet', 'J02AC01', false, 0, '02245293', 'FreeDiams::CA_HCDPD::DIN', 69317);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reversa Uv Fluide Hydratant Non Gras Fps 15', 'lotion', 'D02BA30', false, 0, '02245318', 'FreeDiams::CA_HCDPD::DIN', 69344);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fosamax', 'tablet', 'M05BA04', false, 0, '02245329', 'FreeDiams::CA_HCDPD::DIN', 69356);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Etidronate', 'tablet', 'M05BA01', false, 0, '02245330', 'FreeDiams::CA_HCDPD::DIN', 69359);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Androgel', 'gel', 'G03BA03', false, 0, '02245345', 'FreeDiams::CA_HCDPD::DIN', 69384);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Androgel', 'gel', 'G03BA03', false, 0, '02245346', 'FreeDiams::CA_HCDPD::DIN', 69385);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bobbi Brown Protective Face Lotion Spf 15', 'solution', 'D02BA30', false, 0, '02245354', 'FreeDiams::CA_HCDPD::DIN', 69393);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bobbi Brown Spf15 Tinted Moisturizer', 'cream', 'D02BA30', false, 0, '02245355', 'FreeDiams::CA_HCDPD::DIN', 69394);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alka-Seltzer Flavoured', 'tablet (effervescent)', 'N02BA51', false, 0, '02245367', 'FreeDiams::CA_HCDPD::DIN', 69406);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Propafenone', 'tablet', 'C01BC03', false, 0, '02245372', 'FreeDiams::CA_HCDPD::DIN', 69411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Propafenone', 'tablet', 'C01BC03', false, 0, '02245373', 'FreeDiams::CA_HCDPD::DIN', 69412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germ Clean', 'liquid', 'V07AV', false, 0, '02245380', 'FreeDiams::CA_HCDPD::DIN', 69419);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chapstick Spf 30', 'stick', 'D02BA30', false, 0, '02245381', 'FreeDiams::CA_HCDPD::DIN', 69420);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Symbicort 100 Turbuhaler', 'powder', 'R03AK07', false, 0, '02245385', 'FreeDiams::CA_HCDPD::DIN', 69428);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Symbicort 200 Turbuhaler', 'powder', 'R03AK07', false, 0, '02245386', 'FreeDiams::CA_HCDPD::DIN', 69429);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Sleep Aid Fast', 'capsule', 'R06AA02', false, 0, '02245388', 'FreeDiams::CA_HCDPD::DIN', 69432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novorapid       -(10ml Vial)', 'solution', 'A10AB05', false, 0, '02245397', 'FreeDiams::CA_HCDPD::DIN', 69441);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylprednisolone Acetate Injectable Suspension Usp', 'suspension', 'H02AB04', false, 0, '02245400', 'FreeDiams::CA_HCDPD::DIN', 69444);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylprednisolone Acetate Injectable Suspension Usp', 'suspension', 'H02AB04', false, 0, '02245406', 'FreeDiams::CA_HCDPD::DIN', 69454);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylprednisolone Acetate Injectable Suspension Usp  -(40mg/Ml With Preservative)', 'suspension', 'H02AB04', false, 0, '02245407', 'FreeDiams::CA_HCDPD::DIN', 69455);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylprednisolone Acetate Injectable Suspension Usp   -(80mg/Ml With Preservative)', 'suspension', 'H02AB04', false, 0, '02245408', 'FreeDiams::CA_HCDPD::DIN', 69456);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Motion Sickness Tablet 50 Mg', 'tablet', 'R06AA02', false, 0, '02245416', 'FreeDiams::CA_HCDPD::DIN', 69468);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Digoxin', 'tablet', 'C01AA05', false, 0, '02245426', 'FreeDiams::CA_HCDPD::DIN', 69478);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Digoxin', 'tablet', 'C01AA05', false, 0, '02245427', 'FreeDiams::CA_HCDPD::DIN', 69479);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Digoxin', 'tablet', 'C01AA05', false, 0, '02245428', 'FreeDiams::CA_HCDPD::DIN', 69480);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pimozide', 'tablet', 'N05AG02', false, 0, '02245432', 'FreeDiams::CA_HCDPD::DIN', 69484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pimozide', 'tablet', 'N05AG02', false, 0, '02245433', 'FreeDiams::CA_HCDPD::DIN', 69485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Starlix 60mg', 'tablet', 'A10BX03', false, 0, '02245438', 'FreeDiams::CA_HCDPD::DIN', 69490);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Starlix 120mg', 'tablet', 'A10BX03', false, 0, '02245439', 'FreeDiams::CA_HCDPD::DIN', 69491);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('A.S.A. 325 Mg Tablet', 'tablet', 'N02BA01', false, 0, '02245443', 'FreeDiams::CA_HCDPD::DIN', 69500);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Aurothiomalate Injection Bp', 'solution', 'M01CB01', false, 0, '02245456', 'FreeDiams::CA_HCDPD::DIN', 69514);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Aurothiomalate Injection Bp', 'solution', 'M01CB01', false, 0, '02245457', 'FreeDiams::CA_HCDPD::DIN', 69515);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Aurothiomalate Injection Bp', 'solution', 'M01CB01', false, 0, '02245458', 'FreeDiams::CA_HCDPD::DIN', 69516);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bles', 'suspension', 'R07AA30', false, 0, '02245464', 'FreeDiams::CA_HCDPD::DIN', 69524);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Bac Foam Soap', 'liquid', 'D08AE04', false, 0, '02245467', 'FreeDiams::CA_HCDPD::DIN', 69527);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Flavoxate', 'tablet', 'G04BD02', false, 0, '02245480', 'FreeDiams::CA_HCDPD::DIN', 69540);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Total Effects 7-In-1 Anti-Aging Uv Moisturizer', 'lotion', 'D02BA30', false, 0, '02245491', 'FreeDiams::CA_HCDPD::DIN', 69552);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pediacol', 'drops', 'A03AX13', false, 0, '02245510', 'FreeDiams::CA_HCDPD::DIN', 69597);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Clobetasol Topical Solution Usp, 0.05%', 'solution', 'D07AD01', false, 0, '02245522', 'FreeDiams::CA_HCDPD::DIN', 69609);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Clobetasol Cream Usp, 0.05%', 'cream', 'D07AD01', false, 0, '02245523', 'FreeDiams::CA_HCDPD::DIN', 69610);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Clobetasol Ointment Usp, 0.05%', 'ointment', 'D07AD01', false, 0, '02245524', 'FreeDiams::CA_HCDPD::DIN', 69611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Household Cleaner With Pine Oil', 'liquid', 'V07AV', false, 0, '02245528', 'FreeDiams::CA_HCDPD::DIN', 69615);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exsept', 'liquid', 'D08AX07', false, 0, '02245530', 'FreeDiams::CA_HCDPD::DIN', 69617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arixtra', 'solution', 'B01AX05', false, 0, '02245531', 'FreeDiams::CA_HCDPD::DIN', 69618);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Prednisolone', 'solution', 'H02AB06', false, 0, '02245532', 'FreeDiams::CA_HCDPD::DIN', 69619);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Miconazole Nitrate Vaginal Cream 2%', 'cream', 'G01AF04', false, 0, '02245546', 'FreeDiams::CA_HCDPD::DIN', 69637);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tamiflu Oral Suspension', 'powder for suspension', 'J05AH02', false, 0, '02245549', 'FreeDiams::CA_HCDPD::DIN', 69640);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xatral', 'tablet (extended-release)', 'G04CA01', false, 0, '02245565', 'FreeDiams::CA_HCDPD::DIN', 69657);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Barbicide', 'liquid', 'V07AV', false, 0, '02245567', 'FreeDiams::CA_HCDPD::DIN', 69659);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baciject 50,000 Units/Vial', 'powder for solution', 'J01XX10', false, 0, '02245571', 'FreeDiams::CA_HCDPD::DIN', 69667);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Drixoral No Drip Extra Moisturizing', 'spray', 'R01AA05', false, 0, '02245575', 'FreeDiams::CA_HCDPD::DIN', 69670);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Drixoral No Drip Original', 'spray', 'R01AA05', false, 0, '02245578', 'FreeDiams::CA_HCDPD::DIN', 69673);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Drixoral No Drip With Cooling Menthol', 'spray', 'R01AA05', false, 0, '02245580', 'FreeDiams::CA_HCDPD::DIN', 69676);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Damylin With Codeine Syrup', 'syrup', 'R05FA02', false, 0, '02245592', 'FreeDiams::CA_HCDPD::DIN', 69689);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biosan', 'liquid', 'V07AV', false, 0, '02245599', 'FreeDiams::CA_HCDPD::DIN', 69698);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterisan', 'liquid', 'V07AV', false, 0, '02245600', 'FreeDiams::CA_HCDPD::DIN', 69699);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Warfarin', 'tablet', 'B01AA03', false, 0, '02245618', 'FreeDiams::CA_HCDPD::DIN', 69718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Copaxone', 'solution', 'L03AX13', false, 0, '02245619', 'FreeDiams::CA_HCDPD::DIN', 69719);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Amoxi Clav 875/125', 'tablet', 'J01CR02', false, 0, '02245623', 'FreeDiams::CA_HCDPD::DIN', 69723);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Profilm Fumigant Concentrate Solution', 'solution', 'V07AV', false, 0, '02245634', 'FreeDiams::CA_HCDPD::DIN', 69733);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Farm And Animal Care Disinfectant-256', 'liquid', 'V07AV', false, 0, '02245635', 'FreeDiams::CA_HCDPD::DIN', 69735);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coricidin Ii Cough And Cold', 'tablet', 'R05DA20', false, 0, '02245637', 'FreeDiams::CA_HCDPD::DIN', 69737);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coricidin Ii Extra Strength Cold And Flu', 'tablet', 'N02BE51', false, 0, '02245638', 'FreeDiams::CA_HCDPD::DIN', 69738);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Orgalutran', 'solution', 'H01CC01', false, 0, '02245641', 'FreeDiams::CA_HCDPD::DIN', 69741);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fluconazole', 'tablet', 'J02AC01', false, 0, '02245643', 'FreeDiams::CA_HCDPD::DIN', 69743);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fluconazole', 'tablet', 'J02AC01', false, 0, '02245644', 'FreeDiams::CA_HCDPD::DIN', 69744);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02245647', 'FreeDiams::CA_HCDPD::DIN', 69747);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02245648', 'FreeDiams::CA_HCDPD::DIN', 69748);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02245649', 'FreeDiams::CA_HCDPD::DIN', 69749);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clear Care One Bottle Solution For Cleaning And Disinfecting', 'solution', 'S01XA20', false, 0, '02245661', 'FreeDiams::CA_HCDPD::DIN', 69761);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ketoderm Cream 2%', 'cream', 'D01AC08', false, 0, '02245662', 'FreeDiams::CA_HCDPD::DIN', 69762);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trimebutine', 'tablet', 'A03AA05', false, 0, '02245663', 'FreeDiams::CA_HCDPD::DIN', 69763);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trimebutine', 'tablet', 'A03AA05', false, 0, '02245664', 'FreeDiams::CA_HCDPD::DIN', 69764);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euro-Cyproheptadine 4mg/Tablet', 'tablet', 'R06AX02', false, 0, '02245667', 'FreeDiams::CA_HCDPD::DIN', 69767);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euro-Cyproheptadine 2mg/5ml', 'syrup', 'R06AX02', false, 0, '02245668', 'FreeDiams::CA_HCDPD::DIN', 69768);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Salvent Cfc Free', 'metered-dose (aerosol)', 'R03AC02', false, 0, '02245669', 'FreeDiams::CA_HCDPD::DIN', 69769);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estradot 25', 'patch', 'G03CA03', false, 0, '02245676', 'FreeDiams::CA_HCDPD::DIN', 69776);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abreva', 'cream', 'D06BB11', false, 0, '02245677', 'FreeDiams::CA_HCDPD::DIN', 69777);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Calcitriol Injection', 'solution', 'A11CC04', false, 0, '02245686', 'FreeDiams::CA_HCDPD::DIN', 69787);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Topisalic', 'lotion', 'D07XC01', false, 0, '02245688', 'FreeDiams::CA_HCDPD::DIN', 69789);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lantus', 'solution', 'A10AE04', false, 0, '02245689', 'FreeDiams::CA_HCDPD::DIN', 69790);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neo-Strata Up-Lifting Daytime Firming Lotion', 'lotion', 'D02BA30', false, 0, '02245690', 'FreeDiams::CA_HCDPD::DIN', 69791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enchante Shampooing Antipelliculaire', 'shampoo', 'D11AX12', false, 0, '02245691', 'FreeDiams::CA_HCDPD::DIN', 69792);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amiodarone Hydrochloride For Intravenous Infusion', 'solution', 'C01BD01', false, 0, '02245696', 'FreeDiams::CA_HCDPD::DIN', 69797);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Fluconazole', 'capsule', 'J02AC01', false, 0, '02245697', 'FreeDiams::CA_HCDPD::DIN', 69798);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Tobramycin', 'solution', 'S01AA12', false, 0, '02245698', 'FreeDiams::CA_HCDPD::DIN', 69799);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorph.Ir - 2mg', 'tablet', 'N02AA03', false, 0, '02245703', 'FreeDiams::CA_HCDPD::DIN', 69806);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorph.Ir - 4mg', 'tablet', 'N02AA03', false, 0, '02245704', 'FreeDiams::CA_HCDPD::DIN', 69807);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorph.Ir - 8mg', 'tablet', 'N02AA03', false, 0, '02245705', 'FreeDiams::CA_HCDPD::DIN', 69808);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin 2 Cold And Flu With Codeine', 'syrup', 'R05FA02', false, 0, '02245709', 'FreeDiams::CA_HCDPD::DIN', 69813);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin All-In-One Cold And Flu Extra Strength Syrup', 'syrup', 'N02BE51', false, 0, '02245710', 'FreeDiams::CA_HCDPD::DIN', 69814);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neostrata Canada Hq Plus Cream', 'cream', 'D11AX11', false, 0, '02245727', 'FreeDiams::CA_HCDPD::DIN', 69834);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Asa 500mg', 'tablet', 'N02BA01', false, 0, '02245729', 'FreeDiams::CA_HCDPD::DIN', 69836);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bismuth Caplets', 'tablet', 'A07BB', false, 0, '02245730', 'FreeDiams::CA_HCDPD::DIN', 69837);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bismuth Chewables', 'tablet', 'A07BB', false, 0, '02245731', 'FreeDiams::CA_HCDPD::DIN', 69838);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rapide', 'aerosol', 'V07AV', false, 0, '02245733', 'FreeDiams::CA_HCDPD::DIN', 69840);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antiseptic Body Cleanser', 'wipe', 'D08AC02', false, 0, '02245741', 'FreeDiams::CA_HCDPD::DIN', 69848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Sertraline', 'capsule', 'N06AB06', false, 0, '02245748', 'FreeDiams::CA_HCDPD::DIN', 69856);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Sertraline', 'capsule', 'N06AB06', false, 0, '02245749', 'FreeDiams::CA_HCDPD::DIN', 69857);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Sertraline', 'capsule', 'N06AB06', false, 0, '02245750', 'FreeDiams::CA_HCDPD::DIN', 69858);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Divalproex', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02245751', 'FreeDiams::CA_HCDPD::DIN', 69859);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Divalproex', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02245752', 'FreeDiams::CA_HCDPD::DIN', 69860);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Divalproex', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02245753', 'FreeDiams::CA_HCDPD::DIN', 69861);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Oxycodone - Acetaminophen', 'tablet', 'N02BE51', false, 0, '02245758', 'FreeDiams::CA_HCDPD::DIN', 69866);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Dandruff Shampoo', 'shampoo', 'D11AX12', false, 0, '02245769', 'FreeDiams::CA_HCDPD::DIN', 69880);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Watkins Aloe Vera Botanical Lip Balm', 'stick', 'D02BA30', false, 0, '02245773', 'FreeDiams::CA_HCDPD::DIN', 69886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valcyte', 'tablet', 'J05AB14', false, 0, '02245777', 'FreeDiams::CA_HCDPD::DIN', 69890);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Amiodarone', 'tablet', 'C01BD01', false, 0, '02245781', 'FreeDiams::CA_HCDPD::DIN', 69894);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Ranitidine', 'tablet', 'A02BA02', false, 0, '02245782', 'FreeDiams::CA_HCDPD::DIN', 69895);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Ranitidine', 'tablet', 'A02BA02', false, 0, '02245783', 'FreeDiams::CA_HCDPD::DIN', 69896);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Lorazepam', 'tablet', 'N05BA06', false, 0, '02245784', 'FreeDiams::CA_HCDPD::DIN', 69897);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Lorazepam', 'tablet', 'N05BA06', false, 0, '02245785', 'FreeDiams::CA_HCDPD::DIN', 69898);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Lorazepam', 'tablet', 'N05BA06', false, 0, '02245786', 'FreeDiams::CA_HCDPD::DIN', 69899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Sertraline', 'capsule', 'N06AB06', false, 0, '02245787', 'FreeDiams::CA_HCDPD::DIN', 69900);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Sertraline', 'capsule', 'N06AB06', false, 0, '02245788', 'FreeDiams::CA_HCDPD::DIN', 69901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Sertraline', 'capsule', 'N06AB06', false, 0, '02245789', 'FreeDiams::CA_HCDPD::DIN', 69902);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exsept (0.114%)', 'liquid', 'D08AX07', false, 0, '02245790', 'FreeDiams::CA_HCDPD::DIN', 69903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dr. Scholl''S Cracked Heel Relief Cream', 'cream', 'D04AB01', false, 0, '02245801', 'FreeDiams::CA_HCDPD::DIN', 69914);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ndc Morning Fresh Neutral Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02245816', 'FreeDiams::CA_HCDPD::DIN', 69931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Phosphate Inj 3mmp/Ml', 'solution', 'B05XA06', false, 0, '00351539', 'FreeDiams::CA_HCDPD::DIN', 69934);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('State Formula 362 No Rinse Cleaner/Sanitizer', 'liquid', 'V07AV', false, 0, '02245820', 'FreeDiams::CA_HCDPD::DIN', 69936);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ketorolac Ophthalmic Solution    -(With Surfactant)', 'solution', 'S01BC05', false, 0, '02245821', 'FreeDiams::CA_HCDPD::DIN', 69937);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Lovastatin', 'tablet', 'C10AA02', false, 0, '02245822', 'FreeDiams::CA_HCDPD::DIN', 69938);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Lovastatin', 'tablet', 'C10AA02', false, 0, '02245823', 'FreeDiams::CA_HCDPD::DIN', 69939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Sertraline', 'capsule', 'N06AB06', false, 0, '02245824', 'FreeDiams::CA_HCDPD::DIN', 69940);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Sertraline', 'capsule', 'N06AB06', false, 0, '02245825', 'FreeDiams::CA_HCDPD::DIN', 69941);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Sertraline', 'capsule', 'N06AB06', false, 0, '02245826', 'FreeDiams::CA_HCDPD::DIN', 69942);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Oxybutynin', 'tablet', 'G04BD04', false, 0, '02245827', 'FreeDiams::CA_HCDPD::DIN', 69943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clasteon', 'capsule', 'M05BA02', false, 0, '02245828', 'FreeDiams::CA_HCDPD::DIN', 69944);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Foster 40-80 Hvac & Wall Disinfectant', 'solution', 'V07AV', false, 0, '02245840', 'FreeDiams::CA_HCDPD::DIN', 69957);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Select Spf 15 Foundation', 'suspension', 'D02BA02', false, 0, '02245846', 'FreeDiams::CA_HCDPD::DIN', 69963);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('N.A.C. Plus', 'liquid', 'V07AV', false, 0, '02245853', 'FreeDiams::CA_HCDPD::DIN', 69970);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cathflo', 'powder for solution', 'B01AD02', false, 0, '02245859', 'FreeDiams::CA_HCDPD::DIN', 69976);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lumigan', 'solution', 'S01EE03', false, 0, '02245860', 'FreeDiams::CA_HCDPD::DIN', 69977);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gravol 50mg Softgel Capsule', 'capsule', 'R06AA02', false, 0, '02245867', 'FreeDiams::CA_HCDPD::DIN', 69984);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fiber-On-Tablet', 'tablet', 'A06AC08', false, 0, '02245870', 'FreeDiams::CA_HCDPD::DIN', 69987);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Comfort Shield', 'wipe', 'D02AA', false, 0, '02245871', 'FreeDiams::CA_HCDPD::DIN', 69988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hexit Lotion', 'lotion', 'P03AB02', false, 0, '02245872', 'FreeDiams::CA_HCDPD::DIN', 69989);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methazolamide', 'tablet', 'S01EC05', false, 0, '02245882', 'FreeDiams::CA_HCDPD::DIN', 69999);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marquat', 'liquid', 'V07AV', false, 0, '02245883', 'FreeDiams::CA_HCDPD::DIN', 70000);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pure Cleaner Disinfectant', 'liquid', 'V07AV', false, 0, '02245884', 'FreeDiams::CA_HCDPD::DIN', 70001);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Relief Asa Extra Strength', 'tablet', 'N02BA01', false, 0, '02245887', 'FreeDiams::CA_HCDPD::DIN', 70004);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synagis', 'powder for solution', 'J06BB16', false, 0, '02245889', 'FreeDiams::CA_HCDPD::DIN', 70006);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synagis', 'powder for solution', 'J06BB16', false, 0, '02245890', 'FreeDiams::CA_HCDPD::DIN', 70007);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Urso Ds', 'tablet', 'A05AA02', false, 0, '02245894', 'FreeDiams::CA_HCDPD::DIN', 70011);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyproterone', 'tablet', 'G03HA01', false, 0, '02245898', 'FreeDiams::CA_HCDPD::DIN', 70015);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sproam', 'liquid', 'D08AJ08', false, 0, '02245903', 'FreeDiams::CA_HCDPD::DIN', 70020);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Betacaine Gel', 'gel', 'D04AB01', false, 0, '02245906', 'FreeDiams::CA_HCDPD::DIN', 70023);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kineret', 'solution', 'L04AC03', false, 0, '02245913', 'FreeDiams::CA_HCDPD::DIN', 70033);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Carvedilol', 'tablet', 'C07AG02', false, 0, '02245914', 'FreeDiams::CA_HCDPD::DIN', 70034);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Carvedilol', 'tablet', 'C07AG02', false, 0, '02245915', 'FreeDiams::CA_HCDPD::DIN', 70035);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Carvedilol', 'tablet', 'C07AG02', false, 0, '02245916', 'FreeDiams::CA_HCDPD::DIN', 70036);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Carvedilol', 'tablet', 'C07AG02', false, 0, '02245917', 'FreeDiams::CA_HCDPD::DIN', 70037);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Diltiazem T', 'capsule (extended release)', 'C08DB01', false, 0, '02245918', 'FreeDiams::CA_HCDPD::DIN', 70038);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Diltiazem T', 'capsule (extended release)', 'C08DB01', false, 0, '02245919', 'FreeDiams::CA_HCDPD::DIN', 70039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Diltiazem T', 'capsule (extended release)', 'C08DB01', false, 0, '02245920', 'FreeDiams::CA_HCDPD::DIN', 70040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Diltiazem T', 'capsule (extended release)', 'C08DB01', false, 0, '02245921', 'FreeDiams::CA_HCDPD::DIN', 70041);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Diltiazem T', 'capsule (extended release)', 'C08DB01', false, 0, '02245922', 'FreeDiams::CA_HCDPD::DIN', 70042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quat-A-Bac', 'liquid', 'D08AJ01', false, 0, '02245924', 'FreeDiams::CA_HCDPD::DIN', 70044);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lysol Multi-Surface Cleaner', 'liquid', 'V07AV', false, 0, '02245935', 'FreeDiams::CA_HCDPD::DIN', 70059);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maxilene 5', 'cream', 'D04AB01', false, 0, '02245939', 'FreeDiams::CA_HCDPD::DIN', 70063);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pcs-Quatrocide', 'solution', 'V07AV', false, 0, '02245943', 'FreeDiams::CA_HCDPD::DIN', 70067);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Docusate Sodium Capsules Usp', 'capsule', 'A06AA02', false, 0, '02245946', 'FreeDiams::CA_HCDPD::DIN', 70070);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levothyroxine Sodium For Injection', 'powder for solution', 'H03AA01', false, 0, '02245948', 'FreeDiams::CA_HCDPD::DIN', 70072);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermalogica Solar Defense Booster Spf 30', 'liquid', 'D02BA30', false, 0, '02245959', 'FreeDiams::CA_HCDPD::DIN', 70085);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Day Defense Treatment Spf 15', 'stick', 'D02BA30', false, 0, '02245960', 'FreeDiams::CA_HCDPD::DIN', 70086);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solar Defense Wipes Spf 15', 'wipe', 'D02BA30', false, 0, '02245961', 'FreeDiams::CA_HCDPD::DIN', 70087);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermalogica Special Clearing Booster', 'lotion', 'D10AE01', false, 0, '02245965', 'FreeDiams::CA_HCDPD::DIN', 70091);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Androderm', 'patch', 'G03BA03', false, 0, '02245972', 'FreeDiams::CA_HCDPD::DIN', 70098);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Recombivax Hb     -(Adult Dialysis-Preservative Free)', 'solution', 'J07BC01', false, 0, '02245977', 'FreeDiams::CA_HCDPD::DIN', 70103);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vigorox Liquid Sanitizer And Disinfectant', 'liquid', 'V07AV', false, 0, '02245979', 'FreeDiams::CA_HCDPD::DIN', 70105);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Luxiva Timeless Spf 20', 'liquid', 'D02BA30', false, 0, '02245985', 'FreeDiams::CA_HCDPD::DIN', 70111);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitalumičre - Fluide De Teint Éclat - Spf 15', 'lotion', 'D02BA02', false, 0, '02245987', 'FreeDiams::CA_HCDPD::DIN', 70113);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Skin Caviar Foundation Spf 15', 'liquid', 'D02BA02', false, 0, '02245988', 'FreeDiams::CA_HCDPD::DIN', 70114);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pamidronate', 'powder for solution', 'M05BA03', false, 0, '02245998', 'FreeDiams::CA_HCDPD::DIN', 70124);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pamidronate', 'powder for solution', 'M05BA03', false, 0, '02245999', 'FreeDiams::CA_HCDPD::DIN', 70125);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lp 450', 'liquid', 'V07AV', false, 0, '02246009', 'FreeDiams::CA_HCDPD::DIN', 70135);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Metoprolol', 'tablet', 'C07AB02', false, 0, '02246010', 'FreeDiams::CA_HCDPD::DIN', 70136);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lp 400', 'liquid', 'V07AV', false, 0, '02246011', 'FreeDiams::CA_HCDPD::DIN', 70137);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caviwipes Xl', 'pad', 'V07AV', false, 0, '02246012', 'FreeDiams::CA_HCDPD::DIN', 70138);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lovastatin', 'tablet', 'C10AA02', false, 0, '02246013', 'FreeDiams::CA_HCDPD::DIN', 70139);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lovastatin', 'tablet', 'C10AA02', false, 0, '02246014', 'FreeDiams::CA_HCDPD::DIN', 70140);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Thyrogen', 'powder for solution', 'V04CJ01', false, 0, '02246016', 'FreeDiams::CA_HCDPD::DIN', 70142);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pcs-Bio-Spray', 'liquid', 'V07AV', false, 0, '02246017', 'FreeDiams::CA_HCDPD::DIN', 70143);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pcs-Quatrosan', 'solution', 'V07AV', false, 0, '02246018', 'FreeDiams::CA_HCDPD::DIN', 70144);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Decongestant Nasal Spray', 'spray', 'R01AA07', false, 0, '02246021', 'FreeDiams::CA_HCDPD::DIN', 70147);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Long Lasting Nasal Mist', 'spray', 'R01AA05', false, 0, '02246022', 'FreeDiams::CA_HCDPD::DIN', 70148);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Decongestant Nasal Spray With Moisturizers', 'spray', 'R01AA07', false, 0, '02246023', 'FreeDiams::CA_HCDPD::DIN', 70149);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hextend', 'solution', 'B05AA07', false, 0, '02246024', 'FreeDiams::CA_HCDPD::DIN', 70150);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pegetron', 'kit', 'L03AB60', false, 0, '02246026', 'FreeDiams::CA_HCDPD::DIN', 70155);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pegetron', 'kit', 'L03AB60', false, 0, '02246027', 'FreeDiams::CA_HCDPD::DIN', 70156);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pegetron', 'kit', 'L03AB60', false, 0, '02246028', 'FreeDiams::CA_HCDPD::DIN', 70157);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pegetron', 'kit', 'L03AB60', false, 0, '02246030', 'FreeDiams::CA_HCDPD::DIN', 70159);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germicidal Surface Cleaner', 'aerosol', 'V07AV', false, 0, '02246034', 'FreeDiams::CA_HCDPD::DIN', 70165);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Disinfectant Spray For Health Care Use', 'aerosol', 'V07AV', false, 0, '02246035', 'FreeDiams::CA_HCDPD::DIN', 70166);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Docusate Sodium', 'capsule', 'A06AA02', false, 0, '02246036', 'FreeDiams::CA_HCDPD::DIN', 70167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bisacodyl Tablets 5 Mg', 'tablet', 'A06AB02', false, 0, '02246039', 'FreeDiams::CA_HCDPD::DIN', 70170);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sustiva Tablets', 'tablet', 'J05AG03', false, 0, '02246045', 'FreeDiams::CA_HCDPD::DIN', 70176);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zep-I-Dine', 'liquid', 'V07AV', false, 0, '02246049', 'FreeDiams::CA_HCDPD::DIN', 70180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Modyne', 'solution', 'V07AV', false, 0, '02246053', 'FreeDiams::CA_HCDPD::DIN', 70184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Citalopram', 'tablet', 'N06AB04', false, 0, '02246056', 'FreeDiams::CA_HCDPD::DIN', 70187);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Citalopram', 'tablet', 'N06AB04', false, 0, '02246057', 'FreeDiams::CA_HCDPD::DIN', 70188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Calcitonin Injectable', 'liquid', 'H05BA01', false, 0, '02246058', 'FreeDiams::CA_HCDPD::DIN', 70189);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol Muscle Aches & Body Pain', 'tablet (extended-release)', 'N02BE01', false, 0, '02246060', 'FreeDiams::CA_HCDPD::DIN', 70191);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Airx 15 Rtu', 'liquid', 'V07AV', false, 0, '02246062', 'FreeDiams::CA_HCDPD::DIN', 70197);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Testosterone Cypionate Injection Usp', 'liquid', 'G03BA03', false, 0, '02246063', 'FreeDiams::CA_HCDPD::DIN', 70198);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Airx 44 Rtu', 'liquid', 'V07AV', false, 0, '02246064', 'FreeDiams::CA_HCDPD::DIN', 70199);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pregvit', 'tablet', 'B03AE04', false, 0, '02246067', 'FreeDiams::CA_HCDPD::DIN', 70202);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Varivax Iii', 'powder for solution', 'J07BK01', false, 0, '02246081', 'FreeDiams::CA_HCDPD::DIN', 70216);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flunarizine', 'capsule', 'N07CA03', false, 0, '02246082', 'FreeDiams::CA_HCDPD::DIN', 70217);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ipravent Nasal Spray', 'solution', 'R01AX03', false, 0, '02246083', 'FreeDiams::CA_HCDPD::DIN', 70218);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ipravent Nasal Spray', 'solution', 'R01AX03', false, 0, '02246084', 'FreeDiams::CA_HCDPD::DIN', 70219);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen, Caffeine & 8mg Codeine Phosphate Tablets', 'tablet', 'N02BE51', false, 0, '02246085', 'FreeDiams::CA_HCDPD::DIN', 70220);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Tablets Usp Soft Chews 160mg', 'tablet', 'N02BE01', false, 0, '02246087', 'FreeDiams::CA_HCDPD::DIN', 70222);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life -Shampooing Et Revitalisant Antipelliculaire Classique - 2 En 1', 'shampoo', 'D11AX12', false, 0, '02246089', 'FreeDiams::CA_HCDPD::DIN', 70224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hibiclens Antiseptic/Antimicrobial Skin Cleanser', 'liquid', 'D08AC02', false, 0, '02246091', 'FreeDiams::CA_HCDPD::DIN', 70226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actiflex Pain Relief Rub', 'cream', 'M02AC', false, 0, '02246102', 'FreeDiams::CA_HCDPD::DIN', 70239);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetylsalicylic Acid, Caffeine & 8 Mg Codeine Phosphate Tablets', 'tablet', 'N02BA51', false, 0, '02246103', 'FreeDiams::CA_HCDPD::DIN', 70240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Fluconazole', 'tablet', 'J02AC01', false, 0, '02246108', 'FreeDiams::CA_HCDPD::DIN', 70245);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Fluconazole', 'tablet', 'J02AC01', false, 0, '02246109', 'FreeDiams::CA_HCDPD::DIN', 70246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Regenerist Enhancing Lotion With Uv Protection', 'lotion', 'D02BA30', false, 0, '02246110', 'FreeDiams::CA_HCDPD::DIN', 70253);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diorskin Fluide', 'emulsion', 'D02BA30', false, 0, '02246117', 'FreeDiams::CA_HCDPD::DIN', 70260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diorskin Compact', 'powder', 'D02BA30', false, 0, '02246118', 'FreeDiams::CA_HCDPD::DIN', 70261);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Provon Antiseptic Lotion Soap With 2% Chg', 'lotion', 'D08AE02', false, 0, '02246121', 'FreeDiams::CA_HCDPD::DIN', 70264);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clorox Disinfecting Spray', 'aerosol', 'V07AV', false, 0, '02246125', 'FreeDiams::CA_HCDPD::DIN', 70268);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proquat Germicidal Detergent Concentrate', 'liquid', 'V07AV', false, 0, '02246131', 'FreeDiams::CA_HCDPD::DIN', 70274);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pressyn Ar', 'liquid', 'H01BA01', false, 0, '02246133', 'FreeDiams::CA_HCDPD::DIN', 70276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('40 Mmols Potassium Chloride In Lactated Ringer''S Injection', 'liquid', 'B05BB01', false, 0, '02246134', 'FreeDiams::CA_HCDPD::DIN', 70277);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinus Relief Extra Strength Tablet', 'tablet', 'N02BE51', false, 0, '02246141', 'FreeDiams::CA_HCDPD::DIN', 70284);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cold Relief Daytime Tablet', 'tablet', 'N02BE51', false, 0, '02246142', 'FreeDiams::CA_HCDPD::DIN', 70285);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cold Relief Nightime Tablet', 'tablet', 'N02BE51', false, 0, '02246143', 'FreeDiams::CA_HCDPD::DIN', 70286);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Body Series Anti-Bacterial Hand Soap', 'liquid', 'D08AE04', false, 0, '02246145', 'FreeDiams::CA_HCDPD::DIN', 70288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polysporin Itch Relief', 'lotion', 'D04AB07', false, 0, '02246156', 'FreeDiams::CA_HCDPD::DIN', 70300);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reactine Allergy & Sinus', 'tablet (extended-release)', 'R01BA52', false, 0, '02246162', 'FreeDiams::CA_HCDPD::DIN', 70312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Amiodarone Tablets', 'tablet', 'C01BD01', false, 0, '02246194', 'FreeDiams::CA_HCDPD::DIN', 70344);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Digiclean Slim-Line Anti-Bacterial Foam Hand Soap', 'liquid', 'D08AE04', false, 0, '02246200', 'FreeDiams::CA_HCDPD::DIN', 70352);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vittal Xp', 'liquid', 'V07AV', false, 0, '02246209', 'FreeDiams::CA_HCDPD::DIN', 70365);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Old Dutch 12', 'liquid', 'V07AV', false, 0, '02246211', 'FreeDiams::CA_HCDPD::DIN', 70367);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lavo 12 Sodium Hypochlorite', 'liquid', 'V07AV', false, 0, '02246212', 'FreeDiams::CA_HCDPD::DIN', 70368);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sudden Change Scar Zone Cream W/Spf 15', 'cream', 'D02BA30', false, 0, '02246218', 'FreeDiams::CA_HCDPD::DIN', 70373);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creolin Disinfectant', 'liquid', 'V07AV', false, 0, '02246225', 'FreeDiams::CA_HCDPD::DIN', 70383);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fludara', 'tablet', 'L01BB05', false, 0, '02246226', 'FreeDiams::CA_HCDPD::DIN', 70384);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clorox Disinfecting Wipes', 'wipe', 'V07AV', false, 0, '02246233', 'FreeDiams::CA_HCDPD::DIN', 70392);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cold And Flu Capsules', 'capsule', 'N02BE51', false, 0, '02246238', 'FreeDiams::CA_HCDPD::DIN', 70399);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sanicide Ca Powder', 'powder', 'V07AV', false, 0, '02246249', 'FreeDiams::CA_HCDPD::DIN', 70410);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fantastik Germ Away', 'solution', 'V07AV', false, 0, '02246272', 'FreeDiams::CA_HCDPD::DIN', 70433);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amino-Prophyl (3004)', 'liquid', 'V07AV', false, 0, '02246281', 'FreeDiams::CA_HCDPD::DIN', 70442);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenosept (3181)', 'liquid', 'V07AV', false, 0, '02246282', 'FreeDiams::CA_HCDPD::DIN', 70443);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Brimonidine', 'solution', 'S01EA05', false, 0, '02246284', 'FreeDiams::CA_HCDPD::DIN', 70445);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sani-Cloth Household Surface Wipes', 'wipe', 'V07AV', false, 0, '02246298', 'FreeDiams::CA_HCDPD::DIN', 70460);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lysol Disinfectant All Purpose Cleaner', 'liquid', 'V07AV', false, 0, '02246307', 'FreeDiams::CA_HCDPD::DIN', 70469);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Painaid Pmf Premenstrual Formula', 'tablet', 'N02BE51', false, 0, '02246308', 'FreeDiams::CA_HCDPD::DIN', 70470);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chemquat 1s', 'solution', 'V07AV', false, 0, '02246309', 'FreeDiams::CA_HCDPD::DIN', 70471);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hex-Odour Control Liquid Disinfectant, Deodorizer, & Cleaner', 'solution', 'V07AV', false, 0, '02246312', 'FreeDiams::CA_HCDPD::DIN', 70475);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gabapentin', 'capsule', 'N03AX12', false, 0, '02246314', 'FreeDiams::CA_HCDPD::DIN', 70477);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gabapentin', 'capsule', 'N03AX12', false, 0, '02246315', 'FreeDiams::CA_HCDPD::DIN', 70478);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gabapentin', 'capsule', 'N03AX12', false, 0, '02246316', 'FreeDiams::CA_HCDPD::DIN', 70479);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Zopiclone', 'tablet', 'N05CF01', false, 0, '02246317', 'FreeDiams::CA_HCDPD::DIN', 70480);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rapicide High Level Disinfectant And Sterilant', 'solution', 'V07AV', false, 0, '02246323', 'FreeDiams::CA_HCDPD::DIN', 70486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Disinfectant Spray', 'aerosol', 'V07AV', false, 0, '02246329', 'FreeDiams::CA_HCDPD::DIN', 70493);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Amiodarone', 'tablet', 'C01BD01', false, 0, '02246331', 'FreeDiams::CA_HCDPD::DIN', 70495);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Doxazosin', 'tablet', 'C02CA04', false, 0, '02246332', 'FreeDiams::CA_HCDPD::DIN', 70496);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Doxazosin', 'tablet', 'C02CA04', false, 0, '02246333', 'FreeDiams::CA_HCDPD::DIN', 70497);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Doxazosin', 'tablet', 'C02CA04', false, 0, '02246334', 'FreeDiams::CA_HCDPD::DIN', 70498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aviation Rtu Cleaner Disinfectant', 'liquid', 'V07AV', false, 0, '02246339', 'FreeDiams::CA_HCDPD::DIN', 70506);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aranesp        -(Hsa-Free)', 'solution', 'B03XA02', false, 0, '02246354', 'FreeDiams::CA_HCDPD::DIN', 70520);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aranesp        -(Hsa-Free)', 'solution', 'B03XA02', false, 0, '02246355', 'FreeDiams::CA_HCDPD::DIN', 70521);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aranesp        -(Hsa-Free)', 'solution', 'B03XA02', false, 0, '02246357', 'FreeDiams::CA_HCDPD::DIN', 70523);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aranesp        -(Hsa-Free)', 'solution', 'B03XA02', false, 0, '02246358', 'FreeDiams::CA_HCDPD::DIN', 70524);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aranesp        -(Hsa-Free)', 'solution', 'B03XA02', false, 0, '02246360', 'FreeDiams::CA_HCDPD::DIN', 70526);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tranexamic Acid Injection Bp', 'solution', 'B02AA02', false, 0, '02246365', 'FreeDiams::CA_HCDPD::DIN', 70531);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clorox Clean-Up Disinfectant Bleach Cleaner', 'liquid', 'V07AV', false, 0, '02246368', 'FreeDiams::CA_HCDPD::DIN', 70535);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shiseido The Skincare Protective Lip Conditioner', 'stick', 'D02BA02', false, 0, '02246372', 'FreeDiams::CA_HCDPD::DIN', 70539);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ombrelle-Lotion Spf 45', 'lotion', 'D02BA30', false, 0, '02246374', 'FreeDiams::CA_HCDPD::DIN', 70541);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lysol Antibacterial Kitchen Cleaner', 'spray', 'V07AV', false, 0, '02246379', 'FreeDiams::CA_HCDPD::DIN', 70546);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunlight Antibacterial Dishwashing Liquid', 'solution', 'V07AV', false, 0, '02246380', 'FreeDiams::CA_HCDPD::DIN', 70547);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Febreze Antibacterial (Domestic)', 'spray', 'V07AV', false, 0, '02246382', 'FreeDiams::CA_HCDPD::DIN', 70549);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tilex Mold & Mildew Remover', 'spray', 'V07AV', false, 0, '02246384', 'FreeDiams::CA_HCDPD::DIN', 70551);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Commercial P-250 Pine Disinfectant', 'solution', 'V07AV', false, 0, '02246386', 'FreeDiams::CA_HCDPD::DIN', 70553);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tears Naturale Forte', 'solution', 'S01XA20', false, 0, '02246397', 'FreeDiams::CA_HCDPD::DIN', 70567);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advil Junior Strength Chewable Tablets', 'tablet (chewable)', 'M01AE01', false, 0, '02246403', 'FreeDiams::CA_HCDPD::DIN', 70575);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avelox I.V.', 'solution', 'J01MA14', false, 0, '02246414', 'FreeDiams::CA_HCDPD::DIN', 70586);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 15 Lip Balm', 'stick', 'D02BA30', false, 0, '02246416', 'FreeDiams::CA_HCDPD::DIN', 70588);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shear-X Tb Germicidal Detergent', 'liquid', 'V07AV', false, 0, '02246417', 'FreeDiams::CA_HCDPD::DIN', 70589);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multi San', 'solution', 'V07AV', false, 0, '02246426', 'FreeDiams::CA_HCDPD::DIN', 70599);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Keystone Foam Hand Sanitizer', 'liquid', 'D08AJ01', false, 0, '02246427', 'FreeDiams::CA_HCDPD::DIN', 70601);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Handclens', 'spray', 'D08AJ01', false, 0, '02246430', 'FreeDiams::CA_HCDPD::DIN', 70605);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Provocholine', 'powder for solution', 'V04CX', false, 0, '02246492', 'FreeDiams::CA_HCDPD::DIN', 70667);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Provocholine', 'powder for solution', 'V04CX', false, 0, '02246493', 'FreeDiams::CA_HCDPD::DIN', 70668);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minirin', 'tablet', 'H01BA02', false, 0, '02246500', 'FreeDiams::CA_HCDPD::DIN', 70677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Carvedilol Tablets', 'tablet', 'C07AG02', false, 0, '02246529', 'FreeDiams::CA_HCDPD::DIN', 70711);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Carvedilol Tablets', 'tablet', 'C07AG02', false, 0, '02246530', 'FreeDiams::CA_HCDPD::DIN', 70712);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Carvedilol Tablets', 'tablet', 'C07AG02', false, 0, '02246531', 'FreeDiams::CA_HCDPD::DIN', 70713);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Carvedilol Tablets', 'tablet', 'C07AG02', false, 0, '02246532', 'FreeDiams::CA_HCDPD::DIN', 70714);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Angiomax', 'powder for solution', 'B01AE06', false, 0, '02246533', 'FreeDiams::CA_HCDPD::DIN', 70715);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Zopiclone', 'tablet', 'N05CF01', false, 0, '02246534', 'FreeDiams::CA_HCDPD::DIN', 70717);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Lovastatin', 'tablet', 'C10AA02', false, 0, '02246543', 'FreeDiams::CA_HCDPD::DIN', 70725);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Lovastatin', 'tablet', 'C10AA02', false, 0, '02246542', 'FreeDiams::CA_HCDPD::DIN', 70726);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Terazosin', 'tablet', 'G04CA03', false, 0, '02246544', 'FreeDiams::CA_HCDPD::DIN', 70727);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Terazosin', 'tablet', 'G04CA03', false, 0, '02246545', 'FreeDiams::CA_HCDPD::DIN', 70728);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Terazosin', 'tablet', 'G04CA03', false, 0, '02246546', 'FreeDiams::CA_HCDPD::DIN', 70729);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Terazosin', 'tablet', 'G04CA03', false, 0, '02246547', 'FreeDiams::CA_HCDPD::DIN', 70730);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Remodulin', 'solution', 'B01AC21', false, 0, '02246552', 'FreeDiams::CA_HCDPD::DIN', 70735);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Remodulin', 'solution', 'B01AC21', false, 0, '02246553', 'FreeDiams::CA_HCDPD::DIN', 70736);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Remodulin', 'solution', 'B01AC21', false, 0, '02246554', 'FreeDiams::CA_HCDPD::DIN', 70737);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Remodulin', 'solution', 'B01AC21', false, 0, '02246555', 'FreeDiams::CA_HCDPD::DIN', 70738);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valtrex', 'tablet', 'J05AB11', false, 0, '02246559', 'FreeDiams::CA_HCDPD::DIN', 70742);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ifosfamide For Injection, Usp', 'powder for solution', 'L01AA06', false, 0, '02246565', 'FreeDiams::CA_HCDPD::DIN', 70748);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coversyl Plus Ld', 'tablet', 'C09BA04', false, 0, '02246568', 'FreeDiams::CA_HCDPD::DIN', 70751);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coversyl Plus', 'tablet', 'C09BA04', false, 0, '02246569', 'FreeDiams::CA_HCDPD::DIN', 70752);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('3 In 1 Disinfecting All Purpose And Glass Cleaner', 'solution', 'V07AV', false, 0, '02246578', 'FreeDiams::CA_HCDPD::DIN', 70765);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('No Name All Purpose Cleaner', 'liquid', 'V07AV', false, 0, '02246580', 'FreeDiams::CA_HCDPD::DIN', 70767);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Atenolol', 'tablet', 'C07AB03', false, 0, '02246581', 'FreeDiams::CA_HCDPD::DIN', 70768);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Simvastatin', 'tablet', 'C10AA01', false, 0, '02246582', 'FreeDiams::CA_HCDPD::DIN', 70769);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Simvastatin', 'tablet', 'C10AA01', false, 0, '02246583', 'FreeDiams::CA_HCDPD::DIN', 70770);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Simvastatin', 'tablet', 'C10AA01', false, 0, '02246584', 'FreeDiams::CA_HCDPD::DIN', 70771);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Simvastatin', 'tablet', 'C10AA01', false, 0, '02246585', 'FreeDiams::CA_HCDPD::DIN', 70772);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Citalopram', 'tablet', 'N06AB04', false, 0, '02246594', 'FreeDiams::CA_HCDPD::DIN', 70781);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Citalopram', 'tablet', 'N06AB04', false, 0, '02246595', 'FreeDiams::CA_HCDPD::DIN', 70782);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Norfloxacin', 'tablet', 'J01MA06', false, 0, '02246596', 'FreeDiams::CA_HCDPD::DIN', 70783);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pamidronate Disodium For Injection', 'solution', 'M05BA03', false, 0, '02246597', 'FreeDiams::CA_HCDPD::DIN', 70784);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pamidronate Disodium For Injection', 'solution', 'M05BA03', false, 0, '02246598', 'FreeDiams::CA_HCDPD::DIN', 70785);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pamidronate Disodium For Injection', 'solution', 'M05BA03', false, 0, '02246599', 'FreeDiams::CA_HCDPD::DIN', 70786);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neo Citran Colds & Flu', 'powder', 'N02BE51', false, 0, '02246602', 'FreeDiams::CA_HCDPD::DIN', 70790);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('No Name Foaming Bathroom Cleaner', 'aerosol', 'V07AV', false, 0, '02246616', 'FreeDiams::CA_HCDPD::DIN', 70804);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Foaming Bathroom Cleaner', 'aerosol', 'V07AV', false, 0, '02246617', 'FreeDiams::CA_HCDPD::DIN', 70805);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xalacom', 'solution', 'S01ED51', false, 0, '02246619', 'FreeDiams::CA_HCDPD::DIN', 70807);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fluconazole-150', 'capsule', 'J02AC01', false, 0, '02246620', 'FreeDiams::CA_HCDPD::DIN', 70808);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coversyl (8mg Tablet)', 'tablet', 'C09AA04', false, 0, '02246624', 'FreeDiams::CA_HCDPD::DIN', 70814);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Medroxyprogesterone', 'tablet', 'G03DA02', false, 0, '02246627', 'FreeDiams::CA_HCDPD::DIN', 70819);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Medroxyprogesterone', 'tablet', 'G03DA02', false, 0, '02246628', 'FreeDiams::CA_HCDPD::DIN', 70820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Medroxyprogesterone', 'tablet', 'G03DA02', false, 0, '02246629', 'FreeDiams::CA_HCDPD::DIN', 70821);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stoko Refresh Antibacterial Foam Soap', 'liquid', 'D08AE04', false, 0, '02246633', 'FreeDiams::CA_HCDPD::DIN', 70825);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piperacillin For Injection', 'powder for solution', 'J01CA12', false, 0, '02246640', 'FreeDiams::CA_HCDPD::DIN', 70832);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piperacillin For Injection', 'powder for solution', 'J01CA12', false, 0, '02246641', 'FreeDiams::CA_HCDPD::DIN', 70833);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piperacillin For Injection', 'powder for solution', 'J01CA12', false, 0, '02246642', 'FreeDiams::CA_HCDPD::DIN', 70834);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tb Minuteman', 'liquid', 'V07AV', false, 0, '02246644', 'FreeDiams::CA_HCDPD::DIN', 70836);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prodiem Bulk Fibre Therapy', 'tablet', 'A06AC08', false, 0, '02246645', 'FreeDiams::CA_HCDPD::DIN', 70837);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen For Body Spf 30', 'lotion', 'D02BA30', false, 0, '02246662', 'FreeDiams::CA_HCDPD::DIN', 70856);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 20 Sports Blend', 'lotion', 'D02BA30', false, 0, '02246683', 'FreeDiams::CA_HCDPD::DIN', 70878);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 8 Sun Protection For All Seasons', 'lotion', 'D02BA30', false, 0, '02246684', 'FreeDiams::CA_HCDPD::DIN', 70879);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Sun Protection For All Seasons', 'lotion', 'D02BA30', false, 0, '02246685', 'FreeDiams::CA_HCDPD::DIN', 70880);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elizabeth Arden Extreme Conditioning Cream', 'cream', 'D02BA30', false, 0, '02246686', 'FreeDiams::CA_HCDPD::DIN', 70881);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Hydroxyquine', 'tablet', 'P01BA02', false, 0, '02246691', 'FreeDiams::CA_HCDPD::DIN', 70886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triple Antibiotic Ointment', 'ointment', 'D06AX30', false, 0, '02246693', 'FreeDiams::CA_HCDPD::DIN', 70888);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Calamine Lotion With Antihistamine', 'lotion', 'D04AA32', false, 0, '02246696', 'FreeDiams::CA_HCDPD::DIN', 70891);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Naproxen Ec Tablets', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02246699', 'FreeDiams::CA_HCDPD::DIN', 70894);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Naproxen Ec Tablets', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02246700', 'FreeDiams::CA_HCDPD::DIN', 70895);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Naproxen Ec Tablets', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02246701', 'FreeDiams::CA_HCDPD::DIN', 70896);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Day Cream Spf 15', 'cream', 'D02BA30', false, 0, '02246708', 'FreeDiams::CA_HCDPD::DIN', 70903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Youthful Look', 'cream', 'D02BA30', false, 0, '02246709', 'FreeDiams::CA_HCDPD::DIN', 70904);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Amcinonide', 'cream', 'D07AC11', false, 0, '02246714', 'FreeDiams::CA_HCDPD::DIN', 70909);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gambrosol Trio 10', 'solution', 'B05ZA', false, 0, '02246719', 'FreeDiams::CA_HCDPD::DIN', 70916);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gambrosol Trio 40', 'solution', 'B05ZA', false, 0, '02246720', 'FreeDiams::CA_HCDPD::DIN', 70917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Simvastatin', 'tablet', 'C10AA01', false, 0, '02246737', 'FreeDiams::CA_HCDPD::DIN', 70934);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Docusate Calcium', 'capsule', 'A06AA02', false, 0, '02246741', 'FreeDiams::CA_HCDPD::DIN', 70938);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibacterial', 'liquid', 'D08AE05', false, 0, '02246752', 'FreeDiams::CA_HCDPD::DIN', 70951);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Lip Conditioner Spf 15', 'stick', 'D02BA02', false, 0, '02246781', 'FreeDiams::CA_HCDPD::DIN', 70981);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spiriva', 'capsule', 'R03BB04', false, 0, '02246793', 'FreeDiams::CA_HCDPD::DIN', 70993);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ketamine Hydrochloride Injection Usp', 'solution', 'N01AX03', false, 0, '02246795', 'FreeDiams::CA_HCDPD::DIN', 70995);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ketamine Hydrochloride Injection Usp', 'solution', 'N01AX03', false, 0, '02246796', 'FreeDiams::CA_HCDPD::DIN', 70996);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prescriptives Incredible Sheer Lipcolor Spf 15', 'stick', 'D02BA02', false, 0, '02246797', 'FreeDiams::CA_HCDPD::DIN', 70997);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ombrelle-Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02246798', 'FreeDiams::CA_HCDPD::DIN', 70998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ombrelle-Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02246799', 'FreeDiams::CA_HCDPD::DIN', 70999);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levaquin 750mg', 'tablet', 'J01MA12', false, 0, '02246804', 'FreeDiams::CA_HCDPD::DIN', 71004);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Thymoglobulin', 'powder for solution', 'L04AA04', false, 0, '02246805', 'FreeDiams::CA_HCDPD::DIN', 71005);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Metformin Fc', 'tablet', 'A10BA02', false, 0, '02246820', 'FreeDiams::CA_HCDPD::DIN', 71020);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Metformin Fc', 'tablet', 'A10BA02', false, 0, '02246821', 'FreeDiams::CA_HCDPD::DIN', 71021);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02246825', 'FreeDiams::CA_HCDPD::DIN', 71025);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02246826', 'FreeDiams::CA_HCDPD::DIN', 71026);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02246827', 'FreeDiams::CA_HCDPD::DIN', 71027);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('D.Cide', 'solution', 'V07AV', false, 0, '02246831', 'FreeDiams::CA_HCDPD::DIN', 71031);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medicament Sinus Pour La Nuit Extra-Fort', 'tablet', 'N02BE51', false, 0, '02246847', 'FreeDiams::CA_HCDPD::DIN', 71047);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hot Lemon Relief For Symptoms Of Cough, Cold And Flu Extra Strength', 'powder', 'N02BE51', false, 0, '02246848', 'FreeDiams::CA_HCDPD::DIN', 71050);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Docusate Sodium', 'syrup', 'A06AA02', false, 0, '02246854', 'FreeDiams::CA_HCDPD::DIN', 71056);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Feno-Super', 'tablet', 'C10AB05', false, 0, '02246859', 'FreeDiams::CA_HCDPD::DIN', 71082);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Feno-Super', 'tablet', 'C10AB05', false, 0, '02246860', 'FreeDiams::CA_HCDPD::DIN', 71083);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oasis 299', 'solution', 'V07AV', false, 0, '02246862', 'FreeDiams::CA_HCDPD::DIN', 71086);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coricidin Ii Chest Congestion And Cough', 'capsule', 'R05FA02', false, 0, '02246866', 'FreeDiams::CA_HCDPD::DIN', 71091);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coricidin Ii Cold And Flu', 'tablet', 'N02BE51', false, 0, '02246869', 'FreeDiams::CA_HCDPD::DIN', 71094);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Daywear Plus Multiprotection Creme Spf 15 For Normal/Combination Skin', 'cream', 'D02BA30', false, 0, '02246873', 'FreeDiams::CA_HCDPD::DIN', 71098);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Daywear Plus Multiprotection Creme Spf 15 For Dry Skin', 'cream', 'D02BA30', false, 0, '02246874', 'FreeDiams::CA_HCDPD::DIN', 71099);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Daywear Plus Multiprotection Lotion Spf 15 For Oily Skin', 'lotion', 'D02BA30', false, 0, '02246875', 'FreeDiams::CA_HCDPD::DIN', 71100);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Daywear Plus Multiprotection Moisturizer Sheer Tint Release Formula Spf 15 For All Skin Types', 'cream', 'D02BA30', false, 0, '02246876', 'FreeDiams::CA_HCDPD::DIN', 71101);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avagard Chg', 'lotion', 'D08AC52', false, 0, '02246888', 'FreeDiams::CA_HCDPD::DIN', 71113);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Verap Sr', 'tablet (extended-release)', 'C08DA01', false, 0, '02246893', 'FreeDiams::CA_HCDPD::DIN', 71120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Verap Sr', 'tablet (extended-release)', 'C08DA01', false, 0, '02246894', 'FreeDiams::CA_HCDPD::DIN', 71121);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Verap Sr', 'tablet (extended-release)', 'C08DA01', false, 0, '02246895', 'FreeDiams::CA_HCDPD::DIN', 71122);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actonel', 'tablet', 'M05BA07', false, 0, '02246896', 'FreeDiams::CA_HCDPD::DIN', 71123);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lamotrigine', 'tablet', 'N03AX09', false, 0, '02246897', 'FreeDiams::CA_HCDPD::DIN', 71124);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lamotrigine', 'tablet', 'N03AX09', false, 0, '02246898', 'FreeDiams::CA_HCDPD::DIN', 71125);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lamotrigine', 'tablet', 'N03AX09', false, 0, '02246899', 'FreeDiams::CA_HCDPD::DIN', 71126);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accel Tb', 'liquid', 'V07AV', false, 0, '02246903', 'FreeDiams::CA_HCDPD::DIN', 71130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bobbi Brown Lip Balm Spf 15', 'ointment', 'D02BA30', false, 0, '02246921', 'FreeDiams::CA_HCDPD::DIN', 71148);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Complete Multi-Purpose Solution', 'solution', 'S01XA20', false, 0, '02246923', 'FreeDiams::CA_HCDPD::DIN', 71150);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Pravastatin', 'tablet', 'C10AA03', false, 0, '02246930', 'FreeDiams::CA_HCDPD::DIN', 71157);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Pravastatin', 'tablet', 'C10AA03', false, 0, '02246931', 'FreeDiams::CA_HCDPD::DIN', 71158);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Pravastatin', 'tablet', 'C10AA03', false, 0, '02246932', 'FreeDiams::CA_HCDPD::DIN', 71159);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Allergy Formula', 'syrup', 'R06AA02', false, 0, '02246936', 'FreeDiams::CA_HCDPD::DIN', 71163);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stanhexidine Aqueous 2% With 4% Isopropyl Alcohol', 'solution', 'D08AC02', false, 0, '02246950', 'FreeDiams::CA_HCDPD::DIN', 71177);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Senna S. Tablets', 'tablet', 'A06AB56', false, 0, '02246951', 'FreeDiams::CA_HCDPD::DIN', 71178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amiodarone For Injection 50mg/Ml', 'solution', 'C01BD01', false, 0, '02246953', 'FreeDiams::CA_HCDPD::DIN', 71180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diovan-Hct 160/25mg', 'tablet', 'C09DA03', false, 0, '02246955', 'FreeDiams::CA_HCDPD::DIN', 71182);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Lamotrigine', 'tablet', 'N03AX09', false, 0, '02246963', 'FreeDiams::CA_HCDPD::DIN', 71190);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Metformin', 'tablet', 'A10BA02', false, 0, '02246964', 'FreeDiams::CA_HCDPD::DIN', 71193);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metformin', 'tablet', 'A10BA02', false, 0, '02246965', 'FreeDiams::CA_HCDPD::DIN', 71194);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methocarbamol Omega', 'liquid', 'M03BA03', false, 0, '02246966', 'FreeDiams::CA_HCDPD::DIN', 71195);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Estradiol Derm 50', 'patch', 'G03CA03', false, 0, '02246967', 'FreeDiams::CA_HCDPD::DIN', 71196);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Estradiol Derm 75', 'patch', 'G03CA03', false, 0, '02246968', 'FreeDiams::CA_HCDPD::DIN', 71197);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Estradiol Derm 100', 'patch', 'G03CA03', false, 0, '02246969', 'FreeDiams::CA_HCDPD::DIN', 71198);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Entex La', 'tablet (extended-release)', 'R05CA10', false, 0, '02246971', 'FreeDiams::CA_HCDPD::DIN', 71201);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Psoriasin Liquid', 'solution', 'D05AA', false, 0, '02246974', 'FreeDiams::CA_HCDPD::DIN', 71204);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('3m Bathroom Disinfectant Cleaner Concentrate', 'liquid', 'V07AV', false, 0, '02246979', 'FreeDiams::CA_HCDPD::DIN', 71209);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Lovastatin', 'tablet', 'C10AA02', false, 0, '02246989', 'FreeDiams::CA_HCDPD::DIN', 71221);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Lovastatin', 'tablet', 'C10AA02', false, 0, '02246990', 'FreeDiams::CA_HCDPD::DIN', 71222);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Methylphenidate', 'tablet', 'N06BA04', false, 0, '02246991', 'FreeDiams::CA_HCDPD::DIN', 71223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daily Moisturizing Cream Spf 15', 'cream', 'D02BA30', false, 0, '02246994', 'FreeDiams::CA_HCDPD::DIN', 71227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pravastatin Tablets', 'tablet', 'C10AA03', false, 0, '02247008', 'FreeDiams::CA_HCDPD::DIN', 71241);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pravastatin Tablets', 'tablet', 'C10AA03', false, 0, '02247009', 'FreeDiams::CA_HCDPD::DIN', 71242);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Pravastatin Tablets', 'tablet', 'C10AA03', false, 0, '02247010', 'FreeDiams::CA_HCDPD::DIN', 71243);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Simvastatin', 'tablet', 'C10AA01', false, 0, '02247011', 'FreeDiams::CA_HCDPD::DIN', 71245);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Simvastatin', 'tablet', 'C10AA01', false, 0, '02247012', 'FreeDiams::CA_HCDPD::DIN', 71246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Simvastatin', 'tablet', 'C10AA01', false, 0, '02247013', 'FreeDiams::CA_HCDPD::DIN', 71247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Simvastatin', 'tablet', 'C10AA01', false, 0, '02247014', 'FreeDiams::CA_HCDPD::DIN', 71248);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Simvastatin', 'tablet', 'C10AA01', false, 0, '02247015', 'FreeDiams::CA_HCDPD::DIN', 71249);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Aclavulanate', 'tablet', 'J01CR02', false, 0, '02247021', 'FreeDiams::CA_HCDPD::DIN', 71255);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desferrioxamine Mesilate For Injection', 'powder for solution', 'V03AC01', false, 0, '02247022', 'FreeDiams::CA_HCDPD::DIN', 71256);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Keppra', 'tablet', 'N03AX14', false, 0, '02247027', 'FreeDiams::CA_HCDPD::DIN', 71262);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Keppra', 'tablet', 'N03AX14', false, 0, '02247028', 'FreeDiams::CA_HCDPD::DIN', 71263);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Keppra', 'tablet', 'N03AX14', false, 0, '02247029', 'FreeDiams::CA_HCDPD::DIN', 71264);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nature''S Cure Acne Treatment', 'cream', 'D10AE01', false, 0, '02247035', 'FreeDiams::CA_HCDPD::DIN', 71270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Liquid Allergy Formula', 'liquid', 'R06AA02', false, 0, '02247037', 'FreeDiams::CA_HCDPD::DIN', 71272);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cellular Day Defense Firming Complex Spf 15', 'cream', 'D02BA30', false, 0, '02247042', 'FreeDiams::CA_HCDPD::DIN', 71277);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soft Care Nutra-Germ Antibacterial Lotion Soap', 'liquid', 'D08AE04', false, 0, '02247049', 'FreeDiams::CA_HCDPD::DIN', 71282);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Sertraline Capsules', 'capsule', 'N06AB06', false, 0, '02247047', 'FreeDiams::CA_HCDPD::DIN', 71283);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Sertraline Capsules', 'capsule', 'N06AB06', false, 0, '02247048', 'FreeDiams::CA_HCDPD::DIN', 71284);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Sertraline Capsules', 'capsule', 'N06AB06', false, 0, '02247050', 'FreeDiams::CA_HCDPD::DIN', 71285);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Fluvoxamine', 'tablet', 'N06AB08', false, 0, '02247054', 'FreeDiams::CA_HCDPD::DIN', 71289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Fluvoxamine', 'tablet', 'N06AB08', false, 0, '02247055', 'FreeDiams::CA_HCDPD::DIN', 71290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Lovastatin', 'tablet', 'C10AA02', false, 0, '02247056', 'FreeDiams::CA_HCDPD::DIN', 71291);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Lovastatin', 'tablet', 'C10AA02', false, 0, '02247057', 'FreeDiams::CA_HCDPD::DIN', 71292);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Simvastatin', 'tablet', 'C10AA01', false, 0, '02247067', 'FreeDiams::CA_HCDPD::DIN', 71302);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Simvastatin', 'tablet', 'C10AA01', false, 0, '02247068', 'FreeDiams::CA_HCDPD::DIN', 71303);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Simvastatin', 'tablet', 'C10AA01', false, 0, '02247069', 'FreeDiams::CA_HCDPD::DIN', 71304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Simvastatin', 'tablet', 'C10AA01', false, 0, '02247070', 'FreeDiams::CA_HCDPD::DIN', 71305);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Simvastatin', 'tablet', 'C10AA01', false, 0, '02247071', 'FreeDiams::CA_HCDPD::DIN', 71306);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Simvastatin Tablets', 'tablet', 'C10AA01', false, 0, '02247072', 'FreeDiams::CA_HCDPD::DIN', 71307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Cyclosporine', 'capsule', 'L04AD01', false, 0, '02247073', 'FreeDiams::CA_HCDPD::DIN', 71308);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Cyclosporine', 'capsule', 'L04AD01', false, 0, '02247074', 'FreeDiams::CA_HCDPD::DIN', 71309);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Simvastatin Tablets', 'tablet', 'C10AA01', false, 0, '02247075', 'FreeDiams::CA_HCDPD::DIN', 71310);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Simvastatin Tablets', 'tablet', 'C10AA01', false, 0, '02247076', 'FreeDiams::CA_HCDPD::DIN', 71311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Simvastatin Tablets', 'tablet', 'C10AA01', false, 0, '02247077', 'FreeDiams::CA_HCDPD::DIN', 71312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Simvastatin Tablets', 'tablet', 'C10AA01', false, 0, '02247078', 'FreeDiams::CA_HCDPD::DIN', 71313);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio Klean', 'liquid', 'V07AV', false, 0, '02247083', 'FreeDiams::CA_HCDPD::DIN', 71318);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avandamet', 'tablet', 'A10BD03', false, 0, '02247085', 'FreeDiams::CA_HCDPD::DIN', 71322);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avandamet', 'tablet', 'A10BD03', false, 0, '02247086', 'FreeDiams::CA_HCDPD::DIN', 71323);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avandamet', 'tablet', 'A10BD03', false, 0, '02247087', 'FreeDiams::CA_HCDPD::DIN', 71324);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Bismuth', 'liquid', 'A07BB', false, 0, '02247094', 'FreeDiams::CA_HCDPD::DIN', 71331);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Amcinonide Ointment 0.1%', 'ointment', 'D07AC11', false, 0, '02247096', 'FreeDiams::CA_HCDPD::DIN', 71333);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Amcinonide Lotion 0.1%', 'lotion', 'D07AC11', false, 0, '02247097', 'FreeDiams::CA_HCDPD::DIN', 71334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Amcinonide Cream 0.1%', 'cream', 'D07AC11', false, 0, '02247098', 'FreeDiams::CA_HCDPD::DIN', 71335);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyprexa Intramuscular', 'powder for solution', 'N05AH03', false, 0, '02247099', 'FreeDiams::CA_HCDPD::DIN', 71336);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stoko Spray Antibacterial Cleanser', 'liquid', 'D08AE04', false, 0, '02247100', 'FreeDiams::CA_HCDPD::DIN', 71337);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Periostat', 'capsule', 'A01AB22', false, 0, '02247104', 'FreeDiams::CA_HCDPD::DIN', 71343);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rapamune', 'tablet', 'L04AA10', false, 0, '02247111', 'FreeDiams::CA_HCDPD::DIN', 71350);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solo-Care Aqua', 'solution', 'S01XA20', false, 0, '02247116', 'FreeDiams::CA_HCDPD::DIN', 71357);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maple Treatment Hand Cream Spf 20', 'cream', 'D02BA30', false, 0, '02247119', 'FreeDiams::CA_HCDPD::DIN', 71359);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Strength Ovol', 'tablet', 'A03AX13', false, 0, '02247127', 'FreeDiams::CA_HCDPD::DIN', 71367);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Viread', 'tablet', 'J05AF07', false, 0, '02247128', 'FreeDiams::CA_HCDPD::DIN', 71368);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xigris (5mg/Vial)', 'powder for solution', 'B01AD10', false, 0, '02247129', 'FreeDiams::CA_HCDPD::DIN', 71369);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xigris  (20mg/Vial)', 'powder for solution', 'B01AD10', false, 0, '02247130', 'FreeDiams::CA_HCDPD::DIN', 71370);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Senna Laxative And Docusate Sodium Tablets', 'tablet', 'A06AB56', false, 0, '02247134', 'FreeDiams::CA_HCDPD::DIN', 71374);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 15', 'lotion', 'D02BA30', false, 0, '02247141', 'FreeDiams::CA_HCDPD::DIN', 71382);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30', 'lotion', 'D02BA30', false, 0, '02247142', 'FreeDiams::CA_HCDPD::DIN', 71383);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 45', 'lotion', 'D02BA30', false, 0, '02247143', 'FreeDiams::CA_HCDPD::DIN', 71384);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Sport Lotion 30 Spf', 'lotion', 'D02BA30', false, 0, '02247145', 'FreeDiams::CA_HCDPD::DIN', 71386);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robax Platinum', 'tablet', 'M03BA53', false, 0, '02247147', 'FreeDiams::CA_HCDPD::DIN', 71388);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diabetic Basics Brand Antiseptic Skin Cleansing Instant Foot Sanitizer', 'spray', 'D08AJ01', false, 0, '02247154', 'FreeDiams::CA_HCDPD::DIN', 71395);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diabetic Basics Brand Antiseptic Powder For Feet', 'powder', 'D08AJ01', false, 0, '02247155', 'FreeDiams::CA_HCDPD::DIN', 71396);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diabetic Basics Brand Antiseptic Skin Cleansing Foot And Body Lotion', 'lotion', 'D08AJ01', false, 0, '02247156', 'FreeDiams::CA_HCDPD::DIN', 71397);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crestor - 10mg', 'tablet', 'C10AA07', false, 0, '02247162', 'FreeDiams::CA_HCDPD::DIN', 71404);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crestor - 20mg', 'tablet', 'C10AA07', false, 0, '02247163', 'FreeDiams::CA_HCDPD::DIN', 71405);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crestor - 40mg', 'tablet', 'C10AA07', false, 0, '02247164', 'FreeDiams::CA_HCDPD::DIN', 71406);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-Amitriptyline', 'tablet', 'N06AA09', false, 0, '02247166', 'FreeDiams::CA_HCDPD::DIN', 71408);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-Amitriptyline', 'tablet', 'N06AA09', false, 0, '02247167', 'FreeDiams::CA_HCDPD::DIN', 71409);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-Amitriptyline', 'tablet', 'N06AA09', false, 0, '02247168', 'FreeDiams::CA_HCDPD::DIN', 71411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-Hydrochlorothiazide', 'tablet', 'C03AA03', false, 0, '02247170', 'FreeDiams::CA_HCDPD::DIN', 71412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-Hydrochlorothiazide', 'tablet', 'C03AA03', false, 0, '02247171', 'FreeDiams::CA_HCDPD::DIN', 71413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-Diazepam', 'tablet', 'N05BA01', false, 0, '02247173', 'FreeDiams::CA_HCDPD::DIN', 71416);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-Diazepam', 'tablet', 'N05BA01', false, 0, '02247174', 'FreeDiams::CA_HCDPD::DIN', 71417);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-Diazepam', 'tablet', 'N05BA01', false, 0, '02247176', 'FreeDiams::CA_HCDPD::DIN', 71418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-Oxazepam', 'tablet', 'N05BA04', false, 0, '02247177', 'FreeDiams::CA_HCDPD::DIN', 71419);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-Oxazepam', 'tablet', 'N05BA04', false, 0, '02247178', 'FreeDiams::CA_HCDPD::DIN', 71420);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-Oxazepam', 'tablet', 'N05BA04', false, 0, '02247179', 'FreeDiams::CA_HCDPD::DIN', 71421);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Atenolol', 'tablet', 'C07AB03', false, 0, '02247182', 'FreeDiams::CA_HCDPD::DIN', 71424);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fibre Laxative', 'tablet', 'A06AC08', false, 0, '02247187', 'FreeDiams::CA_HCDPD::DIN', 71429);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aerius Kids', 'syrup', 'R06AX27', false, 0, '02247193', 'FreeDiams::CA_HCDPD::DIN', 71435);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dukoral', 'suspension', 'J07AE01', false, 0, '02247208', 'FreeDiams::CA_HCDPD::DIN', 71450);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Amiodarone', 'tablet', 'C01BD01', false, 0, '02247217', 'FreeDiams::CA_HCDPD::DIN', 71459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simvastatin-10', 'tablet', 'C10AA01', false, 0, '02247221', 'FreeDiams::CA_HCDPD::DIN', 71463);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simvastatin-20', 'tablet', 'C10AA01', false, 0, '02247222', 'FreeDiams::CA_HCDPD::DIN', 71464);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simvastatin-40', 'tablet', 'C10AA01', false, 0, '02247223', 'FreeDiams::CA_HCDPD::DIN', 71465);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simvastatin-80', 'tablet', 'C10AA01', false, 0, '02247224', 'FreeDiams::CA_HCDPD::DIN', 71466);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stieprox Shampoo', 'shampoo', 'D01AE14', false, 0, '02247228', 'FreeDiams::CA_HCDPD::DIN', 71470);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Clobazam', 'tablet', 'N05BA09', false, 0, '02247230', 'FreeDiams::CA_HCDPD::DIN', 71472);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Lovastatin', 'tablet', 'C10AA02', false, 0, '02247231', 'FreeDiams::CA_HCDPD::DIN', 71473);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Lovastatin', 'tablet', 'C10AA02', false, 0, '02247232', 'FreeDiams::CA_HCDPD::DIN', 71474);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elidel', 'cream', 'D11AH02', false, 0, '02247238', 'FreeDiams::CA_HCDPD::DIN', 71480);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gen-Clozapine', 'tablet', 'N05AH02', false, 0, '02247243', 'FreeDiams::CA_HCDPD::DIN', 71485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gen-Clozapine', 'tablet', 'N05AH02', false, 0, '02247244', 'FreeDiams::CA_HCDPD::DIN', 71486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Indapamide 1.25', 'tablet', 'C03BA11', false, 0, '02247245', 'FreeDiams::CA_HCDPD::DIN', 71487);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Complete Plus Ultra Rich Uv Moisturizer', 'lotion', 'D02BA30', false, 0, '02247260', 'FreeDiams::CA_HCDPD::DIN', 71503);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pennsaid', 'solution', 'M02AA15', false, 0, '02247265', 'FreeDiams::CA_HCDPD::DIN', 71508);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sanni Rinse', 'liquid', 'V07AV', false, 0, '02247279', 'FreeDiams::CA_HCDPD::DIN', 71522);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sure 5', 'liquid', 'V07AV', false, 0, '02247280', 'FreeDiams::CA_HCDPD::DIN', 71523);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Microcide Disinfectant Cleaner', 'solution', 'V07AV', false, 0, '02247285', 'FreeDiams::CA_HCDPD::DIN', 71528);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zoom Protective Lip Cream', 'cream', 'D02BA30', false, 0, '02247291', 'FreeDiams::CA_HCDPD::DIN', 71534);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Simvastatin', 'tablet', 'C10AA01', false, 0, '02247297', 'FreeDiams::CA_HCDPD::DIN', 71540);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Simvastatin', 'tablet', 'C10AA01', false, 0, '02247298', 'FreeDiams::CA_HCDPD::DIN', 71541);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Simvastatin', 'tablet', 'C10AA01', false, 0, '02247299', 'FreeDiams::CA_HCDPD::DIN', 71542);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Simvastatin', 'tablet', 'C10AA01', false, 0, '02247300', 'FreeDiams::CA_HCDPD::DIN', 71543);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Simvastatin', 'tablet', 'C10AA01', false, 0, '02247301', 'FreeDiams::CA_HCDPD::DIN', 71544);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Amitriptyline', 'tablet', 'N06AA09', false, 0, '02247302', 'FreeDiams::CA_HCDPD::DIN', 71545);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Amitriptyline', 'tablet', 'N06AA09', false, 0, '02247303', 'FreeDiams::CA_HCDPD::DIN', 71546);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Amitriptyline', 'tablet', 'N06AA09', false, 0, '02247304', 'FreeDiams::CA_HCDPD::DIN', 71547);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vir-Kil', 'powder', 'V07AV', false, 0, '02247305', 'FreeDiams::CA_HCDPD::DIN', 71548);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Fenofibrate Micro', 'capsule', 'C10AB05', false, 0, '02247306', 'FreeDiams::CA_HCDPD::DIN', 71549);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Twinject 0.3mg Auto-Injector', 'solution', 'C01CA24', false, 0, '02247310', 'FreeDiams::CA_HCDPD::DIN', 71553);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rolaids Extra Strength Multi-Symptom Tablets', 'tablet', 'A02AF02', false, 0, '02247314', 'FreeDiams::CA_HCDPD::DIN', 71557);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Asa', 'tablet', 'N02BA01', false, 0, '02247318', 'FreeDiams::CA_HCDPD::DIN', 71561);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proctol Ointment', 'ointment', 'C05AA01', false, 0, '02247322', 'FreeDiams::CA_HCDPD::DIN', 71565);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Eti-Cal Carepac', 'kit', 'M05BB01', false, 0, '02247323', 'FreeDiams::CA_HCDPD::DIN', 71566);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Ciprofloxacin Tablet, 250mg', 'tablet', 'J01MA02', false, 0, '02247339', 'FreeDiams::CA_HCDPD::DIN', 71582);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Ciprofloxacin Tablet, 500mg', 'tablet', 'J01MA02', false, 0, '02247340', 'FreeDiams::CA_HCDPD::DIN', 71583);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Ciprofloxacin Tablet, 750mg', 'tablet', 'J01MA02', false, 0, '02247341', 'FreeDiams::CA_HCDPD::DIN', 71584);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Motrin Chewable Tablets', 'tablet', 'M01AE01', false, 0, '02247343', 'FreeDiams::CA_HCDPD::DIN', 71586);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Junior Strength Motrin Chewable Tablets', 'tablet', 'M01AE01', false, 0, '02247344', 'FreeDiams::CA_HCDPD::DIN', 71587);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Gabapentin', 'tablet', 'N03AX12', false, 0, '02247346', 'FreeDiams::CA_HCDPD::DIN', 71589);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ndd-900', 'solution', 'V07AV', false, 0, '02247352', 'FreeDiams::CA_HCDPD::DIN', 71597);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ds-911', 'solution', 'V07AV', false, 0, '02247353', 'FreeDiams::CA_HCDPD::DIN', 71598);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Asa E.C.', 'tablet (delayed-release)', 'N02BA01', false, 0, '02247355', 'FreeDiams::CA_HCDPD::DIN', 71600);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Methylphenidate', 'tablet', 'N06BA04', false, 0, '02247364', 'FreeDiams::CA_HCDPD::DIN', 71609);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elizabeth Arden Flawless Finish Bare Perfection Makeup', 'cream', 'D02BA02', false, 0, '02247369', 'FreeDiams::CA_HCDPD::DIN', 71614);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-Furosemide', 'tablet', 'C03CA01', false, 0, '02247371', 'FreeDiams::CA_HCDPD::DIN', 71616);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-Furosemide', 'tablet', 'C03CA01', false, 0, '02247372', 'FreeDiams::CA_HCDPD::DIN', 71617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Alendronate', 'tablet', 'M05BA04', false, 0, '02247373', 'FreeDiams::CA_HCDPD::DIN', 71618);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euro-Lac', 'solution', 'A06AD11', false, 0, '02247383', 'FreeDiams::CA_HCDPD::DIN', 71628);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euro-Docusate Capsules', 'capsule', 'A06AA02', false, 0, '02247385', 'FreeDiams::CA_HCDPD::DIN', 71630);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Hydrochlorothiazide', 'tablet', 'C03AA03', false, 0, '02247386', 'FreeDiams::CA_HCDPD::DIN', 71631);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Hydrochlorothiazide', 'tablet', 'C03AA03', false, 0, '02247387', 'FreeDiams::CA_HCDPD::DIN', 71632);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euro-Senna S.', 'tablet', 'A06AB56', false, 0, '02247390', 'FreeDiams::CA_HCDPD::DIN', 71635);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun And Snow Sport Spray Spf 30', 'spray', 'D02BA30', false, 0, '02247403', 'FreeDiams::CA_HCDPD::DIN', 71649);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun And Snow Sport Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02247404', 'FreeDiams::CA_HCDPD::DIN', 71650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Azithromycin', 'tablet', 'J01FA10', false, 0, '02247423', 'FreeDiams::CA_HCDPD::DIN', 71669);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Invanz', 'powder for solution', 'J01DH03', false, 0, '02247437', 'FreeDiams::CA_HCDPD::DIN', 71683);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Bisoprolol', 'tablet', 'C07AB07', false, 0, '02247439', 'FreeDiams::CA_HCDPD::DIN', 71685);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Bisoprolol', 'tablet', 'C07AB07', false, 0, '02247440', 'FreeDiams::CA_HCDPD::DIN', 71686);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Agentquat', 'liquid', 'V07AV', false, 0, '02247452', 'FreeDiams::CA_HCDPD::DIN', 71698);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chorionic Gonadotropin For Injection, Usp', 'powder for solution', 'G03GA01', false, 0, '02247459', 'FreeDiams::CA_HCDPD::DIN', 71705);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ketorolac', 'solution', 'S01BC05', false, 0, '02247461', 'FreeDiams::CA_HCDPD::DIN', 71709);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Leminee 64', 'solution', 'V07AV', false, 0, '02247465', 'FreeDiams::CA_HCDPD::DIN', 71713);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pine Cleaner', 'liquid', 'V07AV', false, 0, '02247470', 'FreeDiams::CA_HCDPD::DIN', 71718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Fenofibrate Micro', 'capsule', 'C10AB05', false, 0, '02247489', 'FreeDiams::CA_HCDPD::DIN', 71739);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diazepam', 'tablet', 'N05BA01', false, 0, '02247490', 'FreeDiams::CA_HCDPD::DIN', 71740);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diazepam', 'tablet', 'N05BA01', false, 0, '02247491', 'FreeDiams::CA_HCDPD::DIN', 71741);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diazepam', 'tablet', 'N05BA01', false, 0, '02247492', 'FreeDiams::CA_HCDPD::DIN', 71742);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Furosemide', 'tablet', 'C03CA01', false, 0, '02247493', 'FreeDiams::CA_HCDPD::DIN', 71743);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Furosemide', 'tablet', 'C03CA01', false, 0, '02247494', 'FreeDiams::CA_HCDPD::DIN', 71744);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyanocobalamin Injection Usp, 1000mcg/Ml', 'liquid', 'B03BA01', false, 0, '02247496', 'FreeDiams::CA_HCDPD::DIN', 71746);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Climara 25', 'patch', 'G03CA03', false, 0, '02247499', 'FreeDiams::CA_HCDPD::DIN', 71749);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Climara 75', 'patch', 'G03CA03', false, 0, '02247500', 'FreeDiams::CA_HCDPD::DIN', 71750);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zinc Zap Cream', 'cream', 'D11AX12', false, 0, '02247517', 'FreeDiams::CA_HCDPD::DIN', 71767);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ezetrol', 'tablet', 'C10AX09', false, 0, '02247521', 'FreeDiams::CA_HCDPD::DIN', 71771);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Murine', 'solution', 'S01XA20', false, 0, '02247538', 'FreeDiams::CA_HCDPD::DIN', 71788);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asaphen Ec', 'tablet (delayed-release)', 'B01AC06', false, 0, '02247550', 'FreeDiams::CA_HCDPD::DIN', 71800);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Reducer', 'tablet', 'A02BA02', false, 0, '02247551', 'FreeDiams::CA_HCDPD::DIN', 71801);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Itch Cream', 'cream', 'D04AA32', false, 0, '02247560', 'FreeDiams::CA_HCDPD::DIN', 71812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Clarithromycin', 'tablet', 'J01FA09', false, 0, '02247573', 'FreeDiams::CA_HCDPD::DIN', 71828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Clarithromycin', 'tablet', 'J01FA09', false, 0, '02247574', 'FreeDiams::CA_HCDPD::DIN', 71829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Medroxyprogesterone', 'tablet', 'G03DA02', false, 0, '02247581', 'FreeDiams::CA_HCDPD::DIN', 71837);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Medroxyprogesterone', 'tablet', 'G03DA02', false, 0, '02247582', 'FreeDiams::CA_HCDPD::DIN', 71839);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Medroxyprogesterone', 'tablet', 'G03DA02', false, 0, '02247583', 'FreeDiams::CA_HCDPD::DIN', 71840);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlorhexidine Antiseptic Soap', 'liquid', 'D08AC02', false, 0, '02247584', 'FreeDiams::CA_HCDPD::DIN', 71841);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Calcitonin Nasal Spray', 'solution', 'H05BA01', false, 0, '02247585', 'FreeDiams::CA_HCDPD::DIN', 71842);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Boostrix', 'suspension', 'J07AX', false, 0, '02247600', 'FreeDiams::CA_HCDPD::DIN', 71860);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Levo-Carbidopa', 'tablet', 'N04BA02', false, 0, '02247606', 'FreeDiams::CA_HCDPD::DIN', 71866);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Clonidine', 'tablet', 'C02AC01', false, 0, '02247607', 'FreeDiams::CA_HCDPD::DIN', 71867);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Clonidine', 'tablet', 'C02AC01', false, 0, '02247608', 'FreeDiams::CA_HCDPD::DIN', 71868);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chloral Hydrate Syrup Odan', 'syrup', 'N05CC01', false, 0, '02247621', 'FreeDiams::CA_HCDPD::DIN', 71882);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tanac Liquid', 'liquid', 'A01AD11', false, 0, '02247644', 'FreeDiams::CA_HCDPD::DIN', 71907);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Terconazole Cream', 'cream', 'G01AG02', false, 0, '02247651', 'FreeDiams::CA_HCDPD::DIN', 71914);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pravastatin', 'tablet', 'C10AA03', false, 0, '02247655', 'FreeDiams::CA_HCDPD::DIN', 71918);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pravastatin', 'tablet', 'C10AA03', false, 0, '02247656', 'FreeDiams::CA_HCDPD::DIN', 71919);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pravastatin', 'tablet', 'C10AA03', false, 0, '02247657', 'FreeDiams::CA_HCDPD::DIN', 71920);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hibistat Germicidal Hand Rinse', 'liquid', 'D08AC52', false, 0, '02247683', 'FreeDiams::CA_HCDPD::DIN', 71947);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atrovent Hfa', 'metered-dose (aerosol)', 'R03BB01', false, 0, '02247686', 'FreeDiams::CA_HCDPD::DIN', 71950);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Anuzinc Hc', 'ointment', 'C05AA01', false, 0, '02247691', 'FreeDiams::CA_HCDPD::DIN', 71955);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Anuzinc Hc Plus', 'ointment', 'C05AA01', false, 0, '02247692', 'FreeDiams::CA_HCDPD::DIN', 71956);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metadol', 'solution', 'N07BC02', false, 0, '02247694', 'FreeDiams::CA_HCDPD::DIN', 71958);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metadol', 'tablet', 'N07BC02', false, 0, '02247698', 'FreeDiams::CA_HCDPD::DIN', 71959);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metadol', 'tablet', 'N07BC02', false, 0, '02247699', 'FreeDiams::CA_HCDPD::DIN', 71963);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metadol', 'tablet', 'N07BC02', false, 0, '02247700', 'FreeDiams::CA_HCDPD::DIN', 71964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metadol', 'tablet', 'N07BC02', false, 0, '02247701', 'FreeDiams::CA_HCDPD::DIN', 71965);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eliminator 125', 'liquid', 'V07AV', false, 0, '02247703', 'FreeDiams::CA_HCDPD::DIN', 71966);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperdal M-Tab', 'tablet (orally disintegrating)', 'N05AX08', false, 0, '02247704', 'FreeDiams::CA_HCDPD::DIN', 71971);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperdal M-Tab', 'tablet (orally disintegrating)', 'N05AX08', false, 0, '02247705', 'FreeDiams::CA_HCDPD::DIN', 71973);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperdal M-Tab', 'tablet (orally disintegrating)', 'N05AX08', false, 0, '02247706', 'FreeDiams::CA_HCDPD::DIN', 71974);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eliminator 42', 'liquid', 'V07AV', false, 0, '02247715', 'FreeDiams::CA_HCDPD::DIN', 71987);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Selection', 'solution', 'V07AV', false, 0, '02247720', 'FreeDiams::CA_HCDPD::DIN', 71992);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Physioneal 40 Glucose 1.36% W/V 13.6mg/Ml Solution For Peritoneal Dialysis', 'solution', 'B05ZA', false, 0, '02247721', 'FreeDiams::CA_HCDPD::DIN', 71993);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Physioneal 40 Glucose 2.27% W/V 22.7 Mg/Ml, Solution For Peritoneal Dialysis', 'solution', 'B05ZA', false, 0, '02247722', 'FreeDiams::CA_HCDPD::DIN', 71997);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Physioneal 40 Glucose 3.86% W/V 38.6mg/Ml, Solution For Peritoneal Dialysis', 'solution', 'B05ZA', false, 0, '02247723', 'FreeDiams::CA_HCDPD::DIN', 71998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gamunex', 'solution', 'J06BA02', false, 0, '02247724', 'FreeDiams::CA_HCDPD::DIN', 72002);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fuzeon', 'powder for solution', 'J05AX07', false, 0, '02247725', 'FreeDiams::CA_HCDPD::DIN', 72003);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Concerta', 'tablet (extended-release)', 'N06BA04', false, 0, '02247732', 'FreeDiams::CA_HCDPD::DIN', 72012);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Concerta', 'tablet (extended-release)', 'N06BA04', false, 0, '02247733', 'FreeDiams::CA_HCDPD::DIN', 72013);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Concerta', 'tablet (extended-release)', 'N06BA04', false, 0, '02247734', 'FreeDiams::CA_HCDPD::DIN', 72014);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Famotidine Omega  -(Without Preservative)', 'solution', 'A02BA03', false, 0, '02247735', 'FreeDiams::CA_HCDPD::DIN', 72016);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Famotidine Omega   -(With Preservative,Benzyl Alcohol)', 'solution', 'A02BA03', false, 0, '02247745', 'FreeDiams::CA_HCDPD::DIN', 72026);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluconazole Omega', 'solution', 'J02AC01', false, 0, '02247749', 'FreeDiams::CA_HCDPD::DIN', 72035);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Paroxetine', 'tablet', 'N06AB05', false, 0, '02247750', 'FreeDiams::CA_HCDPD::DIN', 72042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Paroxetine', 'tablet', 'N06AB05', false, 0, '02247751', 'FreeDiams::CA_HCDPD::DIN', 72043);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Paroxetine', 'tablet', 'N06AB05', false, 0, '02247752', 'FreeDiams::CA_HCDPD::DIN', 72044);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Omega Allergenic Extracts - Pollens (Aqueous)', 'liquid', 'V01AA20', false, 0, '02247753', 'FreeDiams::CA_HCDPD::DIN', 72045);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Omega Allergenic Extracts - Pollens (Glycerinated)', 'liquid', 'V01AA20', false, 0, '02247754', 'FreeDiams::CA_HCDPD::DIN', 72046);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Omega Allergenic Extracts - Pollens (Suspal)', 'liquid', 'V01AA20', false, 0, '02247755', 'FreeDiams::CA_HCDPD::DIN', 72047);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Omega Allergenic Extracts - Non-Pollens (Aqueous)', 'liquid', 'V01AA20', false, 0, '02247756', 'FreeDiams::CA_HCDPD::DIN', 72048);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Omega Allergenic Extracts - Non-Pollens (Glycerinated)', 'liquid', 'V01AA20', false, 0, '02247757', 'FreeDiams::CA_HCDPD::DIN', 72049);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Omega Allergenic Extracts - Non-Pollens (Suspal)', 'liquid', 'V01AA20', false, 0, '02247758', 'FreeDiams::CA_HCDPD::DIN', 72050);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluide De Jour Fps 20 Pro-Derm', 'gel', 'D02BA30', false, 0, '02247760', 'FreeDiams::CA_HCDPD::DIN', 72053);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cetrotide', 'powder for solution', 'H01CC02', false, 0, '02247766', 'FreeDiams::CA_HCDPD::DIN', 72060);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cetrotide', 'powder for solution', 'H01CC02', false, 0, '02247767', 'FreeDiams::CA_HCDPD::DIN', 72061);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Radiant C Body Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02247775', 'FreeDiams::CA_HCDPD::DIN', 72068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Repronex', 'powder for solution', 'G03GA02', false, 0, '02247790', 'FreeDiams::CA_HCDPD::DIN', 72083);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dayquil D', 'liquid', 'N02BE51', false, 0, '02247801', 'FreeDiams::CA_HCDPD::DIN', 72095);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Fosinopril', 'tablet', 'C09AA09', false, 0, '02247802', 'FreeDiams::CA_HCDPD::DIN', 72096);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Fosinopril', 'tablet', 'C09AA09', false, 0, '02247803', 'FreeDiams::CA_HCDPD::DIN', 72097);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Derm Healthy Skin Protection Spf 35', 'cream', 'D02BA30', false, 0, '02247808', 'FreeDiams::CA_HCDPD::DIN', 72102);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Paroxetine', 'tablet', 'N06AB05', false, 0, '02247810', 'FreeDiams::CA_HCDPD::DIN', 72104);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Paroxetine', 'tablet', 'N06AB05', false, 0, '02247811', 'FreeDiams::CA_HCDPD::DIN', 72105);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Paroxetine', 'tablet', 'N06AB05', false, 0, '02247812', 'FreeDiams::CA_HCDPD::DIN', 72106);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avodart', 'capsule', 'G04CB02', false, 0, '02247813', 'FreeDiams::CA_HCDPD::DIN', 72107);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Ranitidine 150', 'tablet', 'A02BA02', false, 0, '02247814', 'FreeDiams::CA_HCDPD::DIN', 72108);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Ranitidine 300', 'tablet', 'A02BA02', false, 0, '02247815', 'FreeDiams::CA_HCDPD::DIN', 72109);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Clarithromycin', 'tablet', 'J01FA09', false, 0, '02247818', 'FreeDiams::CA_HCDPD::DIN', 72112);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Clarithromycin', 'tablet', 'J01FA09', false, 0, '02247819', 'FreeDiams::CA_HCDPD::DIN', 72114);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hepsera', 'tablet', 'J05AF08', false, 0, '02247823', 'FreeDiams::CA_HCDPD::DIN', 72117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Air Guard Konk Disinfectant Spray', 'aerosol', 'V07AV', false, 0, '02247824', 'FreeDiams::CA_HCDPD::DIN', 72119);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('3tc', 'tablet', 'J05AF05', false, 0, '02247825', 'FreeDiams::CA_HCDPD::DIN', 72120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Simvastatin', 'tablet', 'C10AA01', false, 0, '02247827', 'FreeDiams::CA_HCDPD::DIN', 72122);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Simvastatin', 'tablet', 'C10AA01', false, 0, '02247828', 'FreeDiams::CA_HCDPD::DIN', 72123);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Simvastatin', 'tablet', 'C10AA01', false, 0, '02247830', 'FreeDiams::CA_HCDPD::DIN', 72126);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Simvastatin', 'tablet', 'C10AA01', false, 0, '02247831', 'FreeDiams::CA_HCDPD::DIN', 72128);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Simvastatin', 'tablet', 'C10AA01', false, 0, '02247833', 'FreeDiams::CA_HCDPD::DIN', 72129);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clean''Ems Disinfectant Towels', 'wipe', 'V07AV', false, 0, '02247843', 'FreeDiams::CA_HCDPD::DIN', 72148);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Microclean', 'solution', 'V07AV', false, 0, '02247845', 'FreeDiams::CA_HCDPD::DIN', 72152);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Attack', 'solution', 'V07AV', false, 0, '02247846', 'FreeDiams::CA_HCDPD::DIN', 72153);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Orderly', 'solution', 'V07AV', false, 0, '02247847', 'FreeDiams::CA_HCDPD::DIN', 72154);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen Usp', 'gas', 'V03AN01', false, 0, '02247852', 'FreeDiams::CA_HCDPD::DIN', 72159);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Pravastatin', 'tablet', 'C10AA03', false, 0, '02247856', 'FreeDiams::CA_HCDPD::DIN', 72163);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Pravastatin', 'tablet', 'C10AA03', false, 0, '02247857', 'FreeDiams::CA_HCDPD::DIN', 72165);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Pravastatin', 'tablet', 'C10AA03', false, 0, '02247858', 'FreeDiams::CA_HCDPD::DIN', 72166);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Metoprolol (Type L)', 'tablet', 'C07AB02', false, 0, '02247875', 'FreeDiams::CA_HCDPD::DIN', 72183);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Metoprolol (Type L)', 'tablet', 'C07AB02', false, 0, '02247876', 'FreeDiams::CA_HCDPD::DIN', 72185);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Timentin', 'powder for solution', 'J01CR03', false, 0, '02247880', 'FreeDiams::CA_HCDPD::DIN', 72188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proctol Suppositories', 'suppository', 'C05AA01', false, 0, '02247882', 'FreeDiams::CA_HCDPD::DIN', 72190);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glyquin Xm', 'cream', 'D11AX11', false, 0, '02247884', 'FreeDiams::CA_HCDPD::DIN', 72192);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Meloxicam', 'tablet', 'M01AC06', false, 0, '02247889', 'FreeDiams::CA_HCDPD::DIN', 72198);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Seccure', 'powder', 'V07AV', false, 0, '02247890', 'FreeDiams::CA_HCDPD::DIN', 72199);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ed Everyday Disinfectant', 'liquid', 'V07AV', false, 0, '02247891', 'FreeDiams::CA_HCDPD::DIN', 72200);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cough, Cold And Flu Daytime Caplets', 'tablet', 'N02BE51', false, 0, '02247907', 'FreeDiams::CA_HCDPD::DIN', 72216);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cough, Cold And Flu Nightime Caplets', 'tablet', 'N02BE51', false, 0, '02247908', 'FreeDiams::CA_HCDPD::DIN', 72217);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cipro Xl', 'tablet (extended-release)', 'J01MA02', false, 0, '02247916', 'FreeDiams::CA_HCDPD::DIN', 72225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ramipril', 'capsule', 'C09AA05', false, 0, '02247917', 'FreeDiams::CA_HCDPD::DIN', 72226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ramipril', 'capsule', 'C09AA05', false, 0, '02247918', 'FreeDiams::CA_HCDPD::DIN', 72227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ramipril', 'capsule', 'C09AA05', false, 0, '02247919', 'FreeDiams::CA_HCDPD::DIN', 72228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Opticort', 'solution', 'S03CA01', false, 0, '02247920', 'FreeDiams::CA_HCDPD::DIN', 72229);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluconazole Injection', 'solution', 'J02AC01', false, 0, '02247922', 'FreeDiams::CA_HCDPD::DIN', 72232);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Everyday Sunscreen', 'lotion', 'D02BA30', false, 0, '02247926', 'FreeDiams::CA_HCDPD::DIN', 72236);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Carvedilol', 'tablet', 'C07AG02', false, 0, '02247933', 'FreeDiams::CA_HCDPD::DIN', 72243);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Carvedilol', 'tablet', 'C07AG02', false, 0, '02247934', 'FreeDiams::CA_HCDPD::DIN', 72244);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Carvedilol', 'tablet', 'C07AG02', false, 0, '02247935', 'FreeDiams::CA_HCDPD::DIN', 72245);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Carvedilol', 'tablet', 'C07AG02', false, 0, '02247936', 'FreeDiams::CA_HCDPD::DIN', 72246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Hydroxyurea', 'capsule', 'L01XX05', false, 0, '02247937', 'FreeDiams::CA_HCDPD::DIN', 72247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vasopressin Injection Usp', 'solution', 'H01BA01', false, 0, '02247938', 'FreeDiams::CA_HCDPD::DIN', 72248);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pure Pefection Classic Replenishing Cleanser', 'cream', 'D10AE01', false, 0, '02247942', 'FreeDiams::CA_HCDPD::DIN', 72252);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pure Perfection Classic Renewing Creme', 'cream', 'D10AE01', false, 0, '02247943', 'FreeDiams::CA_HCDPD::DIN', 72253);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Ramipril', 'capsule', 'C09AA05', false, 0, '02247945', 'FreeDiams::CA_HCDPD::DIN', 72255);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Ramipril', 'capsule', 'C09AA05', false, 0, '02247946', 'FreeDiams::CA_HCDPD::DIN', 72256);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Ramipril', 'capsule', 'C09AA05', false, 0, '02247947', 'FreeDiams::CA_HCDPD::DIN', 72257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Balm Spf 4', 'ointment', 'D02BA02', false, 0, '02247959', 'FreeDiams::CA_HCDPD::DIN', 72269);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Balm Spf 15', 'ointment', 'D02BA30', false, 0, '02247960', 'FreeDiams::CA_HCDPD::DIN', 72270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Balm Spf 15 Hue', 'stick', 'D02BA30', false, 0, '02247961', 'FreeDiams::CA_HCDPD::DIN', 72271);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vital Sun Protection Spf 30', 'lotion', 'D02BA30', false, 0, '02247965', 'FreeDiams::CA_HCDPD::DIN', 72275);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rodan & Fields Proactiv Solution:  Oil Free Moisture With Spf 15', 'lotion', 'D02BA30', false, 0, '02247980', 'FreeDiams::CA_HCDPD::DIN', 72290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Everbrite', 'liquid', 'V07AV', false, 0, '02247982', 'FreeDiams::CA_HCDPD::DIN', 72292);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fectant-3', 'liquid', 'V07AV', false, 0, '02247984', 'FreeDiams::CA_HCDPD::DIN', 72294);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germa-Cert', 'liquid', 'V07AV', false, 0, '02247985', 'FreeDiams::CA_HCDPD::DIN', 72295);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimension Iii', 'liquid', 'V07AV', false, 0, '02247988', 'FreeDiams::CA_HCDPD::DIN', 72301);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Singulair', 'granules', 'R03DC03', false, 0, '02247997', 'FreeDiams::CA_HCDPD::DIN', 72310);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Serc', 'tablet', 'N07CA01', false, 0, '02247998', 'FreeDiams::CA_HCDPD::DIN', 72312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Glyburide', 'tablet', 'A10BB01', false, 0, '02248008', 'FreeDiams::CA_HCDPD::DIN', 72324);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Glyburide', 'tablet', 'A10BB01', false, 0, '02248009', 'FreeDiams::CA_HCDPD::DIN', 72325);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Citalopram', 'tablet', 'N06AB04', false, 0, '02248010', 'FreeDiams::CA_HCDPD::DIN', 72326);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Citalopram', 'tablet', 'N06AB04', false, 0, '02248011', 'FreeDiams::CA_HCDPD::DIN', 72327);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Paroxetine', 'tablet', 'N06AB05', false, 0, '02248012', 'FreeDiams::CA_HCDPD::DIN', 72328);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Paroxetine', 'tablet', 'N06AB05', false, 0, '02248013', 'FreeDiams::CA_HCDPD::DIN', 72329);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Paroxetine', 'tablet', 'N06AB05', false, 0, '02248014', 'FreeDiams::CA_HCDPD::DIN', 72330);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Day Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02248016', 'FreeDiams::CA_HCDPD::DIN', 72332);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rodan & Fields Proactiv Solution: Sheer Tint Moisture Spf 15 (Sunbronze, Suntan, Sunlight)', 'lotion', 'D02BA30', false, 0, '02248020', 'FreeDiams::CA_HCDPD::DIN', 72336);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sheer Cover Nourishing Moisturizer Spf 15', 'lotion', 'D02BA30', false, 0, '02248023', 'FreeDiams::CA_HCDPD::DIN', 72339);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morning Mist', 'liquid', 'V07AV', false, 0, '02248024', 'FreeDiams::CA_HCDPD::DIN', 72340);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triad Iii Quaternary Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02248025', 'FreeDiams::CA_HCDPD::DIN', 72341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tracer Ii', 'liquid', 'V07AV', false, 0, '02248026', 'FreeDiams::CA_HCDPD::DIN', 72342);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proguard Disinfectant Spray', 'aerosol', 'V07AV', false, 0, '02248028', 'FreeDiams::CA_HCDPD::DIN', 72344);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Meloxicam', 'tablet', 'M01AC06', false, 0, '02248031', 'FreeDiams::CA_HCDPD::DIN', 72351);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clozapine', 'tablet', 'N05AH02', false, 0, '02248034', 'FreeDiams::CA_HCDPD::DIN', 72354);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clozapine', 'tablet', 'N05AH02', false, 0, '02248035', 'FreeDiams::CA_HCDPD::DIN', 72355);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Citalopram', 'tablet', 'N06AB04', false, 0, '02248050', 'FreeDiams::CA_HCDPD::DIN', 72370);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Citalopram', 'tablet', 'N06AB04', false, 0, '02248051', 'FreeDiams::CA_HCDPD::DIN', 72371);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clear Eyes Allergy', 'liquid', 'S01GA51', false, 0, '02248059', 'FreeDiams::CA_HCDPD::DIN', 72379);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clear Eyes', 'liquid', 'S01GA01', false, 0, '02248060', 'FreeDiams::CA_HCDPD::DIN', 72380);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Absolue Hand Spf 15', 'cream', 'D02BA30', false, 0, '02248071', 'FreeDiams::CA_HCDPD::DIN', 72392);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Summerberry Skin Cream', 'cream', 'D02AC', false, 0, '02248075', 'FreeDiams::CA_HCDPD::DIN', 72397);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diaper Rash Ointment/Onguent Pour Le Traitement De L''Érythčme Fessier', 'ointment', 'D02AB', false, 0, '02248076', 'FreeDiams::CA_HCDPD::DIN', 72398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pegasys', 'solution', 'L03AB11', false, 0, '02248077', 'FreeDiams::CA_HCDPD::DIN', 72399);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pegasys', 'solution', 'L03AB11', false, 0, '02248078', 'FreeDiams::CA_HCDPD::DIN', 72400);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Verapamil Sr', 'tablet (extended-release)', 'C08DA01', false, 0, '02248082', 'FreeDiams::CA_HCDPD::DIN', 72404);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Denorex Everyday Strength', 'shampoo', 'D11AX12', false, 0, '02248083', 'FreeDiams::CA_HCDPD::DIN', 72405);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Balm Spf 20', 'ointment', 'D02BA30', false, 0, '02248084', 'FreeDiams::CA_HCDPD::DIN', 72406);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cialis', 'tablet', 'G04BE08', false, 0, '02248088', 'FreeDiams::CA_HCDPD::DIN', 72410);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cialis', 'tablet', 'G04BE08', false, 0, '02248089', 'FreeDiams::CA_HCDPD::DIN', 72411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Getinge Tec-Quat 256', 'solution', 'V07AV', false, 0, '02248101', 'FreeDiams::CA_HCDPD::DIN', 72427);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Getinge Tec-Surf Ii', 'liquid', 'V07AV', false, 0, '02248102', 'FreeDiams::CA_HCDPD::DIN', 72428);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Simvastatin Tablet 5mg', 'tablet', 'C10AA01', false, 0, '02248103', 'FreeDiams::CA_HCDPD::DIN', 72429);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Simvastatin Tablet 10mg', 'tablet', 'C10AA01', false, 0, '02248104', 'FreeDiams::CA_HCDPD::DIN', 72430);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Simvastatin Tablet 20mg', 'tablet', 'C10AA01', false, 0, '02248105', 'FreeDiams::CA_HCDPD::DIN', 72431);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Simvastatin Tablet 40mg', 'tablet', 'C10AA01', false, 0, '02248106', 'FreeDiams::CA_HCDPD::DIN', 72432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Simvastatin Tablet 80mg', 'tablet', 'C10AA01', false, 0, '02248107', 'FreeDiams::CA_HCDPD::DIN', 72433);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polycide', 'solution', 'V07AV', false, 0, '02248116', 'FreeDiams::CA_HCDPD::DIN', 72443);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Furosemide', 'tablet', 'C03CA01', false, 0, '02248124', 'FreeDiams::CA_HCDPD::DIN', 72451);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Furosemide', 'tablet', 'C03CA01', false, 0, '02248125', 'FreeDiams::CA_HCDPD::DIN', 72452);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-Flurazepam', 'capsule', 'N05CD01', false, 0, '02248126', 'FreeDiams::CA_HCDPD::DIN', 72453);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-Flurazepam', 'capsule', 'N05CD01', false, 0, '02248127', 'FreeDiams::CA_HCDPD::DIN', 72454);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Axert 6.25mg', 'tablet', 'N02CC05', false, 0, '02248128', 'FreeDiams::CA_HCDPD::DIN', 72455);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Axert 12.5mg', 'tablet', 'N02CC05', false, 0, '02248129', 'FreeDiams::CA_HCDPD::DIN', 72456);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Mometasone Ointment 0.1%', 'ointment', 'D07AC13', false, 0, '02248130', 'FreeDiams::CA_HCDPD::DIN', 72459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Amitriptyline', 'tablet', 'N06AA09', false, 0, '02248131', 'FreeDiams::CA_HCDPD::DIN', 72460);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Amitriptyline', 'tablet', 'N06AA09', false, 0, '02248132', 'FreeDiams::CA_HCDPD::DIN', 72461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Amitriptyline', 'tablet', 'N06AA09', false, 0, '02248133', 'FreeDiams::CA_HCDPD::DIN', 72462);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Hydrochlorothiazide', 'tablet', 'C03AA03', false, 0, '02248134', 'FreeDiams::CA_HCDPD::DIN', 72463);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Hydrochlorothiazide', 'tablet', 'C03AA03', false, 0, '02248135', 'FreeDiams::CA_HCDPD::DIN', 72464);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Clavamoxin 875', 'tablet', 'J01CR02', false, 0, '02248138', 'FreeDiams::CA_HCDPD::DIN', 72467);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alphagan P', 'solution', 'S01EA05', false, 0, '02248151', 'FreeDiams::CA_HCDPD::DIN', 72483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gonal-F', 'powder for solution', 'G03GA05', false, 0, '02248154', 'FreeDiams::CA_HCDPD::DIN', 72486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gonal-F', 'powder for solution', 'G03GA05', false, 0, '02248156', 'FreeDiams::CA_HCDPD::DIN', 72488);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gonal-F', 'powder for solution', 'G03GA05', false, 0, '02248157', 'FreeDiams::CA_HCDPD::DIN', 72489);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Degraisseur Plus', 'solution', 'V07AV', false, 0, '02248161', 'FreeDiams::CA_HCDPD::DIN', 72493);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spic And Span Disinfecting All-Purpose Spray And Glass Cleaner Concentrate', 'spray', 'V07AV', false, 0, '02248162', 'FreeDiams::CA_HCDPD::DIN', 72494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spic And Span Disinfecting All-Purpose Spray And Glass Cleaner Ready-To-Use', 'spray', 'V07AV', false, 0, '02248164', 'FreeDiams::CA_HCDPD::DIN', 72496);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mopec Path Cloud Foaming Cleaner Disinfectant', 'solution', 'V07AV', false, 0, '02248165', 'FreeDiams::CA_HCDPD::DIN', 72497);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daily Disinfect', 'liquid', 'V07AV', false, 0, '02248166', 'FreeDiams::CA_HCDPD::DIN', 72498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daily Disinfect Sc', 'liquid', 'V07AV', false, 0, '02248167', 'FreeDiams::CA_HCDPD::DIN', 72499);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Citalopram', 'tablet', 'N06AB04', false, 0, '02248170', 'FreeDiams::CA_HCDPD::DIN', 72503);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Citalopram', 'tablet', 'N06AB04', false, 0, '02248171', 'FreeDiams::CA_HCDPD::DIN', 72504);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nitrogen Nf', 'gas', 'V03AN04', false, 0, '02248173', 'FreeDiams::CA_HCDPD::DIN', 72506);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alfentanil Injection Usp', 'solution', 'N01AH02', false, 0, '02248181', 'FreeDiams::CA_HCDPD::DIN', 72517);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Pravastatin Tablet 10mg', 'tablet', 'C10AA03', false, 0, '02248182', 'FreeDiams::CA_HCDPD::DIN', 72518);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Pravastatin Tablet 20mg', 'tablet', 'C10AA03', false, 0, '02248183', 'FreeDiams::CA_HCDPD::DIN', 72519);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Pravastatin Tablet 40mg', 'tablet', 'C10AA03', false, 0, '02248184', 'FreeDiams::CA_HCDPD::DIN', 72520);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polysporin For Kids', 'cream', 'D06AX30', false, 0, '02248189', 'FreeDiams::CA_HCDPD::DIN', 72525);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medical Oxygen', 'gas', 'V03AN01', false, 0, '02248195', 'FreeDiams::CA_HCDPD::DIN', 72531);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metrolotion', 'lotion', 'D06BX01', false, 0, '02248206', 'FreeDiams::CA_HCDPD::DIN', 72542);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Complete Spf30 Defense All Day Moisturizer', 'lotion', 'D02BA30', false, 0, '02248213', 'FreeDiams::CA_HCDPD::DIN', 72549);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Blemish Gel 5%', 'gel', 'D10AE01', false, 0, '02248217', 'FreeDiams::CA_HCDPD::DIN', 72553);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Manorapid Synergy', 'solution', 'D08AX58', false, 0, '02248224', 'FreeDiams::CA_HCDPD::DIN', 72560);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advil Extra Strength Liqui-Gels', 'capsule', 'M01AE01', false, 0, '02248231', 'FreeDiams::CA_HCDPD::DIN', 72567);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lamotrigine', 'tablet', 'N03AX09', false, 0, '02248232', 'FreeDiams::CA_HCDPD::DIN', 72568);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lamotrigine', 'tablet', 'N03AX09', false, 0, '02248233', 'FreeDiams::CA_HCDPD::DIN', 72569);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lamotrigine', 'tablet', 'N03AX09', false, 0, '02248234', 'FreeDiams::CA_HCDPD::DIN', 72570);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Power Quat', 'solution', 'V07AV', false, 0, '02248235', 'FreeDiams::CA_HCDPD::DIN', 72572);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Equate All-In-One Solution', 'solution', 'S01XA20', false, 0, '02248236', 'FreeDiams::CA_HCDPD::DIN', 72573);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fantastik With Bleach All Purpose Cleaner', 'solution', 'V07AV', false, 0, '02248237', 'FreeDiams::CA_HCDPD::DIN', 72574);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fantastik For Total Bathroom With Bleach', 'solution', 'V07AV', false, 0, '02248238', 'FreeDiams::CA_HCDPD::DIN', 72575);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eligard 7.5mg', 'powder for suspension, sustained-release', 'L02AE02', false, 0, '02248239', 'FreeDiams::CA_HCDPD::DIN', 72576);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eligard 22.5mg', 'powder for suspension, sustained-release', 'L02AE02', false, 0, '02248240', 'FreeDiams::CA_HCDPD::DIN', 72577);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Kids Spray''N Play Spf 30', 'lotion', 'D02BA30', false, 0, '02248244', 'FreeDiams::CA_HCDPD::DIN', 72581);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tolsom Skin Protective Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02248245', 'FreeDiams::CA_HCDPD::DIN', 72582);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Balm Baume Pour Les Lčvres Spf 30', 'stick', 'D02BA30', false, 0, '02248246', 'FreeDiams::CA_HCDPD::DIN', 72583);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rio-Bronze Spf 30 Towelettes', 'lotion', 'D02BA30', false, 0, '02248248', 'FreeDiams::CA_HCDPD::DIN', 72585);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Alendronate', 'tablet', 'M05BA04', false, 0, '02248251', 'FreeDiams::CA_HCDPD::DIN', 72588);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Gabapentin', 'capsule', 'N03AX12', false, 0, '02248259', 'FreeDiams::CA_HCDPD::DIN', 72596);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Gabapentin', 'capsule', 'N03AX12', false, 0, '02248260', 'FreeDiams::CA_HCDPD::DIN', 72597);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Gabapentin', 'capsule', 'N03AX12', false, 0, '02248261', 'FreeDiams::CA_HCDPD::DIN', 72598);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Levofloxacin', 'tablet', 'J01MA12', false, 0, '02248262', 'FreeDiams::CA_HCDPD::DIN', 72599);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Levofloxacin', 'tablet', 'J01MA12', false, 0, '02248263', 'FreeDiams::CA_HCDPD::DIN', 72600);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Meloxicam', 'tablet', 'M01AC06', false, 0, '02248267', 'FreeDiams::CA_HCDPD::DIN', 72606);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Meloxicam', 'tablet', 'M01AC06', false, 0, '02248268', 'FreeDiams::CA_HCDPD::DIN', 72607);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sysco Action 3', 'solution', 'V07AV', false, 0, '02248275', 'FreeDiams::CA_HCDPD::DIN', 72614);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Disinfectant Fantastik All Purpose Cleaner I', 'solution', 'V07AV', false, 0, '02248276', 'FreeDiams::CA_HCDPD::DIN', 72615);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zometa Concentrate', 'solution', 'M05BA08', false, 0, '02248296', 'FreeDiams::CA_HCDPD::DIN', 72636);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Evra   -(6/0.60)', 'patch (extended release)', 'G03AA13', false, 0, '02248297', 'FreeDiams::CA_HCDPD::DIN', 72637);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multihance', 'solution', 'V08CA08', false, 0, '02248302', 'FreeDiams::CA_HCDPD::DIN', 72643);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mac Studio Finish Concealer Spf 35', 'powder', 'D02BA30', false, 0, '02248338', 'FreeDiams::CA_HCDPD::DIN', 72680);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Softcide Ec', 'solution', 'D08AE04', false, 0, '02248340', 'FreeDiams::CA_HCDPD::DIN', 72682);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sysco Antimicrobial Hand Soap', 'liquid', 'D08AE04', false, 0, '02248341', 'FreeDiams::CA_HCDPD::DIN', 72683);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Combigan', 'solution', 'S01ED51', false, 0, '02248347', 'FreeDiams::CA_HCDPD::DIN', 72692);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Microbe', 'liquid', 'D08AJ01', false, 0, '02248351', 'FreeDiams::CA_HCDPD::DIN', 72696);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Andis Cool Care Plus For Clipper Blades', 'aerosol', 'V07AV', false, 0, '02248354', 'FreeDiams::CA_HCDPD::DIN', 72700);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vivaxim', 'kit', 'J07CA10', false, 0, '02248361', 'FreeDiams::CA_HCDPD::DIN', 72706);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shiseido Ultra Sun Protection Cream Spf 50', 'cream', 'D02BA30', false, 0, '02248379', 'FreeDiams::CA_HCDPD::DIN', 72724);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shiseido Ultra Sun Protection Lotion Spf 50', 'lotion', 'D02BA30', false, 0, '02248380', 'FreeDiams::CA_HCDPD::DIN', 72726);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shiseido Extra Smooth Sun Protection Cream Spf 38', 'cream', 'D02BA30', false, 0, '02248382', 'FreeDiams::CA_HCDPD::DIN', 72727);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shiseido Sun Protection Stick Foundation Spf 36', 'stick', 'D02BA30', false, 0, '02248392', 'FreeDiams::CA_HCDPD::DIN', 72737);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shiseido Sun Protection Compact Foundation Spf 35', 'cream', 'D02BA30', false, 0, '02248394', 'FreeDiams::CA_HCDPD::DIN', 72739);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lysol Brand Disinfectant Dual Action Disinfecting Wipes', 'wipe', 'V07AV', false, 0, '02248397', 'FreeDiams::CA_HCDPD::DIN', 72742);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ofloxacin Ophthalmic Solution', 'solution', 'S01AX11', false, 0, '02248398', 'FreeDiams::CA_HCDPD::DIN', 72744);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valour Antiseptic Hand Cleanser', 'liquid', 'D08AE04', false, 0, '02248405', 'FreeDiams::CA_HCDPD::DIN', 72751);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cover Fx Total Coverage Cream Foundation Spf 30', 'cream', 'D02BA30', false, 0, '02248411', 'FreeDiams::CA_HCDPD::DIN', 72761);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Natural Fx Water Based Foundation Spf 15', 'suspension', 'D02BA30', false, 0, '02248412', 'FreeDiams::CA_HCDPD::DIN', 72762);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Complete Spf30 Defense All Day Moisturizer - Sensitive Skin', 'lotion', 'D02BA30', false, 0, '02248414', 'FreeDiams::CA_HCDPD::DIN', 72764);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fasturtec', 'powder for solution', 'V03AF07', false, 0, '02248416', 'FreeDiams::CA_HCDPD::DIN', 72766);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gynazole.1', 'cream', 'G01AF15', false, 0, '02248417', 'FreeDiams::CA_HCDPD::DIN', 72767);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('14 Antibacterial All Purpose Cleaner And Disinfectant', 'solution', 'V07AV', false, 0, '02248419', 'FreeDiams::CA_HCDPD::DIN', 72770);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('63 Alkaline Bathroom Cleaner & Disinfectant', 'liquid', 'V07AV', false, 0, '02248420', 'FreeDiams::CA_HCDPD::DIN', 72771);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sani Stuff', 'liquid', 'V07AV', false, 0, '02248422', 'FreeDiams::CA_HCDPD::DIN', 72773);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Anuzinc Plus', 'ointment', 'C05AD07', false, 0, '02248424', 'FreeDiams::CA_HCDPD::DIN', 72775);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avon Beyond Color Plumping Lipcolor Spf 15', 'stick', 'D02BA02', false, 0, '02248432', 'FreeDiams::CA_HCDPD::DIN', 72783);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Advil Cold', 'suspension', 'M01AE51', false, 0, '02248435', 'FreeDiams::CA_HCDPD::DIN', 72786);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02248437', 'FreeDiams::CA_HCDPD::DIN', 72788);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02248438', 'FreeDiams::CA_HCDPD::DIN', 72789);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02248439', 'FreeDiams::CA_HCDPD::DIN', 72790);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avandamet', 'tablet', 'A10BD03', false, 0, '02248440', 'FreeDiams::CA_HCDPD::DIN', 72791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avandamet', 'tablet', 'A10BD03', false, 0, '02248441', 'FreeDiams::CA_HCDPD::DIN', 72792);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Formula 767 Neutral Disinfectant Cleaner Morning Fresh', 'liquid', 'V07AV', false, 0, '02248442', 'FreeDiams::CA_HCDPD::DIN', 72793);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluconazole Injection', 'solution', 'J02AC01', false, 0, '02248443', 'FreeDiams::CA_HCDPD::DIN', 72794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Paroxetine', 'tablet', 'N06AB05', false, 0, '02248447', 'FreeDiams::CA_HCDPD::DIN', 72798);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Paroxetine', 'tablet', 'N06AB05', false, 0, '02248448', 'FreeDiams::CA_HCDPD::DIN', 72799);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Paroxetine', 'tablet', 'N06AB05', false, 0, '02248449', 'FreeDiams::CA_HCDPD::DIN', 72800);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paroxetine', 'tablet', 'N06AB05', false, 0, '02248450', 'FreeDiams::CA_HCDPD::DIN', 72801);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paroxetine', 'tablet', 'N06AB05', false, 0, '02248451', 'FreeDiams::CA_HCDPD::DIN', 72802);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paroxetine', 'tablet', 'N06AB05', false, 0, '02248452', 'FreeDiams::CA_HCDPD::DIN', 72803);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gliclazide-80', 'tablet', 'A10BB09', false, 0, '02248453', 'FreeDiams::CA_HCDPD::DIN', 72804);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clobazam-10', 'tablet', 'N05BA09', false, 0, '02248454', 'FreeDiams::CA_HCDPD::DIN', 72805);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Gabapentin', 'tablet', 'N03AX12', false, 0, '02248457', 'FreeDiams::CA_HCDPD::DIN', 72809);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vionexus No-Rinse Spray', 'spray', 'D08AJ51', false, 0, '02248463', 'FreeDiams::CA_HCDPD::DIN', 72815);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sanitol', 'solution', 'V07AV', false, 0, '02248470', 'FreeDiams::CA_HCDPD::DIN', 72822);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sysco Lemon Fresh Cleaner Disinfectant', 'solution', 'V07AV', false, 0, '02248471', 'FreeDiams::CA_HCDPD::DIN', 72823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benzaclin Topical Gel', 'gel', 'D10AF51', false, 0, '02248472', 'FreeDiams::CA_HCDPD::DIN', 72824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('No More Dandruff Shampoo', 'shampoo', 'D11AX12', false, 0, '02248480', 'FreeDiams::CA_HCDPD::DIN', 72832);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fantastik Cream Cleanser With Baking Soda And Disinfecting Bleach', 'solution', 'V07AV', false, 0, '02248481', 'FreeDiams::CA_HCDPD::DIN', 72833);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Disinfectant Fantastik Original All Purpose Cleaner', 'solution', 'V07AV', false, 0, '02248482', 'FreeDiams::CA_HCDPD::DIN', 72834);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('4% Astracaine Dental With Epinephrine Forte 1:100,000 (0.01mg/Ml)', 'solution', 'N01BB58', false, 0, '02248488', 'FreeDiams::CA_HCDPD::DIN', 72840);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('4% Astracaine Dental With Epinephrine 1:200,000 (0.005mg/Ml)', 'solution', 'N01BB58', false, 0, '02248489', 'FreeDiams::CA_HCDPD::DIN', 72841);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Sertraline 25', 'capsule', 'N06AB06', false, 0, '02248496', 'FreeDiams::CA_HCDPD::DIN', 72848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Sertraline 50', 'capsule', 'N06AB06', false, 0, '02248497', 'FreeDiams::CA_HCDPD::DIN', 72849);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Sertraline 100', 'capsule', 'N06AB06', false, 0, '02248498', 'FreeDiams::CA_HCDPD::DIN', 72850);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paxil Cr', 'tablet (extended-release)', 'N06AB05', false, 0, '02248503', 'FreeDiams::CA_HCDPD::DIN', 72855);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paxil Cr', 'tablet (extended-release)', 'N06AB05', false, 0, '02248504', 'FreeDiams::CA_HCDPD::DIN', 72856);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutra-Cide', 'solution', 'V07AV', false, 0, '02248507', 'FreeDiams::CA_HCDPD::DIN', 72860);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clindamycine-150', 'capsule', 'J01FF01', false, 0, '02248525', 'FreeDiams::CA_HCDPD::DIN', 72878);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clindamycine-300', 'capsule', 'J01FF01', false, 0, '02248526', 'FreeDiams::CA_HCDPD::DIN', 72879);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Trifluridine', 'solution', 'S01AD02', false, 0, '02248529', 'FreeDiams::CA_HCDPD::DIN', 72882);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('No Rinse Bathing Wipes', 'wipe', 'D08AJ01', false, 0, '02248535', 'FreeDiams::CA_HCDPD::DIN', 72889);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mac Hyper Real Spf 15 Foundation', 'liquid', 'D02BA02', false, 0, '02248536', 'FreeDiams::CA_HCDPD::DIN', 72890);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Tryptophan', 'tablet', 'N06AX02', false, 0, '02248538', 'FreeDiams::CA_HCDPD::DIN', 72892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Tryptophan', 'tablet', 'N06AX02', false, 0, '02248539', 'FreeDiams::CA_HCDPD::DIN', 72893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Tryptophan', 'capsule', 'N06AX02', false, 0, '02248540', 'FreeDiams::CA_HCDPD::DIN', 72895);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Remeron Rd', 'tablet (orally disintegrating)', 'N06AX11', false, 0, '02248542', 'FreeDiams::CA_HCDPD::DIN', 72897);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Remeron Rd', 'tablet (orally disintegrating)', 'N06AX11', false, 0, '02248543', 'FreeDiams::CA_HCDPD::DIN', 72898);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Remeron Rd', 'tablet (orally disintegrating)', 'N06AX11', false, 0, '02248544', 'FreeDiams::CA_HCDPD::DIN', 72899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Paroxetine', 'tablet', 'N06AB05', false, 0, '02248556', 'FreeDiams::CA_HCDPD::DIN', 72911);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Paroxetine', 'tablet', 'N06AB05', false, 0, '02248557', 'FreeDiams::CA_HCDPD::DIN', 72912);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Paroxetine', 'tablet', 'N06AB05', false, 0, '02248558', 'FreeDiams::CA_HCDPD::DIN', 72913);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Paroxetine', 'tablet', 'N06AB05', false, 0, '02248559', 'FreeDiams::CA_HCDPD::DIN', 72914);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Paroxetine', 'tablet', 'N06AB05', false, 0, '02248560', 'FreeDiams::CA_HCDPD::DIN', 72915);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Paroxetine', 'tablet', 'N06AB05', false, 0, '02248561', 'FreeDiams::CA_HCDPD::DIN', 72916);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metronidazole', 'capsule', 'P01AB01', false, 0, '02248562', 'FreeDiams::CA_HCDPD::DIN', 72917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robitussin Cough Control For People With Diabetes', 'liquid', 'R05FA02', false, 0, '02248568', 'FreeDiams::CA_HCDPD::DIN', 72923);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Ranitidine', 'tablet', 'A02BA02', false, 0, '02248570', 'FreeDiams::CA_HCDPD::DIN', 72925);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Ranitidine', 'tablet', 'A02BA02', false, 0, '02248571', 'FreeDiams::CA_HCDPD::DIN', 72926);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Lovastatin', 'tablet', 'C10AA02', false, 0, '02248572', 'FreeDiams::CA_HCDPD::DIN', 72927);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Lovastatin', 'tablet', 'C10AA02', false, 0, '02248573', 'FreeDiams::CA_HCDPD::DIN', 72928);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Uva-San Disinfectant', 'liquid', 'V07AV', false, 0, '02248575', 'FreeDiams::CA_HCDPD::DIN', 72930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eclipse 986', 'liquid', 'V07AV', false, 0, '02248576', 'FreeDiams::CA_HCDPD::DIN', 72931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eclipse 984', 'liquid', 'V07AV', false, 0, '02248577', 'FreeDiams::CA_HCDPD::DIN', 72932);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Airx 109 Plus', 'liquid', 'V07AV', false, 0, '02248578', 'FreeDiams::CA_HCDPD::DIN', 72933);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Flu Relief Daytime', 'tablet', 'N02BE51', false, 0, '02248580', 'FreeDiams::CA_HCDPD::DIN', 72935);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Infacol', 'suspension', 'A03AX13', false, 0, '02248588', 'FreeDiams::CA_HCDPD::DIN', 72943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Meloxicam', 'tablet', 'M01AC06', false, 0, '02248605', 'FreeDiams::CA_HCDPD::DIN', 72961);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Meloxicam', 'tablet', 'M01AC06', false, 0, '02248606', 'FreeDiams::CA_HCDPD::DIN', 72962);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Meloxicam', 'tablet', 'M01AC06', false, 0, '02248607', 'FreeDiams::CA_HCDPD::DIN', 72963);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Meloxicam', 'tablet', 'M01AC06', false, 0, '02248608', 'FreeDiams::CA_HCDPD::DIN', 72964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reyataz', 'capsule', 'J05AE08', false, 0, '02248610', 'FreeDiams::CA_HCDPD::DIN', 72966);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reyataz', 'capsule', 'J05AE08', false, 0, '02248611', 'FreeDiams::CA_HCDPD::DIN', 72967);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Faslodex', 'solution', 'L02BA03', false, 0, '02248624', 'FreeDiams::CA_HCDPD::DIN', 72981);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fosamax', 'solution', 'M05BA04', false, 0, '02248625', 'FreeDiams::CA_HCDPD::DIN', 72982);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pf 300', 'liquid', 'V07AV', false, 0, '02248634', 'FreeDiams::CA_HCDPD::DIN', 72991);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Octreotide Acetate Omega 50mcg/Ml', 'solution', 'H01CB02', false, 0, '02248639', 'FreeDiams::CA_HCDPD::DIN', 72996);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Octreotide Acetate Omega 100mcg/Ml', 'solution', 'H01CB02', false, 0, '02248640', 'FreeDiams::CA_HCDPD::DIN', 72997);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Octreotide Acetate Omega 500mcg/Ml', 'solution', 'H01CB02', false, 0, '02248641', 'FreeDiams::CA_HCDPD::DIN', 72998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Octreotide Acetate Omega 200mcg/Ml', 'solution', 'H01CB02', false, 0, '02248642', 'FreeDiams::CA_HCDPD::DIN', 72999);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advil Cold And Sinus Plus', 'tablet', 'M01AE51', false, 0, '02248645', 'FreeDiams::CA_HCDPD::DIN', 73002);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Head Cold And Sinus', 'tablet', 'N02BE51', false, 0, '02248646', 'FreeDiams::CA_HCDPD::DIN', 73003);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Meningitec', 'suspension', 'J07AH07', false, 0, '02248649', 'FreeDiams::CA_HCDPD::DIN', 73006);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Visine Advance Triple Action', 'drops', 'S01GA52', false, 0, '02248657', 'FreeDiams::CA_HCDPD::DIN', 73019);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Snap Envirochem Neutral Disinfectant', 'liquid', 'V07AV', false, 0, '02248662', 'FreeDiams::CA_HCDPD::DIN', 73025);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Promax Attack', 'liquid', 'V07AV', false, 0, '02248671', 'FreeDiams::CA_HCDPD::DIN', 73035);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Promax Germicidal Detergent', 'liquid', 'V07AV', false, 0, '02248672', 'FreeDiams::CA_HCDPD::DIN', 73036);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Promax Orderly', 'liquid', 'V07AV', false, 0, '02248673', 'FreeDiams::CA_HCDPD::DIN', 73037);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Iressa', 'tablet', 'L01XE02', false, 0, '02248676', 'FreeDiams::CA_HCDPD::DIN', 73040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avon Moisture Therapy Intensive Moisturizing Lip Treatment Spf 15', 'stick', 'D02BA30', false, 0, '02248678', 'FreeDiams::CA_HCDPD::DIN', 73042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bobbi Brown Extra Spf 25 Tinted Moisturizing Balm', 'cream', 'D02BA30', false, 0, '02248680', 'FreeDiams::CA_HCDPD::DIN', 73044);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen', 'gas', 'V03AN01', false, 0, '02248682', 'FreeDiams::CA_HCDPD::DIN', 73046);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Etidronate, 200mg', 'tablet', 'M05BA01', false, 0, '02248686', 'FreeDiams::CA_HCDPD::DIN', 73050);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zep Commercial Antibacterial Hand Soap Liquid Refill', 'liquid', 'D08AE04', false, 0, '02248691', 'FreeDiams::CA_HCDPD::DIN', 73055);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Flu Relief Nightime', 'tablet', 'N02BE51', false, 0, '02248700', 'FreeDiams::CA_HCDPD::DIN', 73064);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hot Lemon Relief Powder', 'powder', 'N02BE51', false, 0, '02248703', 'FreeDiams::CA_HCDPD::DIN', 73067);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alprazolam-1', 'tablet', 'N05BA12', false, 0, '02248706', 'FreeDiams::CA_HCDPD::DIN', 73070);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acular Ls', 'solution', 'S01BC05', false, 0, '02248722', 'FreeDiams::CA_HCDPD::DIN', 73086);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen', 'gas', 'V03AN01', false, 0, '02248726', 'FreeDiams::CA_HCDPD::DIN', 73094);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Alendronate', 'tablet', 'M05BA04', false, 0, '02248727', 'FreeDiams::CA_HCDPD::DIN', 73095);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Alendronate', 'tablet', 'M05BA04', false, 0, '02248728', 'FreeDiams::CA_HCDPD::DIN', 73096);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Alendronate', 'tablet', 'M05BA04', false, 0, '02248730', 'FreeDiams::CA_HCDPD::DIN', 73098);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clonidine', 'tablet', 'C02AC01', false, 0, '02248732', 'FreeDiams::CA_HCDPD::DIN', 73100);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Large Ecran Uv', 'cream', 'D02BA30', false, 0, '02248738', 'FreeDiams::CA_HCDPD::DIN', 73106);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Carvedilol', 'tablet', 'C07AG02', false, 0, '02248748', 'FreeDiams::CA_HCDPD::DIN', 73116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Carvedilol', 'tablet', 'C07AG02', false, 0, '02248749', 'FreeDiams::CA_HCDPD::DIN', 73117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Carvedilol', 'tablet', 'C07AG02', false, 0, '02248750', 'FreeDiams::CA_HCDPD::DIN', 73118);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Carvedilol', 'tablet', 'C07AG02', false, 0, '02248751', 'FreeDiams::CA_HCDPD::DIN', 73119);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Carvedilol', 'tablet', 'C07AG02', false, 0, '02248752', 'FreeDiams::CA_HCDPD::DIN', 73120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Carvedilol', 'tablet', 'C07AG02', false, 0, '02248753', 'FreeDiams::CA_HCDPD::DIN', 73121);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Carvedilol', 'tablet', 'C07AG02', false, 0, '02248754', 'FreeDiams::CA_HCDPD::DIN', 73122);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Carvedilol', 'tablet', 'C07AG02', false, 0, '02248755', 'FreeDiams::CA_HCDPD::DIN', 73123);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02248756', 'FreeDiams::CA_HCDPD::DIN', 73124);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02248757', 'FreeDiams::CA_HCDPD::DIN', 73125);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02248758', 'FreeDiams::CA_HCDPD::DIN', 73126);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Viracept', 'tablet', 'J05AE04', false, 0, '02248761', 'FreeDiams::CA_HCDPD::DIN', 73129);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Mirtazapine', 'tablet', 'N06AX11', false, 0, '02248762', 'FreeDiams::CA_HCDPD::DIN', 73130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Atenidone', 'tablet', 'C07CB03', false, 0, '02248763', 'FreeDiams::CA_HCDPD::DIN', 73131);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Atenidone', 'tablet', 'C07CB03', false, 0, '02248764', 'FreeDiams::CA_HCDPD::DIN', 73132);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sheer Moisture', 'cream', 'D02BA30', false, 0, '02248788', 'FreeDiams::CA_HCDPD::DIN', 73157);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sheer Tint Moisture - Light', 'cream', 'D02BA30', false, 0, '02248789', 'FreeDiams::CA_HCDPD::DIN', 73158);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sheer Tint Moisture - Medium', 'cream', 'D02BA30', false, 0, '02248790', 'FreeDiams::CA_HCDPD::DIN', 73159);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sheer Tint Moisture - Dark', 'cream', 'D02BA30', false, 0, '02248792', 'FreeDiams::CA_HCDPD::DIN', 73161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aquasource Non Stop Spf 15 - Peau Normale Mixte', 'suspension', 'D02BA30', false, 0, '02248797', 'FreeDiams::CA_HCDPD::DIN', 73166);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adderall Xr 5mg', 'capsule (extended release)', 'N06BA01', false, 0, '02248808', 'FreeDiams::CA_HCDPD::DIN', 73177);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adderall Xr 10mg', 'capsule (extended release)', 'N06BA01', false, 0, '02248809', 'FreeDiams::CA_HCDPD::DIN', 73178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adderall Xr 15mg', 'capsule (extended release)', 'N06BA01', false, 0, '02248810', 'FreeDiams::CA_HCDPD::DIN', 73179);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adderall Xr 20mg', 'capsule (extended release)', 'N06BA01', false, 0, '02248811', 'FreeDiams::CA_HCDPD::DIN', 73180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adderall Xr 25mg', 'capsule (extended release)', 'N06BA01', false, 0, '02248812', 'FreeDiams::CA_HCDPD::DIN', 73181);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adderall Xr 30mg', 'capsule (extended release)', 'N06BA01', false, 0, '02248813', 'FreeDiams::CA_HCDPD::DIN', 73182);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen, Caffeine And 8 Mg Of Codeine Phosphate Tablets', 'tablet', 'N02BE51', false, 0, '02248817', 'FreeDiams::CA_HCDPD::DIN', 73187);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triple Antibiotic Ointment', 'ointment', 'D06AX30', false, 0, '02248818', 'FreeDiams::CA_HCDPD::DIN', 73188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1253', 'solution', 'B05ZA', false, 0, '02248823', 'FreeDiams::CA_HCDPD::DIN', 73193);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Paclitaxel Injectable', 'solution', 'L01CD01', false, 0, '02248844', 'FreeDiams::CA_HCDPD::DIN', 73215);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Terbinafine', 'tablet', 'D01BA02', false, 0, '02248845', 'FreeDiams::CA_HCDPD::DIN', 73216);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clarite 4', 'cream', 'D11AX11', false, 0, '02248849', 'FreeDiams::CA_HCDPD::DIN', 73220);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Active 4', 'cream', 'D11AX11', false, 0, '02248851', 'FreeDiams::CA_HCDPD::DIN', 73222);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Theratears Lubricant Eye Drops', 'solution', 'S01XA20', false, 0, '02248854', 'FreeDiams::CA_HCDPD::DIN', 73225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Metoprolol-L', 'tablet', 'C07AB02', false, 0, '02248855', 'FreeDiams::CA_HCDPD::DIN', 73226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Clarithromycin', 'tablet', 'J01FA09', false, 0, '02248856', 'FreeDiams::CA_HCDPD::DIN', 73227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Clarithromycin', 'tablet', 'J01FA09', false, 0, '02248857', 'FreeDiams::CA_HCDPD::DIN', 73228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Topiramate', 'tablet', 'N03AX11', false, 0, '02248860', 'FreeDiams::CA_HCDPD::DIN', 73232);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Topiramate', 'tablet', 'N03AX11', false, 0, '02248861', 'FreeDiams::CA_HCDPD::DIN', 73233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Topiramate', 'tablet', 'N03AX11', false, 0, '02248862', 'FreeDiams::CA_HCDPD::DIN', 73234);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hemorrhoidal Ointment', 'ointment', 'C05AD07', false, 0, '02248891', 'FreeDiams::CA_HCDPD::DIN', 73264);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paroxetine-10', 'tablet', 'N06AB05', false, 0, '02248913', 'FreeDiams::CA_HCDPD::DIN', 73287);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paroxetine-20', 'tablet', 'N06AB05', false, 0, '02248914', 'FreeDiams::CA_HCDPD::DIN', 73288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paroxetine-30', 'tablet', 'N06AB05', false, 0, '02248915', 'FreeDiams::CA_HCDPD::DIN', 73289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oasis 499 Disinfectant Cleaner', 'solution', 'V07AV', false, 0, '02248921', 'FreeDiams::CA_HCDPD::DIN', 73296);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Generation 3', 'liquid', 'V07AV', false, 0, '02248922', 'FreeDiams::CA_HCDPD::DIN', 73297);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Generation 5', 'liquid', 'V07AV', false, 0, '02248923', 'FreeDiams::CA_HCDPD::DIN', 73298);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Repairwear Day Spf 15 Intensive Cream', 'cream', 'D02BA30', false, 0, '02248929', 'FreeDiams::CA_HCDPD::DIN', 73304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Balm Spf 20', 'suspension', 'D02BA30', false, 0, '02248933', 'FreeDiams::CA_HCDPD::DIN', 73308);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bicarbonate Concentrate B38', 'solution', 'B05ZA', false, 0, '02248934', 'FreeDiams::CA_HCDPD::DIN', 73309);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piperacillin For Injection, Usp', 'powder for solution', 'J01CA12', false, 0, '02248939', 'FreeDiams::CA_HCDPD::DIN', 73314);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piperacillin For Injection, Usp', 'powder for solution', 'J01CA12', false, 0, '02248940', 'FreeDiams::CA_HCDPD::DIN', 73315);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piperacillin For Injection, Usp', 'powder for solution', 'J01CA12', false, 0, '02248941', 'FreeDiams::CA_HCDPD::DIN', 73316);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Citalopram', 'tablet', 'N06AB04', false, 0, '02248942', 'FreeDiams::CA_HCDPD::DIN', 73317);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Citalopram', 'tablet', 'N06AB04', false, 0, '02248943', 'FreeDiams::CA_HCDPD::DIN', 73318);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Citalopram', 'tablet', 'N06AB04', false, 0, '02248944', 'FreeDiams::CA_HCDPD::DIN', 73319);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Citalopram', 'tablet', 'N06AB04', false, 0, '02248945', 'FreeDiams::CA_HCDPD::DIN', 73320);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shade Spray', 'spray', 'D02BA30', false, 0, '02248948', 'FreeDiams::CA_HCDPD::DIN', 73323);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lab Series Skincare For Men Daily Moisture Defense Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02248949', 'FreeDiams::CA_HCDPD::DIN', 73324);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fabrazyme', 'powder for solution', 'A16AB04', false, 0, '02248965', 'FreeDiams::CA_HCDPD::DIN', 73340);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fabrazyme', 'powder for solution', 'A16AB04', false, 0, '02248966', 'FreeDiams::CA_HCDPD::DIN', 73341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Systane Lubricant Eye Drops', 'drops', 'S01XA20', false, 0, '02248967', 'FreeDiams::CA_HCDPD::DIN', 73342);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zep Foam San', 'liquid', 'D08AJ08', false, 0, '02248971', 'FreeDiams::CA_HCDPD::DIN', 73352);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Meloxicam', 'tablet', 'M01AC06', false, 0, '02248973', 'FreeDiams::CA_HCDPD::DIN', 73355);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Meloxicam', 'tablet', 'M01AC06', false, 0, '02248974', 'FreeDiams::CA_HCDPD::DIN', 73356);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sanitizer 3', 'liquid', 'V07AV', false, 0, '02248975', 'FreeDiams::CA_HCDPD::DIN', 73357);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spray Cleaner', 'spray', 'V07AV', false, 0, '02248976', 'FreeDiams::CA_HCDPD::DIN', 73358);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle And Back Pain Relief-8', 'tablet', 'M03BA53', false, 0, '02248977', 'FreeDiams::CA_HCDPD::DIN', 73359);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diorskin Pure Light Spf 15', 'emulsion', 'D02BA30', false, 0, '02248979', 'FreeDiams::CA_HCDPD::DIN', 73363);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ready Bath Antibacterial Total Body Cleansing System - Msc 095100', 'wipe', 'D08AJ01', false, 0, '02248988', 'FreeDiams::CA_HCDPD::DIN', 73373);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ready Bath Antibacterial Total Body Cleansing System - Msc 095101', 'wipe', 'D08AJ01', false, 0, '02248989', 'FreeDiams::CA_HCDPD::DIN', 73374);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ready Bath Antibacterial Total Body Cleansing System - Msc 095104', 'wipe', 'D08AJ01', false, 0, '02248990', 'FreeDiams::CA_HCDPD::DIN', 73375);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ready Bath Antibacterial Total Body Cleansing System - Msc 095105', 'wipe', 'D08AJ01', false, 0, '02248991', 'FreeDiams::CA_HCDPD::DIN', 73376);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zomig Nasal Spray', 'spray', 'N02CC03', false, 0, '02248992', 'FreeDiams::CA_HCDPD::DIN', 73377);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zomig Nasal Spray', 'spray', 'N02CC03', false, 0, '02248993', 'FreeDiams::CA_HCDPD::DIN', 73378);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diarrhea Relief', 'tablet', 'A07DA03', false, 0, '02248994', 'FreeDiams::CA_HCDPD::DIN', 73379);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zep Lemongrass Hand Soap - Antibacterial', 'liquid', 'D08AE04', false, 0, '02248998', 'FreeDiams::CA_HCDPD::DIN', 73383);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eligard 30 Mg', 'powder for suspension, sustained-release', 'L02AE02', false, 0, '02248999', 'FreeDiams::CA_HCDPD::DIN', 73384);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nutropin Aq Pen Cartridge', 'solution', 'H01AC01', false, 0, '02249002', 'FreeDiams::CA_HCDPD::DIN', 73387);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('6 Lait Solaire', 'lotion', 'D02BA02', false, 0, '02249022', 'FreeDiams::CA_HCDPD::DIN', 73389);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('6 Creme 410 Teintee', 'cream', 'D02BA02', false, 0, '02249049', 'FreeDiams::CA_HCDPD::DIN', 73391);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Replagal', 'solution', 'A16AB03', false, 0, '02249057', 'FreeDiams::CA_HCDPD::DIN', 73392);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Smartshield After Sun', 'gel', 'D04AB01', false, 0, '02249081', 'FreeDiams::CA_HCDPD::DIN', 73395);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ful - Trole 64', 'solution', 'V07AV', false, 0, '02249200', 'FreeDiams::CA_HCDPD::DIN', 73405);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Citalopram', 'tablet', 'N06AB04', false, 0, '02249278', 'FreeDiams::CA_HCDPD::DIN', 73411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Citalopram', 'tablet', 'N06AB04', false, 0, '02249286', 'FreeDiams::CA_HCDPD::DIN', 73412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Fluconazole', 'tablet', 'J02AC01', false, 0, '02249294', 'FreeDiams::CA_HCDPD::DIN', 73413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Fluconazole', 'tablet', 'J02AC01', false, 0, '02249308', 'FreeDiams::CA_HCDPD::DIN', 73414);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Methylphenidate', 'tablet', 'N06BA04', false, 0, '02249324', 'FreeDiams::CA_HCDPD::DIN', 73416);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Methylphenidate', 'tablet', 'N06BA04', false, 0, '02249332', 'FreeDiams::CA_HCDPD::DIN', 73417);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibacterial Lotion Soap', 'liquid', 'D08AE04', false, 0, '02249340', 'FreeDiams::CA_HCDPD::DIN', 73418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Cyclobenzaprine', 'tablet', 'M03BX08', false, 0, '02249359', 'FreeDiams::CA_HCDPD::DIN', 73419);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Activelle', 'tablet', 'G03FA01', false, 0, '02249405', 'FreeDiams::CA_HCDPD::DIN', 73420);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prevacid Fastab', 'tablet (delayed-release)', 'A02BC03', false, 0, '02249464', 'FreeDiams::CA_HCDPD::DIN', 73429);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prevacid Fastab', 'tablet (delayed-release)', 'A02BC03', false, 0, '02249472', 'FreeDiams::CA_HCDPD::DIN', 73430);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Androgel', 'gel', 'G03BA03', false, 0, '02249499', 'FreeDiams::CA_HCDPD::DIN', 73432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Midamor', 'tablet', 'C03DB01', false, 0, '02249510', 'FreeDiams::CA_HCDPD::DIN', 73433);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vital Sun Protection Spf 40', 'lotion', 'D02BA30', false, 0, '02249537', 'FreeDiams::CA_HCDPD::DIN', 73436);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flumazenil Injection', 'solution', 'V03AB25', false, 0, '02249561', 'FreeDiams::CA_HCDPD::DIN', 73439);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soft Care Foam Select', 'liquid', 'D08AE04', false, 0, '02249588', 'FreeDiams::CA_HCDPD::DIN', 73440);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pamidronate Disodium Omega 3 Mg/Ml', 'solution', 'M05BA03', false, 0, '02249669', 'FreeDiams::CA_HCDPD::DIN', 73447);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pamidronate Disodium Omega 6 Mg/Ml', 'solution', 'M05BA03', false, 0, '02249677', 'FreeDiams::CA_HCDPD::DIN', 73448);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pamidronate Disodium Omega 9 Mg/Ml', 'solution', 'M05BA03', false, 0, '02249685', 'FreeDiams::CA_HCDPD::DIN', 73449);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Pravastatin', 'tablet', 'C10AA03', false, 0, '02249723', 'FreeDiams::CA_HCDPD::DIN', 73456);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Pravastatin', 'tablet', 'C10AA03', false, 0, '02249731', 'FreeDiams::CA_HCDPD::DIN', 73457);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Pravastatin', 'tablet', 'C10AA03', false, 0, '02249758', 'FreeDiams::CA_HCDPD::DIN', 73458);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravastatin', 'tablet', 'C10AA03', false, 0, '02249766', 'FreeDiams::CA_HCDPD::DIN', 73459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravastatin', 'tablet', 'C10AA03', false, 0, '02249774', 'FreeDiams::CA_HCDPD::DIN', 73460);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravastatin', 'tablet', 'C10AA03', false, 0, '02249782', 'FreeDiams::CA_HCDPD::DIN', 73461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neulasta', 'solution', 'L03AA13', false, 0, '02249790', 'FreeDiams::CA_HCDPD::DIN', 73463);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Trazodone', 'tablet', 'N06AX05', false, 0, '02249804', 'FreeDiams::CA_HCDPD::DIN', 73464);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Verap Sr', 'tablet (extended-release)', 'C08DA01', false, 0, '02249812', 'FreeDiams::CA_HCDPD::DIN', 73465);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Milrinone Injectable', 'solution', 'C01CE02', false, 0, '02249820', 'FreeDiams::CA_HCDPD::DIN', 73466);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lemon Scented All Purpose Cleaner', 'liquid', 'V07AV', false, 0, '02249863', 'FreeDiams::CA_HCDPD::DIN', 73470);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorphone', 'tablet', 'N02AA03', false, 0, '02249928', 'FreeDiams::CA_HCDPD::DIN', 73474);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorphone', 'tablet', 'N02AA03', false, 0, '02249936', 'FreeDiams::CA_HCDPD::DIN', 73475);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fenomax', 'capsule', 'C10AB05', false, 0, '02250004', 'FreeDiams::CA_HCDPD::DIN', 73482);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Meloxicam Tablet 7.5 Mg', 'tablet', 'M01AC06', false, 0, '02250012', 'FreeDiams::CA_HCDPD::DIN', 73483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Meloxicam Tablet 15mg', 'tablet', 'M01AC06', false, 0, '02250020', 'FreeDiams::CA_HCDPD::DIN', 73484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Fenofibrate Mc', 'capsule', 'C10AB05', false, 0, '02250039', 'FreeDiams::CA_HCDPD::DIN', 73485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Dexamethasone', 'tablet', 'H02AB02', false, 0, '02250055', 'FreeDiams::CA_HCDPD::DIN', 73487);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nuderm Sunfader', 'cream', 'D11AX11', false, 0, '02250063', 'FreeDiams::CA_HCDPD::DIN', 73488);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elizabeth Arden Lip Protectant Stick Spf 15', 'stick', 'D02BA30', false, 0, '02250071', 'FreeDiams::CA_HCDPD::DIN', 73489);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Simvastatin', 'tablet', 'C10AA01', false, 0, '02250144', 'FreeDiams::CA_HCDPD::DIN', 73495);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Simvastatin', 'tablet', 'C10AA01', false, 0, '02250152', 'FreeDiams::CA_HCDPD::DIN', 73496);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Simvastatin', 'tablet', 'C10AA01', false, 0, '02250160', 'FreeDiams::CA_HCDPD::DIN', 73497);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Simvastatin', 'tablet', 'C10AA01', false, 0, '02250179', 'FreeDiams::CA_HCDPD::DIN', 73498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Simvastatin', 'tablet', 'C10AA01', false, 0, '02250187', 'FreeDiams::CA_HCDPD::DIN', 73499);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sudafed Pe Extra Strength', 'tablet', 'R01BA03', false, 0, '02250217', 'FreeDiams::CA_HCDPD::DIN', 73502);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Concerta', 'tablet (extended-release)', 'N06BA04', false, 0, '02250241', 'FreeDiams::CA_HCDPD::DIN', 73505);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone Sodium For Injection, Bp', 'powder for solution', 'J01DD04', false, 0, '02250276', 'FreeDiams::CA_HCDPD::DIN', 73507);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone Sodium For Injection, Bp', 'powder for solution', 'J01DD04', false, 0, '02250292', 'FreeDiams::CA_HCDPD::DIN', 73509);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone Sodium For Injection, Bp', 'powder for solution', 'J01DD04', false, 0, '02250306', 'FreeDiams::CA_HCDPD::DIN', 73510);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sween 24', 'cream', 'D02AA', false, 0, '02250322', 'FreeDiams::CA_HCDPD::DIN', 73513);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Comet Cleaner With Bleach', 'kit', 'V07AV', false, 0, '02250357', 'FreeDiams::CA_HCDPD::DIN', 73516);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterrad 50 Cassette', 'liquid', 'V07AV', false, 0, '02250365', 'FreeDiams::CA_HCDPD::DIN', 73517);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Render Iii Quaternary Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02250373', 'FreeDiams::CA_HCDPD::DIN', 73518);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clean & Clear Morning Glow Moisturizer Spf 15', 'cream', 'D02BA30', false, 0, '02250411', 'FreeDiams::CA_HCDPD::DIN', 73522);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levitra', 'tablet', 'G04BE09', false, 0, '02250462', 'FreeDiams::CA_HCDPD::DIN', 73526);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levitra', 'tablet', 'G04BE09', false, 0, '02250470', 'FreeDiams::CA_HCDPD::DIN', 73527);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levitra', 'tablet', 'G04BE09', false, 0, '02250489', 'FreeDiams::CA_HCDPD::DIN', 73528);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Amlodipine', 'tablet', 'C08CA01', false, 0, '02250497', 'FreeDiams::CA_HCDPD::DIN', 73529);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Amlodipine', 'tablet', 'C08CA01', false, 0, '02250500', 'FreeDiams::CA_HCDPD::DIN', 73530);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zavesca', 'capsule', 'A16AX06', false, 0, '02250519', 'FreeDiams::CA_HCDPD::DIN', 73533);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lescol Xl', 'tablet (extended-release)', 'C10AA04', false, 0, '02250527', 'FreeDiams::CA_HCDPD::DIN', 73534);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Penlac', 'solution', 'D01AE14', false, 0, '02250535', 'FreeDiams::CA_HCDPD::DIN', 73535);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle And Back Pain Relief - 8 Tablets', 'tablet', 'M03BA53', false, 0, '02250551', 'FreeDiams::CA_HCDPD::DIN', 73537);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Mirtazapine', 'tablet', 'N06AX11', false, 0, '02250594', 'FreeDiams::CA_HCDPD::DIN', 73540);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Mirtazapine', 'tablet', 'N06AX11', false, 0, '02250608', 'FreeDiams::CA_HCDPD::DIN', 73541);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Climara Pro', 'patch', 'G03FA11', false, 0, '02250616', 'FreeDiams::CA_HCDPD::DIN', 73542);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lacrisert', 'insert', 'S01XA20', false, 0, '02250624', 'FreeDiams::CA_HCDPD::DIN', 73543);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dandruff Shampoo', 'shampoo', 'D11AX12', false, 0, '02250632', 'FreeDiams::CA_HCDPD::DIN', 73544);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dandruff Shampoo', 'shampoo', 'D11AX12', false, 0, '02250640', 'FreeDiams::CA_HCDPD::DIN', 73545);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Hydro', 'tablet', 'C03AA03', false, 0, '02250659', 'FreeDiams::CA_HCDPD::DIN', 73546);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Hydro', 'tablet', 'C03AA03', false, 0, '02250667', 'FreeDiams::CA_HCDPD::DIN', 73547);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euro-Asa Chewable Tablet', 'tablet (chewable)', 'N02BA01', false, 0, '02250675', 'FreeDiams::CA_HCDPD::DIN', 73562);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advil Cold & Sinus Liqui-Gels', 'capsule', 'M01AE51', false, 0, '02250705', 'FreeDiams::CA_HCDPD::DIN', 73565);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Decongestant Nasal Spray', 'spray', 'R01AA07', false, 0, '02250845', 'FreeDiams::CA_HCDPD::DIN', 73579);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Decongestant Nasal Spray With Moisturizers', 'spray', 'R01AA07', false, 0, '02250853', 'FreeDiams::CA_HCDPD::DIN', 73580);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Long Lasting Nasal Mist', 'solution', 'R01AA05', false, 0, '02250861', 'FreeDiams::CA_HCDPD::DIN', 73581);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Phenytoin', 'suspension', 'N03AB02', false, 0, '02250896', 'FreeDiams::CA_HCDPD::DIN', 73583);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Positively Radiant Daily Moisturizer Spf 15', 'cream', 'D02BA30', false, 0, '02250942', 'FreeDiams::CA_HCDPD::DIN', 73587);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Winning Hands Premium Antibacterial Hand Cleaner', 'liquid', 'D08AE05', false, 0, '02250969', 'FreeDiams::CA_HCDPD::DIN', 73589);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Winning Hands Alcohol Free Hand Sanitizer', 'liquid', 'D08AJ08', false, 0, '02250977', 'FreeDiams::CA_HCDPD::DIN', 73590);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Winning Hands Foaming Antibacterial Hand Cleanser', 'liquid', 'D08AE04', false, 0, '02250985', 'FreeDiams::CA_HCDPD::DIN', 73591);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benadryl Total', 'tablet', 'N02BE51', false, 0, '02250993', 'FreeDiams::CA_HCDPD::DIN', 73592);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gojo Antibacterial Luxury Foam Handwash', 'liquid', 'D08AE05', false, 0, '02251094', 'FreeDiams::CA_HCDPD::DIN', 73604);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Continuum Sunscreen Spf 15', 'lotion', 'D02BA30', false, 0, '02251116', 'FreeDiams::CA_HCDPD::DIN', 73606);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Continuum Suncreen Spf 25', 'lotion', 'D02BA30', false, 0, '02251124', 'FreeDiams::CA_HCDPD::DIN', 73607);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('T/Gel Daily Control 2 In 1', 'shampoo', 'D11AX12', false, 0, '02251159', 'FreeDiams::CA_HCDPD::DIN', 73611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Gabapentin', 'capsule', 'N03AX12', false, 0, '02251167', 'FreeDiams::CA_HCDPD::DIN', 73612);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Gabapentin', 'capsule', 'N03AX12', false, 0, '02251175', 'FreeDiams::CA_HCDPD::DIN', 73613);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Gabapentin', 'capsule', 'N03AX12', false, 0, '02251183', 'FreeDiams::CA_HCDPD::DIN', 73614);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02251221', 'FreeDiams::CA_HCDPD::DIN', 73618);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02251248', 'FreeDiams::CA_HCDPD::DIN', 73619);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02251256', 'FreeDiams::CA_HCDPD::DIN', 73620);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02251272', 'FreeDiams::CA_HCDPD::DIN', 73622);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02251280', 'FreeDiams::CA_HCDPD::DIN', 73623);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02251299', 'FreeDiams::CA_HCDPD::DIN', 73624);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02251310', 'FreeDiams::CA_HCDPD::DIN', 73626);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02251329', 'FreeDiams::CA_HCDPD::DIN', 73627);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02251337', 'FreeDiams::CA_HCDPD::DIN', 73628);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Unica Biogerm', 'liquid', 'V07AV', false, 0, '02251388', 'FreeDiams::CA_HCDPD::DIN', 73631);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Swiffer Wetjet Antibacterial Floor Cleaner', 'liquid', 'V07AV', false, 0, '02251396', 'FreeDiams::CA_HCDPD::DIN', 73633);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Zopiclone', 'tablet', 'N05CF01', false, 0, '02251450', 'FreeDiams::CA_HCDPD::DIN', 73638);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Zopiclone', 'tablet', 'N05CF01', false, 0, '02251469', 'FreeDiams::CA_HCDPD::DIN', 73639);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baxedin 2% - 70%', 'solution', 'D08AC52', false, 0, '02251477', 'FreeDiams::CA_HCDPD::DIN', 73640);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ramipril', 'capsule', 'C09AA05', false, 0, '02251515', 'FreeDiams::CA_HCDPD::DIN', 73644);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ramipril', 'capsule', 'C09AA05', false, 0, '02251531', 'FreeDiams::CA_HCDPD::DIN', 73646);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Citalopram', 'tablet', 'N06AB04', false, 0, '02251558', 'FreeDiams::CA_HCDPD::DIN', 73647);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ramipril', 'capsule', 'C09AA05', false, 0, '02251574', 'FreeDiams::CA_HCDPD::DIN', 73648);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Citalopram', 'tablet', 'N06AB04', false, 0, '02251566', 'FreeDiams::CA_HCDPD::DIN', 73649);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ramipril', 'capsule', 'C09AA05', false, 0, '02251582', 'FreeDiams::CA_HCDPD::DIN', 73650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clairissime Clear Complexion Lotion', 'lotion', 'D11AX11', false, 0, '02251590', 'FreeDiams::CA_HCDPD::DIN', 73651);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gentle Fresh Defense', 'liquid', 'D08AE04', false, 0, '02251604', 'FreeDiams::CA_HCDPD::DIN', 73652);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Advanced Stop Signs Eye Preventive Cream Spf15', 'cream', 'D02BA30', false, 0, '02251620', 'FreeDiams::CA_HCDPD::DIN', 73654);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multi-Symptom Pms Relief Caplets', 'tablet', 'N02BE51', false, 0, '02251639', 'FreeDiams::CA_HCDPD::DIN', 73655);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle & Back Pain Relief Caplets', 'tablet', 'M03BA53', false, 0, '02251647', 'FreeDiams::CA_HCDPD::DIN', 73656);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carmex Lip Moisturizer With Sunscreen Spf 15', 'stick', 'D02BA30', false, 0, '02251655', 'FreeDiams::CA_HCDPD::DIN', 73657);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cipro Xl', 'tablet (extended-release)', 'J01MA02', false, 0, '02251787', 'FreeDiams::CA_HCDPD::DIN', 73669);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Repairwear Day Spf 15 Intensive Cream Very Dry Skin Formula', 'cream', 'D02BA30', false, 0, '02251833', 'FreeDiams::CA_HCDPD::DIN', 73674);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sani Cart Wipes', 'wipe', 'V07AV', false, 0, '02251841', 'FreeDiams::CA_HCDPD::DIN', 73675);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Genie Plus Wipes', 'wipe', 'V07AV', false, 0, '02251868', 'FreeDiams::CA_HCDPD::DIN', 73676);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle And Back Pain Relief Regular Strength Tablets', 'tablet', 'M03BA53', false, 0, '02251876', 'FreeDiams::CA_HCDPD::DIN', 73677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle And Back Pain Relief Extra Strength Tablets', 'tablet', 'M03BA53', false, 0, '02251884', 'FreeDiams::CA_HCDPD::DIN', 73678);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle Relaxant And Back Pain Relief Extra Strength Tablets', 'tablet', 'M03BA53', false, 0, '02251906', 'FreeDiams::CA_HCDPD::DIN', 73680);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen, Caffeine, And 8mg Of Codeine Phosphate Tablets', 'tablet', 'N02BE51', false, 0, '02251914', 'FreeDiams::CA_HCDPD::DIN', 73681);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lantus', 'solution', 'A10AE04', false, 0, '02251930', 'FreeDiams::CA_HCDPD::DIN', 73683);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Winning Hands Mild Antibacterial Cleaner', 'liquid', 'D08AE04', false, 0, '02251973', 'FreeDiams::CA_HCDPD::DIN', 73688);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hemorrhoid Ointment', 'ointment', 'C05AD07', false, 0, '02251981', 'FreeDiams::CA_HCDPD::DIN', 73689);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Risperidone', 'tablet', 'N05AX08', false, 0, '02252007', 'FreeDiams::CA_HCDPD::DIN', 73690);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Risperidone', 'tablet', 'N05AX08', false, 0, '02252015', 'FreeDiams::CA_HCDPD::DIN', 73691);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Risperidone', 'tablet', 'N05AX08', false, 0, '02252023', 'FreeDiams::CA_HCDPD::DIN', 73692);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Risperidone', 'tablet', 'N05AX08', false, 0, '02252031', 'FreeDiams::CA_HCDPD::DIN', 73693);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Risperidone', 'tablet', 'N05AX08', false, 0, '02252058', 'FreeDiams::CA_HCDPD::DIN', 73694);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Risperidone', 'tablet', 'N05AX08', false, 0, '02252066', 'FreeDiams::CA_HCDPD::DIN', 73695);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Citalopram', 'tablet', 'N06AB04', false, 0, '02252112', 'FreeDiams::CA_HCDPD::DIN', 73700);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Citalopram', 'tablet', 'N06AB04', false, 0, '02252120', 'FreeDiams::CA_HCDPD::DIN', 73701);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nighttime Cold Relief Extra Strength Tablets', 'tablet', 'N02BE51', false, 0, '02252139', 'FreeDiams::CA_HCDPD::DIN', 73702);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daytime Cold Relief Extra Strength Tablets', 'tablet', 'N02BE51', false, 0, '02252147', 'FreeDiams::CA_HCDPD::DIN', 73703);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy + Sinus Relief Extra Strength Tablets', 'tablet', 'N02BE51', false, 0, '02252155', 'FreeDiams::CA_HCDPD::DIN', 73704);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daytime Sinus Relief Extra Strength Tablets', 'tablet', 'N02BE51', false, 0, '02252163', 'FreeDiams::CA_HCDPD::DIN', 73705);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro Clear Antiseptic Solution', 'solution', 'D08AJ01', false, 0, '02252198', 'FreeDiams::CA_HCDPD::DIN', 73707);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle & Back Pain Asa 325 Mg Methocarbamol 400 Mg & Acetylsalicylic Acid 325 Mg', 'tablet', 'M03BA53', false, 0, '02252201', 'FreeDiams::CA_HCDPD::DIN', 73709);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Muscle & Back Pain Asa 500 Mg Methocarbamol 400 Mg & Acetylsalicylic Acid 500 Mg', 'tablet', 'M03BA53', false, 0, '02252228', 'FreeDiams::CA_HCDPD::DIN', 73710);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Metoprolol-L', 'tablet', 'C07AB02', false, 0, '02252252', 'FreeDiams::CA_HCDPD::DIN', 73713);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vigamox', 'solution', 'S01AX22', false, 0, '02252260', 'FreeDiams::CA_HCDPD::DIN', 73714);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mirtazapine', 'tablet', 'N06AX11', false, 0, '02252279', 'FreeDiams::CA_HCDPD::DIN', 73715);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Mirtazapine', 'tablet', 'N06AX11', false, 0, '02252287', 'FreeDiams::CA_HCDPD::DIN', 73716);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Carvedilol Tablets 3.125mg', 'tablet', 'C07AG02', false, 0, '02252309', 'FreeDiams::CA_HCDPD::DIN', 73718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Carvedilol Tablets 6.25mg', 'tablet', 'C07AG02', false, 0, '02252317', 'FreeDiams::CA_HCDPD::DIN', 73719);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Carvedilol Tablets 12.5mg', 'tablet', 'C07AG02', false, 0, '02252325', 'FreeDiams::CA_HCDPD::DIN', 73720);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Carvedilol Tablets 25mg', 'tablet', 'C07AG02', false, 0, '02252333', 'FreeDiams::CA_HCDPD::DIN', 73721);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quality Care Foaming Disinfectant Bathroom Cleaner', 'aerosol', 'V07AV', false, 0, '02252368', 'FreeDiams::CA_HCDPD::DIN', 73722);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Formula C', 'solution', 'V07AV', false, 0, '02252341', 'FreeDiams::CA_HCDPD::DIN', 73723);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin All-In-One Cold And Flu Night Extra Strength Syrup', 'syrup', 'N02BE51', false, 0, '02252376', 'FreeDiams::CA_HCDPD::DIN', 73724);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Unica Germi-10', 'liquid', 'V07AV', false, 0, '02252392', 'FreeDiams::CA_HCDPD::DIN', 73726);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robitussin Dm Coughgels Liqui-Gels Toux', 'capsule', 'R05DA09', false, 0, '02252554', 'FreeDiams::CA_HCDPD::DIN', 73742);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ofloxacin', 'solution', 'S01AX11', false, 0, '02252570', 'FreeDiams::CA_HCDPD::DIN', 73745);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Hydroxychloroquine', 'tablet', 'P01BA02', false, 0, '02252600', 'FreeDiams::CA_HCDPD::DIN', 73748);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Simvastatin', 'tablet', 'C10AA01', false, 0, '02252619', 'FreeDiams::CA_HCDPD::DIN', 73750);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Simvastatin', 'tablet', 'C10AA01', false, 0, '02252635', 'FreeDiams::CA_HCDPD::DIN', 73751);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Simvastatin', 'tablet', 'C10AA01', false, 0, '02252643', 'FreeDiams::CA_HCDPD::DIN', 73752);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Simvastatin', 'tablet', 'C10AA01', false, 0, '02252651', 'FreeDiams::CA_HCDPD::DIN', 73753);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Simvastatin', 'tablet', 'C10AA01', false, 0, '02252678', 'FreeDiams::CA_HCDPD::DIN', 73754);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avon Sun Spf 40 Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02252686', 'FreeDiams::CA_HCDPD::DIN', 73755);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avon Sun Kids Spf 40 Disappearing Color Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02252694', 'FreeDiams::CA_HCDPD::DIN', 73756);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ciprodex', 'suspension', 'S02CA06', false, 0, '02252716', 'FreeDiams::CA_HCDPD::DIN', 73758);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen 325mg Tablets Regular Strength', 'tablet', 'N02BE01', false, 0, '02252805', 'FreeDiams::CA_HCDPD::DIN', 73774);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen 500mg Tablets Extra Strength', 'tablet', 'N02BE01', false, 0, '02252813', 'FreeDiams::CA_HCDPD::DIN', 73775);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetylsalicylic Acid 325mg Tablets Usp', 'tablet', 'N02BA01', false, 0, '02252856', 'FreeDiams::CA_HCDPD::DIN', 73778);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetylsalicylic Acid Extra Strength 500mg Tablets Usp', 'tablet', 'N02BA01', false, 0, '02252864', 'FreeDiams::CA_HCDPD::DIN', 73779);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Anagrelide', 'capsule', 'L01XX35', false, 0, '02253054', 'FreeDiams::CA_HCDPD::DIN', 73797);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euro D 10000', 'capsule', 'A11CC05', false, 0, '02253178', 'FreeDiams::CA_HCDPD::DIN', 73813);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nuvaring', 'ring (slow-release)', 'G02BB01', false, 0, '02253186', 'FreeDiams::CA_HCDPD::DIN', 73815);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterrad Nx Cassette', 'liquid', 'V07AV', false, 0, '02253194', 'FreeDiams::CA_HCDPD::DIN', 73816);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anthelios Spray Spf 30', 'lotion', 'D02BA30', false, 0, '02253240', 'FreeDiams::CA_HCDPD::DIN', 73821);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gleevec', 'tablet', 'L01XE01', false, 0, '02253275', 'FreeDiams::CA_HCDPD::DIN', 73824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gleevec', 'tablet', 'L01XE01', false, 0, '02253283', 'FreeDiams::CA_HCDPD::DIN', 73825);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dormax', 'tablet', 'R06AA02', false, 0, '02253313', 'FreeDiams::CA_HCDPD::DIN', 73828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lanacane Anti-Bacterial First Aid Spray', 'spray', 'D04AB04', false, 0, '02253364', 'FreeDiams::CA_HCDPD::DIN', 73832);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Servicemaster Gliderinse 4', 'liquid', 'V07AV', false, 0, '02253402', 'FreeDiams::CA_HCDPD::DIN', 73838);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pegasys Rbv', 'kit', 'L03AB61', false, 0, '02253410', 'FreeDiams::CA_HCDPD::DIN', 73839);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pegasys Rbv', 'kit', 'L03AB61', false, 0, '02253429', 'FreeDiams::CA_HCDPD::DIN', 73840);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alimta', 'powder for solution', 'L01BA04', false, 0, '02253437', 'FreeDiams::CA_HCDPD::DIN', 73841);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoprolol-L', 'tablet', 'C07AB02', false, 0, '02253496', 'FreeDiams::CA_HCDPD::DIN', 73846);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoprolol-L', 'tablet', 'C07AB02', false, 0, '02253518', 'FreeDiams::CA_HCDPD::DIN', 73847);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoprolol-L', 'tablet', 'C07AB02', false, 0, '02253526', 'FreeDiams::CA_HCDPD::DIN', 73848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medroxy-2.5', 'tablet', 'G03DA02', false, 0, '02253550', 'FreeDiams::CA_HCDPD::DIN', 73852);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medroxy-5', 'tablet', 'G03DA02', false, 0, '02253577', 'FreeDiams::CA_HCDPD::DIN', 73853);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quanet', 'solution', 'V07AV', false, 0, '02253623', 'FreeDiams::CA_HCDPD::DIN', 73858);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teveten Plus', 'tablet', 'C09DA02', false, 0, '02253631', 'FreeDiams::CA_HCDPD::DIN', 73859);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Simvastatin', 'tablet', 'C10AA01', false, 0, '02253690', 'FreeDiams::CA_HCDPD::DIN', 73864);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Simvastatin', 'tablet', 'C10AA01', false, 0, '02253704', 'FreeDiams::CA_HCDPD::DIN', 73865);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Simvastatin', 'tablet', 'C10AA01', false, 0, '02253712', 'FreeDiams::CA_HCDPD::DIN', 73866);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Simvastatin', 'tablet', 'C10AA01', false, 0, '02253720', 'FreeDiams::CA_HCDPD::DIN', 73867);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Simvastatin', 'tablet', 'C10AA01', false, 0, '02253739', 'FreeDiams::CA_HCDPD::DIN', 73868);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Simvastatin', 'tablet', 'C10AA01', false, 0, '02253747', 'FreeDiams::CA_HCDPD::DIN', 73869);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Simvastatin', 'tablet', 'C10AA01', false, 0, '02253755', 'FreeDiams::CA_HCDPD::DIN', 73870);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Simvastatin', 'tablet', 'C10AA01', false, 0, '02253763', 'FreeDiams::CA_HCDPD::DIN', 73871);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Simvastatin', 'tablet', 'C10AA01', false, 0, '02253771', 'FreeDiams::CA_HCDPD::DIN', 73872);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Simvastatin', 'tablet', 'C10AA01', false, 0, '02253798', 'FreeDiams::CA_HCDPD::DIN', 73873);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Infanrix-Hexa', 'suspension', 'J07CA02', false, 0, '02253852', 'FreeDiams::CA_HCDPD::DIN', 73878);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Virkon Tablets', 'tablet (effervescent)', 'V07AV', false, 0, '02253917', 'FreeDiams::CA_HCDPD::DIN', 73885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ciprofloxacin 0.3%', 'solution', 'S01AX13', false, 0, '02253933', 'FreeDiams::CA_HCDPD::DIN', 73887);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bottom Butter', 'cream', 'D02AC', false, 0, '02253941', 'FreeDiams::CA_HCDPD::DIN', 73888);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Boston Simplus Multi-Action Solution', 'solution', 'S01XA20', false, 0, '02253992', 'FreeDiams::CA_HCDPD::DIN', 73892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('H2orange2 Concentrate 117', 'liquid', 'V07AV', false, 0, '02254018', 'FreeDiams::CA_HCDPD::DIN', 73893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('State Quicksan', 'liquid', 'V07AV', false, 0, '02254042', 'FreeDiams::CA_HCDPD::DIN', 73896);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Performance Moisturizer Spf 15', 'cream', 'D02BA30', false, 0, '02254077', 'FreeDiams::CA_HCDPD::DIN', 73900);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1230', 'solution', 'B05ZA', false, 0, '02254085', 'FreeDiams::CA_HCDPD::DIN', 73901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1243', 'solution', 'B05ZA', false, 0, '02254093', 'FreeDiams::CA_HCDPD::DIN', 73902);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1251', 'solution', 'B05ZA', false, 0, '02254107', 'FreeDiams::CA_HCDPD::DIN', 73903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1252', 'solution', 'B05ZA', false, 0, '02254115', 'FreeDiams::CA_HCDPD::DIN', 73904);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1255', 'solution', 'B05ZA', false, 0, '02254123', 'FreeDiams::CA_HCDPD::DIN', 73905);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1228', 'solution', 'B05ZA', false, 0, '02254239', 'FreeDiams::CA_HCDPD::DIN', 73915);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1227', 'solution', 'B05ZA', false, 0, '02254247', 'FreeDiams::CA_HCDPD::DIN', 73916);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1226', 'solution', 'B05ZA', false, 0, '02254255', 'FreeDiams::CA_HCDPD::DIN', 73917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Acet-Codeine 60', 'tablet', 'N02AA59', false, 0, '02254263', 'FreeDiams::CA_HCDPD::DIN', 73918);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1225', 'solution', 'B05ZA', false, 0, '02254298', 'FreeDiams::CA_HCDPD::DIN', 73919);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Acet-Codeine 30', 'tablet', 'N02AA59', false, 0, '02254271', 'FreeDiams::CA_HCDPD::DIN', 73920);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1224', 'solution', 'B05ZA', false, 0, '02254301', 'FreeDiams::CA_HCDPD::DIN', 73921);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1223', 'solution', 'B05ZA', false, 0, '02254328', 'FreeDiams::CA_HCDPD::DIN', 73922);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1222', 'solution', 'B05ZA', false, 0, '02254336', 'FreeDiams::CA_HCDPD::DIN', 73923);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1221', 'solution', 'B05ZA', false, 0, '02254344', 'FreeDiams::CA_HCDPD::DIN', 73924);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1241', 'solution', 'B05ZA', false, 0, '02254352', 'FreeDiams::CA_HCDPD::DIN', 73925);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1242', 'solution', 'B05ZA', false, 0, '02254379', 'FreeDiams::CA_HCDPD::DIN', 73927);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1231', 'solution', 'B05ZA', false, 0, '02254395', 'FreeDiams::CA_HCDPD::DIN', 73929);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gravol 100 Mg Long Acting Caplets', 'tablet (combined release)', 'R06AA02', false, 0, '02254409', 'FreeDiams::CA_HCDPD::DIN', 73930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neocitran Thin Strips Cough', 'lozenge', 'R05DA09', false, 0, '02254417', 'FreeDiams::CA_HCDPD::DIN', 73931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Thin Strips Cough & Runny Nose', 'strip', 'R06AA02', false, 0, '02254425', 'FreeDiams::CA_HCDPD::DIN', 73932);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neocitran Thin Strips Nighttime Cough', 'lozenge', 'R06AA02', false, 0, '02254433', 'FreeDiams::CA_HCDPD::DIN', 73933);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Thin Strips Cough', 'lozenge', 'R05DA09', false, 0, '02254441', 'FreeDiams::CA_HCDPD::DIN', 73934);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol Ultra Relief', 'tablet', 'N02BE51', false, 0, '02254468', 'FreeDiams::CA_HCDPD::DIN', 73935);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kogenate Fs', 'powder for solution', 'B02BD02', false, 0, '02254476', 'FreeDiams::CA_HCDPD::DIN', 73937);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kogenate Fs', 'powder for solution', 'B02BD02', false, 0, '02254484', 'FreeDiams::CA_HCDPD::DIN', 73938);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kogenate Fs', 'powder for solution', 'B02BD02', false, 0, '02254492', 'FreeDiams::CA_HCDPD::DIN', 73939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aldurazyme', 'solution', 'A16AB05', false, 0, '02254506', 'FreeDiams::CA_HCDPD::DIN', 73940);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pegetron', 'kit', 'L03AB60', false, 0, '02254581', 'FreeDiams::CA_HCDPD::DIN', 73948);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pegetron', 'kit', 'L03AB60', false, 0, '02254603', 'FreeDiams::CA_HCDPD::DIN', 73950);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pegetron', 'kit', 'L03AB60', false, 0, '02254638', 'FreeDiams::CA_HCDPD::DIN', 73951);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pegetron', 'kit', 'L03AB60', false, 0, '02254646', 'FreeDiams::CA_HCDPD::DIN', 73952);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soft Care Cross-Contamination Control Iv', 'lotion', 'D08AE04', false, 0, '02254670', 'FreeDiams::CA_HCDPD::DIN', 73982);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Forteo', 'solution', 'H05AA02', false, 0, '02254689', 'FreeDiams::CA_HCDPD::DIN', 73983);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Terbinafine', 'tablet', 'D01BA02', false, 0, '02254727', 'FreeDiams::CA_HCDPD::DIN', 73989);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxytrol', 'patch', 'G04BD04', false, 0, '02254735', 'FreeDiams::CA_HCDPD::DIN', 73990);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Paroxetine', 'tablet', 'N06AB05', false, 0, '02254751', 'FreeDiams::CA_HCDPD::DIN', 73992);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Paroxetine', 'tablet', 'N06AB05', false, 0, '02254778', 'FreeDiams::CA_HCDPD::DIN', 73993);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pico-Salax', 'powder for solution', 'A06AB58', false, 0, '02254794', 'FreeDiams::CA_HCDPD::DIN', 73995);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reliance Hld High Level Disinfectant', 'powder', 'V07AV', false, 0, '02254840', 'FreeDiams::CA_HCDPD::DIN', 74000);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Gemfibrozil', 'capsule', 'C10AB04', false, 0, '02254859', 'FreeDiams::CA_HCDPD::DIN', 74001);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Gemfibrozil', 'tablet', 'C10AB04', false, 0, '02254867', 'FreeDiams::CA_HCDPD::DIN', 74002);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avon Sun Sport Spf 30 Sunscreen Spray', 'spray', 'D02BA30', false, 0, '02254883', 'FreeDiams::CA_HCDPD::DIN', 74004);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daytime Liqua Caps', 'capsule', 'N02BE51', false, 0, '02254891', 'FreeDiams::CA_HCDPD::DIN', 74005);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nighttime Liqua Caps', 'capsule', 'N02BE51', false, 0, '02254913', 'FreeDiams::CA_HCDPD::DIN', 74007);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinus Medication Night Tablets', 'tablet', 'N02BE51', false, 0, '02255014', 'FreeDiams::CA_HCDPD::DIN', 74016);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sinus Medication Day Regular Tablets', 'tablet', 'N02BE51', false, 0, '02255022', 'FreeDiams::CA_HCDPD::DIN', 74017);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enviro Solutions 512 Sanitizer', 'solution', 'V07AV', false, 0, '02255154', 'FreeDiams::CA_HCDPD::DIN', 74028);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro Vive Spf 30', 'lotion', 'D02BA30', false, 0, '02255243', 'FreeDiams::CA_HCDPD::DIN', 74039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen 500 Mg Tablets Extra Strength Easy To Swallow', 'tablet', 'N02BE01', false, 0, '02255251', 'FreeDiams::CA_HCDPD::DIN', 74040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ramipril', 'capsule', 'C09AA05', false, 0, '02255316', 'FreeDiams::CA_HCDPD::DIN', 74047);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ramipril', 'capsule', 'C09AA05', false, 0, '02255324', 'FreeDiams::CA_HCDPD::DIN', 74048);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ramipril', 'capsule', 'C09AA05', false, 0, '02255332', 'FreeDiams::CA_HCDPD::DIN', 74051);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Azithromycin', 'tablet', 'J01FA10', false, 0, '02255340', 'FreeDiams::CA_HCDPD::DIN', 74052);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Loxapine', 'tablet', 'N05AH01', false, 0, '02255448', 'FreeDiams::CA_HCDPD::DIN', 74061);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Loxapine', 'solution', 'N05AH01', false, 0, '02255456', 'FreeDiams::CA_HCDPD::DIN', 74062);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spray Nine Bbq Grill Cleaner', 'solution', 'V07AV', false, 0, '02255480', 'FreeDiams::CA_HCDPD::DIN', 74065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marine Spray Nine Multi Purpose Cleaner', 'solution', 'V07AV', false, 0, '02255502', 'FreeDiams::CA_HCDPD::DIN', 74069);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Fluconazole', 'capsule', 'J02AC01', false, 0, '02255510', 'FreeDiams::CA_HCDPD::DIN', 74071);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Fluvoxamine', 'tablet', 'N06AB08', false, 0, '02255529', 'FreeDiams::CA_HCDPD::DIN', 74072);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Fluvoxamine', 'tablet', 'N06AB08', false, 0, '02255537', 'FreeDiams::CA_HCDPD::DIN', 74073);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Atenolol', 'tablet', 'C07AB03', false, 0, '02255545', 'FreeDiams::CA_HCDPD::DIN', 74074);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Atenolol', 'tablet', 'C07AB03', false, 0, '02255553', 'FreeDiams::CA_HCDPD::DIN', 74075);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shampooing 2 En 1 Antipelliculaire', 'shampoo', 'D11AX12', false, 0, '02255618', 'FreeDiams::CA_HCDPD::DIN', 74079);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperdal Consta', 'powder for suspension, sustained-release', 'N05AX08', false, 0, '02255707', 'FreeDiams::CA_HCDPD::DIN', 74089);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperdal Consta', 'powder for suspension, sustained-release', 'N05AX08', false, 0, '02255723', 'FreeDiams::CA_HCDPD::DIN', 74091);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperdal Consta', 'powder for suspension, sustained-release', 'N05AX08', false, 0, '02255758', 'FreeDiams::CA_HCDPD::DIN', 74093);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('I.C.E. Lidocaine Gel - Gel Lidocaine', 'gel', 'D04AB01', false, 0, '02255839', 'FreeDiams::CA_HCDPD::DIN', 74102);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Softlips Tints', 'ointment', 'D02BA30', false, 0, '02255871', 'FreeDiams::CA_HCDPD::DIN', 74106);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Gabapentin', 'tablet', 'N03AX12', false, 0, '02255898', 'FreeDiams::CA_HCDPD::DIN', 74111);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Gabapentin', 'tablet', 'N03AX12', false, 0, '02255901', 'FreeDiams::CA_HCDPD::DIN', 74112);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Steroxal 8.5', 'gas', 'V07AV', false, 0, '02255936', 'FreeDiams::CA_HCDPD::DIN', 74114);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fosinopril', 'tablet', 'C09AA09', false, 0, '02255944', 'FreeDiams::CA_HCDPD::DIN', 74116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fosinopril', 'tablet', 'C09AA09', false, 0, '02255952', 'FreeDiams::CA_HCDPD::DIN', 74117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Meloxicam', 'tablet', 'M01AC06', false, 0, '02255987', 'FreeDiams::CA_HCDPD::DIN', 74120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Meloxicam', 'tablet', 'M01AC06', false, 0, '02255995', 'FreeDiams::CA_HCDPD::DIN', 74121);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Azithromycin', 'tablet', 'J01FA10', false, 0, '02256088', 'FreeDiams::CA_HCDPD::DIN', 74132);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Mirtazapine', 'tablet', 'N06AX11', false, 0, '02256096', 'FreeDiams::CA_HCDPD::DIN', 74133);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Mirtazapine', 'tablet', 'N06AX11', false, 0, '02256118', 'FreeDiams::CA_HCDPD::DIN', 74134);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Mirtazapine', 'tablet', 'N06AX11', false, 0, '02256126', 'FreeDiams::CA_HCDPD::DIN', 74135);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Bisoprolol', 'tablet', 'C07AB07', false, 0, '02256134', 'FreeDiams::CA_HCDPD::DIN', 74136);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Gabapentin Capsules 100mg', 'capsule', 'N03AX12', false, 0, '02256142', 'FreeDiams::CA_HCDPD::DIN', 74137);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Gabapentin Capsules 300mg', 'capsule', 'N03AX12', false, 0, '02256150', 'FreeDiams::CA_HCDPD::DIN', 74138);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Gabapentin Capsules 400mg', 'capsule', 'N03AX12', false, 0, '02256169', 'FreeDiams::CA_HCDPD::DIN', 74139);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Bisoprolol', 'tablet', 'C07AB07', false, 0, '02256177', 'FreeDiams::CA_HCDPD::DIN', 74140);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cesamet', 'capsule', 'A04AD11', false, 0, '02256193', 'FreeDiams::CA_HCDPD::DIN', 74143);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermaguard', 'liquid', 'D08AJ01', false, 0, '02256215', 'FreeDiams::CA_HCDPD::DIN', 74145);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spectro Acnecare Vanishing Lotion For Sensitive Skin', 'lotion', 'D10AE01', false, 0, '02256223', 'FreeDiams::CA_HCDPD::DIN', 74146);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spectro Acnecare Deep Pore Vanishing Lotion', 'lotion', 'D10AE01', false, 0, '02256231', 'FreeDiams::CA_HCDPD::DIN', 74147);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Relpax', 'tablet', 'N02CC06', false, 0, '02256290', 'FreeDiams::CA_HCDPD::DIN', 74152);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Relpax', 'tablet', 'N02CC06', false, 0, '02256304', 'FreeDiams::CA_HCDPD::DIN', 74153);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clobex Shampoo', 'shampoo', 'D07AD01', false, 0, '02256371', 'FreeDiams::CA_HCDPD::DIN', 74161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clobex Lotion', 'lotion', 'D07AD01', false, 0, '02256398', 'FreeDiams::CA_HCDPD::DIN', 74162);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Sumatriptan', 'tablet', 'N02CC01', false, 0, '02256428', 'FreeDiams::CA_HCDPD::DIN', 74163);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Sumatriptan', 'tablet', 'N02CC01', false, 0, '02256436', 'FreeDiams::CA_HCDPD::DIN', 74164);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Sumatriptan', 'tablet', 'N02CC01', false, 0, '02256444', 'FreeDiams::CA_HCDPD::DIN', 74165);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diarrhea Relief', 'tablet', 'A07DA03', false, 0, '02256452', 'FreeDiams::CA_HCDPD::DIN', 74169);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vfend', 'tablet', 'J02AC03', false, 0, '02256460', 'FreeDiams::CA_HCDPD::DIN', 74170);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vfend', 'tablet', 'J02AC03', false, 0, '02256479', 'FreeDiams::CA_HCDPD::DIN', 74171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vfend For Injection', 'powder for solution', 'J02AC03', false, 0, '02256487', 'FreeDiams::CA_HCDPD::DIN', 74172);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Leflunomide', 'tablet', 'L04AA13', false, 0, '02256495', 'FreeDiams::CA_HCDPD::DIN', 74173);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Leflunomide', 'tablet', 'L04AA13', false, 0, '02256509', 'FreeDiams::CA_HCDPD::DIN', 74174);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunright Lip Balm Spf 15', 'ointment', 'D02BA30', false, 0, '02256517', 'FreeDiams::CA_HCDPD::DIN', 74176);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin All-In-One Cold And Flu Night Extra Strength', 'tablet', 'N02BE51', false, 0, '02256576', 'FreeDiams::CA_HCDPD::DIN', 74181);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ranitidine Injection Usp', 'solution', 'A02BA02', false, 0, '02256711', 'FreeDiams::CA_HCDPD::DIN', 74194);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tiazac Xc', 'tablet (extended-release)', 'C08DB01', false, 0, '02256738', 'FreeDiams::CA_HCDPD::DIN', 74195);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tiazac Xc', 'tablet (extended-release)', 'C08DB01', false, 0, '02256746', 'FreeDiams::CA_HCDPD::DIN', 74196);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tiazac Xc', 'tablet (extended-release)', 'C08DB01', false, 0, '02256754', 'FreeDiams::CA_HCDPD::DIN', 74197);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tiazac Xc', 'tablet (extended-release)', 'C08DB01', false, 0, '02256762', 'FreeDiams::CA_HCDPD::DIN', 74198);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tiazac Xc', 'tablet (extended-release)', 'C08DB01', false, 0, '02256770', 'FreeDiams::CA_HCDPD::DIN', 74199);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ciprofloxacin Injection Usp', 'solution', 'J01MA02', false, 0, '02256789', 'FreeDiams::CA_HCDPD::DIN', 74200);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Lisinopril P', 'tablet', 'C09AA03', false, 0, '02256797', 'FreeDiams::CA_HCDPD::DIN', 74203);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Lisinopril P', 'tablet', 'C09AA03', false, 0, '02256800', 'FreeDiams::CA_HCDPD::DIN', 74204);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Lisinopril P', 'tablet', 'C09AA03', false, 0, '02256819', 'FreeDiams::CA_HCDPD::DIN', 74205);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Topiramate', 'tablet', 'N03AX11', false, 0, '02256827', 'FreeDiams::CA_HCDPD::DIN', 74206);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Topiramate', 'tablet', 'N03AX11', false, 0, '02256835', 'FreeDiams::CA_HCDPD::DIN', 74207);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Topiramate', 'tablet', 'N03AX11', false, 0, '02256843', 'FreeDiams::CA_HCDPD::DIN', 74208);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Banana Boat Sunscreen Oil Spray Huile Ecran Solaire En Vaporisateur Spf Fps 15', 'spray', 'D02BA30', false, 0, '02256924', 'FreeDiams::CA_HCDPD::DIN', 74215);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydraphase Uv', 'cream', 'D02BA30', false, 0, '02256940', 'FreeDiams::CA_HCDPD::DIN', 74217);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proshield Plus', 'ointment', 'D02AA', false, 0, '02256975', 'FreeDiams::CA_HCDPD::DIN', 74220);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artistry Essential Hand Treatment Spf 15', 'cream', 'D02BA30', false, 0, '02257068', 'FreeDiams::CA_HCDPD::DIN', 74228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Continuum Unifying Lotion Ii', 'lotion', 'D11AX11', false, 0, '02257076', 'FreeDiams::CA_HCDPD::DIN', 74229);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Frova', 'tablet', 'N02CC07', false, 0, '02257084', 'FreeDiams::CA_HCDPD::DIN', 74230);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Pravastatin', 'tablet', 'C10AA03', false, 0, '02257092', 'FreeDiams::CA_HCDPD::DIN', 74231);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Pravastatin', 'tablet', 'C10AA03', false, 0, '02257106', 'FreeDiams::CA_HCDPD::DIN', 74232);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Pravastatin', 'tablet', 'C10AA03', false, 0, '02257114', 'FreeDiams::CA_HCDPD::DIN', 74233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sensipar', 'tablet', 'H05BX01', false, 0, '02257130', 'FreeDiams::CA_HCDPD::DIN', 74235);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sensipar', 'tablet', 'H05BX01', false, 0, '02257149', 'FreeDiams::CA_HCDPD::DIN', 74236);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sensipar', 'tablet', 'H05BX01', false, 0, '02257157', 'FreeDiams::CA_HCDPD::DIN', 74237);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Linessa 28', 'tablet', 'G03AB05', false, 0, '02257238', 'FreeDiams::CA_HCDPD::DIN', 74243);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisturizer Spf 15', 'lotion', 'D02BA30', false, 0, '02257246', 'FreeDiams::CA_HCDPD::DIN', 74244);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zymar', 'solution', 'S01AX21', false, 0, '02257270', 'FreeDiams::CA_HCDPD::DIN', 74247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Amilazide', 'tablet', 'C03EA01', false, 0, '02257378', 'FreeDiams::CA_HCDPD::DIN', 74257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soapy Sudz', 'liquid', 'D08AE04', false, 0, '02257424', 'FreeDiams::CA_HCDPD::DIN', 74262);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lipsorex Plus', 'gel', 'D04AB01', false, 0, '02257432', 'FreeDiams::CA_HCDPD::DIN', 74263);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Care Balm', 'ointment', 'D02BA30', false, 0, '02257483', 'FreeDiams::CA_HCDPD::DIN', 74271);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citalopram-20', 'tablet', 'N06AB04', false, 0, '02257513', 'FreeDiams::CA_HCDPD::DIN', 74277);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citalopram-40', 'tablet', 'N06AB04', false, 0, '02257521', 'FreeDiams::CA_HCDPD::DIN', 74278);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diphenhydramine Hydrochloride 25 Mg Caplet', 'tablet', 'R06AA02', false, 0, '02257548', 'FreeDiams::CA_HCDPD::DIN', 74279);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diphenhydramine Hydrochloride 50mg Caplet', 'tablet', 'R06AA02', false, 0, '02257556', 'FreeDiams::CA_HCDPD::DIN', 74280);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Loperamide', 'tablet', 'A07DA03', false, 0, '02257564', 'FreeDiams::CA_HCDPD::DIN', 74281);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Zopiclone', 'tablet', 'N05CF01', false, 0, '02257572', 'FreeDiams::CA_HCDPD::DIN', 74282);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Zopiclone', 'tablet', 'N05CF01', false, 0, '02257580', 'FreeDiams::CA_HCDPD::DIN', 74283);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Acebutolol', 'tablet', 'C07AB04', false, 0, '02257599', 'FreeDiams::CA_HCDPD::DIN', 74284);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Acebutolol', 'tablet', 'C07AB04', false, 0, '02257602', 'FreeDiams::CA_HCDPD::DIN', 74285);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Acebutolol', 'tablet', 'C07AB04', false, 0, '02257610', 'FreeDiams::CA_HCDPD::DIN', 74286);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desmopressin Tablets', 'tablet', 'H01BA02', false, 0, '02257696', 'FreeDiams::CA_HCDPD::DIN', 74293);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desmopressin Tablets', 'tablet', 'H01BA02', false, 0, '02257718', 'FreeDiams::CA_HCDPD::DIN', 74294);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Metformin, 500mg', 'tablet', 'A10BA02', false, 0, '02257726', 'FreeDiams::CA_HCDPD::DIN', 74296);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Metformin, 850mg', 'tablet', 'A10BA02', false, 0, '02257734', 'FreeDiams::CA_HCDPD::DIN', 74297);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Super Bowl', 'liquid', 'V07AV', false, 0, '02257742', 'FreeDiams::CA_HCDPD::DIN', 74298);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Foamy Sanz', 'solution', 'D08AJ08', false, 0, '02257750', 'FreeDiams::CA_HCDPD::DIN', 74299);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vinorelbine Tartrate For Injection', 'solution', 'L01CA04', false, 0, '02257777', 'FreeDiams::CA_HCDPD::DIN', 74301);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antacid Plus Extra Strength', 'liquid', 'A02AF02', false, 0, '02257807', 'FreeDiams::CA_HCDPD::DIN', 74304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Sotalol', 'tablet', 'C07AA07', false, 0, '02257831', 'FreeDiams::CA_HCDPD::DIN', 74307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Sotalol', 'tablet', 'C07AA07', false, 0, '02257858', 'FreeDiams::CA_HCDPD::DIN', 74308);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Sumatriptan', 'tablet', 'N02CC01', false, 0, '02257882', 'FreeDiams::CA_HCDPD::DIN', 74311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Sumatriptan', 'tablet', 'N02CC01', false, 0, '02257890', 'FreeDiams::CA_HCDPD::DIN', 74312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Sumatriptan', 'tablet', 'N02CC01', false, 0, '02257904', 'FreeDiams::CA_HCDPD::DIN', 74313);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ibuprofen 200 Mg', 'tablet', 'M01AE01', false, 0, '02257912', 'FreeDiams::CA_HCDPD::DIN', 74314);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pine Mist', 'solution', 'V07AV', false, 0, '02257939', 'FreeDiams::CA_HCDPD::DIN', 74316);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Force 5 Quaternary', 'solution', 'V07AV', false, 0, '02257947', 'FreeDiams::CA_HCDPD::DIN', 74317);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clarus', 'capsule', 'D10BA01', false, 0, '02257955', 'FreeDiams::CA_HCDPD::DIN', 74319);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clarus', 'capsule', 'D10BA01', false, 0, '02257963', 'FreeDiams::CA_HCDPD::DIN', 74320);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elizabeth Arden Ceramide Plump Perfect Lip Moisture Cream-Spf30', 'cream', 'D02BA30', false, 0, '02257971', 'FreeDiams::CA_HCDPD::DIN', 74321);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Gabapentin', 'tablet', 'N03AX12', false, 0, '02258005', 'FreeDiams::CA_HCDPD::DIN', 74324);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Gabapentin', 'tablet', 'N03AX12', false, 0, '02258013', 'FreeDiams::CA_HCDPD::DIN', 74325);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Leminee Disinfectant', 'solution', 'V07AV', false, 0, '02258021', 'FreeDiams::CA_HCDPD::DIN', 74326);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('A.P.R 15', 'cream', 'D04AB01', false, 0, '02258048', 'FreeDiams::CA_HCDPD::DIN', 74327);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arixtra', 'solution', 'B01AX05', false, 0, '02258056', 'FreeDiams::CA_HCDPD::DIN', 74328);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cough Syrup With Codeine', 'syrup', 'R05FA02', false, 0, '02258099', 'FreeDiams::CA_HCDPD::DIN', 74333);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Alendronate', 'tablet', 'M05BA04', false, 0, '02258102', 'FreeDiams::CA_HCDPD::DIN', 74334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Alendronate', 'tablet', 'M05BA04', false, 0, '02258110', 'FreeDiams::CA_HCDPD::DIN', 74335);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxycontin 5mg', 'tablet (extended-release)', 'N02AA05', false, 0, '02258129', 'FreeDiams::CA_HCDPD::DIN', 74336);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spirit Ii', 'liquid', 'V07AV', false, 0, '02258145', 'FreeDiams::CA_HCDPD::DIN', 74338);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ondansetron', 'tablet', 'A04AA01', false, 0, '02258188', 'FreeDiams::CA_HCDPD::DIN', 74341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ondansetron', 'tablet', 'A04AA01', false, 0, '02258196', 'FreeDiams::CA_HCDPD::DIN', 74342);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Irinotecan Hydrochloride Trihydrate For Injection', 'solution', 'L01XX19', false, 0, '02258218', 'FreeDiams::CA_HCDPD::DIN', 74343);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckeye Sanicare Tbx', 'liquid', 'V07AV', false, 0, '02258226', 'FreeDiams::CA_HCDPD::DIN', 74344);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Meloxicam', 'tablet', 'M01AC06', false, 0, '02258315', 'FreeDiams::CA_HCDPD::DIN', 74353);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Meloxicam', 'tablet', 'M01AC06', false, 0, '02258323', 'FreeDiams::CA_HCDPD::DIN', 74354);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Clindamycin', 'capsule', 'J01FF01', false, 0, '02258331', 'FreeDiams::CA_HCDPD::DIN', 74355);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Clindamycin', 'capsule', 'J01FF01', false, 0, '02258358', 'FreeDiams::CA_HCDPD::DIN', 74356);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydrafresh Gel-Creme Normal To Oily Skin', 'cream', 'D02BA30', false, 0, '02258366', 'FreeDiams::CA_HCDPD::DIN', 74357);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydrafresh Gel-Creme Normal To Dry Skin', 'cream', 'D02BA30', false, 0, '02258374', 'FreeDiams::CA_HCDPD::DIN', 74358);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Overnight Acne Control Lotion', 'lotion', 'D10AE01', false, 0, '02258382', 'FreeDiams::CA_HCDPD::DIN', 74359);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pyrithione Zinc Dandruff Shampoo Classic Clean', 'shampoo', 'D11AX12', false, 0, '02258404', 'FreeDiams::CA_HCDPD::DIN', 74361);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neostrata Oil Free Anti Aging Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02258420', 'FreeDiams::CA_HCDPD::DIN', 74363);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Risperidone', 'tablet', 'N05AX08', false, 0, '02258439', 'FreeDiams::CA_HCDPD::DIN', 74364);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Risperidone', 'tablet', 'N05AX08', false, 0, '02258447', 'FreeDiams::CA_HCDPD::DIN', 74365);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Risperidone', 'tablet', 'N05AX08', false, 0, '02258455', 'FreeDiams::CA_HCDPD::DIN', 74366);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Risperidone', 'tablet', 'N05AX08', false, 0, '02258463', 'FreeDiams::CA_HCDPD::DIN', 74367);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Risperidone', 'tablet', 'N05AX08', false, 0, '02258471', 'FreeDiams::CA_HCDPD::DIN', 74368);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Risperidone', 'tablet', 'N05AX08', false, 0, '02258498', 'FreeDiams::CA_HCDPD::DIN', 74369);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Edecrin', 'tablet', 'C03CC01', false, 0, '02258528', 'FreeDiams::CA_HCDPD::DIN', 74372);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tri-Cyclen Lo        (-21 Day)', 'tablet', 'G03AB11', false, 0, '02258560', 'FreeDiams::CA_HCDPD::DIN', 74376);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tri-Cyclen Lo        (28 Day)', 'tablet', 'G03AB11', false, 0, '02258587', 'FreeDiams::CA_HCDPD::DIN', 74378);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humira', 'solution', 'L04AB04', false, 0, '02258595', 'FreeDiams::CA_HCDPD::DIN', 74379);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Strattera', 'capsule', 'N06BA09', false, 0, '02262827', 'FreeDiams::CA_HCDPD::DIN', 74820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Preservative-Free Cosopt', 'solution', 'S01ED51', false, 0, '02258692', 'FreeDiams::CA_HCDPD::DIN', 74388);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Iodoform Packing Strip', 'strip', 'D09AA13', false, 0, '02258757', 'FreeDiams::CA_HCDPD::DIN', 74399);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Absolue Makeup', 'cream', 'D02BA02', false, 0, '02258862', 'FreeDiams::CA_HCDPD::DIN', 74408);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Renergie Lift Makeup', 'cream', 'D02BA30', false, 0, '02258897', 'FreeDiams::CA_HCDPD::DIN', 74412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('First Aid Antiseptic Skin Cleanser', 'liquid', 'D08AC02', false, 0, '02258900', 'FreeDiams::CA_HCDPD::DIN', 74413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daytime Cold & Flu Liquid Capsules', 'capsule', 'N02BE51', false, 0, '02258919', 'FreeDiams::CA_HCDPD::DIN', 74414);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nighttime Cold & Flu Liquid Capsules', 'capsule', 'N02BE51', false, 0, '02258927', 'FreeDiams::CA_HCDPD::DIN', 74415);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Methimazole', 'tablet', 'H03BB02', false, 0, '02258935', 'FreeDiams::CA_HCDPD::DIN', 74416);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Revlon Age Defying Make Up For Dry Skin', 'liquid', 'D02BA30', false, 0, '02259028', 'FreeDiams::CA_HCDPD::DIN', 74430);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cough And Chest Congestion Syrup', 'syrup', 'R05FA02', false, 0, '02259044', 'FreeDiams::CA_HCDPD::DIN', 74432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amevive', 'powder for solution', 'L04AA15', false, 0, '02259052', 'FreeDiams::CA_HCDPD::DIN', 74433);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Herbal Serenity Age Defying Hand Treatment Spf 15', 'cream', 'D02BA30', false, 0, '02259060', 'FreeDiams::CA_HCDPD::DIN', 74434);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Defense Uv', 'lotion', 'D02BA30', false, 0, '02259133', 'FreeDiams::CA_HCDPD::DIN', 74441);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nourifusion Multi-Vitamin Moisturizer Normal To Dry Spf 15', 'lotion', 'D02BA30', false, 0, '02259192', 'FreeDiams::CA_HCDPD::DIN', 74447);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nourifusion Multi-Vitamin Moisturizer Normal To Oily Spf 15', 'lotion', 'D02BA30', false, 0, '02259206', 'FreeDiams::CA_HCDPD::DIN', 74448);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun Shield Day Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02259273', 'FreeDiams::CA_HCDPD::DIN', 74455);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alyria Skin Optimizing System Corrective Protection Oil Free Spf 30 Lotion', 'lotion', 'D02BA30', false, 0, '02259311', 'FreeDiams::CA_HCDPD::DIN', 74458);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teint Lift Anti-Rides Fps20-Spf20', 'cream', 'D02BA02', false, 0, '02259338', 'FreeDiams::CA_HCDPD::DIN', 74459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Mirtazapine Tablets', 'tablet', 'N06AX11', false, 0, '02259354', 'FreeDiams::CA_HCDPD::DIN', 74461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Amlodipine Tablets 5mg', 'tablet', 'C08CA01', false, 0, '02259605', 'FreeDiams::CA_HCDPD::DIN', 74489);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Amlodipine Tablets 10mg', 'tablet', 'C08CA01', false, 0, '02259613', 'FreeDiams::CA_HCDPD::DIN', 74490);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('2030 Bio-Cidol Neutral Germicidal Detergent', 'liquid', 'V07AV', false, 0, '02259621', 'FreeDiams::CA_HCDPD::DIN', 74491);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baume Levres Anti-Dessechement Transparent Spf 30', 'stick', 'D02BA30', false, 0, '02259729', 'FreeDiams::CA_HCDPD::DIN', 74500);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Gabapentin', 'tablet', 'N03AX12', false, 0, '02259796', 'FreeDiams::CA_HCDPD::DIN', 74506);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Gabapentin', 'tablet', 'N03AX12', false, 0, '02259818', 'FreeDiams::CA_HCDPD::DIN', 74507);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Tizanidine', 'tablet', 'M03BX02', false, 0, '02259893', 'FreeDiams::CA_HCDPD::DIN', 74515);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hands2go', 'spray', 'D08AJ01', false, 0, '02259915', 'FreeDiams::CA_HCDPD::DIN', 74517);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Topiramate', 'tablet', 'N03AX11', false, 0, '02260050', 'FreeDiams::CA_HCDPD::DIN', 74529);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Topiramate', 'tablet', 'N03AX11', false, 0, '02260069', 'FreeDiams::CA_HCDPD::DIN', 74530);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Brimonidine', 'solution', 'S01EA05', false, 0, '02260077', 'FreeDiams::CA_HCDPD::DIN', 74531);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Anagrelide', 'capsule', 'L01XX35', false, 0, '02260107', 'FreeDiams::CA_HCDPD::DIN', 74534);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fantastik Disinfectant Toilet Bowl Cleaner', 'liquid', 'V07AV', false, 0, '02260123', 'FreeDiams::CA_HCDPD::DIN', 74536);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Bupropion Sr Tablets', 'tablet (extended-release)', 'N06AX12', false, 0, '02260239', 'FreeDiams::CA_HCDPD::DIN', 74546);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Calming Daily Moisturizer Spf 15', 'lotion', 'D02BA30', false, 0, '02260255', 'FreeDiams::CA_HCDPD::DIN', 74548);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daytime Cold And Flu Relief', 'capsule', 'N02BE51', false, 0, '02260263', 'FreeDiams::CA_HCDPD::DIN', 74549);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nighttime Cold And Flu Relief', 'capsule', 'N02BE51', false, 0, '02260271', 'FreeDiams::CA_HCDPD::DIN', 74550);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Dexamethasone', 'elixir', 'H02AB02', false, 0, '02260298', 'FreeDiams::CA_HCDPD::DIN', 74552);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Dexamethasone', 'liquid', 'H02AB02', false, 0, '02260301', 'FreeDiams::CA_HCDPD::DIN', 74553);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Age Defying Anti-Wrinkle - Daily Spf 15 Lotion', 'suspension', 'D02BA30', false, 0, '02260328', 'FreeDiams::CA_HCDPD::DIN', 74554);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synergize', 'solution', 'V07AV', false, 0, '02260336', 'FreeDiams::CA_HCDPD::DIN', 74558);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tinted Lip Conditioner Spf 15', 'ointment', 'D02BA30', false, 0, '02260344', 'FreeDiams::CA_HCDPD::DIN', 74559);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mac Lip Conditioner Stick Spf 15', 'stick', 'D02BA30', false, 0, '02260352', 'FreeDiams::CA_HCDPD::DIN', 74560);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eco Lips Lip Balm', 'stick', 'D02BA30', false, 0, '02260395', 'FreeDiams::CA_HCDPD::DIN', 74564);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Moisture Sheer Tint Spf 15', 'cream', 'D02BA30', false, 0, '02260484', 'FreeDiams::CA_HCDPD::DIN', 74589);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Conditioner Spf 15', 'gel', 'D02BA30', false, 0, '02260506', 'FreeDiams::CA_HCDPD::DIN', 74591);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Claritin Allergy + Sinus Extra Strength', 'tablet (extended-release)', 'R01BA52', false, 0, '02260557', 'FreeDiams::CA_HCDPD::DIN', 74601);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xolair', 'powder for solution', 'R03DX05', false, 0, '02260565', 'FreeDiams::CA_HCDPD::DIN', 74602);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ebixa', 'tablet', 'N06DX01', false, 0, '02260638', 'FreeDiams::CA_HCDPD::DIN', 74607);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zorcaine', 'solution', 'N01BB58', false, 0, '02260646', 'FreeDiams::CA_HCDPD::DIN', 74608);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Valproic Acid', 'capsule', 'N03AG01', false, 0, '02260654', 'FreeDiams::CA_HCDPD::DIN', 74609);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Valproic Acid E.C.', 'capsule (enteric-coated)', 'N03AG01', false, 0, '02260662', 'FreeDiams::CA_HCDPD::DIN', 74610);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Oxybutynin', 'tablet', 'G04BD04', false, 0, '02260751', 'FreeDiams::CA_HCDPD::DIN', 74619);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Oxybutynin', 'syrup', 'G04BD04', false, 0, '02260778', 'FreeDiams::CA_HCDPD::DIN', 74620);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Omeprazole 10mg', 'tablet (delayed-release)', 'A02BC01', false, 0, '02260859', 'FreeDiams::CA_HCDPD::DIN', 74628);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Omeprazole 20mg', 'tablet (delayed-release)', 'A02BC01', false, 0, '02260867', 'FreeDiams::CA_HCDPD::DIN', 74629);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Lip Balm', 'stick', 'D02BA30', false, 0, '02260875', 'FreeDiams::CA_HCDPD::DIN', 74630);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Gabapentin', 'capsule', 'N03AX12', false, 0, '02260883', 'FreeDiams::CA_HCDPD::DIN', 74631);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Gabapentin', 'capsule', 'N03AX12', false, 0, '02260891', 'FreeDiams::CA_HCDPD::DIN', 74632);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Gabapentin', 'capsule', 'N03AX12', false, 0, '02260905', 'FreeDiams::CA_HCDPD::DIN', 74633);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Gabapentin', 'tablet', 'N03AX12', false, 0, '02260913', 'FreeDiams::CA_HCDPD::DIN', 74634);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Gabapentin', 'tablet', 'N03AX12', false, 0, '02260921', 'FreeDiams::CA_HCDPD::DIN', 74635);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balance 1.5% Glucose, 1.25mmol/L Calcium', 'solution', 'B05DB', false, 0, '02261057', 'FreeDiams::CA_HCDPD::DIN', 74647);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balance 4.25% Glucose, 1.25mmol/L Calcium', 'solution', 'B05DB', false, 0, '02261065', 'FreeDiams::CA_HCDPD::DIN', 74648);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balance 2.3% Glucose, 1.25mmol/L Calcium', 'solution', 'B05DB', false, 0, '02261073', 'FreeDiams::CA_HCDPD::DIN', 74649);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Dexamethasone', 'tablet', 'H02AB02', false, 0, '02261081', 'FreeDiams::CA_HCDPD::DIN', 74650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soleil Expert Sun Care Spf 30 Face Creme', 'cream', 'D02BA30', false, 0, '02261103', 'FreeDiams::CA_HCDPD::DIN', 74651);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soleil Expert Sun Care Spf 25 Face And Body Lotion', 'lotion', 'D02BA30', false, 0, '02261146', 'FreeDiams::CA_HCDPD::DIN', 74654);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soleil Ultra Expert Sun Care Spf 40 Face And Body Lotion', 'lotion', 'D02BA30', false, 0, '02261154', 'FreeDiams::CA_HCDPD::DIN', 74655);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humate-P', 'powder for solution', 'B02BD06', false, 0, '02261219', 'FreeDiams::CA_HCDPD::DIN', 74661);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humate-P', 'powder for solution', 'B02BD06', false, 0, '02261227', 'FreeDiams::CA_HCDPD::DIN', 74662);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Humate-P', 'powder for solution', 'B02BD06', false, 0, '02261235', 'FreeDiams::CA_HCDPD::DIN', 74663);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Leflunomide', 'tablet', 'L04AA13', false, 0, '02261251', 'FreeDiams::CA_HCDPD::DIN', 74665);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Leflunomide', 'tablet', 'L04AA13', false, 0, '02261278', 'FreeDiams::CA_HCDPD::DIN', 74666);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dry Cough Syrup', 'syrup', 'R05DA09', false, 0, '02261294', 'FreeDiams::CA_HCDPD::DIN', 74668);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Salbutamol Oral Liquid', 'solution', 'R03CC02', false, 0, '02261324', 'FreeDiams::CA_HCDPD::DIN', 74671);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol Cough', 'liquid', 'N02BE51', false, 0, '02261448', 'FreeDiams::CA_HCDPD::DIN', 74683);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluconazole Injection', 'solution', 'J02AC01', false, 0, '02261472', 'FreeDiams::CA_HCDPD::DIN', 74685);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefotaxime Sodium For Injection, Bp', 'powder for solution', 'J01DD01', false, 0, '02261502', 'FreeDiams::CA_HCDPD::DIN', 74688);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefotaxime Sodium For Injection, Bp', 'powder for solution', 'J01DD01', false, 0, '02261510', 'FreeDiams::CA_HCDPD::DIN', 74689);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefotaxime Sodium For Injection, Bp', 'powder for solution', 'J01DD01', false, 0, '02261529', 'FreeDiams::CA_HCDPD::DIN', 74690);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('C.I. Formula 6-88', 'liquid', 'V07AV', false, 0, '02261537', 'FreeDiams::CA_HCDPD::DIN', 74691);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Telzir', 'tablet', 'J05AE07', false, 0, '02261545', 'FreeDiams::CA_HCDPD::DIN', 74692);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Telzir', 'suspension', 'J05AE07', false, 0, '02261553', 'FreeDiams::CA_HCDPD::DIN', 74693);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antacid Regular With Anti-Gas', 'liquid', 'A02AF02', false, 0, '02261588', 'FreeDiams::CA_HCDPD::DIN', 74696);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Azithromycin', 'tablet', 'J01FA10', false, 0, '02261634', 'FreeDiams::CA_HCDPD::DIN', 74701);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Azithromycin', 'tablet', 'J01FA10', false, 0, '02261642', 'FreeDiams::CA_HCDPD::DIN', 74702);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Sodium Polystyrene Sulfonate Powder', 'powder', 'V03AE01', false, 0, '02261677', 'FreeDiams::CA_HCDPD::DIN', 74705);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Alendronate', 'tablet', 'M05BA04', false, 0, '02261715', 'FreeDiams::CA_HCDPD::DIN', 74709);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Yasmin 21', 'tablet', 'G03AA12', false, 0, '02261723', 'FreeDiams::CA_HCDPD::DIN', 74710);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Yasmin 28', 'tablet', 'G03AA12', false, 0, '02261731', 'FreeDiams::CA_HCDPD::DIN', 74711);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz-Calcitonin Ns', 'liquid', 'H05BA01', false, 0, '02261766', 'FreeDiams::CA_HCDPD::DIN', 74713);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz-Diclofenac Rapide', 'tablet', 'M01AB05', false, 0, '02261774', 'FreeDiams::CA_HCDPD::DIN', 74714);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz-Pindolol', 'tablet', 'C07AA03', false, 0, '02261782', 'FreeDiams::CA_HCDPD::DIN', 74715);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz-Pindolol', 'tablet', 'C07AA03', false, 0, '02261790', 'FreeDiams::CA_HCDPD::DIN', 74716);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz-Pindolol', 'tablet', 'C07AA03', false, 0, '02261804', 'FreeDiams::CA_HCDPD::DIN', 74717);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz-Carbamazepine Cr', 'tablet (extended-release)', 'N03AF01', false, 0, '02261839', 'FreeDiams::CA_HCDPD::DIN', 74720);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz-Carbamazepine Cr', 'tablet (extended-release)', 'N03AF01', false, 0, '02261847', 'FreeDiams::CA_HCDPD::DIN', 74721);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz-Carbamazepine Chewtabs', 'tablet', 'N03AF01', false, 0, '02261855', 'FreeDiams::CA_HCDPD::DIN', 74722);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz-Carbamazepine Chewtabs', 'tablet', 'N03AF01', false, 0, '02261863', 'FreeDiams::CA_HCDPD::DIN', 74723);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz-Diclofenac Sr', 'tablet (extended-release)', 'M01AB05', false, 0, '02261901', 'FreeDiams::CA_HCDPD::DIN', 74726);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz-Diclofenac', 'suppository', 'M01AB05', false, 0, '02261928', 'FreeDiams::CA_HCDPD::DIN', 74727);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz-Diclofenac', 'suppository', 'M01AB05', false, 0, '02261936', 'FreeDiams::CA_HCDPD::DIN', 74728);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz-Diclofenac Sr', 'tablet (extended-release)', 'M01AB05', false, 0, '02261944', 'FreeDiams::CA_HCDPD::DIN', 74729);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz-Diclofenac', 'tablet (delayed-release)', 'M01AB05', false, 0, '02261952', 'FreeDiams::CA_HCDPD::DIN', 74730);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz-Diclofenac', 'tablet (delayed-release)', 'M01AB05', false, 0, '02261960', 'FreeDiams::CA_HCDPD::DIN', 74731);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lisinopril/Hctz', 'tablet', 'C09BA03', false, 0, '02261979', 'FreeDiams::CA_HCDPD::DIN', 74732);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lisinopril/Hctz', 'tablet', 'C09BA03', false, 0, '02261987', 'FreeDiams::CA_HCDPD::DIN', 74733);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lisinopril/Hctz', 'tablet', 'C09BA03', false, 0, '02261995', 'FreeDiams::CA_HCDPD::DIN', 74734);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creme Ecran Solaire', 'cream', 'D02BA30', false, 0, '02262002', 'FreeDiams::CA_HCDPD::DIN', 74735);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ovidrel', 'solution', 'G03GA08', false, 0, '02262088', 'FreeDiams::CA_HCDPD::DIN', 74742);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soleil Expert Sun Care Spf 15 Face And Body Lotion', 'lotion', 'D02BA30', false, 0, '02262134', 'FreeDiams::CA_HCDPD::DIN', 74749);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oraquat', 'liquid', 'V07AV', false, 0, '02262150', 'FreeDiams::CA_HCDPD::DIN', 74753);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz-Terbinafine', 'tablet', 'D01BA02', false, 0, '02262177', 'FreeDiams::CA_HCDPD::DIN', 74755);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Burn Relief Gel With Lidocaine', 'gel', 'D04AB01', false, 0, '02262215', 'FreeDiams::CA_HCDPD::DIN', 74760);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Niaspan', 'tablet (extended-release)', 'C10AD02', false, 0, '02262347', 'FreeDiams::CA_HCDPD::DIN', 74771);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Niaspan', 'tablet (extended-release)', 'C10AD02', false, 0, '02262355', 'FreeDiams::CA_HCDPD::DIN', 74772);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Niaspan', 'tablet (extended-release)', 'C10AD02', false, 0, '02262339', 'FreeDiams::CA_HCDPD::DIN', 74773);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stomak-Care Multi Action', 'suspension', 'A07BB', false, 0, '02262363', 'FreeDiams::CA_HCDPD::DIN', 74775);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Fosinopril', 'tablet', 'C09AA09', false, 0, '02262401', 'FreeDiams::CA_HCDPD::DIN', 74778);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Fosinopril', 'tablet', 'C09AA09', false, 0, '02262428', 'FreeDiams::CA_HCDPD::DIN', 74779);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Tryptophan', 'tablet', 'N06AX02', false, 0, '02262436', 'FreeDiams::CA_HCDPD::DIN', 74780);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Tryptophan', 'capsule', 'N06AX02', false, 0, '02262444', 'FreeDiams::CA_HCDPD::DIN', 74781);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Velcade', 'powder for solution', 'L01XX32', false, 0, '02262452', 'FreeDiams::CA_HCDPD::DIN', 74782);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1229', 'solution', 'B05ZA', false, 0, '02262460', 'FreeDiams::CA_HCDPD::DIN', 74785);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1262', 'solution', 'B05ZA', false, 0, '02262487', 'FreeDiams::CA_HCDPD::DIN', 74787);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1265', 'solution', 'B05ZA', false, 0, '02262517', 'FreeDiams::CA_HCDPD::DIN', 74790);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1266', 'solution', 'B05ZA', false, 0, '02262525', 'FreeDiams::CA_HCDPD::DIN', 74791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1267', 'solution', 'B05ZA', false, 0, '02262533', 'FreeDiams::CA_HCDPD::DIN', 74792);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1268', 'solution', 'B05ZA', false, 0, '02262541', 'FreeDiams::CA_HCDPD::DIN', 74793);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cold & Flu Relief Syrup', 'syrup', 'N02BE51', false, 0, '02262592', 'FreeDiams::CA_HCDPD::DIN', 74797);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dry Cough & Cold Syrup For Children', 'syrup', 'R05DA20', false, 0, '02262614', 'FreeDiams::CA_HCDPD::DIN', 74799);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Fluvoxamine', 'tablet', 'N06AB08', false, 0, '02262622', 'FreeDiams::CA_HCDPD::DIN', 74800);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Fluvoxamine', 'tablet', 'N06AB08', false, 0, '02262630', 'FreeDiams::CA_HCDPD::DIN', 74801);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Amantadine Syrup 10mg/Ml', 'syrup', 'N04BB01', false, 0, '02262649', 'FreeDiams::CA_HCDPD::DIN', 74802);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cesco 690', 'solution', 'V07AV', false, 0, '02262711', 'FreeDiams::CA_HCDPD::DIN', 74808);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Paroxetine', 'tablet', 'N06AB05', false, 0, '02262746', 'FreeDiams::CA_HCDPD::DIN', 74810);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Paroxetine', 'tablet', 'N06AB05', false, 0, '02262754', 'FreeDiams::CA_HCDPD::DIN', 74811);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Paroxetine', 'tablet', 'N06AB05', false, 0, '02262762', 'FreeDiams::CA_HCDPD::DIN', 74812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Strattera', 'capsule', 'N06BA09', false, 0, '02262800', 'FreeDiams::CA_HCDPD::DIN', 74816);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Strattera', 'capsule', 'N06BA09', false, 0, '02262819', 'FreeDiams::CA_HCDPD::DIN', 74817);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Strattera', 'capsule', 'N06BA09', false, 0, '02262835', 'FreeDiams::CA_HCDPD::DIN', 74822);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Strattera', 'capsule', 'N06BA09', false, 0, '02262843', 'FreeDiams::CA_HCDPD::DIN', 74823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Amoxicillin', 'capsule', 'J01CA04', false, 0, '02262851', 'FreeDiams::CA_HCDPD::DIN', 74824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Amoxicillin', 'capsule', 'J01CA04', false, 0, '02262878', 'FreeDiams::CA_HCDPD::DIN', 74827);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Amoxicillin', 'powder for suspension', 'J01CA04', false, 0, '02262886', 'FreeDiams::CA_HCDPD::DIN', 74828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Amoxicillin', 'powder for suspension', 'J01CA04', false, 0, '02262894', 'FreeDiams::CA_HCDPD::DIN', 74829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Buspirone', 'tablet', 'N05BE01', false, 0, '02262916', 'FreeDiams::CA_HCDPD::DIN', 74832);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Terbinafine', 'tablet', 'D01BA02', false, 0, '02262924', 'FreeDiams::CA_HCDPD::DIN', 74833);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Supeudol', 'tablet', 'N02AA05', false, 0, '02262983', 'FreeDiams::CA_HCDPD::DIN', 74839);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Topiramate', 'tablet', 'N03AX11', false, 0, '02262991', 'FreeDiams::CA_HCDPD::DIN', 74840);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Topiramate', 'tablet', 'N03AX11', false, 0, '02263009', 'FreeDiams::CA_HCDPD::DIN', 74841);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Topiramate', 'tablet', 'N03AX11', false, 0, '02263017', 'FreeDiams::CA_HCDPD::DIN', 74842);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Sumatriptan', 'tablet', 'N02CC01', false, 0, '02263025', 'FreeDiams::CA_HCDPD::DIN', 74843);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Sumatriptan', 'tablet', 'N02CC01', false, 0, '02263033', 'FreeDiams::CA_HCDPD::DIN', 74844);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Spray 30 Spf', 'lotion', 'D02BA30', false, 0, '02263084', 'FreeDiams::CA_HCDPD::DIN', 74849);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chest Congestion, Cough & Cold Syrup', 'syrup', 'R05FB02', false, 0, '02263114', 'FreeDiams::CA_HCDPD::DIN', 74852);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chest Congestion, Cough & Cold Syrup Extra Strength', 'syrup', 'R05FB02', false, 0, '02263122', 'FreeDiams::CA_HCDPD::DIN', 74853);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ciproflox', 'solution', 'S01AX13', false, 0, '02263130', 'FreeDiams::CA_HCDPD::DIN', 74854);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cipralex   -10mg', 'tablet', 'N06AB10', false, 0, '02263238', 'FreeDiams::CA_HCDPD::DIN', 74862);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cipralex   -20mg', 'tablet', 'N06AB10', false, 0, '02263254', 'FreeDiams::CA_HCDPD::DIN', 74864);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Topiramate', 'tablet', 'N03AX11', false, 0, '02263351', 'FreeDiams::CA_HCDPD::DIN', 74874);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Topiramate', 'tablet', 'N03AX11', false, 0, '02263378', 'FreeDiams::CA_HCDPD::DIN', 74875);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Topiramate', 'tablet', 'N03AX11', false, 0, '02263386', 'FreeDiams::CA_HCDPD::DIN', 74876);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Skinceuticals Uv Defense Spf 30', 'cream', 'D02BA30', false, 0, '02263424', 'FreeDiams::CA_HCDPD::DIN', 74880);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Travel Tabs', 'tablet', 'R06AA02', false, 0, '02263432', 'FreeDiams::CA_HCDPD::DIN', 74882);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Lotion 15 Spf', 'lotion', 'D02BA30', false, 0, '02263440', 'FreeDiams::CA_HCDPD::DIN', 74883);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Lotion 30 Spf', 'lotion', 'D02BA30', false, 0, '02263459', 'FreeDiams::CA_HCDPD::DIN', 74884);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Lotion 45 Spf', 'lotion', 'D02BA30', false, 0, '02263467', 'FreeDiams::CA_HCDPD::DIN', 74885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bac-Stop', 'liquid', 'V07AV', false, 0, '02263483', 'FreeDiams::CA_HCDPD::DIN', 74887);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Performance Sunscreen Spf 45 Cream', 'cream', 'D02BA30', false, 0, '02263769', 'FreeDiams::CA_HCDPD::DIN', 74916);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avon Sun Age Defying Spf 30 Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02263785', 'FreeDiams::CA_HCDPD::DIN', 74918);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pediaphen Children''S Acetaminophen Oral Solution Usp Drops 80mg/Ml', 'solution', 'N02BE01', false, 0, '02263793', 'FreeDiams::CA_HCDPD::DIN', 74919);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pediaphen 80mg/5ml', 'solution', 'N02BE01', false, 0, '02263807', 'FreeDiams::CA_HCDPD::DIN', 74920);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pediaphen Children''S Acetaminophen Chewable Tablets Usp 80mg/Tablet', 'tablet', 'N02BE01', false, 0, '02263815', 'FreeDiams::CA_HCDPD::DIN', 74921);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pediaphen Children''S Acetaminophen Chewable Tablets Usp 160mg/Tablet', 'tablet (chewable)', 'N02BE01', false, 0, '02263823', 'FreeDiams::CA_HCDPD::DIN', 74922);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pediaphen Children''S Acetaminophen Oral Solution Usp 160mg/5ml', 'solution', 'N02BE01', false, 0, '02263831', 'FreeDiams::CA_HCDPD::DIN', 74923);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dial Complete With Lotion Antibacterial Foaming Hand Wash', 'solution', 'D08AE04', false, 0, '02263858', 'FreeDiams::CA_HCDPD::DIN', 74924);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Etidrocal', 'tablet', 'M05BB01', false, 0, '02263866', 'FreeDiams::CA_HCDPD::DIN', 74925);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methacholine Omega', 'powder for solution', 'V04CX', false, 0, '02263890', 'FreeDiams::CA_HCDPD::DIN', 74930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methacholine Omega', 'powder for solution', 'V04CX', false, 0, '02263904', 'FreeDiams::CA_HCDPD::DIN', 74931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methacholine Omega', 'powder for solution', 'V04CX', false, 0, '02263912', 'FreeDiams::CA_HCDPD::DIN', 74932);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Strepsils Extra Black Cherry', 'lozenge', 'R02AA12', false, 0, '02263998', 'FreeDiams::CA_HCDPD::DIN', 74940);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multi Action 5', 'liquid', 'V07AV', false, 0, '02264021', 'FreeDiams::CA_HCDPD::DIN', 74943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Ondansetron', 'tablet', 'A04AA01', false, 0, '02264056', 'FreeDiams::CA_HCDPD::DIN', 74947);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Ondansetron', 'tablet', 'A04AA01', false, 0, '02264064', 'FreeDiams::CA_HCDPD::DIN', 74948);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alpha Dyne Plus', 'aerosol', 'V07AV', false, 0, '02264072', 'FreeDiams::CA_HCDPD::DIN', 74949);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Canesten Combi-Pak Comfortab 3', 'kit', 'G01AF02', false, 0, '02264099', 'FreeDiams::CA_HCDPD::DIN', 74951);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Canesten Combi-Pak Comfortab 1', 'kit', 'G01AF02', false, 0, '02264102', 'FreeDiams::CA_HCDPD::DIN', 74952);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prescriptives Flawless Skin Total Protection Makeup Spf 15', 'liquid', 'D02BA30', false, 0, '02264137', 'FreeDiams::CA_HCDPD::DIN', 74955);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Risperidone', 'tablet', 'N05AX08', false, 0, '02264188', 'FreeDiams::CA_HCDPD::DIN', 74961);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Risperidone', 'tablet', 'N05AX08', false, 0, '02264196', 'FreeDiams::CA_HCDPD::DIN', 74963);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Risperidone', 'tablet', 'N05AX08', false, 0, '02264218', 'FreeDiams::CA_HCDPD::DIN', 74964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Risperidone', 'tablet', 'N05AX08', false, 0, '02264226', 'FreeDiams::CA_HCDPD::DIN', 74965);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Risperidone', 'tablet', 'N05AX08', false, 0, '02264234', 'FreeDiams::CA_HCDPD::DIN', 74966);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('30 Spf Fps Kids High Protection Sunscreen', 'lotion', 'D02BA30', false, 0, '02264242', 'FreeDiams::CA_HCDPD::DIN', 74967);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('15 Spf Fps Premium Sunscreen', 'lotion', 'D02BA30', false, 0, '02264250', 'FreeDiams::CA_HCDPD::DIN', 74968);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('45 Spf Fps High Protection Sunscreen', 'lotion', 'D02BA30', false, 0, '02264269', 'FreeDiams::CA_HCDPD::DIN', 74969);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('30 Spf Fps High Protection Sunscreen', 'lotion', 'D02BA30', false, 0, '02264277', 'FreeDiams::CA_HCDPD::DIN', 74970);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Sodium Injection, Usp', 'solution', 'B01AB01', false, 0, '02264307', 'FreeDiams::CA_HCDPD::DIN', 74973);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Sodium Injection, Usp', 'solution', 'B01AB01', false, 0, '02264315', 'FreeDiams::CA_HCDPD::DIN', 74976);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euthyrox', 'tablet', 'H03AA01', false, 0, '02264323', 'FreeDiams::CA_HCDPD::DIN', 74978);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euthyrox', 'tablet', 'H03AA01', false, 0, '02264331', 'FreeDiams::CA_HCDPD::DIN', 74979);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euthyrox', 'tablet', 'H03AA01', false, 0, '02264358', 'FreeDiams::CA_HCDPD::DIN', 74980);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euthyrox', 'tablet', 'H03AA01', false, 0, '02264366', 'FreeDiams::CA_HCDPD::DIN', 74981);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euthyrox', 'tablet', 'H03AA01', false, 0, '02264374', 'FreeDiams::CA_HCDPD::DIN', 74982);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euthyrox', 'tablet', 'H03AA01', false, 0, '02264390', 'FreeDiams::CA_HCDPD::DIN', 74984);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euthyrox', 'tablet', 'H03AA01', false, 0, '02264404', 'FreeDiams::CA_HCDPD::DIN', 74985);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euthyrox', 'tablet', 'H03AA01', false, 0, '02264412', 'FreeDiams::CA_HCDPD::DIN', 74986);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euthyrox', 'tablet', 'H03AA01', false, 0, '02264420', 'FreeDiams::CA_HCDPD::DIN', 74987);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euthyrox', 'tablet', 'H03AA01', false, 0, '02264439', 'FreeDiams::CA_HCDPD::DIN', 74988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euthyrox', 'tablet', 'H03AA01', false, 0, '02264447', 'FreeDiams::CA_HCDPD::DIN', 74989);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euthyrox', 'tablet', 'H03AA01', false, 0, '02264455', 'FreeDiams::CA_HCDPD::DIN', 74991);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tri-Phasic White Day Milk Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02264463', 'FreeDiams::CA_HCDPD::DIN', 74992);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('30 Spf Oil Free', 'lotion', 'D02BA30', false, 0, '02264544', 'FreeDiams::CA_HCDPD::DIN', 74998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kids 45 Spf Sunscreen Spray', 'lotion', 'D02BA30', false, 0, '02264552', 'FreeDiams::CA_HCDPD::DIN', 74999);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Myfortic', 'tablet (enteric-coated)', 'L04AA06', false, 0, '02264560', 'FreeDiams::CA_HCDPD::DIN', 75000);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Myfortic', 'tablet (enteric-coated)', 'L04AA06', false, 0, '02264579', 'FreeDiams::CA_HCDPD::DIN', 75001);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fsme-Immun', 'suspension', 'J07BA01', false, 0, '02264625', 'FreeDiams::CA_HCDPD::DIN', 75009);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Retin-A Micro', 'gel', 'D10AD01', false, 0, '02264633', 'FreeDiams::CA_HCDPD::DIN', 75010);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Lotion Trčs Douce', 'lotion', 'D02BA30', false, 0, '02264668', 'FreeDiams::CA_HCDPD::DIN', 75015);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enteric Coated A.S.A', 'tablet (delayed-release)', 'N02BA01', false, 0, '02264706', 'FreeDiams::CA_HCDPD::DIN', 75019);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enteric Coated A.S.A', 'tablet (delayed-release)', 'N02BA01', false, 0, '02264722', 'FreeDiams::CA_HCDPD::DIN', 75021);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Mometasone Ointment', 'ointment', 'D07AC13', false, 0, '02264749', 'FreeDiams::CA_HCDPD::DIN', 75025);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Risperidone', 'tablet', 'N05AX08', false, 0, '02264757', 'FreeDiams::CA_HCDPD::DIN', 75026);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Risperidone', 'tablet', 'N05AX08', false, 0, '02264765', 'FreeDiams::CA_HCDPD::DIN', 75027);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Risperidone', 'tablet', 'N05AX08', false, 0, '02264773', 'FreeDiams::CA_HCDPD::DIN', 75028);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Risperidone', 'tablet', 'N05AX08', false, 0, '02264781', 'FreeDiams::CA_HCDPD::DIN', 75029);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Risperidone', 'tablet', 'N05AX08', false, 0, '02264803', 'FreeDiams::CA_HCDPD::DIN', 75030);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Risperidone', 'tablet', 'N05AX08', false, 0, '02264811', 'FreeDiams::CA_HCDPD::DIN', 75031);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tramacet', 'tablet', 'N02AX52', false, 0, '02264846', 'FreeDiams::CA_HCDPD::DIN', 75035);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Headache Relief', 'tablet', 'N02BE51', false, 0, '02264870', 'FreeDiams::CA_HCDPD::DIN', 75038);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisturizing Antibacterial Hand Cleanser', 'gel', 'D08AE04', false, 0, '02264889', 'FreeDiams::CA_HCDPD::DIN', 75039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Septiline Ii Antimicrobial Lotion Soap', 'lotion', 'D08AE05', false, 0, '02264897', 'FreeDiams::CA_HCDPD::DIN', 75040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epirubicin Hydrochloride Injection', 'solution', 'L01DB03', false, 0, '02264927', 'FreeDiams::CA_HCDPD::DIN', 75043);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Malarone Pediatric', 'tablet', 'P01BB51', false, 0, '02264935', 'FreeDiams::CA_HCDPD::DIN', 75044);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pamidronate Disodium For Injection', 'solution', 'M05BA03', false, 0, '02264951', 'FreeDiams::CA_HCDPD::DIN', 75046);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pamidronate Disodium For Injection', 'solution', 'M05BA03', false, 0, '02264978', 'FreeDiams::CA_HCDPD::DIN', 75047);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pamidronate Disodium For Injection', 'solution', 'M05BA03', false, 0, '02264986', 'FreeDiams::CA_HCDPD::DIN', 75048);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aquasource Levres Spf 8', 'cream', 'D02BA02', false, 0, '02265125', 'FreeDiams::CA_HCDPD::DIN', 75061);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Divalproex', 'tablet (delayed-release)', 'N03AG01', false, 0, '02265133', 'FreeDiams::CA_HCDPD::DIN', 75063);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Divalproex', 'tablet (delayed-release)', 'N03AG01', false, 0, '02265141', 'FreeDiams::CA_HCDPD::DIN', 75064);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Divalproex', 'tablet (delayed-release)', 'N03AG01', false, 0, '02265168', 'FreeDiams::CA_HCDPD::DIN', 75065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Mirtazapine', 'tablet', 'N06AX11', false, 0, '02265265', 'FreeDiams::CA_HCDPD::DIN', 75075);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Warfarin', 'tablet', 'B01AA03', false, 0, '02265273', 'FreeDiams::CA_HCDPD::DIN', 75076);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Warfarin', 'tablet', 'B01AA03', false, 0, '02265281', 'FreeDiams::CA_HCDPD::DIN', 75077);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Warfarin', 'tablet', 'B01AA03', false, 0, '02265303', 'FreeDiams::CA_HCDPD::DIN', 75078);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Warfarin', 'tablet', 'B01AA03', false, 0, '02265311', 'FreeDiams::CA_HCDPD::DIN', 75079);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Warfarin', 'tablet', 'B01AA03', false, 0, '02265338', 'FreeDiams::CA_HCDPD::DIN', 75080);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Warfarin', 'tablet', 'B01AA03', false, 0, '02265346', 'FreeDiams::CA_HCDPD::DIN', 75081);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Dm-D-E Extra Strength Cough And Cold', 'syrup', 'R05FA02', false, 0, '02265400', 'FreeDiams::CA_HCDPD::DIN', 75087);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Dm-E Menthol Extra Strength Cough And Chest Congestion', 'syrup', 'R05FA02', false, 0, '02265419', 'FreeDiams::CA_HCDPD::DIN', 75088);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin E Menthol Extra Strength', 'syrup', 'R05CA03', false, 0, '02265427', 'FreeDiams::CA_HCDPD::DIN', 75089);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novomix 30       (Penfill Cartridge)', 'suspension', 'A10AD05', false, 0, '02265435', 'FreeDiams::CA_HCDPD::DIN', 75090);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Lamotrigine', 'tablet', 'N03AX09', false, 0, '02265494', 'FreeDiams::CA_HCDPD::DIN', 75095);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Lamotrigine', 'tablet', 'N03AX09', false, 0, '02265508', 'FreeDiams::CA_HCDPD::DIN', 75096);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Lamotrigine', 'tablet', 'N03AX09', false, 0, '02265516', 'FreeDiams::CA_HCDPD::DIN', 75097);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ondansetron Injection     -(Preservative-Free)', 'solution', 'A04AA01', false, 0, '02265524', 'FreeDiams::CA_HCDPD::DIN', 75098);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ondansetron Injection     -(With Preservative)', 'solution', 'A04AA01', false, 0, '02265532', 'FreeDiams::CA_HCDPD::DIN', 75099);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crestor - 5mg', 'tablet', 'C10AA07', false, 0, '02265540', 'FreeDiams::CA_HCDPD::DIN', 75100);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlorpheniramine Maleate 4mg Tablet', 'tablet', 'R06AB04', false, 0, '02265559', 'FreeDiams::CA_HCDPD::DIN', 75101);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Hypochlorite 12%', 'solution', 'V07AV', false, 0, '02265729', 'FreeDiams::CA_HCDPD::DIN', 75117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kilphor Plus', 'liquid', 'V07AV', false, 0, '02265737', 'FreeDiams::CA_HCDPD::DIN', 75118);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alviral', 'powder', 'V07AV', false, 0, '02265745', 'FreeDiams::CA_HCDPD::DIN', 75119);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Azithromycin', 'tablet', 'J01FA10', false, 0, '02265826', 'FreeDiams::CA_HCDPD::DIN', 75127);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Simvastatin', 'tablet', 'C10AA01', false, 0, '02265885', 'FreeDiams::CA_HCDPD::DIN', 75133);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Simvastatin', 'tablet', 'C10AA01', false, 0, '02265893', 'FreeDiams::CA_HCDPD::DIN', 75134);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Simvastatin', 'tablet', 'C10AA01', false, 0, '02265907', 'FreeDiams::CA_HCDPD::DIN', 75135);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Fosinopril', 'tablet', 'C09AA09', false, 0, '02265923', 'FreeDiams::CA_HCDPD::DIN', 75137);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Fosinopril', 'tablet', 'C09AA09', false, 0, '02265931', 'FreeDiams::CA_HCDPD::DIN', 75138);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sevoflurane', 'liquid', 'N01AB08', false, 0, '02265974', 'FreeDiams::CA_HCDPD::DIN', 75141);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bleomycin For Injection, Usp', 'powder for solution', 'L01DC01', false, 0, '02265982', 'FreeDiams::CA_HCDPD::DIN', 75142);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vinorelbine Injection, Usp', 'solution', 'L01CA04', false, 0, '02265990', 'FreeDiams::CA_HCDPD::DIN', 75143);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Fosinopril', 'tablet', 'C09AA09', false, 0, '02266008', 'FreeDiams::CA_HCDPD::DIN', 75144);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Fosinopril', 'tablet', 'C09AA09', false, 0, '02266016', 'FreeDiams::CA_HCDPD::DIN', 75145);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neocitran Extra Strength Nighttime Total', 'powder for solution', 'N02BE51', false, 0, '02266024', 'FreeDiams::CA_HCDPD::DIN', 75146);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pure Perfection Classic Oil Free Moisturizer With Spf 15', 'cream', 'D02BA30', false, 0, '02266067', 'FreeDiams::CA_HCDPD::DIN', 75151);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sativex', 'spray', 'N02BG10', false, 0, '02266121', 'FreeDiams::CA_HCDPD::DIN', 75157);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dilotab Ii', 'tablet', 'N02BE51', false, 0, '02266148', 'FreeDiams::CA_HCDPD::DIN', 75158);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Suntan Lotion Spf4', 'lotion', 'D02BA30', false, 0, '02266172', 'FreeDiams::CA_HCDPD::DIN', 75161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cold Syrup', 'syrup', 'R01BA53', false, 0, '02266180', 'FreeDiams::CA_HCDPD::DIN', 75162);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Cold Syrup', 'syrup', 'R01BA53', false, 0, '02266199', 'FreeDiams::CA_HCDPD::DIN', 75163);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Compliments Value Antibacterial All-Purpose Cleaner', 'solution', 'V07AV', false, 0, '02266288', 'FreeDiams::CA_HCDPD::DIN', 75171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spa Sun - Sun Protection Spf 30 - Face And Body', 'cream', 'D02BA30', false, 0, '02266296', 'FreeDiams::CA_HCDPD::DIN', 75172);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flumazenil Injection, Usp', 'solution', 'V03AB25', false, 0, '02266342', 'FreeDiams::CA_HCDPD::DIN', 75176);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cilazapril', 'tablet', 'C09AA08', false, 0, '02266350', 'FreeDiams::CA_HCDPD::DIN', 75177);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cilazapril', 'tablet', 'C09AA08', false, 0, '02266369', 'FreeDiams::CA_HCDPD::DIN', 75178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cilazapril', 'tablet', 'C09AA08', false, 0, '02266377', 'FreeDiams::CA_HCDPD::DIN', 75179);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Mometasone Lotion', 'solution', 'D07AC13', false, 0, '02266385', 'FreeDiams::CA_HCDPD::DIN', 75180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Salvent-Ipravent Sterules', 'solution', 'R03AK04', false, 0, '02266393', 'FreeDiams::CA_HCDPD::DIN', 75181);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Little Tummys Gas Relief Drops', 'liquid', 'A03AX13', false, 0, '02266407', 'FreeDiams::CA_HCDPD::DIN', 75184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm Cough And Cold Syrup', 'syrup', 'R05DA20', false, 0, '02266466', 'FreeDiams::CA_HCDPD::DIN', 75189);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Dm Cough And Cold Syrup', 'syrup', 'R05DA20', false, 0, '02266474', 'FreeDiams::CA_HCDPD::DIN', 75190);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multi-Purpose Solution', 'solution', 'S01XA20', false, 0, '02266504', 'FreeDiams::CA_HCDPD::DIN', 75193);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Clarithromycin', 'tablet', 'J01FA09', false, 0, '02266539', 'FreeDiams::CA_HCDPD::DIN', 75196);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Clarithromycin', 'tablet', 'J01FA09', false, 0, '02266547', 'FreeDiams::CA_HCDPD::DIN', 75197);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Super Neutral L10', 'liquid', 'V07AV', false, 0, '02266644', 'FreeDiams::CA_HCDPD::DIN', 75205);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Damp Mop Quat 2', 'liquid', 'V07AV', false, 0, '02266652', 'FreeDiams::CA_HCDPD::DIN', 75206);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Atenolol', 'tablet', 'C07AB03', false, 0, '02266660', 'FreeDiams::CA_HCDPD::DIN', 75207);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clear Skin Treatment Repairing Lotion', 'liquid', 'D10AE01', false, 0, '02266679', 'FreeDiams::CA_HCDPD::DIN', 75208);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Methylphenidate Sr', 'tablet (extended-release)', 'N06BA04', false, 0, '02266687', 'FreeDiams::CA_HCDPD::DIN', 75209);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lithmax', 'tablet (extended-release)', 'N05AN01', false, 0, '02266695', 'FreeDiams::CA_HCDPD::DIN', 75210);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reminyl Er', 'capsule (extended release)', 'N06DA04', false, 0, '02266717', 'FreeDiams::CA_HCDPD::DIN', 75213);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reminyl Er', 'capsule (extended release)', 'N06DA04', false, 0, '02266725', 'FreeDiams::CA_HCDPD::DIN', 75214);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reminyl Er', 'capsule (extended release)', 'N06DA04', false, 0, '02266733', 'FreeDiams::CA_HCDPD::DIN', 75215);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aseptol 2000', 'liquid', 'V07AV', false, 0, '02266814', 'FreeDiams::CA_HCDPD::DIN', 75223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proven Pine Disinfectant', 'liquid', 'V07AV', false, 0, '02266830', 'FreeDiams::CA_HCDPD::DIN', 75225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elastology Age Blocker Spf 25', 'cream', 'D02BA30', false, 0, '02266873', 'FreeDiams::CA_HCDPD::DIN', 75229);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polysporin Lip Treatment', 'ointment', 'D04AB07', false, 0, '02266881', 'FreeDiams::CA_HCDPD::DIN', 75230);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Terminator 2 Disinfectant Spray N Wipe', 'liquid', 'V07AV', false, 0, '02266903', 'FreeDiams::CA_HCDPD::DIN', 75231);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Clindamycin', 'solution', 'D10AF01', false, 0, '02266938', 'FreeDiams::CA_HCDPD::DIN', 75233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Uv Hydrator', 'lotion', 'D02BA30', false, 0, '02266954', 'FreeDiams::CA_HCDPD::DIN', 75235);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02266962', 'FreeDiams::CA_HCDPD::DIN', 75238);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02266970', 'FreeDiams::CA_HCDPD::DIN', 75239);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arrest Foaming Restroom Cleaner', 'liquid', 'V07AV', false, 0, '02267004', 'FreeDiams::CA_HCDPD::DIN', 75242);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Luster Non-Acid Bathroom Disinfectant', 'liquid', 'V07AV', false, 0, '02267012', 'FreeDiams::CA_HCDPD::DIN', 75243);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lens Care Multi-Purpose Solution', 'solution', 'S01XA20', false, 0, '02267098', 'FreeDiams::CA_HCDPD::DIN', 75250);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nu-Quat Neutral Disinfectant', 'liquid', 'V07AV', false, 0, '02267101', 'FreeDiams::CA_HCDPD::DIN', 75251);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hygienipak 2% Chg Foaming Skin Cleanser', 'liquid', 'D08AC02', false, 0, '02267144', 'FreeDiams::CA_HCDPD::DIN', 75254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asacol 800', 'tablet (delayed-release)', 'A07EC02', false, 0, '02267217', 'FreeDiams::CA_HCDPD::DIN', 75261);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Macugen', 'solution', 'S01LA03', false, 0, '02267225', 'FreeDiams::CA_HCDPD::DIN', 75262);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tecta', 'tablet (enteric-coated)', 'A02BC02', false, 0, '02267233', 'FreeDiams::CA_HCDPD::DIN', 75263);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Swipes Plus Disinfectant Disposable Cloth', 'wipe', 'V07AV', false, 0, '02267276', 'FreeDiams::CA_HCDPD::DIN', 75267);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Resilience Lift Extreme Ultra Firming Creme Spf 15 Normal/Combination Skin', 'cream', 'D02BA30', false, 0, '02267314', 'FreeDiams::CA_HCDPD::DIN', 75271);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Resilience Lift Extreme Ultra Firming Creme Spf 15 Dry Skin', 'cream', 'D02BA30', false, 0, '02267349', 'FreeDiams::CA_HCDPD::DIN', 75277);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ino-F-San Instant Hand Sanitizer', 'liquid', 'D08AJ08', false, 0, '02267365', 'FreeDiams::CA_HCDPD::DIN', 75279);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ino-F Antibac Antibacterial Hand Soap', 'liquid', 'D08AE04', false, 0, '02267373', 'FreeDiams::CA_HCDPD::DIN', 75280);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cold Liquid', 'solution', 'R01BA53', false, 0, '02267411', 'FreeDiams::CA_HCDPD::DIN', 75283);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm Cough And Cold Liquid', 'solution', 'R05DA20', false, 0, '02267446', 'FreeDiams::CA_HCDPD::DIN', 75285);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Dm Cough And Cold Liquid', 'solution', 'R05DA20', false, 0, '02267454', 'FreeDiams::CA_HCDPD::DIN', 75286);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ciprofloxacin Intravenous Infusion', 'solution', 'J01MA02', false, 0, '02267462', 'FreeDiams::CA_HCDPD::DIN', 75287);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Bisoprolol', 'tablet', 'C07AB07', false, 0, '02267470', 'FreeDiams::CA_HCDPD::DIN', 75288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Bisoprolol', 'tablet', 'C07AB07', false, 0, '02267489', 'FreeDiams::CA_HCDPD::DIN', 75289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Champion Sprayon Instant Action Foaming Cleaner, Disinfectant And Deodorizer', 'aerosol', 'V07AV', false, 0, '02267497', 'FreeDiams::CA_HCDPD::DIN', 75290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mitoxantrone Injection', 'solution', 'L01DB07', false, 0, '02267535', 'FreeDiams::CA_HCDPD::DIN', 75294);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cover Girl Advanced Radiance Age Defying Make-Up', 'suspension', 'D02BA30', false, 0, '02267543', 'FreeDiams::CA_HCDPD::DIN', 75296);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Aging Daily Moisturizer Spf 15', 'lotion', 'D02BA30', false, 0, '02267578', 'FreeDiams::CA_HCDPD::DIN', 75298);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Excedrin Tension Headache', 'tablet', 'N02BE51', false, 0, '02267586', 'FreeDiams::CA_HCDPD::DIN', 75299);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advil Cold And Sinus Daytime', 'tablet', 'M01AE51', false, 0, '02267616', 'FreeDiams::CA_HCDPD::DIN', 75302);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advil Cold And Sinus Nighttime', 'tablet', 'M01AE51', false, 0, '02267632', 'FreeDiams::CA_HCDPD::DIN', 75304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Medroxy', 'tablet', 'G03DA02', false, 0, '02267640', 'FreeDiams::CA_HCDPD::DIN', 75305);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adenosine Injection, Usp', 'solution', 'C01EB10', false, 0, '02267659', 'FreeDiams::CA_HCDPD::DIN', 75307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rabavert', 'powder for solution', 'J07BG01', false, 0, '02267667', 'FreeDiams::CA_HCDPD::DIN', 75308);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medi-White Petroleum Jelly', 'gel', 'D02AC', false, 0, '02267691', 'FreeDiams::CA_HCDPD::DIN', 75311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ibuprofen And Pseudoephedrine', 'tablet', 'M01AE51', false, 0, '02267748', 'FreeDiams::CA_HCDPD::DIN', 75315);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Topiramate', 'tablet', 'N03AX11', false, 0, '02267837', 'FreeDiams::CA_HCDPD::DIN', 75324);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Azithromycin', 'tablet', 'J01FA10', false, 0, '02267845', 'FreeDiams::CA_HCDPD::DIN', 75325);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoprolol Tartrate Injection Usp', 'solution', 'C07AB02', false, 0, '02267853', 'FreeDiams::CA_HCDPD::DIN', 75326);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Zopiclone', 'tablet', 'N05CF01', false, 0, '02267918', 'FreeDiams::CA_HCDPD::DIN', 75330);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Zopiclone', 'tablet', 'N05CF01', false, 0, '02267926', 'FreeDiams::CA_HCDPD::DIN', 75331);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Lovastatin', 'tablet', 'C10AA02', false, 0, '02267969', 'FreeDiams::CA_HCDPD::DIN', 75335);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Lovastatin', 'tablet', 'C10AA02', false, 0, '02267977', 'FreeDiams::CA_HCDPD::DIN', 75336);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Atenolol', 'tablet', 'C07AB03', false, 0, '02267985', 'FreeDiams::CA_HCDPD::DIN', 75337);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Atenolol', 'tablet', 'C07AB03', false, 0, '02267993', 'FreeDiams::CA_HCDPD::DIN', 75338);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Carvedilol', 'tablet', 'C07AG02', false, 0, '02268027', 'FreeDiams::CA_HCDPD::DIN', 75342);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Carvedilol', 'tablet', 'C07AG02', false, 0, '02268035', 'FreeDiams::CA_HCDPD::DIN', 75343);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Carvedilol', 'tablet', 'C07AG02', false, 0, '02268043', 'FreeDiams::CA_HCDPD::DIN', 75344);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Carvedilol', 'tablet', 'C07AG02', false, 0, '02268051', 'FreeDiams::CA_HCDPD::DIN', 75345);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Domperidone', 'tablet', 'A03FA03', false, 0, '02268078', 'FreeDiams::CA_HCDPD::DIN', 75346);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperdal M-Tab', 'tablet (orally disintegrating)', 'N05AX08', false, 0, '02268086', 'FreeDiams::CA_HCDPD::DIN', 75347);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperdal M-Tab', 'tablet (orally disintegrating)', 'N05AX08', false, 0, '02268094', 'FreeDiams::CA_HCDPD::DIN', 75348);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Essential Moisture Lip Conditioner Spf 15', 'cream', 'D02BA30', false, 0, '02268116', 'FreeDiams::CA_HCDPD::DIN', 75350);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bravelle', 'powder for solution', 'G03GA04', false, 0, '02268140', 'FreeDiams::CA_HCDPD::DIN', 75353);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Dandruff 2 In 1 Shampoo & Conditioner', 'shampoo', 'D11AX12', false, 0, '02268167', 'FreeDiams::CA_HCDPD::DIN', 75355);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Twinject 0.15mg Auto-Injector', 'solution', 'C01CA24', false, 0, '02268205', 'FreeDiams::CA_HCDPD::DIN', 75360);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('All Fresh By Alsco Antimicrobial Lotion Hand Soap', 'lotion', 'D08AE05', false, 0, '02268256', 'FreeDiams::CA_HCDPD::DIN', 75365);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('All Fresh By Alsco Anti-Microbial Foaming Hand Soap', 'liquid', 'D08AE05', false, 0, '02268264', 'FreeDiams::CA_HCDPD::DIN', 75366);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xyrem', 'solution', 'N07XX04', false, 0, '02268272', 'FreeDiams::CA_HCDPD::DIN', 75367);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Sport Continuous Spray Sunscreen Spf 30', 'lotion', 'D02BA30', false, 0, '02268302', 'FreeDiams::CA_HCDPD::DIN', 75370);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Sinus Pain And Congestion Nighttime', 'tablet', 'N02BE51', false, 0, '02268310', 'FreeDiams::CA_HCDPD::DIN', 75371);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solarcaine Medicated Lidocaine Gel', 'gel', 'D04AB01', false, 0, '02268361', 'FreeDiams::CA_HCDPD::DIN', 75376);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Sumatriptan', 'tablet', 'N02CC01', false, 0, '02268388', 'FreeDiams::CA_HCDPD::DIN', 75377);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Sumatriptan', 'tablet', 'N02CC01', false, 0, '02268396', 'FreeDiams::CA_HCDPD::DIN', 75378);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lyrica', 'capsule', 'N03AX16', false, 0, '02268418', 'FreeDiams::CA_HCDPD::DIN', 75379);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lyrica', 'capsule', 'N03AX16', false, 0, '02268426', 'FreeDiams::CA_HCDPD::DIN', 75380);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lyrica', 'capsule', 'N03AX16', false, 0, '02268434', 'FreeDiams::CA_HCDPD::DIN', 75381);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lyrica', 'capsule', 'N03AX16', false, 0, '02268450', 'FreeDiams::CA_HCDPD::DIN', 75383);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lyrica', 'capsule', 'N03AX16', false, 0, '02268477', 'FreeDiams::CA_HCDPD::DIN', 75385);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lyrica', 'capsule', 'N03AX16', false, 0, '02268485', 'FreeDiams::CA_HCDPD::DIN', 75386);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glumetza', 'tablet (extended-release)', 'A10BA02', false, 0, '02268493', 'FreeDiams::CA_HCDPD::DIN', 75387);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creme Haute Exigence Jour Spf 20', 'emulsion', 'D02BA30', false, 0, '02268523', 'FreeDiams::CA_HCDPD::DIN', 75392);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gentamicin Injection Usp', 'solution', 'J01GB03', false, 0, '02268531', 'FreeDiams::CA_HCDPD::DIN', 75394);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sucrets Vapor Black Cherry', 'lozenge', 'R02AD04', false, 0, '02268604', 'FreeDiams::CA_HCDPD::DIN', 75400);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Retaliate', 'shampoo', 'D11AX12', false, 0, '02268612', 'FreeDiams::CA_HCDPD::DIN', 75401);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('3m Neutral Quat Disinfectant Cleaner Concentrate #23', 'liquid', 'V07AV', false, 0, '02268620', 'FreeDiams::CA_HCDPD::DIN', 75402);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultramist Banana Boat Dark Tanning Lotion Spf 4', 'aerosol', 'D02BA30', false, 0, '02268647', 'FreeDiams::CA_HCDPD::DIN', 75404);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimension Foaming Antibacterial Hand Soap', 'liquid', 'D08AE04', false, 0, '02268655', 'FreeDiams::CA_HCDPD::DIN', 75407);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Kids Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02268671', 'FreeDiams::CA_HCDPD::DIN', 75409);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1294', 'solution', 'B05ZA', false, 0, '02268728', 'FreeDiams::CA_HCDPD::DIN', 75411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Advil Cold & Flu Multi-Symptom', 'suspension', 'M01AE51', false, 0, '02268701', 'FreeDiams::CA_HCDPD::DIN', 75412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ombrelle L''Oreal Suncare Research Kids (Spf 45)', 'lotion', 'D02BA30', false, 0, '02268736', 'FreeDiams::CA_HCDPD::DIN', 75413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ombrelle L''Oreal Suncare Research Kids (Spf 30)', 'lotion', 'D02BA30', false, 0, '02268744', 'FreeDiams::CA_HCDPD::DIN', 75414);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Optim Cs', 'solution', 'V07AV', false, 0, '02268787', 'FreeDiams::CA_HCDPD::DIN', 75418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Acne Medication', 'gel', 'D10AE01', false, 0, '02268817', 'FreeDiams::CA_HCDPD::DIN', 75421);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Angeliq', 'tablet', 'G03FA17', false, 0, '02268825', 'FreeDiams::CA_HCDPD::DIN', 75422);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Continuum Unifying Lotion I', 'lotion', 'D11AX11', false, 0, '02268868', 'FreeDiams::CA_HCDPD::DIN', 75425);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crest Pro-Health Multi Protection', 'mouthwash/gargle', 'R02AA06', false, 0, '02268884', 'FreeDiams::CA_HCDPD::DIN', 75427);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eligard 45 Mg', 'powder for suspension, sustained-release', 'L02AE02', false, 0, '02268892', 'FreeDiams::CA_HCDPD::DIN', 75428);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Sumatriptan', 'tablet', 'N02CC01', false, 0, '02268906', 'FreeDiams::CA_HCDPD::DIN', 75430);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Sumatriptan', 'tablet', 'N02CC01', false, 0, '02268914', 'FreeDiams::CA_HCDPD::DIN', 75431);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Sumatriptan', 'tablet', 'N02CC01', false, 0, '02268922', 'FreeDiams::CA_HCDPD::DIN', 75432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tarceva', 'tablet', 'L01XE03', false, 0, '02269007', 'FreeDiams::CA_HCDPD::DIN', 75441);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tarceva', 'tablet', 'L01XE03', false, 0, '02269015', 'FreeDiams::CA_HCDPD::DIN', 75442);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tarceva', 'tablet', 'L01XE03', false, 0, '02269023', 'FreeDiams::CA_HCDPD::DIN', 75443);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Metformin', 'tablet', 'A10BA02', false, 0, '02269031', 'FreeDiams::CA_HCDPD::DIN', 75444);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Metformin', 'tablet', 'A10BA02', false, 0, '02269058', 'FreeDiams::CA_HCDPD::DIN', 75445);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Luveris', 'powder for solution', 'G03GA07', false, 0, '02269066', 'FreeDiams::CA_HCDPD::DIN', 75446);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lipidil Ez', 'tablet', 'C10AB05', false, 0, '02269074', 'FreeDiams::CA_HCDPD::DIN', 75447);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lipidil Ez', 'tablet', 'C10AB05', false, 0, '02269082', 'FreeDiams::CA_HCDPD::DIN', 75448);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trusopt     -(Preservative-Free Formulation)', 'solution', 'S01EC03', false, 0, '02269090', 'FreeDiams::CA_HCDPD::DIN', 75449);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Dry Oil Sunscreen Spray Spf 8', 'lotion', 'D02BA30', false, 0, '02269104', 'FreeDiams::CA_HCDPD::DIN', 75450);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Acetaminophen 500mg Easy To Swallow Tablets', 'tablet', 'N02BE01', false, 0, '02269120', 'FreeDiams::CA_HCDPD::DIN', 75452);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetylsalicylic Acid 80 Mg Chewable Tablets', 'tablet', 'N02BA01', false, 0, '02269139', 'FreeDiams::CA_HCDPD::DIN', 75453);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rolaids Ultra Strength Plus Gas', 'tablet', 'A02AF02', false, 0, '02269171', 'FreeDiams::CA_HCDPD::DIN', 75457);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aclasta', 'solution', 'M05BA08', false, 0, '02269198', 'FreeDiams::CA_HCDPD::DIN', 75458);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avonex Ps', 'solution', 'L03AB07', false, 0, '02269201', 'FreeDiams::CA_HCDPD::DIN', 75459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Simvastatin', 'tablet', 'C10AA01', false, 0, '02269252', 'FreeDiams::CA_HCDPD::DIN', 75463);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Simvastatin', 'tablet', 'C10AA01', false, 0, '02269260', 'FreeDiams::CA_HCDPD::DIN', 75464);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Simvastatin', 'tablet', 'C10AA01', false, 0, '02269279', 'FreeDiams::CA_HCDPD::DIN', 75465);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Simvastatin', 'tablet', 'C10AA01', false, 0, '02269287', 'FreeDiams::CA_HCDPD::DIN', 75466);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Simvastatin', 'tablet', 'C10AA01', false, 0, '02269295', 'FreeDiams::CA_HCDPD::DIN', 75467);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Pramipexole', 'tablet', 'N04BC05', false, 0, '02269309', 'FreeDiams::CA_HCDPD::DIN', 75469);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Pramipexole', 'tablet', 'N04BC05', false, 0, '02269317', 'FreeDiams::CA_HCDPD::DIN', 75470);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Pramipexole', 'tablet', 'N04BC05', false, 0, '02269325', 'FreeDiams::CA_HCDPD::DIN', 75471);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Pramipexole', 'tablet', 'N04BC05', false, 0, '02269333', 'FreeDiams::CA_HCDPD::DIN', 75472);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kivexa', 'tablet', 'J05AR02', false, 0, '02269341', 'FreeDiams::CA_HCDPD::DIN', 75473);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Potassium Chloride In Sodium Chloride Injection Usp', 'solution', 'B05BB01', false, 0, '02269414', 'FreeDiams::CA_HCDPD::DIN', 75479);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Paroxetine', 'tablet', 'N06AB05', false, 0, '02269422', 'FreeDiams::CA_HCDPD::DIN', 75480);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Paroxetine', 'tablet', 'N06AB05', false, 0, '02269430', 'FreeDiams::CA_HCDPD::DIN', 75481);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Paroxetine', 'tablet', 'N06AB05', false, 0, '02269449', 'FreeDiams::CA_HCDPD::DIN', 75482);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aricept Rdt', 'tablet (orally disintegrating)', 'N06DA02', false, 0, '02269457', 'FreeDiams::CA_HCDPD::DIN', 75483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aricept Rdt', 'tablet (orally disintegrating)', 'N06DA02', false, 0, '02269465', 'FreeDiams::CA_HCDPD::DIN', 75484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Comet Disinfecting Cleanser With Chlorinol Plus', 'powder', 'V07AV', false, 0, '02269473', 'FreeDiams::CA_HCDPD::DIN', 75485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Influvac', 'suspension', 'J07BB01', false, 0, '02269562', 'FreeDiams::CA_HCDPD::DIN', 75489);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Water For Injection, Usp', 'liquid', 'V07AB', false, 0, '02269570', 'FreeDiams::CA_HCDPD::DIN', 75493);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Glimepiride', 'tablet', 'A10BB12', false, 0, '02269589', 'FreeDiams::CA_HCDPD::DIN', 75494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Glimepiride', 'tablet', 'A10BB12', false, 0, '02269597', 'FreeDiams::CA_HCDPD::DIN', 75495);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Glimepiride', 'tablet', 'A10BB12', false, 0, '02269619', 'FreeDiams::CA_HCDPD::DIN', 75497);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Norfloxacin', 'tablet', 'J01MA06', false, 0, '02269627', 'FreeDiams::CA_HCDPD::DIN', 75498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Provon Foaming Medicated Handwash With Triclosan And Moisturizers', 'solution', 'D08AE04', false, 0, '02269686', 'FreeDiams::CA_HCDPD::DIN', 75504);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Qfs Antimicrobial Hand Soap With Triclosan', 'solution', 'D08AE04', false, 0, '02269694', 'FreeDiams::CA_HCDPD::DIN', 75505);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Continuous Spray Sunscreen Spf 30', 'lotion', 'D02BA30', false, 0, '02269740', 'FreeDiams::CA_HCDPD::DIN', 75512);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Super City Block Oil-Free Daily Face Protector Spf 40', 'cream', 'D02BA30', false, 0, '02269759', 'FreeDiams::CA_HCDPD::DIN', 75513);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm + Expectorant Syrup', 'syrup', 'R05FA02', false, 0, '02269775', 'FreeDiams::CA_HCDPD::DIN', 75515);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm + Expectorant Extra Strength Syrup', 'syrup', 'R05FA02', false, 0, '02269783', 'FreeDiams::CA_HCDPD::DIN', 75516);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ombrelle Sport Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02269902', 'FreeDiams::CA_HCDPD::DIN', 75527);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ombrelle Sport Lotion Spf 45', 'lotion', 'D02BA30', false, 0, '02269910', 'FreeDiams::CA_HCDPD::DIN', 75528);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Timewise Day Solution Sunscreen Spf 25', 'lotion', 'D02BA30', false, 0, '02269945', 'FreeDiams::CA_HCDPD::DIN', 75531);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen 500mg And Caffeine 65mg', 'tablet', 'N02BE51', false, 0, '02269988', 'FreeDiams::CA_HCDPD::DIN', 75534);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Concrobium', 'liquid', 'V07AV', false, 0, '02269996', 'FreeDiams::CA_HCDPD::DIN', 75535);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gojo E2 Foam Sanitizing Soap', 'liquid', 'D08AE05', false, 0, '02270021', 'FreeDiams::CA_HCDPD::DIN', 75542);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Little Noses Decongestant Nose Drops', 'liquid', 'R01BA03', false, 0, '02270056', 'FreeDiams::CA_HCDPD::DIN', 75545);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flomax Cr', 'tablet (extended-release)', 'G04CA02', false, 0, '02270102', 'FreeDiams::CA_HCDPD::DIN', 75550);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Alendronate', 'tablet', 'M05BA04', false, 0, '02270129', 'FreeDiams::CA_HCDPD::DIN', 75552);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultrasan 10 % Solution', 'solution', 'V07AV', false, 0, '02270137', 'FreeDiams::CA_HCDPD::DIN', 75554);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultracide', 'solution', 'V07AV', false, 0, '02270145', 'FreeDiams::CA_HCDPD::DIN', 75555);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bienfait Multi-Vital Spf 30', 'lotion', 'D02BA30', false, 0, '02270161', 'FreeDiams::CA_HCDPD::DIN', 75557);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Little Colds Multi-Symptom Cold Formula', 'liquid', 'N02BE51', false, 0, '02270188', 'FreeDiams::CA_HCDPD::DIN', 75558);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Little Colds Decongestant Plus Cough', 'liquid', 'R05DA20', false, 0, '02270196', 'FreeDiams::CA_HCDPD::DIN', 75559);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Bicalutamide Tablets', 'tablet', 'L02BB03', false, 0, '02270226', 'FreeDiams::CA_HCDPD::DIN', 75561);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Pravastatin', 'tablet', 'C10AA03', false, 0, '02270234', 'FreeDiams::CA_HCDPD::DIN', 75562);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Pravastatin', 'tablet', 'C10AA03', false, 0, '02270242', 'FreeDiams::CA_HCDPD::DIN', 75563);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Pravastatin', 'tablet', 'C10AA03', false, 0, '02270250', 'FreeDiams::CA_HCDPD::DIN', 75564);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydrance Optimale Spf 25', 'cream', 'D02BA30', false, 0, '02270269', 'FreeDiams::CA_HCDPD::DIN', 75565);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gas X Thin Strips 62.5mg Simethicone', 'lozenge', 'A03AX13', false, 0, '02270331', 'FreeDiams::CA_HCDPD::DIN', 75572);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gonal-F Pen', 'solution', 'G03GA05', false, 0, '02270382', 'FreeDiams::CA_HCDPD::DIN', 75576);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gonal-F Pen', 'solution', 'G03GA05', false, 0, '02270390', 'FreeDiams::CA_HCDPD::DIN', 75577);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gonal-F Pen', 'solution', 'G03GA05', false, 0, '02270404', 'FreeDiams::CA_HCDPD::DIN', 75578);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soapopular', 'liquid', 'D08AJ01', false, 0, '02270420', 'FreeDiams::CA_HCDPD::DIN', 75580);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advicor', 'kit', 'C10BA01', false, 0, '02270439', 'FreeDiams::CA_HCDPD::DIN', 75581);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advicor', 'kit', 'C10BA01', false, 0, '02270447', 'FreeDiams::CA_HCDPD::DIN', 75582);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bexxar Therapy', 'kit', 'V10XA53', false, 0, '02270471', 'FreeDiams::CA_HCDPD::DIN', 75584);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lysol Disinfectant Bathroom Cleaning Foam', 'aerosol', 'V07AV', false, 0, '02270498', 'FreeDiams::CA_HCDPD::DIN', 75586);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Super Swipes', 'wipe', 'V07AV', false, 0, '02270501', 'FreeDiams::CA_HCDPD::DIN', 75587);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diovan', 'tablet', 'C09CA03', false, 0, '02270528', 'FreeDiams::CA_HCDPD::DIN', 75588);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kids Tear Free Sans Larmes Sunscreen Lotion Écran Solaire Pour Enfants Spf Fps 50', 'lotion', 'D02BA30', false, 0, '02270544', 'FreeDiams::CA_HCDPD::DIN', 75591);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Definity Refining Lotion With Uv Protection', 'lotion', 'D02BA30', false, 0, '02270587', 'FreeDiams::CA_HCDPD::DIN', 75594);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Skinlogics Lip Balm With Spf 20', 'stick', 'D02BA30', false, 0, '02270595', 'FreeDiams::CA_HCDPD::DIN', 75596);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Citalopram', 'tablet', 'N06AB04', false, 0, '02270609', 'FreeDiams::CA_HCDPD::DIN', 75597);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Sotalol', 'tablet', 'C07AA07', false, 0, '02270625', 'FreeDiams::CA_HCDPD::DIN', 75600);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Sotalol', 'tablet', 'C07AA07', false, 0, '02270633', 'FreeDiams::CA_HCDPD::DIN', 75601);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Clonazepam', 'tablet', 'N03AE01', false, 0, '02270641', 'FreeDiams::CA_HCDPD::DIN', 75602);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Clonazepam', 'tablet', 'N03AE01', false, 0, '02270668', 'FreeDiams::CA_HCDPD::DIN', 75603);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Clonazepam', 'tablet', 'N03AE01', false, 0, '02270676', 'FreeDiams::CA_HCDPD::DIN', 75604);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Sumatriptan', 'tablet', 'N02CC01', false, 0, '02270714', 'FreeDiams::CA_HCDPD::DIN', 75608);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Sumatriptan', 'tablet', 'N02CC01', false, 0, '02270722', 'FreeDiams::CA_HCDPD::DIN', 75609);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Sumatriptan', 'tablet', 'N02CC01', false, 0, '02270730', 'FreeDiams::CA_HCDPD::DIN', 75610);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Sumatriptan', 'tablet', 'N02CC01', false, 0, '02270749', 'FreeDiams::CA_HCDPD::DIN', 75611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Sumatriptan', 'tablet', 'N02CC01', false, 0, '02270757', 'FreeDiams::CA_HCDPD::DIN', 75612);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Sumatriptan', 'tablet', 'N02CC01', false, 0, '02270765', 'FreeDiams::CA_HCDPD::DIN', 75613);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Finacea', 'gel', 'D10AX03', false, 0, '02270811', 'FreeDiams::CA_HCDPD::DIN', 75617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Inomax', 'gas', 'R07AX01', false, 0, '02270838', 'FreeDiams::CA_HCDPD::DIN', 75618);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Inomax', 'gas', 'R07AX01', false, 0, '02270846', 'FreeDiams::CA_HCDPD::DIN', 75619);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Mometasone', 'ointment', 'D07AC13', false, 0, '02270862', 'FreeDiams::CA_HCDPD::DIN', 75622);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rinse-Free', 'spray', 'D08AJ01', false, 0, '02272326', 'FreeDiams::CA_HCDPD::DIN', 75784);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva Alendronate', 'tablet', 'M05BA04', false, 0, '02270889', 'FreeDiams::CA_HCDPD::DIN', 75626);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract, Standardized Mite Mixed', 'liquid', 'V01AA03', false, 0, '02270919', 'FreeDiams::CA_HCDPD::DIN', 75630);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Mirtazapine', 'tablet', 'N06AX11', false, 0, '02270927', 'FreeDiams::CA_HCDPD::DIN', 75631);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Wipes', 'wipe', 'V07AV', false, 0, '02270935', 'FreeDiams::CA_HCDPD::DIN', 75632);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nettoyant Desinfectant Tout Usage', 'solution', 'V07AV', false, 0, '02270943', 'FreeDiams::CA_HCDPD::DIN', 75633);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artistry Time Defiance Firming Crčme Foundation Spf 15', 'lotion', 'D02BA30', false, 0, '02270951', 'FreeDiams::CA_HCDPD::DIN', 75634);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidocaine 2% And Epinephrine 1:100,000', 'solution', 'N01BB52', false, 0, '02270978', 'FreeDiams::CA_HCDPD::DIN', 75640);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solar Sense Spf 45 For Face, Nose And Lips', 'cream', 'D02BA30', false, 0, '02270986', 'FreeDiams::CA_HCDPD::DIN', 75641);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avastin', 'solution', 'L01XC07', false, 0, '02270994', 'FreeDiams::CA_HCDPD::DIN', 75642);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidocaine 2% And Epinephrine 1:50,000', 'solution', 'N01BB52', false, 0, '02271001', 'FreeDiams::CA_HCDPD::DIN', 75645);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Sumatriptan', 'tablet', 'N02CC01', false, 0, '02271117', 'FreeDiams::CA_HCDPD::DIN', 75655);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Sumatriptan', 'tablet', 'N02CC01', false, 0, '02271125', 'FreeDiams::CA_HCDPD::DIN', 75656);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Topiramate', 'tablet', 'N03AX11', false, 0, '02271141', 'FreeDiams::CA_HCDPD::DIN', 75663);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Topiramate', 'tablet', 'N03AX11', false, 0, '02271168', 'FreeDiams::CA_HCDPD::DIN', 75664);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Topiramate', 'tablet', 'N03AX11', false, 0, '02271176', 'FreeDiams::CA_HCDPD::DIN', 75665);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Topiramate', 'tablet', 'N03AX11', false, 0, '02271184', 'FreeDiams::CA_HCDPD::DIN', 75666);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Topiramate', 'tablet', 'N03AX11', false, 0, '02271192', 'FreeDiams::CA_HCDPD::DIN', 75667);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Topiramate', 'tablet', 'N03AX11', false, 0, '02271206', 'FreeDiams::CA_HCDPD::DIN', 75668);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vinorelbine Tartrate For Injection', 'solution', 'L01CA04', false, 0, '02271214', 'FreeDiams::CA_HCDPD::DIN', 75669);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Erbitux', 'solution', 'L01XC06', false, 0, '02271249', 'FreeDiams::CA_HCDPD::DIN', 75672);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prescriptives Anti-Age Advanced Protection Moisturizer Spf 25', 'cream', 'D02BA30', false, 0, '02271281', 'FreeDiams::CA_HCDPD::DIN', 75676);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prescriptives Anti-Age Advanced Protection Lotion Spf 25', 'lotion', 'D02BA30', false, 0, '02271303', 'FreeDiams::CA_HCDPD::DIN', 75677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proactiv Solution Advanced Blemish Treatment', 'cream', 'D10AE01', false, 0, '02271419', 'FreeDiams::CA_HCDPD::DIN', 75687);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artistry Time Defiance Day Protect Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02271435', 'FreeDiams::CA_HCDPD::DIN', 75689);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Lisinopril', 'tablet', 'C09AA03', false, 0, '02271443', 'FreeDiams::CA_HCDPD::DIN', 75690);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Lisinopril', 'tablet', 'C09AA03', false, 0, '02271451', 'FreeDiams::CA_HCDPD::DIN', 75691);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Lisinopril', 'tablet', 'C09AA03', false, 0, '02271478', 'FreeDiams::CA_HCDPD::DIN', 75692);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amazing Nok Out', 'solution', 'V07AV', false, 0, '02271486', 'FreeDiams::CA_HCDPD::DIN', 75693);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Skin Supplies For Men M Protect Spf 21', 'cream', 'D02BA30', false, 0, '02271508', 'FreeDiams::CA_HCDPD::DIN', 75697);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Fluconazole', 'tablet', 'J02AC01', false, 0, '02271516', 'FreeDiams::CA_HCDPD::DIN', 75698);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Complete Touch Of Sun', 'suspension', 'D02BA30', false, 0, '02271540', 'FreeDiams::CA_HCDPD::DIN', 75709);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lysol Disinfectant Toilet Bowl Cleaner With Bleach', 'liquid', 'V07AV', false, 0, '02271559', 'FreeDiams::CA_HCDPD::DIN', 75710);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gamut Plus', 'liquid', 'V07AV', false, 0, '02271567', 'FreeDiams::CA_HCDPD::DIN', 75711);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diltiazem Hcl Er Capsules', 'capsule (extended release)', 'C08DB01', false, 0, '02271605', 'FreeDiams::CA_HCDPD::DIN', 75715);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diltiazem Hcl Er Capsules', 'capsule (extended release)', 'C08DB01', false, 0, '02271613', 'FreeDiams::CA_HCDPD::DIN', 75716);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diltiazem Hcl Er Capsules', 'capsule (extended release)', 'C08DB01', false, 0, '02271621', 'FreeDiams::CA_HCDPD::DIN', 75717);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diltiazem Hcl Er Capsules', 'capsule (extended release)', 'C08DB01', false, 0, '02271648', 'FreeDiams::CA_HCDPD::DIN', 75718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Diltiazem Hcl Er Capsules', 'capsule (extended release)', 'C08DB01', false, 0, '02271656', 'FreeDiams::CA_HCDPD::DIN', 75719);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gamut Plus Wipes', 'wipe', 'V07AV', false, 0, '02271680', 'FreeDiams::CA_HCDPD::DIN', 75722);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Thin Strips Nasal Congestion', 'strip', 'R01BA03', false, 0, '02271737', 'FreeDiams::CA_HCDPD::DIN', 75727);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Thin Strips Cold & Cough', 'strip', 'R05DA20', false, 0, '02271745', 'FreeDiams::CA_HCDPD::DIN', 75728);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ep66 Disinfectant', 'solution', 'V07AV', false, 0, '02271753', 'FreeDiams::CA_HCDPD::DIN', 75729);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ondansetron Omega   -(Preservative Free - Single Dose Vials)', 'liquid', 'A04AA01', false, 0, '02271761', 'FreeDiams::CA_HCDPD::DIN', 75730);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ondansetron Omega   -(With Preservative - Multidose Vial)', 'liquid', 'A04AA01', false, 0, '02271788', 'FreeDiams::CA_HCDPD::DIN', 75731);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbocaine 3%', 'solution', 'N01BB03', false, 0, '02271796', 'FreeDiams::CA_HCDPD::DIN', 75732);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levemir Penfill', 'solution', 'A10AE05', false, 0, '02271842', 'FreeDiams::CA_HCDPD::DIN', 75736);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('True Test', 'patch', 'V04CL', false, 0, '02271885', 'FreeDiams::CA_HCDPD::DIN', 75739);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Zopiclone', 'tablet', 'N05CF01', false, 0, '02271931', 'FreeDiams::CA_HCDPD::DIN', 75747);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Zopiclone', 'tablet', 'N05CF01', false, 0, '02271958', 'FreeDiams::CA_HCDPD::DIN', 75748);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kidsport', 'cream', 'D02BA30', false, 0, '02272008', 'FreeDiams::CA_HCDPD::DIN', 75752);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crew Mean Green Heavy Duty Disinfectant Bowl Cleaner', 'liquid', 'V07AV', false, 0, '02271990', 'FreeDiams::CA_HCDPD::DIN', 75753);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aquasport', 'cream', 'D02BA30', false, 0, '02272024', 'FreeDiams::CA_HCDPD::DIN', 75755);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Terrasport', 'cream', 'D02BA30', false, 0, '02272032', 'FreeDiams::CA_HCDPD::DIN', 75756);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Tizanidine', 'tablet', 'M03BX02', false, 0, '02272059', 'FreeDiams::CA_HCDPD::DIN', 75758);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Saizen 8.8mg (5.83mg/Ml)', 'powder for solution', 'H01AC01', false, 0, '02272083', 'FreeDiams::CA_HCDPD::DIN', 75761);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Emtriva', 'capsule', 'J05AF09', false, 0, '02272091', 'FreeDiams::CA_HCDPD::DIN', 75762);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Amlodipine', 'tablet', 'C08CA01', false, 0, '02272113', 'FreeDiams::CA_HCDPD::DIN', 75765);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Amlodipine', 'tablet', 'C08CA01', false, 0, '02272121', 'FreeDiams::CA_HCDPD::DIN', 75766);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dristan Dm', 'tablet', 'R05DA09', false, 0, '02272148', 'FreeDiams::CA_HCDPD::DIN', 75767);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neostrata Canada Spf 15 Daytime Ultra-Smoothing Cream', 'cream', 'D02BA', false, 0, '02272156', 'FreeDiams::CA_HCDPD::DIN', 75768);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Sotalol', 'tablet', 'C07AA07', false, 0, '02272164', 'FreeDiams::CA_HCDPD::DIN', 75769);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Somavert', 'powder for solution', 'H01AX01', false, 0, '02272199', 'FreeDiams::CA_HCDPD::DIN', 75772);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Somavert', 'powder for solution', 'H01AX01', false, 0, '02272202', 'FreeDiams::CA_HCDPD::DIN', 75774);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Somavert', 'powder for solution', 'H01AX01', false, 0, '02272210', 'FreeDiams::CA_HCDPD::DIN', 75775);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro Lumičre', 'lotion', 'D02BA30', false, 0, '02272237', 'FreeDiams::CA_HCDPD::DIN', 75777);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baby Tear Free Sans Larmes Sunscreen Écran Solaire Pour Bébés Spf Fps 50', 'lotion', 'D02BA30', false, 0, '02272253', 'FreeDiams::CA_HCDPD::DIN', 75779);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Lovastatin', 'tablet', 'C10AA02', false, 0, '02272288', 'FreeDiams::CA_HCDPD::DIN', 75781);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Lovastatin', 'tablet', 'C10AA02', false, 0, '02272296', 'FreeDiams::CA_HCDPD::DIN', 75782);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fresh-Gear', 'solution', 'V07AV', false, 0, '02272318', 'FreeDiams::CA_HCDPD::DIN', 75783);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravasa', 'kit', 'C10BX02', false, 0, '02272415', 'FreeDiams::CA_HCDPD::DIN', 75794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravasa', 'kit', 'C10BX02', false, 0, '02272423', 'FreeDiams::CA_HCDPD::DIN', 75795);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravasa', 'kit', 'C10BX02', false, 0, '02272431', 'FreeDiams::CA_HCDPD::DIN', 75796);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Arthritis Pain', 'tablet (extended-release)', 'N02BE01', false, 0, '02272482', 'FreeDiams::CA_HCDPD::DIN', 75800);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1271', 'solution', 'B05ZA', false, 0, '02272520', 'FreeDiams::CA_HCDPD::DIN', 75804);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1272', 'solution', 'B05ZA', false, 0, '02272539', 'FreeDiams::CA_HCDPD::DIN', 75805);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1278', 'solution', 'B05ZA', false, 0, '02272601', 'FreeDiams::CA_HCDPD::DIN', 75811);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Concentrate A1279', 'solution', 'B05ZA', false, 0, '02272628', 'FreeDiams::CA_HCDPD::DIN', 75812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Combo Sterinebs', 'solution', 'R03AK04', false, 0, '02272695', 'FreeDiams::CA_HCDPD::DIN', 75820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sucrets Dm Cough Suppressant-Honey Lemon', 'lozenge', 'R05DA09', false, 0, '02272709', 'FreeDiams::CA_HCDPD::DIN', 75821);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spray Ecran Solaire', 'spray', 'D02BA30', false, 0, '02272725', 'FreeDiams::CA_HCDPD::DIN', 75823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Custom Care Nasal Congestion/Cough', 'liquid', 'R05DA20', false, 0, '02272776', 'FreeDiams::CA_HCDPD::DIN', 75827);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Dayquil Cold And Flu Multi-Symptom Relief Liquicaps', 'capsule', 'N02BE51', false, 0, '02272784', 'FreeDiams::CA_HCDPD::DIN', 75828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Nyquil Liquicaps Cold And Flu Multi-Symptom Relief', 'capsule', 'N02BE51', false, 0, '02272792', 'FreeDiams::CA_HCDPD::DIN', 75829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ismn', 'tablet (extended-release)', 'C01DA14', false, 0, '02272830', 'FreeDiams::CA_HCDPD::DIN', 75834);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ibuprofen Tablets 200 Mg', 'tablet', 'M01AE01', false, 0, '02272849', 'FreeDiams::CA_HCDPD::DIN', 75835);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ibuprofen Caplets 200 Mg', 'tablet', 'M01AE01', false, 0, '02272857', 'FreeDiams::CA_HCDPD::DIN', 75836);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levocarb Cr', 'tablet (extended-release)', 'N04BA02', false, 0, '02272873', 'FreeDiams::CA_HCDPD::DIN', 75839);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Linessa 21', 'tablet', 'G03AB05', false, 0, '02272903', 'FreeDiams::CA_HCDPD::DIN', 75841);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf/Fps 30 Sport Eco Lips', 'stick', 'D02BA30', false, 0, '02272970', 'FreeDiams::CA_HCDPD::DIN', 75847);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('T36 Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02272989', 'FreeDiams::CA_HCDPD::DIN', 75848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Temazepam', 'capsule', 'N05CD07', false, 0, '02273039', 'FreeDiams::CA_HCDPD::DIN', 75853);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Temazepam', 'capsule', 'N05CD07', false, 0, '02273047', 'FreeDiams::CA_HCDPD::DIN', 75854);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Citalopram', 'tablet', 'N06AB04', false, 0, '02273055', 'FreeDiams::CA_HCDPD::DIN', 75855);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Nyquil Cold And Flu', 'liquid', 'N02BE51', false, 0, '02273071', 'FreeDiams::CA_HCDPD::DIN', 75858);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Glimepiride', 'tablet', 'A10BB12', false, 0, '02273101', 'FreeDiams::CA_HCDPD::DIN', 75861);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Glimepiride', 'tablet', 'A10BB12', false, 0, '02273128', 'FreeDiams::CA_HCDPD::DIN', 75862);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Glimepiride', 'tablet', 'A10BB12', false, 0, '02273136', 'FreeDiams::CA_HCDPD::DIN', 75863);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Revlon Spf 15 Lipgloss', 'emulsion', 'D02BA02', false, 0, '02273144', 'FreeDiams::CA_HCDPD::DIN', 75864);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Alendronate', 'tablet', 'M05BA04', false, 0, '02273179', 'FreeDiams::CA_HCDPD::DIN', 75867);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creme Solaire Haute Protection Special Visage 15 Spf', 'emulsion', 'D02BA30', false, 0, '02273187', 'FreeDiams::CA_HCDPD::DIN', 75868);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creme Solaire Tres Haute Protection Special Intolerances 30 Spf', 'emulsion', 'D02BA30', false, 0, '02273195', 'FreeDiams::CA_HCDPD::DIN', 75869);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enablex', 'tablet (extended-release)', 'G04BD10', false, 0, '02273217', 'FreeDiams::CA_HCDPD::DIN', 75871);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enablex', 'tablet (extended-release)', 'G04BD10', false, 0, '02273225', 'FreeDiams::CA_HCDPD::DIN', 75872);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caduet', 'tablet', 'C10BX03', false, 0, '02273233', 'FreeDiams::CA_HCDPD::DIN', 75873);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caduet', 'tablet', 'C10BX03', false, 0, '02273241', 'FreeDiams::CA_HCDPD::DIN', 75874);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caduet', 'tablet', 'C10BX03', false, 0, '02273268', 'FreeDiams::CA_HCDPD::DIN', 75875);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caduet', 'tablet', 'C10BX03', false, 0, '02273276', 'FreeDiams::CA_HCDPD::DIN', 75876);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caduet', 'tablet', 'C10BX03', false, 0, '02273284', 'FreeDiams::CA_HCDPD::DIN', 75877);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caduet', 'tablet', 'C10BX03', false, 0, '02273292', 'FreeDiams::CA_HCDPD::DIN', 75878);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caduet', 'tablet', 'C10BX03', false, 0, '02273306', 'FreeDiams::CA_HCDPD::DIN', 75879);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caduet', 'tablet', 'C10BX03', false, 0, '02273314', 'FreeDiams::CA_HCDPD::DIN', 75880);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aptivus', 'capsule', 'J05AE09', false, 0, '02273322', 'FreeDiams::CA_HCDPD::DIN', 75881);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Children''S Nyquil Cold & Cough Multi-Symptom Relief', 'liquid', 'R05DA20', false, 0, '02273330', 'FreeDiams::CA_HCDPD::DIN', 75882);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maximum Strength Pepcid Ac', 'tablet', 'A02BA03', false, 0, '02273357', 'FreeDiams::CA_HCDPD::DIN', 75884);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Amlodipine', 'tablet', 'C08CA01', false, 0, '02273373', 'FreeDiams::CA_HCDPD::DIN', 75886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Amlodipine', 'tablet', 'C08CA01', false, 0, '02273381', 'FreeDiams::CA_HCDPD::DIN', 75887);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bisacodyl-Odan', 'tablet (delayed-release)', 'A06AB02', false, 0, '02273411', 'FreeDiams::CA_HCDPD::DIN', 75889);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Original Eye Drops', 'drops', 'S01GA02', false, 0, '02273446', 'FreeDiams::CA_HCDPD::DIN', 75893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teen Midol Complete', 'tablet', 'N02BE51', false, 0, '02273454', 'FreeDiams::CA_HCDPD::DIN', 75894);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Cold & Sinus', 'tablet', 'N02BE51', false, 0, '02273462', 'FreeDiams::CA_HCDPD::DIN', 75895);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Cold & Sinus Plus', 'tablet', 'N02BE51', false, 0, '02273470', 'FreeDiams::CA_HCDPD::DIN', 75896);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ursodiol C', 'tablet', 'A05AA02', false, 0, '02273497', 'FreeDiams::CA_HCDPD::DIN', 75898);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ursodiol C', 'tablet', 'A05AA02', false, 0, '02273500', 'FreeDiams::CA_HCDPD::DIN', 75899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prime Source Antimicrobial Foaming Hand Soap With Chloroxylenol', 'liquid', 'D08AE05', false, 0, '02273527', 'FreeDiams::CA_HCDPD::DIN', 75901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Citalopram', 'tablet', 'N06AB04', false, 0, '02273543', 'FreeDiams::CA_HCDPD::DIN', 75903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fenofibrate Micro', 'capsule', 'C10AB05', false, 0, '02273551', 'FreeDiams::CA_HCDPD::DIN', 75904);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Uromax', 'tablet (extended-release)', 'G04BD04', false, 0, '02273578', 'FreeDiams::CA_HCDPD::DIN', 75905);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Uromax', 'tablet (extended-release)', 'G04BD04', false, 0, '02273586', 'FreeDiams::CA_HCDPD::DIN', 75906);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creme Antirougeurs Apaisante Fps 25', 'cream', 'D02BA30', false, 0, '02273594', 'FreeDiams::CA_HCDPD::DIN', 75907);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Sertraline', 'capsule', 'N06AB06', false, 0, '02273683', 'FreeDiams::CA_HCDPD::DIN', 75916);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Sertraline', 'capsule', 'N06AB06', false, 0, '02273691', 'FreeDiams::CA_HCDPD::DIN', 75917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Sertraline', 'capsule', 'N06AB06', false, 0, '02273705', 'FreeDiams::CA_HCDPD::DIN', 75918);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soleil Identité', 'lotion', 'D02BA30', false, 0, '02273713', 'FreeDiams::CA_HCDPD::DIN', 75919);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Almay Nearly Naked Liquid Makeup Spf 15', 'emulsion', 'D02BA30', false, 0, '02273721', 'FreeDiams::CA_HCDPD::DIN', 75920);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Glimepiride', 'tablet', 'A10BB12', false, 0, '02273756', 'FreeDiams::CA_HCDPD::DIN', 75923);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Glimepiride', 'tablet', 'A10BB12', false, 0, '02273764', 'FreeDiams::CA_HCDPD::DIN', 75924);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Glimepiride', 'tablet', 'A10BB12', false, 0, '02273772', 'FreeDiams::CA_HCDPD::DIN', 75926);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nyquil Sinus Liquicaps', 'capsule', 'N02BE51', false, 0, '02273810', 'FreeDiams::CA_HCDPD::DIN', 75929);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dayquil Sinus Liquicaps', 'capsule', 'N02BE51', false, 0, '02273829', 'FreeDiams::CA_HCDPD::DIN', 75930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('For Kids Spf 45 Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02273861', 'FreeDiams::CA_HCDPD::DIN', 75934);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benazepril', 'tablet', 'C09AA07', false, 0, '02273918', 'FreeDiams::CA_HCDPD::DIN', 75937);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin All-In-One Cold And Flu Night Pe Caplets', 'tablet', 'N02BE51', false, 0, '02273934', 'FreeDiams::CA_HCDPD::DIN', 75939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Mirtazapine', 'tablet', 'N06AX11', false, 0, '02273942', 'FreeDiams::CA_HCDPD::DIN', 75940);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Methylphenidate', 'tablet', 'N06BA04', false, 0, '02273950', 'FreeDiams::CA_HCDPD::DIN', 75941);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02273969', 'FreeDiams::CA_HCDPD::DIN', 75942);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02273977', 'FreeDiams::CA_HCDPD::DIN', 75943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02273985', 'FreeDiams::CA_HCDPD::DIN', 75944);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Differin Xp', 'gel', 'D10AD03', false, 0, '02274000', 'FreeDiams::CA_HCDPD::DIN', 75946);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('One Step Foaming Hand Sanitizer', 'liquid', 'D08AJ01', false, 0, '02274027', 'FreeDiams::CA_HCDPD::DIN', 75948);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Hydrochlorothiazide', 'tablet', 'C03AA03', false, 0, '02274086', 'FreeDiams::CA_HCDPD::DIN', 75953);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Green Earth Daily Disinfectant', 'liquid', 'V07AV', false, 0, '02274132', 'FreeDiams::CA_HCDPD::DIN', 75959);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Levetiracetam', 'tablet', 'N03AX14', false, 0, '02274183', 'FreeDiams::CA_HCDPD::DIN', 75964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Levetiracetam', 'tablet', 'N03AX14', false, 0, '02274191', 'FreeDiams::CA_HCDPD::DIN', 75965);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Levetiracetam', 'tablet', 'N03AX14', false, 0, '02274205', 'FreeDiams::CA_HCDPD::DIN', 75966);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kepivance', 'powder for solution', 'V03AF08', false, 0, '02274221', 'FreeDiams::CA_HCDPD::DIN', 75968);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Glimepiride', 'tablet', 'A10BB12', false, 0, '02274248', 'FreeDiams::CA_HCDPD::DIN', 75969);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Glimepiride', 'tablet', 'A10BB12', false, 0, '02274256', 'FreeDiams::CA_HCDPD::DIN', 75970);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Glimepiride', 'tablet', 'A10BB12', false, 0, '02274272', 'FreeDiams::CA_HCDPD::DIN', 75972);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Ondansetron', 'tablet', 'A04AA01', false, 0, '02274310', 'FreeDiams::CA_HCDPD::DIN', 75976);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Ondansetron', 'tablet', 'A04AA01', false, 0, '02274329', 'FreeDiams::CA_HCDPD::DIN', 75977);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Bicalutamide', 'tablet', 'L02BB03', false, 0, '02274337', 'FreeDiams::CA_HCDPD::DIN', 75978);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Matte Moisturizer Spf 15', 'lotion', 'D02BA30', false, 0, '02274345', 'FreeDiams::CA_HCDPD::DIN', 75980);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Mirtazapine', 'tablet', 'N06AX11', false, 0, '02274361', 'FreeDiams::CA_HCDPD::DIN', 75981);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Azithromycin', 'powder for suspension', 'J01FA10', false, 0, '02274388', 'FreeDiams::CA_HCDPD::DIN', 75984);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Azithromycin', 'powder for suspension', 'J01FA10', false, 0, '02274396', 'FreeDiams::CA_HCDPD::DIN', 75985);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ondansetron Injection Usp     -(Preservative Free)', 'solution', 'A04AA01', false, 0, '02274426', 'FreeDiams::CA_HCDPD::DIN', 75987);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ondansetron Injection Usp     -(With Preservatives)', 'solution', 'A04AA01', false, 0, '02274434', 'FreeDiams::CA_HCDPD::DIN', 75988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02274442', 'FreeDiams::CA_HCDPD::DIN', 75989);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Botanics Face Renewal Cream Spf 15', 'cream', 'D02BA30', false, 0, '02274450', 'FreeDiams::CA_HCDPD::DIN', 75990);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Azithromycin', 'tablet', 'J01FA10', false, 0, '02274531', 'FreeDiams::CA_HCDPD::DIN', 75998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Botanics Face Firming Moisturizing Cream Spf 10', 'cream', 'D02BA30', false, 0, '02274590', 'FreeDiams::CA_HCDPD::DIN', 76004);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('No7 Time Resisting Day Cream Spf 12', 'cream', 'D02BA30', false, 0, '02274620', 'FreeDiams::CA_HCDPD::DIN', 76007);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clicksan Disinfectant/Sanitizer', 'solution', 'V07AV', false, 0, '02274647', 'FreeDiams::CA_HCDPD::DIN', 76012);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alburex - 5', 'solution', 'B05AA01', false, 0, '02274655', 'FreeDiams::CA_HCDPD::DIN', 76013);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alburex - 25', 'solution', 'B05AA01', false, 0, '02274663', 'FreeDiams::CA_HCDPD::DIN', 76014);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enbrel', 'solution', 'L04AB01', false, 0, '02274728', 'FreeDiams::CA_HCDPD::DIN', 76019);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clarithromycin', 'tablet', 'J01FA09', false, 0, '02274744', 'FreeDiams::CA_HCDPD::DIN', 76021);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Clarithromycin', 'tablet', 'J01FA09', false, 0, '02274752', 'FreeDiams::CA_HCDPD::DIN', 76022);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sprayzinc', 'suspension', 'D11AX12', false, 0, '02274760', 'FreeDiams::CA_HCDPD::DIN', 76023);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artistry Time Defiance Day Protect Crčme Spf 15', 'cream', 'D02BA30', false, 0, '02274825', 'FreeDiams::CA_HCDPD::DIN', 76030);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Lisinopril', 'tablet', 'C09AA03', false, 0, '02274833', 'FreeDiams::CA_HCDPD::DIN', 76037);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Lisinopril', 'tablet', 'C09AA03', false, 0, '02274841', 'FreeDiams::CA_HCDPD::DIN', 76038);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Lisinopril', 'tablet', 'C09AA03', false, 0, '02274868', 'FreeDiams::CA_HCDPD::DIN', 76039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prismocal', 'solution', 'B05ZA', false, 0, '02274876', 'FreeDiams::CA_HCDPD::DIN', 76040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Truvada', 'tablet', 'J05AR03', false, 0, '02274906', 'FreeDiams::CA_HCDPD::DIN', 76043);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02274914', 'FreeDiams::CA_HCDPD::DIN', 76044);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02274922', 'FreeDiams::CA_HCDPD::DIN', 76045);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02274930', 'FreeDiams::CA_HCDPD::DIN', 76046);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Anagrelide', 'capsule', 'L01XX35', false, 0, '02274949', 'FreeDiams::CA_HCDPD::DIN', 76047);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('65 Disinfecting Heavy Duty Acid Bathroom Cleaner', 'liquid', 'V07AV', false, 0, '02274965', 'FreeDiams::CA_HCDPD::DIN', 76049);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oasis Pro 66 Heavy Duty Alkaline Bathroom Cleaner And Disinfectant', 'liquid', 'V07AV', false, 0, '02274973', 'FreeDiams::CA_HCDPD::DIN', 76050);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02275023', 'FreeDiams::CA_HCDPD::DIN', 76054);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02275031', 'FreeDiams::CA_HCDPD::DIN', 76055);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02275058', 'FreeDiams::CA_HCDPD::DIN', 76056);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trosec', 'tablet', 'G04BD09', false, 0, '02275066', 'FreeDiams::CA_HCDPD::DIN', 76057);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Bupropion Sr', 'tablet (extended-release)', 'N06AX12', false, 0, '02275074', 'FreeDiams::CA_HCDPD::DIN', 76058);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Bupropion Sr', 'tablet (extended-release)', 'N06AX12', false, 0, '02275082', 'FreeDiams::CA_HCDPD::DIN', 76059);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Wellbutrin Xl', 'tablet (extended-release)', 'N06AX12', false, 0, '02275090', 'FreeDiams::CA_HCDPD::DIN', 76060);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Wellbutrin Xl', 'tablet (extended-release)', 'N06AX12', false, 0, '02275104', 'FreeDiams::CA_HCDPD::DIN', 76061);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint Disinfectant', 'liquid', 'V07AV', false, 0, '02275120', 'FreeDiams::CA_HCDPD::DIN', 76078);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Menstrual Midol Complete', 'tablet', 'N02BE51', false, 0, '02275201', 'FreeDiams::CA_HCDPD::DIN', 76086);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms Midol Complete', 'tablet', 'N02BE51', false, 0, '02275228', 'FreeDiams::CA_HCDPD::DIN', 76087);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio Alendronate', 'tablet', 'M05BA04', false, 0, '02275279', 'FreeDiams::CA_HCDPD::DIN', 76091);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio Azithromycin', 'tablet', 'J01FA10', false, 0, '02275287', 'FreeDiams::CA_HCDPD::DIN', 76092);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva Azithromycin', 'tablet', 'J01FA10', false, 0, '02275309', 'FreeDiams::CA_HCDPD::DIN', 76094);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva Azithromycin', 'tablet', 'J01FA10', false, 0, '02275317', 'FreeDiams::CA_HCDPD::DIN', 76095);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bleach', 'solution', 'V07AV', false, 0, '02275341', 'FreeDiams::CA_HCDPD::DIN', 76098);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Botanics Daily Hand Therapy Spf 10', 'lotion', 'D02BA30', false, 0, '02275449', 'FreeDiams::CA_HCDPD::DIN', 76108);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sani-T-10', 'liquid', 'V07AV', false, 0, '02275457', 'FreeDiams::CA_HCDPD::DIN', 76109);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lysol Disinfectant Toilet Bowl Cleaner Power', 'liquid', 'V07AV', false, 0, '02275465', 'FreeDiams::CA_HCDPD::DIN', 76110);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sucrets Complete', 'lozenge', 'R02AD04', false, 0, '02275481', 'FreeDiams::CA_HCDPD::DIN', 76114);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flecainide', 'tablet', 'C01BC04', false, 0, '02275538', 'FreeDiams::CA_HCDPD::DIN', 76117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flecainide', 'tablet', 'C01BC04', false, 0, '02275546', 'FreeDiams::CA_HCDPD::DIN', 76118);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cuff Cleaner Plus', 'liquid', 'V07AV', false, 0, '02275554', 'FreeDiams::CA_HCDPD::DIN', 76119);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Bicalutamide', 'tablet', 'L02BB03', false, 0, '02275589', 'FreeDiams::CA_HCDPD::DIN', 76122);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Regular Strength Tylenol Cold Daytime', 'tablet', 'N02BE51', false, 0, '02275627', 'FreeDiams::CA_HCDPD::DIN', 76130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mac Prep+Prime Face Protect Spf 50', 'cream', 'D02BA30', false, 0, '02275635', 'FreeDiams::CA_HCDPD::DIN', 76132);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Regular Strength Tylenol Sinus Daytime', 'tablet', 'N02BE51', false, 0, '02275708', 'FreeDiams::CA_HCDPD::DIN', 76137);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Regular Strength Tylenol Cold Nighttime', 'tablet', 'N02BE51', false, 0, '02275716', 'FreeDiams::CA_HCDPD::DIN', 76138);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prescriptives Flawless Skin Total Protection Pressed Powder Uva/Uvb Spf 15', 'powder', 'D02BA30', false, 0, '02275724', 'FreeDiams::CA_HCDPD::DIN', 76139);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('B. Kamins, Chemist Bio Maple Booster Blue Moisturizer Spf 15', 'cream', 'D02BA30', false, 0, '02275791', 'FreeDiams::CA_HCDPD::DIN', 76146);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Duragesic Mat', 'patch', 'N02AB03', false, 0, '02275813', 'FreeDiams::CA_HCDPD::DIN', 76148);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Duragesic Mat', 'patch', 'N02AB03', false, 0, '02275821', 'FreeDiams::CA_HCDPD::DIN', 76149);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Duragesic Mat', 'patch', 'N02AB03', false, 0, '02275848', 'FreeDiams::CA_HCDPD::DIN', 76150);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Duragesic Mat', 'patch', 'N02AB03', false, 0, '02275856', 'FreeDiams::CA_HCDPD::DIN', 76151);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hypurin Nph Insulin Isophane Pork', 'suspension', 'A10AC03', false, 0, '02275864', 'FreeDiams::CA_HCDPD::DIN', 76152);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hypurin Regular Insulin Pork', 'solution', 'A10AB03', false, 0, '02275872', 'FreeDiams::CA_HCDPD::DIN', 76153);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neocitran Extra Strength Nighttime Total Cold & Flu', 'liquid', 'N02BE51', false, 0, '02275961', 'FreeDiams::CA_HCDPD::DIN', 76164);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neocitran Extra Strength Daytime Total Cold & Flu', 'liquid', 'N02BE51', false, 0, '02275988', 'FreeDiams::CA_HCDPD::DIN', 76166);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Flu Daytime', 'tablet', 'N02BE51', false, 0, '02275996', 'FreeDiams::CA_HCDPD::DIN', 76167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Sinus Daytime', 'tablet', 'N02BE51', false, 0, '02276003', 'FreeDiams::CA_HCDPD::DIN', 76168);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Sinus Nighttime', 'tablet', 'N02BE51', false, 0, '02276038', 'FreeDiams::CA_HCDPD::DIN', 76170);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Flu Nighttime', 'tablet', 'N02BE51', false, 0, '02276046', 'FreeDiams::CA_HCDPD::DIN', 76171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Allergy', 'tablet', 'N02BE51', false, 0, '02276054', 'FreeDiams::CA_HCDPD::DIN', 76172);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Bicalutamide', 'tablet', 'L02BB03', false, 0, '02276089', 'FreeDiams::CA_HCDPD::DIN', 76175);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Water For Injection Usp', 'liquid', 'V07AB', false, 0, '02276097', 'FreeDiams::CA_HCDPD::DIN', 76176);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Histenol Ii', 'tablet', 'N02BE51', false, 0, '02276119', 'FreeDiams::CA_HCDPD::DIN', 76178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Age Fitness Power 2 Spf 15', 'lotion', 'D02BA30', false, 0, '02276127', 'FreeDiams::CA_HCDPD::DIN', 76179);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Cold Daytime', 'tablet', 'N02BE51', false, 0, '02276186', 'FreeDiams::CA_HCDPD::DIN', 76185);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pregvit Folic 5', 'tablet', 'B03AE04', false, 0, '02276194', 'FreeDiams::CA_HCDPD::DIN', 76186);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nighttime Extra Strength Contac Cold & Sore Throat', 'tablet', 'N02BE51', false, 0, '02276216', 'FreeDiams::CA_HCDPD::DIN', 76188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Contac Complete Cough, Cold & Flu', 'tablet', 'N02BE51', false, 0, '02276224', 'FreeDiams::CA_HCDPD::DIN', 76189);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nighttime Extra Strength Contac Complete Cough, Cold & Flu', 'tablet', 'N02BE51', false, 0, '02276232', 'FreeDiams::CA_HCDPD::DIN', 76190);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Cold Nighttime', 'tablet', 'N02BE51', false, 0, '02276259', 'FreeDiams::CA_HCDPD::DIN', 76192);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fresh Cooling Body Mist Sunscreen Spf 45', 'aerosol', 'D02BA30', false, 0, '02276321', 'FreeDiams::CA_HCDPD::DIN', 76200);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Virkon Aquatic', 'powder for solution', 'V07AV', false, 0, '02276356', 'FreeDiams::CA_HCDPD::DIN', 76203);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Sheer Dry-Touch Sunscreen Spf 55', 'lotion', 'D02BA30', false, 0, '02276364', 'FreeDiams::CA_HCDPD::DIN', 76204);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triple Protect Face Lotion Spf 20', 'lotion', 'D02BA30', false, 0, '02276380', 'FreeDiams::CA_HCDPD::DIN', 76206);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fosavance', 'tablet', 'M05BB03', false, 0, '02276429', 'FreeDiams::CA_HCDPD::DIN', 76210);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aveeno Active Naturals Sunscreen Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02276453', 'FreeDiams::CA_HCDPD::DIN', 76213);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aveeno Active Naturals Sunscreen Lotion  Spf 45', 'lotion', 'D02BA30', false, 0, '02276461', 'FreeDiams::CA_HCDPD::DIN', 76214);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aveeno Sunscreen Lotion Face Spf 30', 'lotion', 'D02BA30', false, 0, '02276488', 'FreeDiams::CA_HCDPD::DIN', 76215);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Normocarb 25', 'solution', 'B05ZA', false, 0, '02276585', 'FreeDiams::CA_HCDPD::DIN', 76226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol Cold And Flu Daytime', 'liquid', 'N02BE51', false, 0, '02276658', 'FreeDiams::CA_HCDPD::DIN', 76233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Contac Cold Chest Congestion', 'tablet', 'N02BE51', false, 0, '02276682', 'FreeDiams::CA_HCDPD::DIN', 76236);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Contac Cold & Sore Throat', 'tablet', 'N02BE51', false, 0, '02276704', 'FreeDiams::CA_HCDPD::DIN', 76238);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Olanzapine', 'tablet', 'N05AH03', false, 0, '02276712', 'FreeDiams::CA_HCDPD::DIN', 76239);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Olanzapine', 'tablet', 'N05AH03', false, 0, '02276720', 'FreeDiams::CA_HCDPD::DIN', 76240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Olanzapine', 'tablet', 'N05AH03', false, 0, '02276739', 'FreeDiams::CA_HCDPD::DIN', 76241);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Olanzapine', 'tablet', 'N05AH03', false, 0, '02276747', 'FreeDiams::CA_HCDPD::DIN', 76242);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Olanzapine', 'tablet', 'N05AH03', false, 0, '02276755', 'FreeDiams::CA_HCDPD::DIN', 76243);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soin Hydratant Anti-Rides Fps 15', 'cream', 'D02BA30', false, 0, '02276801', 'FreeDiams::CA_HCDPD::DIN', 76247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol Cold And Flu Nighttime', 'liquid', 'N02BE51', false, 0, '02276879', 'FreeDiams::CA_HCDPD::DIN', 76254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dupont Relyon Disinfectant Wipes', 'wipe', 'V07AV', false, 0, '02276968', 'FreeDiams::CA_HCDPD::DIN', 76263);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germisyl', 'liquid', 'V07AV', false, 0, '02276976', 'FreeDiams::CA_HCDPD::DIN', 76264);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlor-Tripolon Day And Night', 'kit', 'R06AB04', false, 0, '02277123', 'FreeDiams::CA_HCDPD::DIN', 76278);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biphentin', 'capsule (extended release)', 'N06BA04', false, 0, '02277131', 'FreeDiams::CA_HCDPD::DIN', 76279);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biphentin', 'capsule (extended release)', 'N06BA04', false, 0, '02277158', 'FreeDiams::CA_HCDPD::DIN', 76280);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biphentin', 'capsule (extended release)', 'N06BA04', false, 0, '02277166', 'FreeDiams::CA_HCDPD::DIN', 76281);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biphentin', 'capsule (extended release)', 'N06BA04', false, 0, '02277174', 'FreeDiams::CA_HCDPD::DIN', 76282);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biphentin', 'capsule (extended release)', 'N06BA04', false, 0, '02277182', 'FreeDiams::CA_HCDPD::DIN', 76283);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biphentin', 'capsule (extended release)', 'N06BA04', false, 0, '02277190', 'FreeDiams::CA_HCDPD::DIN', 76284);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biphentin', 'capsule (extended release)', 'N06BA04', false, 0, '02277204', 'FreeDiams::CA_HCDPD::DIN', 76285);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biphentin', 'capsule (extended release)', 'N06BA04', false, 0, '02277212', 'FreeDiams::CA_HCDPD::DIN', 76286);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimetapp Chewables For Kids', 'tablet (chewable)', 'R01BA53', false, 0, '02277239', 'FreeDiams::CA_HCDPD::DIN', 76288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vesicare', 'tablet', 'G04BD08', false, 0, '02277263', 'FreeDiams::CA_HCDPD::DIN', 76292);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vesicare', 'tablet', 'G04BD08', false, 0, '02277271', 'FreeDiams::CA_HCDPD::DIN', 76293);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Medroxy', 'tablet', 'G03DA02', false, 0, '02277298', 'FreeDiams::CA_HCDPD::DIN', 76294);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zantac Maximum Strength Non-Prescription', 'tablet', 'A02BA02', false, 0, '02277301', 'FreeDiams::CA_HCDPD::DIN', 76295);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio Trazodone', 'tablet', 'N06AX05', false, 0, '02277344', 'FreeDiams::CA_HCDPD::DIN', 76298);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio Trazodone', 'tablet', 'N06AX05', false, 0, '02277352', 'FreeDiams::CA_HCDPD::DIN', 76299);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio Trazodone', 'tablet', 'N06AX05', false, 0, '02277360', 'FreeDiams::CA_HCDPD::DIN', 76300);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Atenolol', 'tablet', 'C07AB03', false, 0, '02277379', 'FreeDiams::CA_HCDPD::DIN', 76301);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prismasol 2', 'solution', 'B05ZA', false, 0, '02277441', 'FreeDiams::CA_HCDPD::DIN', 76308);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prismasol 4', 'solution', 'B05ZA', false, 0, '02277476', 'FreeDiams::CA_HCDPD::DIN', 76310);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Liquid Disinfectant', 'liquid', 'V07AV', false, 0, '02277484', 'FreeDiams::CA_HCDPD::DIN', 76311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rebif', 'solution', 'L03AB07', false, 0, '02277492', 'FreeDiams::CA_HCDPD::DIN', 76312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Disinfectant Fantastik Lemon Citrus All Purpose Cleaner 1', 'liquid', 'V07AV', false, 0, '02277514', 'FreeDiams::CA_HCDPD::DIN', 76314);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Disinfectant Fantastik Original All Purpose Cleaner', 'liquid', 'V07AV', false, 0, '02277522', 'FreeDiams::CA_HCDPD::DIN', 76315);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutrogena Ultra Sheer Spf 30', 'lotion', 'D02BA30', false, 0, '02277646', 'FreeDiams::CA_HCDPD::DIN', 76325);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Protectyl Soleil Moisturizing Sunscreen Lotion High Protection Spf30', 'lotion', 'D02BA30', false, 0, '02277662', 'FreeDiams::CA_HCDPD::DIN', 76327);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cellular Anti-Wrinkle Sun Cream Spf 30', 'cream', 'D02BA30', false, 0, '02277670', 'FreeDiams::CA_HCDPD::DIN', 76328);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Bicalutamide', 'tablet', 'L02BB03', false, 0, '02277700', 'FreeDiams::CA_HCDPD::DIN', 76331);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Critic-Aid Clear', 'ointment', 'D02AC', false, 0, '02277778', 'FreeDiams::CA_HCDPD::DIN', 76338);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dior Bronze Voile Teinté', 'emulsion', 'D02BA30', false, 0, '02277832', 'FreeDiams::CA_HCDPD::DIN', 76343);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mary Kay Tinted Moisturizer With Sunscreen Spf 20', 'lotion', 'D02BA30', false, 0, '02277891', 'FreeDiams::CA_HCDPD::DIN', 76349);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sport Sunscreen Gel Spf 30', 'gel', 'D02BA30', false, 0, '02277913', 'FreeDiams::CA_HCDPD::DIN', 76351);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Igivnex', 'solution', 'J06BA02', false, 0, '02277921', 'FreeDiams::CA_HCDPD::DIN', 76352);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Long Acting Cough', 'syrup', 'R05DA09', false, 0, '02277972', 'FreeDiams::CA_HCDPD::DIN', 76356);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva Zopiclone', 'tablet', 'N05CF01', false, 0, '02278030', 'FreeDiams::CA_HCDPD::DIN', 76362);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva Zopiclone', 'tablet', 'N05CF01', false, 0, '02278049', 'FreeDiams::CA_HCDPD::DIN', 76363);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Voluven', 'solution', 'B05AA07', false, 0, '02278057', 'FreeDiams::CA_HCDPD::DIN', 76364);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Daytime Cough & Cold', 'liquid', 'R05DA20', false, 0, '02278073', 'FreeDiams::CA_HCDPD::DIN', 76366);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Famciclovir', 'tablet', 'J05AB09', false, 0, '02278081', 'FreeDiams::CA_HCDPD::DIN', 76367);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Famciclovir', 'tablet', 'J05AB09', false, 0, '02278103', 'FreeDiams::CA_HCDPD::DIN', 76368);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Famciclovir', 'tablet', 'J05AB09', false, 0, '02278111', 'FreeDiams::CA_HCDPD::DIN', 76369);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micrell Antibacterial Foam Handwash', 'liquid', 'D08AE05', false, 0, '02278138', 'FreeDiams::CA_HCDPD::DIN', 76372);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Provon Medicated Foam Handwash With Advanced Moisturizers', 'liquid', 'D08AE04', false, 0, '02278146', 'FreeDiams::CA_HCDPD::DIN', 76373);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prime Source Antibacterial Foam Soap', 'liquid', 'D08AE04', false, 0, '02278154', 'FreeDiams::CA_HCDPD::DIN', 76374);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Nighttime Cough And Cold', 'liquid', 'R01BA53', false, 0, '02278170', 'FreeDiams::CA_HCDPD::DIN', 76376);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intensive Line Filler Comble-Ridules Intensif Spf/Fps 15', 'stick', 'D02BA30', false, 0, '02278200', 'FreeDiams::CA_HCDPD::DIN', 76379);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arestin Microspheres', 'powder (extended release)', 'A01AB23', false, 0, '02278219', 'FreeDiams::CA_HCDPD::DIN', 76380);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunbalance', 'cream', 'D11AX11', false, 0, '02278243', 'FreeDiams::CA_HCDPD::DIN', 76383);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Duotrav', 'solution', 'S01ED51', false, 0, '02278251', 'FreeDiams::CA_HCDPD::DIN', 76384);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Theraflu Cold And Flu', 'powder', 'N02BE51', false, 0, '02278294', 'FreeDiams::CA_HCDPD::DIN', 76387);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Chest And Nasal Congestion', 'liquid', 'R05CA10', false, 0, '02278308', 'FreeDiams::CA_HCDPD::DIN', 76388);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cidex Opa Concentrate', 'solution', 'V07AV', false, 0, '02278340', 'FreeDiams::CA_HCDPD::DIN', 76392);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Instant Hand Sanitizer', 'liquid', 'D08AJ08', false, 0, '02278375', 'FreeDiams::CA_HCDPD::DIN', 76393);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Azithromycin', 'tablet', 'J01FA10', false, 0, '02278359', 'FreeDiams::CA_HCDPD::DIN', 76396);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vantas', 'kit', 'H01CA03', false, 0, '02278383', 'FreeDiams::CA_HCDPD::DIN', 76398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Ondansetron', 'tablet', 'A04AA01', false, 0, '02278405', 'FreeDiams::CA_HCDPD::DIN', 76400);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Ondansetron', 'tablet', 'A04AA01', false, 0, '02278413', 'FreeDiams::CA_HCDPD::DIN', 76401);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Risperidone', 'tablet', 'N05AX08', false, 0, '02278421', 'FreeDiams::CA_HCDPD::DIN', 76402);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Risperidone', 'tablet', 'N05AX08', false, 0, '02278448', 'FreeDiams::CA_HCDPD::DIN', 76403);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Risperidone', 'tablet', 'N05AX08', false, 0, '02278456', 'FreeDiams::CA_HCDPD::DIN', 76404);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Risperidone', 'tablet', 'N05AX08', false, 0, '02278464', 'FreeDiams::CA_HCDPD::DIN', 76405);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Risperidone', 'tablet', 'N05AX08', false, 0, '02278472', 'FreeDiams::CA_HCDPD::DIN', 76406);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Risperidone', 'tablet', 'N05AX08', false, 0, '02278480', 'FreeDiams::CA_HCDPD::DIN', 76407);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Azithromycin', 'tablet', 'J01FA10', false, 0, '02278499', 'FreeDiams::CA_HCDPD::DIN', 76408);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Azithromycin', 'tablet', 'J01FA10', false, 0, '02278502', 'FreeDiams::CA_HCDPD::DIN', 76409);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Myoflex Deep Therapy', 'patch', 'M02AC', false, 0, '02278510', 'FreeDiams::CA_HCDPD::DIN', 76410);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ondansetron', 'tablet', 'A04AA01', false, 0, '02278529', 'FreeDiams::CA_HCDPD::DIN', 76411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ondansetron', 'tablet', 'A04AA01', false, 0, '02278537', 'FreeDiams::CA_HCDPD::DIN', 76412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02278545', 'FreeDiams::CA_HCDPD::DIN', 76413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02278553', 'FreeDiams::CA_HCDPD::DIN', 76414);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02278561', 'FreeDiams::CA_HCDPD::DIN', 76415);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Azithromycin', 'tablet', 'J01FA10', false, 0, '02278588', 'FreeDiams::CA_HCDPD::DIN', 76416);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Ondansetron', 'tablet', 'A04AA01', false, 0, '02278618', 'FreeDiams::CA_HCDPD::DIN', 76418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Ondansetron', 'tablet', 'A04AA01', false, 0, '02278626', 'FreeDiams::CA_HCDPD::DIN', 76419);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Famciclovir', 'tablet', 'J05AB09', false, 0, '02278634', 'FreeDiams::CA_HCDPD::DIN', 76420);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Famciclovir', 'tablet', 'J05AB09', false, 0, '02278642', 'FreeDiams::CA_HCDPD::DIN', 76421);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Famciclovir', 'tablet', 'J05AB09', false, 0, '02278650', 'FreeDiams::CA_HCDPD::DIN', 76422);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Domperidone', 'tablet', 'A03FA03', false, 0, '02278669', 'FreeDiams::CA_HCDPD::DIN', 76423);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Midodrine', 'tablet', 'C01CA17', false, 0, '02278677', 'FreeDiams::CA_HCDPD::DIN', 76425);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Midodrine', 'tablet', 'C01CA17', false, 0, '02278685', 'FreeDiams::CA_HCDPD::DIN', 76426);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neocitran Thin Strips Nighttime Cough And Cold', 'strip', 'R01BA53', false, 0, '02278693', 'FreeDiams::CA_HCDPD::DIN', 76427);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neocitran Thin Strips Daytime Cough And Cold', 'strip', 'R05DA20', false, 0, '02278715', 'FreeDiams::CA_HCDPD::DIN', 76429);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Cough And Sore Throat Softchews', 'tablet (chewable)', 'N02BE51', false, 0, '02278731', 'FreeDiams::CA_HCDPD::DIN', 76431);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triaminic Fever & Cough', 'liquid', 'N02BE51', false, 0, '02278758', 'FreeDiams::CA_HCDPD::DIN', 76432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('T36 Disinfectant Cleaner Concentrate', 'liquid', 'V07AV', false, 0, '02278820', 'FreeDiams::CA_HCDPD::DIN', 76438);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fight-It 32', 'liquid', 'V07AV', false, 0, '02278863', 'FreeDiams::CA_HCDPD::DIN', 76443);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluoxetine', 'capsule', 'N06AB03', false, 0, '02286068', 'FreeDiams::CA_HCDPD::DIN', 77154);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Blu-Lite Disinfectant Bowl Cleaner', 'liquid', 'V07AV', false, 0, '02278871', 'FreeDiams::CA_HCDPD::DIN', 76444);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Presto Disinfectant Bowl Cleaner', 'liquid', 'V07AV', false, 0, '02278898', 'FreeDiams::CA_HCDPD::DIN', 76446);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pine-Sol Multi-Surface Cleaner Disinfectant', 'liquid', 'V07AV', false, 0, '02278928', 'FreeDiams::CA_HCDPD::DIN', 76448);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creme Pour Peaux Intolerantes Au Soleil', 'cream', 'D02BA30', false, 0, '02278936', 'FreeDiams::CA_HCDPD::DIN', 76449);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spray Pour Peaux Intolerantes Au Soleil', 'spray', 'D02BA30', false, 0, '02278944', 'FreeDiams::CA_HCDPD::DIN', 76450);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germ-Destroyer 24', 'liquid', 'V07AV', false, 0, '02278960', 'FreeDiams::CA_HCDPD::DIN', 76452);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germ-Destroyer 38a', 'liquid', 'V07AV', false, 0, '02278979', 'FreeDiams::CA_HCDPD::DIN', 76453);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bac-Killer 48', 'liquid', 'V07AV', false, 0, '02279010', 'FreeDiams::CA_HCDPD::DIN', 76457);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bac-Killer 90', 'liquid', 'V07AV', false, 0, '02279029', 'FreeDiams::CA_HCDPD::DIN', 76458);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germ-Destroyer 15', 'liquid', 'V07AV', false, 0, '02279037', 'FreeDiams::CA_HCDPD::DIN', 76459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kirkland Signature Household Surface Wipes', 'wipe', 'V07AV', false, 0, '02279045', 'FreeDiams::CA_HCDPD::DIN', 76460);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epicare Antimicrobial Lotion Soap', 'liquid', 'D08AE05', false, 0, '02279053', 'FreeDiams::CA_HCDPD::DIN', 76461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rougier Vap-Chlorhexidine Gluconate 2% W/V', 'solution', 'D08AC02', false, 0, '02279134', 'FreeDiams::CA_HCDPD::DIN', 76467);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prescriptives Anywear Multi-Finish Compact Foundation Spf 12', 'powder', 'D02BA30', false, 0, '02279142', 'FreeDiams::CA_HCDPD::DIN', 76468);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Tylenol Cold And Cough Nighttime', 'suspension', 'N02BE51', false, 0, '02279150', 'FreeDiams::CA_HCDPD::DIN', 76469);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prescriptives Anti-Age Advanced Protection Eye Cream Spf 25', 'cream', 'D02BA30', false, 0, '02279169', 'FreeDiams::CA_HCDPD::DIN', 76470);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lysol Disinfectant Spray', 'aerosol', 'V07AV', false, 0, '02279177', 'FreeDiams::CA_HCDPD::DIN', 76471);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lph Ag', 'liquid', 'V07AV', false, 0, '02279185', 'FreeDiams::CA_HCDPD::DIN', 76472);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Raloxifene', 'tablet', 'G03XC01', false, 0, '02279215', 'FreeDiams::CA_HCDPD::DIN', 76475);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zaditor    (Preservative-Free)', 'solution', 'S01GX08', false, 0, '02279223', 'FreeDiams::CA_HCDPD::DIN', 76476);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Brand Antibacterial All Purpose Cleaner', 'solution', 'V07AV', false, 0, '02279231', 'FreeDiams::CA_HCDPD::DIN', 76479);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Risperidone', 'solution', 'N05AX08', false, 0, '02279266', 'FreeDiams::CA_HCDPD::DIN', 76481);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accel Hld 5', 'liquid', 'V07AV', false, 0, '02279274', 'FreeDiams::CA_HCDPD::DIN', 76483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Invirase', 'tablet', 'J05AE01', false, 0, '02279320', 'FreeDiams::CA_HCDPD::DIN', 76489);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Strattera', 'capsule', 'N06BA09', false, 0, '02279347', 'FreeDiams::CA_HCDPD::DIN', 76495);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Strattera', 'capsule', 'N06BA09', false, 0, '02279355', 'FreeDiams::CA_HCDPD::DIN', 76496);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Dexamethasone', 'tablet', 'H02AB02', false, 0, '02279363', 'FreeDiams::CA_HCDPD::DIN', 76497);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro Sep', 'liquid', 'V07AV', false, 0, '02279371', 'FreeDiams::CA_HCDPD::DIN', 76498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Revatio', 'tablet', 'G04BE03', false, 0, '02279401', 'FreeDiams::CA_HCDPD::DIN', 76500);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ondansetron Injection Usp     -(Preservative Free)', 'solution', 'A04AA01', false, 0, '02279428', 'FreeDiams::CA_HCDPD::DIN', 76501);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ondansetron Injection Usp     -(With Preservative)', 'solution', 'A04AA01', false, 0, '02279436', 'FreeDiams::CA_HCDPD::DIN', 76502);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gammagard Liquid', 'solution', 'J06BA02', false, 0, '02279444', 'FreeDiams::CA_HCDPD::DIN', 76503);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apidra     (10ml Vial)', 'solution', 'A10AB06', false, 0, '02279460', 'FreeDiams::CA_HCDPD::DIN', 76506);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apidra     (3ml Cartridge)', 'solution', 'A10AB06', false, 0, '02279479', 'FreeDiams::CA_HCDPD::DIN', 76507);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rhume Et Grippe Extra-Fort', 'powder', 'N02BE51', false, 0, '02279517', 'FreeDiams::CA_HCDPD::DIN', 76511);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('D.O.R.C. Vision Blue', 'drops', 'S01KX02', false, 0, '02279525', 'FreeDiams::CA_HCDPD::DIN', 76514);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Facial Moisturizer Spf 15', 'lotion', 'D02BA30', false, 0, '02279576', 'FreeDiams::CA_HCDPD::DIN', 76518);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Resultz', 'solution', 'P03AX', false, 0, '02279592', 'FreeDiams::CA_HCDPD::DIN', 76520);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Topiramate', 'tablet', 'N03AX11', false, 0, '02279614', 'FreeDiams::CA_HCDPD::DIN', 76522);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Topiramate', 'tablet', 'N03AX11', false, 0, '02279630', 'FreeDiams::CA_HCDPD::DIN', 76524);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Topiramate', 'tablet', 'N03AX11', false, 0, '02279649', 'FreeDiams::CA_HCDPD::DIN', 76525);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actonel Plus Calcium', 'tablet', 'M05BB02', false, 0, '02279657', 'FreeDiams::CA_HCDPD::DIN', 76526);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mb-10 Tablets', 'tablet', 'V07AV', false, 0, '02279673', 'FreeDiams::CA_HCDPD::DIN', 76528);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckley''S Complete', 'liquid', 'N02BE51', false, 0, '02279703', 'FreeDiams::CA_HCDPD::DIN', 76530);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intervention Rtu', 'liquid', 'V07AV', false, 0, '02279746', 'FreeDiams::CA_HCDPD::DIN', 76533);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride Injection Usp 0.9%', 'solution', 'V07AB', false, 0, '02279754', 'FreeDiams::CA_HCDPD::DIN', 76534);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dishwasher Magic', 'liquid', 'V07AV', false, 0, '02279770', 'FreeDiams::CA_HCDPD::DIN', 76536);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sani/Cide', 'liquid', 'V07AV', false, 0, '02279789', 'FreeDiams::CA_HCDPD::DIN', 76537);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Risperidone', 'tablet', 'N05AX08', false, 0, '02279800', 'FreeDiams::CA_HCDPD::DIN', 76539);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Risperidone', 'tablet', 'N05AX08', false, 0, '02279819', 'FreeDiams::CA_HCDPD::DIN', 76540);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Risperidone', 'tablet', 'N05AX08', false, 0, '02279827', 'FreeDiams::CA_HCDPD::DIN', 76541);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Risperidone', 'tablet', 'N05AX08', false, 0, '02279835', 'FreeDiams::CA_HCDPD::DIN', 76542);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cold + Sinus Caplets', 'tablet', 'M01AE51', false, 0, '02279851', 'FreeDiams::CA_HCDPD::DIN', 76544);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Mirtazapine Od Tablets', 'tablet (orally disintegrating)', 'N06AX11', false, 0, '02279894', 'FreeDiams::CA_HCDPD::DIN', 76547);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Mirtazapine Od Tablets', 'tablet (orally disintegrating)', 'N06AX11', false, 0, '02279908', 'FreeDiams::CA_HCDPD::DIN', 76548);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Mirtazapine Od Tablets', 'tablet (orally disintegrating)', 'N06AX11', false, 0, '02279916', 'FreeDiams::CA_HCDPD::DIN', 76549);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Menactra', 'solution', 'J07AH08', false, 0, '02279924', 'FreeDiams::CA_HCDPD::DIN', 76550);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Mupirocin', 'ointment', 'D06AX09', false, 0, '02279983', 'FreeDiams::CA_HCDPD::DIN', 76560);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vfend', 'powder for suspension', 'J02AC03', false, 0, '02279991', 'FreeDiams::CA_HCDPD::DIN', 76561);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Amlodipine', 'tablet', 'C08CA01', false, 0, '02280132', 'FreeDiams::CA_HCDPD::DIN', 76581);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Amlodipine', 'tablet', 'C08CA01', false, 0, '02280140', 'FreeDiams::CA_HCDPD::DIN', 76582);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('24 Hour Allergy Remedy', 'tablet', 'R06AX13', false, 0, '02280159', 'FreeDiams::CA_HCDPD::DIN', 76583);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asatab 80 Mg Chewable Tablets', 'tablet (chewable)', 'N02BA01', false, 0, '02280167', 'FreeDiams::CA_HCDPD::DIN', 76584);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Ibuprofen Suspension', 'suspension', 'M01AE01', false, 0, '02280175', 'FreeDiams::CA_HCDPD::DIN', 76585);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Betahistine', 'tablet', 'N07CA01', false, 0, '02280183', 'FreeDiams::CA_HCDPD::DIN', 76586);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Betahistine', 'tablet', 'N07CA01', false, 0, '02280191', 'FreeDiams::CA_HCDPD::DIN', 76587);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Betahistine', 'tablet', 'N07CA01', false, 0, '02280205', 'FreeDiams::CA_HCDPD::DIN', 76588);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avalide', 'tablet', 'C09DA04', false, 0, '02280213', 'FreeDiams::CA_HCDPD::DIN', 76589);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Testim 1%', 'gel', 'G03BA03', false, 0, '02280248', 'FreeDiams::CA_HCDPD::DIN', 76591);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Safetec Disinfecting Solution', 'solution', 'V07AV', false, 0, '02280256', 'FreeDiams::CA_HCDPD::DIN', 76592);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Felodipine', 'tablet (extended-release)', 'C08CA02', false, 0, '02280264', 'FreeDiams::CA_HCDPD::DIN', 76593);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Felodipine', 'tablet (extended-release)', 'C08CA02', false, 0, '02280272', 'FreeDiams::CA_HCDPD::DIN', 76594);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun Defense Uvscreen Spf 48', 'cream', 'D02BA30', false, 0, '02280329', 'FreeDiams::CA_HCDPD::DIN', 76600);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ombrelle Cream Spf 60', 'cream', 'D02BA30', false, 0, '02280353', 'FreeDiams::CA_HCDPD::DIN', 76603);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anthelios Xl Cream Spf 60', 'cream', 'D02BA30', false, 0, '02280361', 'FreeDiams::CA_HCDPD::DIN', 76604);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Cream Spf60', 'cream', 'D02BA30', false, 0, '02280388', 'FreeDiams::CA_HCDPD::DIN', 76605);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Risperidone', 'solution', 'N05AX08', false, 0, '02280396', 'FreeDiams::CA_HCDPD::DIN', 76606);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cilazapril', 'tablet', 'C09AA08', false, 0, '02280442', 'FreeDiams::CA_HCDPD::DIN', 76610);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cilazapril', 'tablet', 'C09AA08', false, 0, '02280450', 'FreeDiams::CA_HCDPD::DIN', 76611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cilazapril', 'tablet', 'C09AA08', false, 0, '02280469', 'FreeDiams::CA_HCDPD::DIN', 76612);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lansoprazole', 'capsule (delayed release)', 'A02BC03', false, 0, '02280515', 'FreeDiams::CA_HCDPD::DIN', 76617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lansoprazole', 'capsule (delayed release)', 'A02BC03', false, 0, '02280523', 'FreeDiams::CA_HCDPD::DIN', 76618);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creme De Teint Compacte/Compact Foundation Cream Texture Confort/Rich Formula Fps/Spf30', 'cream', 'D02BA30', false, 0, '02280531', 'FreeDiams::CA_HCDPD::DIN', 76619);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Silver Bullet Suppository', 'suppository', 'A06AB02', false, 0, '02280566', 'FreeDiams::CA_HCDPD::DIN', 76622);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gluquat', 'solution', 'V07AV', false, 0, '02280647', 'FreeDiams::CA_HCDPD::DIN', 76631);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Aging Emulsion Spf 30', 'lotion', 'D02BA30', false, 0, '02280671', 'FreeDiams::CA_HCDPD::DIN', 76634);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Aging Eye Cream Spf 15', 'cream', 'D02BA30', false, 0, '02280698', 'FreeDiams::CA_HCDPD::DIN', 76635);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germinix-64', 'liquid', 'V07AV', false, 0, '02280728', 'FreeDiams::CA_HCDPD::DIN', 76639);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rona Nettoyant Tout Usage Antibacterien', 'solution', 'V07AV', false, 0, '02280736', 'FreeDiams::CA_HCDPD::DIN', 76640);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carmex Lip Balm', 'ointment', 'D02AC', false, 0, '02280760', 'FreeDiams::CA_HCDPD::DIN', 76643);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carmex Lip Ointment', 'ointment', 'D02AC', false, 0, '02280779', 'FreeDiams::CA_HCDPD::DIN', 76644);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Powerfoam C', 'solution', 'V07AV', false, 0, '02280787', 'FreeDiams::CA_HCDPD::DIN', 76646);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sutent', 'capsule', 'L01XE04', false, 0, '02280795', 'FreeDiams::CA_HCDPD::DIN', 76647);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sutent', 'capsule', 'L01XE04', false, 0, '02280809', 'FreeDiams::CA_HCDPD::DIN', 76648);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sutent', 'capsule', 'L01XE04', false, 0, '02280817', 'FreeDiams::CA_HCDPD::DIN', 76649);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Velosan', 'liquid', 'V07AV', false, 0, '02280825', 'FreeDiams::CA_HCDPD::DIN', 76650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ranitidine', 'solution', 'A02BA02', false, 0, '02280833', 'FreeDiams::CA_HCDPD::DIN', 76651);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gentle Fresh Sanitizer', 'liquid', 'D08AJ08', false, 0, '02280841', 'FreeDiams::CA_HCDPD::DIN', 76652);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benadryl Bug Bite Relief', 'liquid', 'D04AA32', false, 0, '02280868', 'FreeDiams::CA_HCDPD::DIN', 76653);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hema Bp-38', 'powder', 'B05ZA', false, 0, '02280884', 'FreeDiams::CA_HCDPD::DIN', 76654);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benadryl Spray', 'spray', 'D04AA32', false, 0, '02280876', 'FreeDiams::CA_HCDPD::DIN', 76655);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Risperidone', 'tablet', 'N05AX08', false, 0, '02280906', 'FreeDiams::CA_HCDPD::DIN', 76658);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Risperidone', 'tablet', 'N05AX08', false, 0, '02280914', 'FreeDiams::CA_HCDPD::DIN', 76659);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Risperidone', 'tablet', 'N05AX08', false, 0, '02280922', 'FreeDiams::CA_HCDPD::DIN', 76660);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Risperidone', 'tablet', 'N05AX08', false, 0, '02280930', 'FreeDiams::CA_HCDPD::DIN', 76662);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Risperidone', 'tablet', 'N05AX08', false, 0, '02280949', 'FreeDiams::CA_HCDPD::DIN', 76663);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Risperidone', 'tablet', 'N05AX08', false, 0, '02280957', 'FreeDiams::CA_HCDPD::DIN', 76664);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidomax 5', 'cream', 'D04AB01', false, 0, '02281023', 'FreeDiams::CA_HCDPD::DIN', 76670);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stool Softener', 'capsule', 'A06AA02', false, 0, '02281031', 'FreeDiams::CA_HCDPD::DIN', 76671);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abraxane For Injectable Suspension', 'powder for suspension', 'L01CD01', false, 0, '02281066', 'FreeDiams::CA_HCDPD::DIN', 76673);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Altace', 'capsule', 'C09AA05', false, 0, '02281112', 'FreeDiams::CA_HCDPD::DIN', 76678);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Bicalutamide', 'tablet', 'L02BB03', false, 0, '02281139', 'FreeDiams::CA_HCDPD::DIN', 76679);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cold And Flu-In-One Extra Strength', 'tablet', 'N02BE51', false, 0, '02281147', 'FreeDiams::CA_HCDPD::DIN', 76681);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Bicalutamide', 'tablet', 'L02BB03', false, 0, '02281163', 'FreeDiams::CA_HCDPD::DIN', 76683);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Digoxin', 'tablet', 'C01AA05', false, 0, '02281201', 'FreeDiams::CA_HCDPD::DIN', 76686);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Digoxin', 'tablet', 'C01AA05', false, 0, '02281228', 'FreeDiams::CA_HCDPD::DIN', 76687);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Digoxin', 'tablet', 'C01AA05', false, 0, '02281236', 'FreeDiams::CA_HCDPD::DIN', 76688);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cherry Creme Hand Soap Antibacterial', 'liquid', 'D08AE04', false, 0, '02281244', 'FreeDiams::CA_HCDPD::DIN', 76689);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aspen Hand Soap Antibacterial', 'liquid', 'D08AE04', false, 0, '02281252', 'FreeDiams::CA_HCDPD::DIN', 76690);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Fluconazole', 'tablet', 'J02AC01', false, 0, '02281260', 'FreeDiams::CA_HCDPD::DIN', 76691);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Fluconazole', 'tablet', 'J02AC01', false, 0, '02281279', 'FreeDiams::CA_HCDPD::DIN', 76692);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Anagrelide', 'capsule', 'L01XX35', false, 0, '02281287', 'FreeDiams::CA_HCDPD::DIN', 76693);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Ursodiol C', 'tablet', 'A05AA02', false, 0, '02281295', 'FreeDiams::CA_HCDPD::DIN', 76694);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Ursodiol C', 'tablet', 'A05AA02', false, 0, '02281309', 'FreeDiams::CA_HCDPD::DIN', 76695);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Ursodiol C', 'tablet', 'A05AA02', false, 0, '02281317', 'FreeDiams::CA_HCDPD::DIN', 76696);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Ursodiol C', 'tablet', 'A05AA02', false, 0, '02281325', 'FreeDiams::CA_HCDPD::DIN', 76697);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ibuprofen Liquid Filled Capsules', 'capsule', 'M01AE01', false, 0, '02281384', 'FreeDiams::CA_HCDPD::DIN', 76703);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carbocaine 2% With Neo-Cobefrin', 'solution', 'N01BB53', false, 0, '02281414', 'FreeDiams::CA_HCDPD::DIN', 76704);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Tamsulosin', 'capsule (sustained-release)', 'G04CA02', false, 0, '02281392', 'FreeDiams::CA_HCDPD::DIN', 76705);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Skin Clarifying Intensive Revitalizing Care Spf 15', 'cream', 'D02BA30', false, 0, '02281422', 'FreeDiams::CA_HCDPD::DIN', 76707);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arbonne International Made In The Shade Self-Tanner Sunscreen Spf 15', 'cream', 'D02BA30', false, 0, '02281465', 'FreeDiams::CA_HCDPD::DIN', 76711);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accel Cs 20', 'liquid', 'V07AV', false, 0, '02281473', 'FreeDiams::CA_HCDPD::DIN', 76716);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Simvastatin', 'tablet', 'C10AA01', false, 0, '02281546', 'FreeDiams::CA_HCDPD::DIN', 76721);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Simvastatin', 'tablet', 'C10AA01', false, 0, '02281554', 'FreeDiams::CA_HCDPD::DIN', 76722);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Simvastatin', 'tablet', 'C10AA01', false, 0, '02281562', 'FreeDiams::CA_HCDPD::DIN', 76723);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Simvastatin', 'tablet', 'C10AA01', false, 0, '02281570', 'FreeDiams::CA_HCDPD::DIN', 76724);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Simvastatin', 'tablet', 'C10AA01', false, 0, '02281589', 'FreeDiams::CA_HCDPD::DIN', 76725);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Simvastatin', 'tablet', 'C10AA01', false, 0, '02281619', 'FreeDiams::CA_HCDPD::DIN', 76728);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Simvastatin', 'tablet', 'C10AA01', false, 0, '02281627', 'FreeDiams::CA_HCDPD::DIN', 76729);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Simvastatin', 'tablet', 'C10AA01', false, 0, '02281635', 'FreeDiams::CA_HCDPD::DIN', 76730);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Simvastatin', 'tablet', 'C10AA01', false, 0, '02281643', 'FreeDiams::CA_HCDPD::DIN', 76731);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Simvastatin', 'tablet', 'C10AA01', false, 0, '02281651', 'FreeDiams::CA_HCDPD::DIN', 76732);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rebif', 'kit', 'L03AB07', false, 0, '02281708', 'FreeDiams::CA_HCDPD::DIN', 76736);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Mirtazapine', 'tablet', 'N06AX11', false, 0, '02281716', 'FreeDiams::CA_HCDPD::DIN', 76737);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mirtazapine', 'tablet', 'N06AX11', false, 0, '02281732', 'FreeDiams::CA_HCDPD::DIN', 76739);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mac Studio Moisture Fix Spf 15', 'lotion', 'D02BA30', false, 0, '02281775', 'FreeDiams::CA_HCDPD::DIN', 76743);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Silkies Enriche Ageless Moisturizer', 'cream', 'D02BA30', false, 0, '02281783', 'FreeDiams::CA_HCDPD::DIN', 76744);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Olanzapine', 'tablet', 'N05AH03', false, 0, '02281791', 'FreeDiams::CA_HCDPD::DIN', 76745);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Olanzapine', 'tablet', 'N05AH03', false, 0, '02281805', 'FreeDiams::CA_HCDPD::DIN', 76746);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Olanzapine', 'tablet', 'N05AH03', false, 0, '02281813', 'FreeDiams::CA_HCDPD::DIN', 76747);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Olanzapine', 'tablet', 'N05AH03', false, 0, '02281821', 'FreeDiams::CA_HCDPD::DIN', 76748);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Olanzapine', 'tablet', 'N05AH03', false, 0, '02281848', 'FreeDiams::CA_HCDPD::DIN', 76749);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simple Green D Pro 5', 'liquid', 'V07AV', false, 0, '02281996', 'FreeDiams::CA_HCDPD::DIN', 76765);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Orencia', 'powder for solution', 'L04AA24', false, 0, '02282097', 'FreeDiams::CA_HCDPD::DIN', 76776);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germ-Killer 107', 'liquid', 'V07AV', false, 0, '02282100', 'FreeDiams::CA_HCDPD::DIN', 76777);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Risperidone', 'tablet', 'N05AX08', false, 0, '02282119', 'FreeDiams::CA_HCDPD::DIN', 76778);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Risperidone', 'tablet', 'N05AX08', false, 0, '02282127', 'FreeDiams::CA_HCDPD::DIN', 76779);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Risperidone', 'tablet', 'N05AX08', false, 0, '02282135', 'FreeDiams::CA_HCDPD::DIN', 76780);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Risperidone', 'tablet', 'N05AX08', false, 0, '02282143', 'FreeDiams::CA_HCDPD::DIN', 76781);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Risperidone', 'tablet', 'N05AX08', false, 0, '02282151', 'FreeDiams::CA_HCDPD::DIN', 76782);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Risperidone', 'tablet', 'N05AX08', false, 0, '02282178', 'FreeDiams::CA_HCDPD::DIN', 76783);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baraclude', 'tablet', 'J05AF10', false, 0, '02282224', 'FreeDiams::CA_HCDPD::DIN', 76788);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Risperidone', 'tablet', 'N05AX08', false, 0, '02282240', 'FreeDiams::CA_HCDPD::DIN', 76790);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Risperidone', 'tablet', 'N05AX08', false, 0, '02282259', 'FreeDiams::CA_HCDPD::DIN', 76791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Risperidone', 'tablet', 'N05AX08', false, 0, '02282267', 'FreeDiams::CA_HCDPD::DIN', 76792);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Risperidone', 'tablet', 'N05AX08', false, 0, '02282275', 'FreeDiams::CA_HCDPD::DIN', 76793);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Risperidone', 'tablet', 'N05AX08', false, 0, '02282283', 'FreeDiams::CA_HCDPD::DIN', 76794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Risperidone', 'tablet', 'N05AX08', false, 0, '02282291', 'FreeDiams::CA_HCDPD::DIN', 76795);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fluconazole', 'capsule', 'J02AC01', false, 0, '02282348', 'FreeDiams::CA_HCDPD::DIN', 76799);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Azithromycin', 'powder for suspension', 'J01FA10', false, 0, '02282380', 'FreeDiams::CA_HCDPD::DIN', 76803);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Azithromycin', 'powder for suspension', 'J01FA10', false, 0, '02282410', 'FreeDiams::CA_HCDPD::DIN', 76805);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zopiclone', 'tablet', 'N05CF01', false, 0, '02282445', 'FreeDiams::CA_HCDPD::DIN', 76809);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tb Minuteman (Ready To Use Towelettes)', 'wipe', 'V07AV', false, 0, '02282461', 'FreeDiams::CA_HCDPD::DIN', 76811);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Optim 33 Tb', 'liquid', 'V07AV', false, 0, '02282488', 'FreeDiams::CA_HCDPD::DIN', 76812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Idamycin Pfs', 'solution', 'L01DB06', false, 0, '02282496', 'FreeDiams::CA_HCDPD::DIN', 76813);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vivaglobin', 'solution', 'J06BA01', false, 0, '02282518', 'FreeDiams::CA_HCDPD::DIN', 76814);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ino Désinfectant Et Assainisseur/Ino Disinfectant And Sanitizer', 'solution', 'V07AV', false, 0, '02282550', 'FreeDiams::CA_HCDPD::DIN', 76819);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ino Eko Neutral Disinfectant', 'solution', 'V07AV', false, 0, '02282569', 'FreeDiams::CA_HCDPD::DIN', 76820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Risperidone', 'tablet', 'N05AX08', false, 0, '02282585', 'FreeDiams::CA_HCDPD::DIN', 76822);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Risperidone', 'tablet', 'N05AX08', false, 0, '02282593', 'FreeDiams::CA_HCDPD::DIN', 76823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Risperidone', 'tablet', 'N05AX08', false, 0, '02282607', 'FreeDiams::CA_HCDPD::DIN', 76824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Risperidone', 'tablet', 'N05AX08', false, 0, '02282615', 'FreeDiams::CA_HCDPD::DIN', 76825);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Risperidone', 'tablet', 'N05AX08', false, 0, '02282623', 'FreeDiams::CA_HCDPD::DIN', 76826);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Risperidone', 'tablet', 'N05AX08', false, 0, '02282631', 'FreeDiams::CA_HCDPD::DIN', 76827);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Risperidone', 'tablet', 'N05AX08', false, 0, '02282690', 'FreeDiams::CA_HCDPD::DIN', 76833);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Alendronate', 'tablet', 'M05BA04', false, 0, '02282763', 'FreeDiams::CA_HCDPD::DIN', 76840);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Alendronate', 'tablet', 'M05BA04', false, 0, '02282771', 'FreeDiams::CA_HCDPD::DIN', 76841);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paroxetine', 'tablet', 'N06AB05', false, 0, '02282844', 'FreeDiams::CA_HCDPD::DIN', 76846);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paroxetine', 'tablet', 'N06AB05', false, 0, '02282852', 'FreeDiams::CA_HCDPD::DIN', 76847);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paroxetine', 'tablet', 'N06AB05', false, 0, '02282860', 'FreeDiams::CA_HCDPD::DIN', 76848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acneban', 'gel', 'D10AE01', false, 0, '02282895', 'FreeDiams::CA_HCDPD::DIN', 76851);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Surface Disinfectant And Air Deodorizing Spray', 'aerosol', 'V07AV', false, 0, '02282917', 'FreeDiams::CA_HCDPD::DIN', 76854);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Fentanyl', 'patch', 'N02AB03', false, 0, '02282941', 'FreeDiams::CA_HCDPD::DIN', 76857);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Fentanyl', 'patch', 'N02AB03', false, 0, '02282968', 'FreeDiams::CA_HCDPD::DIN', 76858);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Fentanyl', 'patch', 'N02AB03', false, 0, '02282976', 'FreeDiams::CA_HCDPD::DIN', 76859);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Fentanyl', 'patch', 'N02AB03', false, 0, '02282984', 'FreeDiams::CA_HCDPD::DIN', 76860);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf/Fps 50', 'lotion', 'D02BA30', false, 0, '02283018', 'FreeDiams::CA_HCDPD::DIN', 76863);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Skin Activator Day Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02283069', 'FreeDiams::CA_HCDPD::DIN', 76869);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Menopur', 'powder for solution', 'G03GA02', false, 0, '02283093', 'FreeDiams::CA_HCDPD::DIN', 76872);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Whisper', 'liquid', 'V07AV', false, 0, '02283107', 'FreeDiams::CA_HCDPD::DIN', 76873);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Altace Hct', 'tablet', 'C09BA05', false, 0, '02283131', 'FreeDiams::CA_HCDPD::DIN', 76876);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Altace Hct', 'tablet', 'C09BA05', false, 0, '02283158', 'FreeDiams::CA_HCDPD::DIN', 76877);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Altace Hct', 'tablet', 'C09BA05', false, 0, '02283166', 'FreeDiams::CA_HCDPD::DIN', 76878);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Altace Hct', 'tablet', 'C09BA05', false, 0, '02283174', 'FreeDiams::CA_HCDPD::DIN', 76879);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Altace Hct', 'tablet', 'C09BA05', false, 0, '02283182', 'FreeDiams::CA_HCDPD::DIN', 76880);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gardasil', 'suspension', 'J07BM01', false, 0, '02283190', 'FreeDiams::CA_HCDPD::DIN', 76882);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Docusate Sodium Syrup Usp', 'syrup', 'A06AA02', false, 0, '02283220', 'FreeDiams::CA_HCDPD::DIN', 76885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Docusate Sodium Syrup Usp', 'syrup', 'A06AA02', false, 0, '02283239', 'FreeDiams::CA_HCDPD::DIN', 76886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Docusate Calcium Capsule Usp', 'capsule', 'A06AA02', false, 0, '02283255', 'FreeDiams::CA_HCDPD::DIN', 76888);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Dry Oil Mist Sunscreen Continuous Spray Spf 10', 'spray', 'D02BA30', false, 0, '02283271', 'FreeDiams::CA_HCDPD::DIN', 76890);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Kids Continuous Spray Sunscreen Spf 50', 'spray', 'D02BA30', false, 0, '02283298', 'FreeDiams::CA_HCDPD::DIN', 76891);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Sport Continuous Spray Sunscreen Spf 15', 'spray', 'D02BA30', false, 0, '02283301', 'FreeDiams::CA_HCDPD::DIN', 76892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Continuous Spray Sunscreen Spf 15', 'lotion', 'D02BA30', false, 0, '02283336', 'FreeDiams::CA_HCDPD::DIN', 76894);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accel Tb Wipes', 'wipe', 'V07AV', false, 0, '02283352', 'FreeDiams::CA_HCDPD::DIN', 76896);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisturizing Skin Activator Lip Refiner Spf 15', 'cream', 'D02BA30', false, 0, '02283360', 'FreeDiams::CA_HCDPD::DIN', 76897);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bienfait Multi-Vital     (Spf 30)', 'cream', 'D02BA30', false, 0, '02283379', 'FreeDiams::CA_HCDPD::DIN', 76898);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Somatuline Autogel', 'solution (extended release)', 'H01CB03', false, 0, '02283395', 'FreeDiams::CA_HCDPD::DIN', 76900);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Somatuline Autogel', 'solution (extended release)', 'H01CB03', false, 0, '02283409', 'FreeDiams::CA_HCDPD::DIN', 76901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Somatuline Autogel', 'solution (extended release)', 'H01CB03', false, 0, '02283417', 'FreeDiams::CA_HCDPD::DIN', 76902);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibiotic Ointment', 'ointment', 'D06AX30', false, 0, '02283425', 'FreeDiams::CA_HCDPD::DIN', 76903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Acetaminophen 8 Hour', 'tablet (extended-release)', 'N02BE01', false, 0, '02283433', 'FreeDiams::CA_HCDPD::DIN', 76904);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Derm Fps 60 Spf', 'cream', 'D02BA30', false, 0, '02283506', 'FreeDiams::CA_HCDPD::DIN', 76910);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxivir Tb', 'liquid', 'V07AV', false, 0, '02283522', 'FreeDiams::CA_HCDPD::DIN', 76912);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxivir Tb Wipes', 'wipe', 'V07AV', false, 0, '02283530', 'FreeDiams::CA_HCDPD::DIN', 76913);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teint Innocence - Teint Fluide Frais Naturel Et Lumineux', 'lotion', 'D02BA02', false, 0, '02283549', 'FreeDiams::CA_HCDPD::DIN', 76914);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teint Innocence - Teint Compact Creme Universel', 'cream', 'D02BA02', false, 0, '02283557', 'FreeDiams::CA_HCDPD::DIN', 76915);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Risperidone', 'tablet', 'N05AX08', false, 0, '02283565', 'FreeDiams::CA_HCDPD::DIN', 76916);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Risperidone', 'tablet', 'N05AX08', false, 0, '02283573', 'FreeDiams::CA_HCDPD::DIN', 76917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Risperidone', 'tablet', 'N05AX08', false, 0, '02283581', 'FreeDiams::CA_HCDPD::DIN', 76918);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Risperidone', 'tablet', 'N05AX08', false, 0, '02283603', 'FreeDiams::CA_HCDPD::DIN', 76919);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Risperidone', 'tablet', 'N05AX08', false, 0, '02283611', 'FreeDiams::CA_HCDPD::DIN', 76920);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Risperidone', 'tablet', 'N05AX08', false, 0, '02283638', 'FreeDiams::CA_HCDPD::DIN', 76921);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Asa', 'tablet', 'N02BA01', false, 0, '02283662', 'FreeDiams::CA_HCDPD::DIN', 76924);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Asa', 'tablet', 'N02BA01', false, 0, '02283670', 'FreeDiams::CA_HCDPD::DIN', 76925);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Asa Ec', 'tablet (delayed-release)', 'N02BA01', false, 0, '02283689', 'FreeDiams::CA_HCDPD::DIN', 76928);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Praxis Asa Ec 81 Mg Daily Low Dose', 'tablet (delayed-release)', 'N02BA01', false, 0, '02283700', 'FreeDiams::CA_HCDPD::DIN', 76929);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Diluent For Allergenic Extract - Albumin Saline With Phenol', 'solution', 'V07AB', false, 0, '02283735', 'FreeDiams::CA_HCDPD::DIN', 76932);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aveeno Active Naturals Positively Radiant Daily Moisturizer', 'lotion', 'D02BA30', false, 0, '02283751', 'FreeDiams::CA_HCDPD::DIN', 76934);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Cilazapril', 'tablet', 'C09AA08', false, 0, '02283778', 'FreeDiams::CA_HCDPD::DIN', 76935);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Cilazapril', 'tablet', 'C09AA08', false, 0, '02283786', 'FreeDiams::CA_HCDPD::DIN', 76936);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Cilazapril', 'tablet', 'C09AA08', false, 0, '02283794', 'FreeDiams::CA_HCDPD::DIN', 76937);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aveeno Baby Sunscreen Lotion Spf 55', 'lotion', 'D02BA30', false, 0, '02283808', 'FreeDiams::CA_HCDPD::DIN', 76938);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibacterial Clean & Smooth', 'solution', 'D08AE04', false, 0, '02283816', 'FreeDiams::CA_HCDPD::DIN', 76939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aveeno Active Naturals Sunscreen Lotion Spf 55', 'lotion', 'D02BA30', false, 0, '02283832', 'FreeDiams::CA_HCDPD::DIN', 76941);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fludarabine Phosphate For Injection', 'solution', 'L01BB05', false, 0, '02283859', 'FreeDiams::CA_HCDPD::DIN', 76943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetylsalicylic Acid Delayed-Release Tablet Usp', 'tablet (delayed-release)', 'N02BA01', false, 0, '02283905', 'FreeDiams::CA_HCDPD::DIN', 76948);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Dayquil Cough', 'liquid', 'R05DA09', false, 0, '02283913', 'FreeDiams::CA_HCDPD::DIN', 76949);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Leflunomide', 'tablet', 'L04AA13', false, 0, '02283964', 'FreeDiams::CA_HCDPD::DIN', 76953);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Leflunomide', 'tablet', 'L04AA13', false, 0, '02283972', 'FreeDiams::CA_HCDPD::DIN', 76954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Alendronate-Fc', 'tablet', 'M05BA04', false, 0, '02284006', 'FreeDiams::CA_HCDPD::DIN', 76957);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Desmopressin', 'tablet', 'H01BA02', false, 0, '02284030', 'FreeDiams::CA_HCDPD::DIN', 76960);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Desmopressin', 'tablet', 'H01BA02', false, 0, '02284049', 'FreeDiams::CA_HCDPD::DIN', 76961);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Amlodipine', 'tablet', 'C08CA01', false, 0, '02284065', 'FreeDiams::CA_HCDPD::DIN', 76963);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Amlodipine', 'tablet', 'C08CA01', false, 0, '02284073', 'FreeDiams::CA_HCDPD::DIN', 76964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advate', 'powder for solution', 'B02BD02', false, 0, '02284138', 'FreeDiams::CA_HCDPD::DIN', 76968);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advate', 'powder for solution', 'B02BD02', false, 0, '02284146', 'FreeDiams::CA_HCDPD::DIN', 76969);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advate', 'powder for solution', 'B02BD02', false, 0, '02284154', 'FreeDiams::CA_HCDPD::DIN', 76970);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advate', 'powder for solution', 'B02BD02', false, 0, '02284162', 'FreeDiams::CA_HCDPD::DIN', 76971);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diorskin Sculpt Fond De Teint Raffermissant Lissant', 'emulsion', 'D02BA02', false, 0, '02284197', 'FreeDiams::CA_HCDPD::DIN', 76974);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Scrubbing Bubbles Bathroom Cleaner', 'solution', 'V07AV', false, 0, '02284219', 'FreeDiams::CA_HCDPD::DIN', 76976);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nexavar', 'tablet', 'L01XE05', false, 0, '02284227', 'FreeDiams::CA_HCDPD::DIN', 76977);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Quetiapine', 'tablet', 'N05AH04', false, 0, '02284235', 'FreeDiams::CA_HCDPD::DIN', 76978);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Quetiapine', 'tablet', 'N05AH04', false, 0, '02284243', 'FreeDiams::CA_HCDPD::DIN', 76979);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Quetiapine', 'tablet', 'N05AH04', false, 0, '02284251', 'FreeDiams::CA_HCDPD::DIN', 76980);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Quetiapine', 'tablet', 'N05AH04', false, 0, '02284278', 'FreeDiams::CA_HCDPD::DIN', 76981);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Quetiapine', 'tablet', 'N05AH04', false, 0, '02284286', 'FreeDiams::CA_HCDPD::DIN', 76982);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Oxcarbazepine', 'tablet', 'N03AF02', false, 0, '02284294', 'FreeDiams::CA_HCDPD::DIN', 76987);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Oxcarbazepine', 'tablet', 'N03AF02', false, 0, '02284308', 'FreeDiams::CA_HCDPD::DIN', 76988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Oxcarbazepine', 'tablet', 'N03AF02', false, 0, '02284316', 'FreeDiams::CA_HCDPD::DIN', 76989);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flexitol Heel Balm', 'cream', 'D02AE51', false, 0, '02284324', 'FreeDiams::CA_HCDPD::DIN', 76990);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Amlodipine', 'tablet', 'C08CA01', false, 0, '02284383', 'FreeDiams::CA_HCDPD::DIN', 76997);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Amlodipine', 'tablet', 'C08CA01', false, 0, '02284391', 'FreeDiams::CA_HCDPD::DIN', 76998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rotateq', 'solution', 'J07BH02', false, 0, '02284413', 'FreeDiams::CA_HCDPD::DIN', 76999);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Pravastatin', 'tablet', 'C10AA03', false, 0, '02284421', 'FreeDiams::CA_HCDPD::DIN', 77000);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Pravastatin', 'tablet', 'C10AA03', false, 0, '02284448', 'FreeDiams::CA_HCDPD::DIN', 77001);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Pravastatin', 'tablet', 'C10AA03', false, 0, '02284456', 'FreeDiams::CA_HCDPD::DIN', 77002);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clean Quick Broad Range Quaternary', 'liquid', 'V07AV', false, 0, '02284480', 'FreeDiams::CA_HCDPD::DIN', 77005);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Disinfectant-Aid', 'spray', 'V07AV', false, 0, '02284499', 'FreeDiams::CA_HCDPD::DIN', 77006);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Microban Disinfectant Cleaner Concentrate', 'liquid', 'V07AV', false, 0, '02284502', 'FreeDiams::CA_HCDPD::DIN', 77007);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Microban Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02284510', 'FreeDiams::CA_HCDPD::DIN', 77008);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Asa Ec', 'tablet (delayed-release)', 'N02BA01', false, 0, '02284529', 'FreeDiams::CA_HCDPD::DIN', 77009);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Asa Ec', 'tablet (delayed-release)', 'N02BA01', false, 0, '02284537', 'FreeDiams::CA_HCDPD::DIN', 77010);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Glimepiride', 'tablet', 'A10BB12', false, 0, '02284545', 'FreeDiams::CA_HCDPD::DIN', 77011);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Glimepiride', 'tablet', 'A10BB12', false, 0, '02284553', 'FreeDiams::CA_HCDPD::DIN', 77012);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prescriptives Virtually Fresh Skin Refining Makeup Uva/Uvb Spf 15', 'liquid', 'D02BA30', false, 0, '02284618', 'FreeDiams::CA_HCDPD::DIN', 77016);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Azilect', 'tablet', 'N04BD02', false, 0, '02284642', 'FreeDiams::CA_HCDPD::DIN', 77019);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Azilect', 'tablet', 'N04BD02', false, 0, '02284650', 'FreeDiams::CA_HCDPD::DIN', 77020);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Levofloxacin', 'tablet', 'J01MA12', false, 0, '02284677', 'FreeDiams::CA_HCDPD::DIN', 77023);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Levofloxacin', 'tablet', 'J01MA12', false, 0, '02284685', 'FreeDiams::CA_HCDPD::DIN', 77024);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Levofloxacin', 'tablet', 'J01MA12', false, 0, '02284707', 'FreeDiams::CA_HCDPD::DIN', 77026);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Levofloxacin', 'tablet', 'J01MA12', false, 0, '02284715', 'FreeDiams::CA_HCDPD::DIN', 77027);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simvastatin', 'tablet', 'C10AA01', false, 0, '02284723', 'FreeDiams::CA_HCDPD::DIN', 77028);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simvastatin', 'tablet', 'C10AA01', false, 0, '02284731', 'FreeDiams::CA_HCDPD::DIN', 77029);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simvastatin', 'tablet', 'C10AA01', false, 0, '02284758', 'FreeDiams::CA_HCDPD::DIN', 77030);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simvastatin', 'tablet', 'C10AA01', false, 0, '02284766', 'FreeDiams::CA_HCDPD::DIN', 77031);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simvastatin', 'tablet', 'C10AA01', false, 0, '02284774', 'FreeDiams::CA_HCDPD::DIN', 77032);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metformin', 'tablet', 'A10BA02', false, 0, '02284782', 'FreeDiams::CA_HCDPD::DIN', 77033);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metformin', 'tablet', 'A10BA02', false, 0, '02284790', 'FreeDiams::CA_HCDPD::DIN', 77034);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citalopram', 'tablet', 'N06AB04', false, 0, '02284847', 'FreeDiams::CA_HCDPD::DIN', 77039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citalopram', 'tablet', 'N06AB04', false, 0, '02284855', 'FreeDiams::CA_HCDPD::DIN', 77040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Myozyme', 'powder for solution', 'A16AB07', false, 0, '02284863', 'FreeDiams::CA_HCDPD::DIN', 77041);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aloe Soothing Moisture Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02284952', 'FreeDiams::CA_HCDPD::DIN', 77048);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cilazapril/Hctz', 'tablet', 'C09BA08', false, 0, '02284987', 'FreeDiams::CA_HCDPD::DIN', 77051);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ddavp Melt', 'tablet (orally disintegrating)', 'H01BA02', false, 0, '02284995', 'FreeDiams::CA_HCDPD::DIN', 77052);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ddavp Melt', 'tablet (orally disintegrating)', 'H01BA02', false, 0, '02285002', 'FreeDiams::CA_HCDPD::DIN', 77053);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ddavp Melt', 'tablet (orally disintegrating)', 'H01BA02', false, 0, '02285010', 'FreeDiams::CA_HCDPD::DIN', 77054);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('No7 Lifting & Firming Day Cream Spf 8', 'cream', 'D02BA30', false, 0, '02285053', 'FreeDiams::CA_HCDPD::DIN', 77058);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lisinopril (Type P)', 'tablet', 'C09AA03', false, 0, '02285061', 'FreeDiams::CA_HCDPD::DIN', 77059);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lisinopril (Type P)', 'tablet', 'C09AA03', false, 0, '02285088', 'FreeDiams::CA_HCDPD::DIN', 77060);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lisinopril (Type P)', 'tablet', 'C09AA03', false, 0, '02285096', 'FreeDiams::CA_HCDPD::DIN', 77061);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lisinopril (Type Z)', 'tablet', 'C09AA03', false, 0, '02285118', 'FreeDiams::CA_HCDPD::DIN', 77062);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lisinopril (Type Z)', 'tablet', 'C09AA03', false, 0, '02285126', 'FreeDiams::CA_HCDPD::DIN', 77063);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lisinopril (Type Z)', 'tablet', 'C09AA03', false, 0, '02285134', 'FreeDiams::CA_HCDPD::DIN', 77064);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun Defense Spf 30', 'cream', 'D02BA30', false, 0, '02285142', 'FreeDiams::CA_HCDPD::DIN', 77065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tobramycin For Injection U.S.P.', 'powder for solution', 'J01GB01', false, 0, '02285150', 'FreeDiams::CA_HCDPD::DIN', 77066);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Metoprolol Sr', 'tablet (extended-release)', 'C07AB02', false, 0, '02285169', 'FreeDiams::CA_HCDPD::DIN', 77067);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Metoprolol Sr', 'tablet (extended-release)', 'C07AB02', false, 0, '02285177', 'FreeDiams::CA_HCDPD::DIN', 77068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Cilazapril', 'tablet', 'C09AA08', false, 0, '02285215', 'FreeDiams::CA_HCDPD::DIN', 77072);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Cilazapril', 'tablet', 'C09AA08', false, 0, '02285223', 'FreeDiams::CA_HCDPD::DIN', 77073);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('G-12', 'liquid', 'V07AV', false, 0, '02285231', 'FreeDiams::CA_HCDPD::DIN', 77075);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Day Renewal Moisturizing Complex With Spf 20', 'cream', 'D02BA30', false, 0, '02285258', 'FreeDiams::CA_HCDPD::DIN', 77076);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alprostadil Injection Usp', 'solution', 'C01EA01', false, 0, '02285282', 'FreeDiams::CA_HCDPD::DIN', 77079);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('2005 Pine Disinfectant', 'solution', 'V07AV', false, 0, '02285290', 'FreeDiams::CA_HCDPD::DIN', 77080);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('No7 Soft And Sheer Tinted Moisturizer Spf 15', 'lotion', 'D02BA30', false, 0, '02285312', 'FreeDiams::CA_HCDPD::DIN', 77082);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mary Kay Lip Protector Sunscreen Spf 15', 'stick', 'D02BA30', false, 0, '02285320', 'FreeDiams::CA_HCDPD::DIN', 77083);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Optim 33 Tb Wipes', 'wipe', 'V07AV', false, 0, '02285347', 'FreeDiams::CA_HCDPD::DIN', 77085);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Asa Ec', 'tablet (enteric-coated)', 'N02BA01', false, 0, '02285371', 'FreeDiams::CA_HCDPD::DIN', 77088);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Modafinil', 'tablet', 'N06BA07', false, 0, '02285398', 'FreeDiams::CA_HCDPD::DIN', 77089);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tygacil', 'powder for solution', 'J01AA12', false, 0, '02285401', 'FreeDiams::CA_HCDPD::DIN', 77090);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Pantoprazole', 'tablet (delayed-release)', 'A02BC02', false, 0, '02285479', 'FreeDiams::CA_HCDPD::DIN', 77096);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Pantoprazole', 'tablet (delayed-release)', 'A02BC02', false, 0, '02285487', 'FreeDiams::CA_HCDPD::DIN', 77097);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kaletra', 'tablet', 'J05AE06', false, 0, '02285533', 'FreeDiams::CA_HCDPD::DIN', 77104);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Colgate Total - Advanced Health', 'toothpaste', 'A01AA51', false, 0, '02285568', 'FreeDiams::CA_HCDPD::DIN', 77106);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norlevo', 'tablet', 'G03AD01', false, 0, '02285576', 'FreeDiams::CA_HCDPD::DIN', 77107);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alvesco', 'metered-dose (aerosol)', 'R03BA08', false, 0, '02285606', 'FreeDiams::CA_HCDPD::DIN', 77111);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alvesco', 'metered-dose (aerosol)', 'R03BA08', false, 0, '02285614', 'FreeDiams::CA_HCDPD::DIN', 77112);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Citalo', 'tablet', 'N06AB04', false, 0, '02285622', 'FreeDiams::CA_HCDPD::DIN', 77113);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Citalo', 'tablet', 'N06AB04', false, 0, '02285630', 'FreeDiams::CA_HCDPD::DIN', 77114);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Levofloxacin', 'tablet', 'J01MA12', false, 0, '02285649', 'FreeDiams::CA_HCDPD::DIN', 77115);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Bupropion Sr', 'tablet (extended-release)', 'N06AX12', false, 0, '02285657', 'FreeDiams::CA_HCDPD::DIN', 77116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Bupropion Sr', 'tablet (extended-release)', 'N06AX12', false, 0, '02285665', 'FreeDiams::CA_HCDPD::DIN', 77117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euro Folic 5mg', 'tablet', 'B03BB01', false, 0, '02285673', 'FreeDiams::CA_HCDPD::DIN', 77118);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Denorex Extra Strength Medicated Shampoo', 'shampoo', 'D05AA', false, 0, '02285703', 'FreeDiams::CA_HCDPD::DIN', 77120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Denorex Extra Strength Medicated Shampoo With Conditioners', 'shampoo', 'D05AA', false, 0, '02285711', 'FreeDiams::CA_HCDPD::DIN', 77121);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ombrelle Stick Spf 60', 'stick', 'D02BA30', false, 0, '02285738', 'FreeDiams::CA_HCDPD::DIN', 77122);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Protection Sunscreen Stick Spf 60', 'stick', 'D02BA30', false, 0, '02285746', 'FreeDiams::CA_HCDPD::DIN', 77123);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clippercide', 'spray', 'V07AV', false, 0, '02285754', 'FreeDiams::CA_HCDPD::DIN', 77124);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carpe Diem Tb', 'liquid', 'V07AV', false, 0, '02285762', 'FreeDiams::CA_HCDPD::DIN', 77125);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('W-400', 'liquid', 'V07AV', false, 0, '02285770', 'FreeDiams::CA_HCDPD::DIN', 77126);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carpe Diem Tb Wipes', 'wipe', 'V07AV', false, 0, '02285789', 'FreeDiams::CA_HCDPD::DIN', 77127);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Acetaminophen', 'tablet', 'N02BE01', false, 0, '02285797', 'FreeDiams::CA_HCDPD::DIN', 77128);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Gabapentin', 'capsule', 'N03AX12', false, 0, '02285819', 'FreeDiams::CA_HCDPD::DIN', 77130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Gabapentin', 'capsule', 'N03AX12', false, 0, '02285827', 'FreeDiams::CA_HCDPD::DIN', 77131);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Gabapentin', 'capsule', 'N03AX12', false, 0, '02285835', 'FreeDiams::CA_HCDPD::DIN', 77132);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Gabapentin', 'tablet', 'N03AX12', false, 0, '02285843', 'FreeDiams::CA_HCDPD::DIN', 77133);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Gabapentin', 'tablet', 'N03AX12', false, 0, '02285851', 'FreeDiams::CA_HCDPD::DIN', 77134);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Levetiracetam', 'tablet', 'N03AX14', false, 0, '02285924', 'FreeDiams::CA_HCDPD::DIN', 77141);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Levetiracetam', 'tablet', 'N03AX14', false, 0, '02285932', 'FreeDiams::CA_HCDPD::DIN', 77142);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Levetiracetam', 'tablet', 'N03AX14', false, 0, '02285940', 'FreeDiams::CA_HCDPD::DIN', 77143);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Acyclovir', 'tablet', 'J05AB01', false, 0, '02285959', 'FreeDiams::CA_HCDPD::DIN', 77144);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Acyclovir', 'tablet', 'J05AB01', false, 0, '02285967', 'FreeDiams::CA_HCDPD::DIN', 77145);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Acyclovir', 'tablet', 'J05AB01', false, 0, '02285975', 'FreeDiams::CA_HCDPD::DIN', 77146);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluoxetine', 'capsule', 'N06AB03', false, 0, '02286076', 'FreeDiams::CA_HCDPD::DIN', 77155);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fenofibrate Micro', 'capsule', 'C10AB05', false, 0, '02286092', 'FreeDiams::CA_HCDPD::DIN', 77156);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ranitidine', 'tablet', 'A02BA02', false, 0, '02286106', 'FreeDiams::CA_HCDPD::DIN', 77158);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ranitidine', 'tablet', 'A02BA02', false, 0, '02286114', 'FreeDiams::CA_HCDPD::DIN', 77159);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acebutolol', 'tablet', 'C07AB04', false, 0, '02286246', 'FreeDiams::CA_HCDPD::DIN', 77170);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acebutolol', 'tablet', 'C07AB04', false, 0, '02286254', 'FreeDiams::CA_HCDPD::DIN', 77171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acebutolol', 'tablet', 'C07AB04', false, 0, '02286262', 'FreeDiams::CA_HCDPD::DIN', 77172);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fight Bac Rtu', 'liquid', 'V07AV', false, 0, '02286297', 'FreeDiams::CA_HCDPD::DIN', 77175);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mitoxantrone Injection, Usp', 'solution', 'L01DB07', false, 0, '02286300', 'FreeDiams::CA_HCDPD::DIN', 77176);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Alendronate', 'tablet', 'M05BA04', false, 0, '02286335', 'FreeDiams::CA_HCDPD::DIN', 77179);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('License', 'liquid', 'V07AV', false, 0, '02286343', 'FreeDiams::CA_HCDPD::DIN', 77180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Genteal Geldrops', 'solution', 'S01XA20', false, 0, '02286351', 'FreeDiams::CA_HCDPD::DIN', 77181);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tysabri', 'solution', 'L04AA23', false, 0, '02286386', 'FreeDiams::CA_HCDPD::DIN', 77184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Total Cold And Flu', 'tablet', 'N02BE51', false, 0, '02286394', 'FreeDiams::CA_HCDPD::DIN', 77185);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shiseido Sun Protection Eye Cream Spf 32', 'cream', 'D02BA30', false, 0, '02286408', 'FreeDiams::CA_HCDPD::DIN', 77186);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zytram Xl', 'tablet (extended-release)', 'N02AX02', false, 0, '02286424', 'FreeDiams::CA_HCDPD::DIN', 77188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zytram Xl', 'tablet (extended-release)', 'N02AX02', false, 0, '02286432', 'FreeDiams::CA_HCDPD::DIN', 77189);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zytram Xl', 'tablet (extended-release)', 'N02AX02', false, 0, '02286440', 'FreeDiams::CA_HCDPD::DIN', 77190);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zytram Xl', 'tablet (extended-release)', 'N02AX02', false, 0, '02286459', 'FreeDiams::CA_HCDPD::DIN', 77191);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Resert Hld High Level Disinfectant - Chemosterilant', 'liquid', 'V07AV', false, 0, '02286467', 'FreeDiams::CA_HCDPD::DIN', 77192);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sumatriptan', 'tablet', 'N02CC01', false, 0, '02286513', 'FreeDiams::CA_HCDPD::DIN', 77197);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sumatriptan', 'tablet', 'N02CC01', false, 0, '02286521', 'FreeDiams::CA_HCDPD::DIN', 77198);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sumatriptan', 'tablet', 'N02CC01', false, 0, '02286548', 'FreeDiams::CA_HCDPD::DIN', 77199);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acyclovir', 'tablet', 'J05AB01', false, 0, '02286556', 'FreeDiams::CA_HCDPD::DIN', 77200);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acyclovir', 'tablet', 'J05AB01', false, 0, '02286564', 'FreeDiams::CA_HCDPD::DIN', 77201);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acyclovir', 'tablet', 'J05AB01', false, 0, '02286572', 'FreeDiams::CA_HCDPD::DIN', 77202);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Mirtazapine', 'tablet', 'N06AX11', false, 0, '02286610', 'FreeDiams::CA_HCDPD::DIN', 77206);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Mirtazapine', 'tablet', 'N06AX11', false, 0, '02286629', 'FreeDiams::CA_HCDPD::DIN', 77207);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Mirtazapine', 'tablet', 'N06AX11', false, 0, '02286637', 'FreeDiams::CA_HCDPD::DIN', 77208);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arthritis Pain Extended Relief', 'tablet (extended-release)', 'N02BE01', false, 0, '02286653', 'FreeDiams::CA_HCDPD::DIN', 77210);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hfs Antimicrobial Foam Hand Soap With Triclosan', 'liquid', 'D08AE04', false, 0, '02286688', 'FreeDiams::CA_HCDPD::DIN', 77213);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Signatry Antibacterial Foam Cleanser', 'liquid', 'D08AE04', false, 0, '02286726', 'FreeDiams::CA_HCDPD::DIN', 77216);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Wilate', 'powder for solution', 'B02BD06', false, 0, '02286750', 'FreeDiams::CA_HCDPD::DIN', 77219);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Wilate', 'powder for solution', 'B02BD06', false, 0, '02286769', 'FreeDiams::CA_HCDPD::DIN', 77222);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Equate Moisturizing Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02286777', 'FreeDiams::CA_HCDPD::DIN', 77223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Microban Medical', 'gel', 'D08AC52', false, 0, '02286793', 'FreeDiams::CA_HCDPD::DIN', 77225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Sumatriptan Df', 'tablet', 'N02CC01', false, 0, '02286815', 'FreeDiams::CA_HCDPD::DIN', 77227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Sumatriptan Df', 'tablet', 'N02CC01', false, 0, '02286823', 'FreeDiams::CA_HCDPD::DIN', 77228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Sumatriptan Df', 'tablet', 'N02CC01', false, 0, '02286831', 'FreeDiams::CA_HCDPD::DIN', 77229);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clear Eyes For Dry Eyes', 'solution', 'S01XA20', false, 0, '02286858', 'FreeDiams::CA_HCDPD::DIN', 77230);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Active 1010 Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02286904', 'FreeDiams::CA_HCDPD::DIN', 77235);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baclofen', 'tablet', 'M03BX01', false, 0, '02287021', 'FreeDiams::CA_HCDPD::DIN', 77246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baclofen', 'tablet', 'M03BX01', false, 0, '02287048', 'FreeDiams::CA_HCDPD::DIN', 77247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyclobenzaprine', 'tablet', 'M03BX08', false, 0, '02287064', 'FreeDiams::CA_HCDPD::DIN', 77249);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gliclazide', 'tablet', 'A10BB09', false, 0, '02287072', 'FreeDiams::CA_HCDPD::DIN', 77250);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bienfait Multi-Vital Teinte', 'lotion', 'D02BA30', false, 0, '02287110', 'FreeDiams::CA_HCDPD::DIN', 77254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fosrenol', 'tablet (chewable)', 'V03AE03', false, 0, '02287145', 'FreeDiams::CA_HCDPD::DIN', 77258);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fosrenol', 'tablet (chewable)', 'V03AE03', false, 0, '02287153', 'FreeDiams::CA_HCDPD::DIN', 77259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fosrenol', 'tablet (chewable)', 'V03AE03', false, 0, '02287161', 'FreeDiams::CA_HCDPD::DIN', 77260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fosrenol', 'tablet (chewable)', 'V03AE03', false, 0, '02287188', 'FreeDiams::CA_HCDPD::DIN', 77261);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minocycline', 'capsule', 'J01AA08', false, 0, '02287226', 'FreeDiams::CA_HCDPD::DIN', 77264);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Minocycline', 'capsule', 'J01AA08', false, 0, '02287234', 'FreeDiams::CA_HCDPD::DIN', 77265);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermoplast Poison Ivy Treatment', 'suspension', 'D04AB07', false, 0, '02287358', 'FreeDiams::CA_HCDPD::DIN', 77276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Excelon Antibacterial Foam Cleanser', 'liquid', 'D08AE04', false, 0, '02287366', 'FreeDiams::CA_HCDPD::DIN', 77277);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carpe Diem', 'liquid', 'V07AV', false, 0, '02287374', 'FreeDiams::CA_HCDPD::DIN', 77278);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxivir Ahp 5', 'liquid', 'V07AV', false, 0, '02287382', 'FreeDiams::CA_HCDPD::DIN', 77279);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Sertraline', 'capsule', 'N06AB06', false, 0, '02287390', 'FreeDiams::CA_HCDPD::DIN', 77280);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Sertraline', 'capsule', 'N06AB06', false, 0, '02287404', 'FreeDiams::CA_HCDPD::DIN', 77281);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Sertraline', 'capsule', 'N06AB06', false, 0, '02287412', 'FreeDiams::CA_HCDPD::DIN', 77282);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exjade', 'tablet for suspension', 'V03AC03', false, 0, '02287420', 'FreeDiams::CA_HCDPD::DIN', 77283);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exjade', 'tablet for suspension', 'V03AC03', false, 0, '02287439', 'FreeDiams::CA_HCDPD::DIN', 77284);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exjade', 'tablet for suspension', 'V03AC03', false, 0, '02287447', 'FreeDiams::CA_HCDPD::DIN', 77285);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gojo Premium Foam Antibacterial Handwash', 'liquid', 'D08AE05', false, 0, '02287455', 'FreeDiams::CA_HCDPD::DIN', 77286);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Daywear Plus Multi Protection Tinted Moisturizer Spf 15', 'lotion', 'D02BA30', false, 0, '02287463', 'FreeDiams::CA_HCDPD::DIN', 77287);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisture Cream Spf 30', 'cream', 'D02BA30', false, 0, '02287471', 'FreeDiams::CA_HCDPD::DIN', 77288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Warfarin', 'tablet', 'B01AA03', false, 0, '02287498', 'FreeDiams::CA_HCDPD::DIN', 77289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Warfarin', 'tablet', 'B01AA03', false, 0, '02287501', 'FreeDiams::CA_HCDPD::DIN', 77290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Warfarin', 'tablet', 'B01AA03', false, 0, '02287528', 'FreeDiams::CA_HCDPD::DIN', 77291);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mac Mineralize Satinfinish Spf 15 Foundation', 'liquid', 'D02BA02', false, 0, '02287560', 'FreeDiams::CA_HCDPD::DIN', 77295);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caribbean Breeze Spf 30 Kids Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02287609', 'FreeDiams::CA_HCDPD::DIN', 77299);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Menu Désinfectant, Assainisseur, Désodorisant, Fongicide Et Virucide/Menu Disinfectant, Sanitizer, Deodorizer, Fungicide And Virucide', 'liquid', 'V07AV', false, 0, '02287617', 'FreeDiams::CA_HCDPD::DIN', 77300);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone Sodium For Injection', 'powder for solution', 'J01DD04', false, 0, '02287633', 'FreeDiams::CA_HCDPD::DIN', 77304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone Sodium For Injection', 'powder for solution', 'J01DD04', false, 0, '02287668', 'FreeDiams::CA_HCDPD::DIN', 77306);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mag', 'liquid', 'V07AV', false, 0, '02287676', 'FreeDiams::CA_HCDPD::DIN', 77307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ramipril', 'capsule', 'C09AA05', false, 0, '02287692', 'FreeDiams::CA_HCDPD::DIN', 77309);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ramipril', 'capsule', 'C09AA05', false, 0, '02287706', 'FreeDiams::CA_HCDPD::DIN', 77310);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ramipril', 'capsule', 'C09AA05', false, 0, '02287714', 'FreeDiams::CA_HCDPD::DIN', 77311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ramipril', 'capsule', 'C09AA05', false, 0, '02287722', 'FreeDiams::CA_HCDPD::DIN', 77312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Desmopressin', 'tablet', 'H01BA02', false, 0, '02287730', 'FreeDiams::CA_HCDPD::DIN', 77313);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Desmopressin', 'tablet', 'H01BA02', false, 0, '02287749', 'FreeDiams::CA_HCDPD::DIN', 77314);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Topiramate', 'tablet', 'N03AX11', false, 0, '02287765', 'FreeDiams::CA_HCDPD::DIN', 77316);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Topiramate', 'tablet', 'N03AX11', false, 0, '02287773', 'FreeDiams::CA_HCDPD::DIN', 77317);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Topiramate', 'tablet', 'N03AX11', false, 0, '02287781', 'FreeDiams::CA_HCDPD::DIN', 77318);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caribbean Breeze Spf15 Sunscreen Spray Lotion', 'lotion', 'D02BA30', false, 0, '02287838', 'FreeDiams::CA_HCDPD::DIN', 77321);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caribbean Breeze Spf15 Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02287846', 'FreeDiams::CA_HCDPD::DIN', 77322);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caribbean Breeze Spf20 Sunscreen Spray Lotion', 'lotion', 'D02BA30', false, 0, '02287854', 'FreeDiams::CA_HCDPD::DIN', 77323);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caribbean Breeze Spf30 Sunscreen Spray Lotion', 'lotion', 'D02BA30', false, 0, '02287862', 'FreeDiams::CA_HCDPD::DIN', 77324);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caribbean Breeze Spf30 Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02287870', 'FreeDiams::CA_HCDPD::DIN', 77325);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caribbean Breeze Spf45 Sunscreen Spray Lotion', 'lotion', 'D02BA30', false, 0, '02287889', 'FreeDiams::CA_HCDPD::DIN', 77326);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caribbean Breeze Burn Relief', 'gel', 'D04AB01', false, 0, '02287919', 'FreeDiams::CA_HCDPD::DIN', 77330);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Ramipril', 'capsule', 'C09AA05', false, 0, '02287927', 'FreeDiams::CA_HCDPD::DIN', 77332);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Ramipril', 'capsule', 'C09AA05', false, 0, '02287935', 'FreeDiams::CA_HCDPD::DIN', 77334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Ramipril', 'capsule', 'C09AA05', false, 0, '02287943', 'FreeDiams::CA_HCDPD::DIN', 77335);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Ramipril', 'capsule', 'C09AA05', false, 0, '02287951', 'FreeDiams::CA_HCDPD::DIN', 77336);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Ramipril', 'capsule', 'C09AA05', false, 0, '02287978', 'FreeDiams::CA_HCDPD::DIN', 77337);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Ramipril', 'capsule', 'C09AA05', false, 0, '02287986', 'FreeDiams::CA_HCDPD::DIN', 77338);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elizabeth Arden Intervene Radiance Boosting Moisture Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02288001', 'FreeDiams::CA_HCDPD::DIN', 77340);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elizabeth Arden Intervene Radiance Boosting Moisture Cream Spf 15', 'cream', 'D02BA30', false, 0, '02288028', 'FreeDiams::CA_HCDPD::DIN', 77341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Fenofibrate S', 'tablet', 'C10AB05', false, 0, '02288044', 'FreeDiams::CA_HCDPD::DIN', 77343);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Fenofibrate S', 'tablet', 'C10AB05', false, 0, '02288052', 'FreeDiams::CA_HCDPD::DIN', 77344);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Alendronate', 'tablet', 'M05BA04', false, 0, '02288079', 'FreeDiams::CA_HCDPD::DIN', 77346);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Alendronate', 'tablet', 'M05BA04', false, 0, '02288087', 'FreeDiams::CA_HCDPD::DIN', 77347);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Alendronate', 'tablet', 'M05BA04', false, 0, '02288109', 'FreeDiams::CA_HCDPD::DIN', 77349);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ondansetron', 'tablet', 'A04AA01', false, 0, '02288184', 'FreeDiams::CA_HCDPD::DIN', 77362);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ondansetron', 'tablet', 'A04AA01', false, 0, '02288192', 'FreeDiams::CA_HCDPD::DIN', 77363);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('70 Spf/Fps Sunscreen Lotion Écran Solaire', 'lotion', 'D02BA30', false, 0, '02288230', 'FreeDiams::CA_HCDPD::DIN', 77368);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ino Cleaner Degreaser Disinfectant', 'solution', 'V07AV', false, 0, '02288249', 'FreeDiams::CA_HCDPD::DIN', 77369);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germalin Cleaner Degreaser Disinfectant', 'solution', 'V07AV', false, 0, '02288257', 'FreeDiams::CA_HCDPD::DIN', 77370);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Leflunomide', 'tablet', 'L04AA13', false, 0, '02288265', 'FreeDiams::CA_HCDPD::DIN', 77371);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Leflunomide', 'tablet', 'L04AA13', false, 0, '02288273', 'FreeDiams::CA_HCDPD::DIN', 77372);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Energizing Pomegranate Moisturizer Spf 15', 'lotion', 'D02BA30', false, 0, '02288303', 'FreeDiams::CA_HCDPD::DIN', 77374);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Correcting Moisturizer Spf 15', 'lotion', 'D02BA30', false, 0, '02288311', 'FreeDiams::CA_HCDPD::DIN', 77375);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02288346', 'FreeDiams::CA_HCDPD::DIN', 77377);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02288354', 'FreeDiams::CA_HCDPD::DIN', 77378);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02288362', 'FreeDiams::CA_HCDPD::DIN', 77379);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02288370', 'FreeDiams::CA_HCDPD::DIN', 77380);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sebivo', 'tablet', 'J05AF11', false, 0, '02288389', 'FreeDiams::CA_HCDPD::DIN', 77381);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Powerfoam Q', 'liquid', 'V07AV', false, 0, '02288397', 'FreeDiams::CA_HCDPD::DIN', 77382);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('60 Spf Stick Protection Ciblee Uva Uvb Anthelios Xl', 'stick', 'D02BA30', false, 0, '02288400', 'FreeDiams::CA_HCDPD::DIN', 77383);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kids Powder-Dri Pour Enfants Sunscreen Lotion Ecran Solaire Spf/Fps 30', 'lotion', 'D02BA30', false, 0, '02288478', 'FreeDiams::CA_HCDPD::DIN', 77389);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sport Performance Spray Sunscreen/Ecran Solaire En Vaporisateur Spf Fps 50', 'aerosol', 'D02BA30', false, 0, '02288486', 'FreeDiams::CA_HCDPD::DIN', 77390);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sport Performance Powder-Dri Sunscreen Lotion Ecran Solaire Spf/Fps 30', 'lotion', 'D02BA30', false, 0, '02288494', 'FreeDiams::CA_HCDPD::DIN', 77391);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Defense Spray Sunscreen/Ecran Solaire En Vaporisateur Spf/Fps 50', 'aerosol', 'D02BA30', false, 0, '02288508', 'FreeDiams::CA_HCDPD::DIN', 77392);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Roc Minesol Protect Ultra High Protection Suncare Cream Spf 60', 'cream', 'D02BA30', false, 0, '02288524', 'FreeDiams::CA_HCDPD::DIN', 77394);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soleil Protexion Velvet Moisture Spf 60', 'spray', 'D02BA30', false, 0, '02288532', 'FreeDiams::CA_HCDPD::DIN', 77395);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soleil Protexion Velvet Moisture Spf 30', 'spray', 'D02BA30', false, 0, '02288540', 'FreeDiams::CA_HCDPD::DIN', 77396);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Amoxi Clav', 'powder for suspension', 'J01CR02', false, 0, '02288559', 'FreeDiams::CA_HCDPD::DIN', 77397);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eprex Sterile Solution', 'solution', 'B03XA01', false, 0, '02288680', 'FreeDiams::CA_HCDPD::DIN', 77409);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Age-Transforming Foundation Fond De Teint Transformation-Age Spf.Fps 15', 'lotion', 'D02BA30', false, 0, '02288699', 'FreeDiams::CA_HCDPD::DIN', 77410);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prescriptives Site Unseen Brightening Concealer Spf 15', 'liquid', 'D02BA30', false, 0, '02288702', 'FreeDiams::CA_HCDPD::DIN', 77411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('D-Germ 5', 'liquid', 'V07AV', false, 0, '02288710', 'FreeDiams::CA_HCDPD::DIN', 77412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Provocholine', 'powder for solution', 'V04CX', false, 0, '02288826', 'FreeDiams::CA_HCDPD::DIN', 77421);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soin Hydratant Anti-Age Fps 20', 'emulsion', 'D02BA30', false, 0, '02288958', 'FreeDiams::CA_HCDPD::DIN', 77434);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Infusion', 'liquid', 'D02BA30', false, 0, '02288974', 'FreeDiams::CA_HCDPD::DIN', 77436);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quo Total Perfection Foundation With Spf 15', 'emulsion', 'D02BA30', false, 0, '02289008', 'FreeDiams::CA_HCDPD::DIN', 77439);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advanced Revitalift Day', 'cream', 'D02BA30', false, 0, '02289016', 'FreeDiams::CA_HCDPD::DIN', 77440);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prescriptives Sunsheen Custom Color Tinted Self Tanner Uva/Uvb Sunscreen Spf 15 For Face And Body', 'liquid', 'D02BA30', false, 0, '02289024', 'FreeDiams::CA_HCDPD::DIN', 77441);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dupont Relyon Disinfectant Solution', 'spray', 'V07AV', false, 0, '02289032', 'FreeDiams::CA_HCDPD::DIN', 77442);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Fenofibrate-S', 'tablet', 'C10AB05', false, 0, '02289083', 'FreeDiams::CA_HCDPD::DIN', 77447);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Fenofibrate-S', 'tablet', 'C10AB05', false, 0, '02289091', 'FreeDiams::CA_HCDPD::DIN', 77448);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckley''S Cough Chest Congestion', 'syrup', 'R05CA03', false, 0, '02289164', 'FreeDiams::CA_HCDPD::DIN', 77454);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Lisinopril', 'tablet', 'C09AA03', false, 0, '02289199', 'FreeDiams::CA_HCDPD::DIN', 77458);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Lisinopril', 'tablet', 'C09AA03', false, 0, '02289202', 'FreeDiams::CA_HCDPD::DIN', 77459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Lisinopril', 'tablet', 'C09AA03', false, 0, '02289229', 'FreeDiams::CA_HCDPD::DIN', 77460);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Waterblock Solar Spray Spf 30', 'spray', 'D02BA30', false, 0, '02289210', 'FreeDiams::CA_HCDPD::DIN', 77461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oil Free Matte Defense Spf 20', 'lotion', 'D02BA30', false, 0, '02289237', 'FreeDiams::CA_HCDPD::DIN', 77462);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Rich Day Defense Spf 30', 'cream', 'D02BA30', false, 0, '02289245', 'FreeDiams::CA_HCDPD::DIN', 77463);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Perindopril', 'tablet', 'C09AA04', false, 0, '02289296', 'FreeDiams::CA_HCDPD::DIN', 77467);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jergens Natural Glow Daily Facial Moisturizer', 'lotion', 'D02BA30', false, 0, '02289334', 'FreeDiams::CA_HCDPD::DIN', 77470);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aspirin Express Pack', 'granules', 'N02BA01', false, 0, '02289350', 'FreeDiams::CA_HCDPD::DIN', 77472);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Brand Sport Sunscreen Continuous Spray', 'spray', 'D02BA30', false, 0, '02289369', 'FreeDiams::CA_HCDPD::DIN', 77473);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Total Cold And Flu Extra Strength', 'syrup', 'N02BE51', false, 0, '02289385', 'FreeDiams::CA_HCDPD::DIN', 77475);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra-Fluid Sun Protection Spf 30', 'lotion', 'D02BA30', false, 0, '02289393', 'FreeDiams::CA_HCDPD::DIN', 77476);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimetane Allergy Tablets', 'tablet', 'R06AA02', false, 0, '02289407', 'FreeDiams::CA_HCDPD::DIN', 77477);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Doxycycline', 'capsule', 'J01AA02', false, 0, '02289431', 'FreeDiams::CA_HCDPD::DIN', 77480);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Doxycycline', 'tablet', 'J01AA02', false, 0, '02289458', 'FreeDiams::CA_HCDPD::DIN', 77481);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Doxycycline', 'tablet', 'J01AA02', false, 0, '02289466', 'FreeDiams::CA_HCDPD::DIN', 77482);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shiseido The Skincare Day Moisture Protection Enriched Spf 15', 'cream', 'D02BA30', false, 0, '02289482', 'FreeDiams::CA_HCDPD::DIN', 77484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shiseido The Skincare Day Moisture Protection Spf 15', 'lotion', 'D02BA30', false, 0, '02289490', 'FreeDiams::CA_HCDPD::DIN', 77485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diovan', 'tablet', 'C09CA03', false, 0, '02289504', 'FreeDiams::CA_HCDPD::DIN', 77486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Regenerist Touch Of Sun Enhancing Lotion With Uv Protection', 'lotion', 'D02BA30', false, 0, '02289520', 'FreeDiams::CA_HCDPD::DIN', 77488);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Doxycycline', 'capsule', 'J01AA02', false, 0, '02289539', 'FreeDiams::CA_HCDPD::DIN', 77489);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Doxycycline', 'tablet', 'J01AA02', false, 0, '02289547', 'FreeDiams::CA_HCDPD::DIN', 77490);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Doxycycline', 'capsule', 'J01AA02', false, 0, '02289598', 'FreeDiams::CA_HCDPD::DIN', 77494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creme Solaire Regions Sensibles Fps 30', 'cream', 'D02BA30', false, 0, '02289792', 'FreeDiams::CA_HCDPD::DIN', 77512);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Block Up Fps/Spf 30 Continuous Spray', 'spray', 'D02BA30', false, 0, '02289806', 'FreeDiams::CA_HCDPD::DIN', 77513);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Block Up Dry Sport Fps/Spf 30 Continuous Spray', 'spray', 'D02BA30', false, 0, '02289822', 'FreeDiams::CA_HCDPD::DIN', 77515);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polysporin Lip Protectant', 'stick', 'D02BA30', false, 0, '02289849', 'FreeDiams::CA_HCDPD::DIN', 77517);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxygen    (Family 1st Medical)', 'gas', 'V03AN01', false, 0, '02289962', 'FreeDiams::CA_HCDPD::DIN', 77527);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aspirin 81mg Quick Chews', 'tablet (chewable)', 'N02BA01', false, 0, '02289970', 'FreeDiams::CA_HCDPD::DIN', 77528);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Kids Alcohol-Free Spray Sunscreen', 'spray', 'D02BA30', false, 0, '02290006', 'FreeDiams::CA_HCDPD::DIN', 77531);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Alcohol-Free Spray Sunscreen', 'spray', 'D02BA30', false, 0, '02290022', 'FreeDiams::CA_HCDPD::DIN', 77533);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adasept B.P.5 Acne Gel', 'gel', 'D10AE01', false, 0, '02290081', 'FreeDiams::CA_HCDPD::DIN', 77539);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lotion Sport', 'lotion', 'D02BA30', false, 0, '02290103', 'FreeDiams::CA_HCDPD::DIN', 77540);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pramipexole', 'tablet', 'N04BC05', false, 0, '02290111', 'FreeDiams::CA_HCDPD::DIN', 77541);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pramipexole', 'tablet', 'N04BC05', false, 0, '02290138', 'FreeDiams::CA_HCDPD::DIN', 77542);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pramipexole', 'tablet', 'N04BC05', false, 0, '02290146', 'FreeDiams::CA_HCDPD::DIN', 77543);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pramipexole', 'tablet', 'N04BC05', false, 0, '02290154', 'FreeDiams::CA_HCDPD::DIN', 77544);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Facilities Maintenance Quaternary Disinfectant Spray Cleaner Gp-20', 'spray', 'V07AV', false, 0, '02290170', 'FreeDiams::CA_HCDPD::DIN', 77546);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Facilities Maintenance Non-Acid Bathroom Disinfectant Cleaner', 'spray', 'V07AV', false, 0, '02290189', 'FreeDiams::CA_HCDPD::DIN', 77547);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Facility Maintenance Disinfectant Cleaner Degreaser Gc-3', 'liquid', 'V07AV', false, 0, '02290197', 'FreeDiams::CA_HCDPD::DIN', 77548);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Facilities Maintenance Detergent Thickened Toilet Bowl Cleaner', 'liquid', 'V07AV', false, 0, '02290200', 'FreeDiams::CA_HCDPD::DIN', 77549);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Brand Sunthera 3 Kids / Enfants', 'lotion', 'D02BA30', false, 0, '02290219', 'FreeDiams::CA_HCDPD::DIN', 77550);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Brand Sunthera 3 Baby / Bébé', 'lotion', 'D02BA30', false, 0, '02290227', 'FreeDiams::CA_HCDPD::DIN', 77551);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Facial Tinted Moisturizer Spf 15 Sunscreen', 'cream', 'D02BA02', false, 0, '02290235', 'FreeDiams::CA_HCDPD::DIN', 77552);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vita Lift   (Spf 15)', 'cream', 'D02BA30', false, 0, '02290251', 'FreeDiams::CA_HCDPD::DIN', 77554);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyestra-35', 'tablet', 'G03HB01', false, 0, '02290308', 'FreeDiams::CA_HCDPD::DIN', 77558);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Age-Transforming Concealer Correcteur Transformation Age Spf  Fps15', 'cream', 'D02BA30', false, 0, '02290324', 'FreeDiams::CA_HCDPD::DIN', 77560);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benazepril', 'tablet', 'C09AA07', false, 0, '02290332', 'FreeDiams::CA_HCDPD::DIN', 77563);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benazepril', 'tablet', 'C09AA07', false, 0, '02290340', 'FreeDiams::CA_HCDPD::DIN', 77564);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lysol Disinfectant All Purpose Cleaner With Bleach', 'liquid', 'V07AV', false, 0, '02290367', 'FreeDiams::CA_HCDPD::DIN', 77566);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Voltaren Emulgel', 'gel', 'M02AA15', false, 0, '02290375', 'FreeDiams::CA_HCDPD::DIN', 77569);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Purmist', 'spray', 'D08AC52', false, 0, '02290456', 'FreeDiams::CA_HCDPD::DIN', 77576);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ombrelle Sport Gel', 'gel', 'D02BA30', false, 0, '02290464', 'FreeDiams::CA_HCDPD::DIN', 77577);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ombrelle Sport Spray', 'spray', 'D02BA30', false, 0, '02290472', 'FreeDiams::CA_HCDPD::DIN', 77578);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen 30 Spf Continuous Spray', 'spray', 'D02BA30', false, 0, '02290502', 'FreeDiams::CA_HCDPD::DIN', 77581);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Back Pain', 'tablet', 'M03BA53', false, 0, '02290510', 'FreeDiams::CA_HCDPD::DIN', 77584);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cold/Flu Medicine', 'liquid', 'N02BE51', false, 0, '02290537', 'FreeDiams::CA_HCDPD::DIN', 77585);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Acne Solutions Clearing Moisturizer', 'lotion', 'D10AE01', false, 0, '02290561', 'FreeDiams::CA_HCDPD::DIN', 77590);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clean''Ems Spirit Ii Disinfectant Towels', 'wipe', 'V07AV', false, 0, '02290588', 'FreeDiams::CA_HCDPD::DIN', 77591);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy Eye Drops', 'drops', 'S01GA52', false, 0, '02290596', 'FreeDiams::CA_HCDPD::DIN', 77592);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Midol Night-Time', 'tablet', 'M03BA53', false, 0, '02290618', 'FreeDiams::CA_HCDPD::DIN', 77593);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creme Solaire Haute Protection 20 Spf', 'emulsion', 'D02BA30', false, 0, '02290626', 'FreeDiams::CA_HCDPD::DIN', 77605);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creme Solaire Tres Haute Protection Special Peaux Sensibles 30 Spf', 'emulsion', 'D02BA30', false, 0, '02290634', 'FreeDiams::CA_HCDPD::DIN', 77606);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spray Solaire Lotion Non Grasse Protection Moyenne Spécial Sports 15 Spf', 'lotion', 'D02BA30', false, 0, '02290650', 'FreeDiams::CA_HCDPD::DIN', 77608);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Brand Sunthera 3 Spf/Fps 15', 'lotion', 'D02BA30', false, 0, '02290685', 'FreeDiams::CA_HCDPD::DIN', 77610);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Perfecting Day Cream Spf 30', 'cream', 'D02BA30', false, 0, '02290677', 'FreeDiams::CA_HCDPD::DIN', 77611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Brand Sunthera 3 Spf/Fps 30', 'lotion', 'D02BA30', false, 0, '02290693', 'FreeDiams::CA_HCDPD::DIN', 77612);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Brand Sunthera 3 Spf/Fps 60', 'lotion', 'D02BA30', false, 0, '02290715', 'FreeDiams::CA_HCDPD::DIN', 77613);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('30 Spf Fps Sunscreen Lotion Ecran Solaire', 'lotion', 'D02BA30', false, 0, '02290707', 'FreeDiams::CA_HCDPD::DIN', 77614);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oil-Free Sunscreen Spf 30', 'liquid', 'D02BA30', false, 0, '02290758', 'FreeDiams::CA_HCDPD::DIN', 77617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Brand Kids Sunscreen Spray', 'lotion', 'D02BA30', false, 0, '02290766', 'FreeDiams::CA_HCDPD::DIN', 77618);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Facial Fuel Spf 15', 'cream', 'D02BA30', false, 0, '02290774', 'FreeDiams::CA_HCDPD::DIN', 77619);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Acne Solutions Emergency Lotion', 'lotion', 'D10AE01', false, 0, '02290804', 'FreeDiams::CA_HCDPD::DIN', 77622);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Timop Gel', 'solution', 'S01ED01', false, 0, '02290812', 'FreeDiams::CA_HCDPD::DIN', 77623);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('X3 Clean Foaming Hand Sanitizer', 'liquid', 'D08AJ01', false, 0, '02290855', 'FreeDiams::CA_HCDPD::DIN', 77627);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daytime Cold/Flu Medicine', 'liquid', 'N02BE51', false, 0, '02290863', 'FreeDiams::CA_HCDPD::DIN', 77628);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluide Lift Jour Toutes Peaux - Multi Régénérante - Spf 15', 'emulsion', 'D02BA30', false, 0, '02290871', 'FreeDiams::CA_HCDPD::DIN', 77629);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sheer Tint Redness Relief Spf 15', 'cream', 'D02BA30', false, 0, '02290898', 'FreeDiams::CA_HCDPD::DIN', 77630);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Headache Ultra Relief', 'tablet', 'N02BE51', false, 0, '02290901', 'FreeDiams::CA_HCDPD::DIN', 77631);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Obagi C-System C-Sunguard Spf 30', 'lotion', 'D02BA30', false, 0, '02290928', 'FreeDiams::CA_HCDPD::DIN', 77632);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mv Body Defense Spf 20', 'cream', 'D02BA30', false, 0, '02290936', 'FreeDiams::CA_HCDPD::DIN', 77633);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mabcampath', 'solution', 'L01XC04', false, 0, '02290960', 'FreeDiams::CA_HCDPD::DIN', 77636);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hepagam B', 'liquid', 'J06BB04', false, 0, '02290979', 'FreeDiams::CA_HCDPD::DIN', 77637);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diltiaz Tz', 'capsule (extended release)', 'C08DB01', false, 0, '02291037', 'FreeDiams::CA_HCDPD::DIN', 77643);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diltiaz Tz', 'capsule (extended release)', 'C08DB01', false, 0, '02291045', 'FreeDiams::CA_HCDPD::DIN', 77644);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diltiaz Tz', 'capsule (extended release)', 'C08DB01', false, 0, '02291053', 'FreeDiams::CA_HCDPD::DIN', 77645);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diltiaz Tz', 'capsule (extended release)', 'C08DB01', false, 0, '02291061', 'FreeDiams::CA_HCDPD::DIN', 77646);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Diltiaz Tz', 'capsule (extended release)', 'C08DB01', false, 0, '02291088', 'FreeDiams::CA_HCDPD::DIN', 77647);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spectr-O-Cide', 'solution', 'V07AV', false, 0, '02291118', 'FreeDiams::CA_HCDPD::DIN', 77649);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multi-Purpose Solution', 'solution', 'S01XA20', false, 0, '02291126', 'FreeDiams::CA_HCDPD::DIN', 77650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cilazapril', 'tablet', 'C09AA08', false, 0, '02291134', 'FreeDiams::CA_HCDPD::DIN', 77651);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cilazapril', 'tablet', 'C09AA08', false, 0, '02291142', 'FreeDiams::CA_HCDPD::DIN', 77652);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cilazapril', 'tablet', 'C09AA08', false, 0, '02291150', 'FreeDiams::CA_HCDPD::DIN', 77653);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Champix', 'tablet', 'N07BA03', false, 0, '02291177', 'FreeDiams::CA_HCDPD::DIN', 77655);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Champix', 'tablet', 'N07BA03', false, 0, '02291185', 'FreeDiams::CA_HCDPD::DIN', 77656);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Virox 5 Rtu Wipes', 'wipe', 'V07AV', false, 0, '02291193', 'FreeDiams::CA_HCDPD::DIN', 77657);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Senna S', 'tablet', 'A06AB56', false, 0, '02291215', 'FreeDiams::CA_HCDPD::DIN', 77658);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bd E-Z Scrub 408', 'solution', 'D08AE05', false, 0, '02291355', 'FreeDiams::CA_HCDPD::DIN', 77673);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robitussin Total Cough, Cold & Flu', 'liquid', 'N02BE51', false, 0, '02291363', 'FreeDiams::CA_HCDPD::DIN', 77674);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Robitussin Total Cough, Cold & Flu Extra Strength', 'liquid', 'N02BE51', false, 0, '02291371', 'FreeDiams::CA_HCDPD::DIN', 77675);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Ramipril', 'tablet', 'C09AA05', false, 0, '02291398', 'FreeDiams::CA_HCDPD::DIN', 77676);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Ramipril', 'tablet', 'C09AA05', false, 0, '02291401', 'FreeDiams::CA_HCDPD::DIN', 77677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Ramipril', 'tablet', 'C09AA05', false, 0, '02291428', 'FreeDiams::CA_HCDPD::DIN', 77678);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Ramipril', 'tablet', 'C09AA05', false, 0, '02291436', 'FreeDiams::CA_HCDPD::DIN', 77679);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mkmen Moisturizer Sunscreen Spf 25', 'lotion', 'D02BA30', false, 0, '02291452', 'FreeDiams::CA_HCDPD::DIN', 77681);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mary Kay Spf 30 Sunscreen', 'lotion', 'D02BA30', false, 0, '02291460', 'FreeDiams::CA_HCDPD::DIN', 77682);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('25 Creme 410', 'cream', 'D02BA30', false, 0, '02291568', 'FreeDiams::CA_HCDPD::DIN', 77692);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimethicone Moisture Barrier Cream', 'cream', 'D02AA', false, 0, '02291584', 'FreeDiams::CA_HCDPD::DIN', 77695);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cleansing Body Lotion', 'lotion', 'D02AA', false, 0, '02291592', 'FreeDiams::CA_HCDPD::DIN', 77696);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Skin Repair Cream', 'cream', 'D02AA', false, 0, '02291606', 'FreeDiams::CA_HCDPD::DIN', 77697);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nutrashield', 'cream', 'D02AA', false, 0, '02291614', 'FreeDiams::CA_HCDPD::DIN', 77698);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pantoprazole', 'powder for solution', 'A02BC02', false, 0, '02291665', 'FreeDiams::CA_HCDPD::DIN', 77703);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dandruff Shampoo (Classic Or Fresh Or Smooth & Silky 2 In 1)', 'suspension', 'D11AX12', false, 0, '02291681', 'FreeDiams::CA_HCDPD::DIN', 77705);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefoxitin For Injection, Usp', 'powder for solution', 'J01DC01', false, 0, '02291711', 'FreeDiams::CA_HCDPD::DIN', 77707);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefoxitin For Injection, Usp', 'powder for solution', 'J01DC01', false, 0, '02291738', 'FreeDiams::CA_HCDPD::DIN', 77708);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibiotic Ointment', 'ointment', 'D06AX30', false, 0, '02291762', 'FreeDiams::CA_HCDPD::DIN', 77712);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Risperidone Odt', 'tablet (orally disintegrating)', 'N05AX08', false, 0, '02291770', 'FreeDiams::CA_HCDPD::DIN', 77713);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Risperidone Odt', 'tablet (orally disintegrating)', 'N05AX08', false, 0, '02291789', 'FreeDiams::CA_HCDPD::DIN', 77714);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Risperidone Odt', 'tablet (orally disintegrating)', 'N05AX08', false, 0, '02291797', 'FreeDiams::CA_HCDPD::DIN', 77715);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imodium Calming Liquid', 'solution', 'A07DA03', false, 0, '02291800', 'FreeDiams::CA_HCDPD::DIN', 77716);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Healthy Defense Daily Moisturizer Spf 45', 'lotion', 'D02BA30', false, 0, '02291851', 'FreeDiams::CA_HCDPD::DIN', 77721);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Enalapril', 'tablet', 'C09AA02', false, 0, '02291878', 'FreeDiams::CA_HCDPD::DIN', 77724);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Enalapril', 'tablet', 'C09AA02', false, 0, '02291886', 'FreeDiams::CA_HCDPD::DIN', 77725);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Enalapril', 'tablet', 'C09AA02', false, 0, '02291894', 'FreeDiams::CA_HCDPD::DIN', 77726);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Enalapril', 'tablet', 'C09AA02', false, 0, '02291908', 'FreeDiams::CA_HCDPD::DIN', 77727);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bicillin L-A', 'suspension', 'J01CE08', false, 0, '02291924', 'FreeDiams::CA_HCDPD::DIN', 77729);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ibuprofen 200 Mg', 'tablet', 'M01AE01', false, 0, '02291932', 'FreeDiams::CA_HCDPD::DIN', 77730);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ondansetron', 'solution', 'A04AA01', false, 0, '02291967', 'FreeDiams::CA_HCDPD::DIN', 77733);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Famciclovir', 'tablet', 'J05AB09', false, 0, '02292025', 'FreeDiams::CA_HCDPD::DIN', 77739);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Famciclovir', 'tablet', 'J05AB09', false, 0, '02292041', 'FreeDiams::CA_HCDPD::DIN', 77741);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Famciclovir', 'tablet', 'J05AB09', false, 0, '02292068', 'FreeDiams::CA_HCDPD::DIN', 77742);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Tylenol Cough And Runny Nose', 'suspension', 'N02BE51', false, 0, '02292122', 'FreeDiams::CA_HCDPD::DIN', 77749);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cetaphil Acne Principles', 'gel', 'D10AE01', false, 0, '02292157', 'FreeDiams::CA_HCDPD::DIN', 77752);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Duodopa', 'gel', 'N04BA02', false, 0, '02292165', 'FreeDiams::CA_HCDPD::DIN', 77753);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Amiodarone', 'tablet', 'C01BD01', false, 0, '02292173', 'FreeDiams::CA_HCDPD::DIN', 77754);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lisinopril', 'tablet', 'C09AA03', false, 0, '02292203', 'FreeDiams::CA_HCDPD::DIN', 77756);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lisinopril', 'tablet', 'C09AA03', false, 0, '02292211', 'FreeDiams::CA_HCDPD::DIN', 77757);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Lisinopril', 'tablet', 'C09AA03', false, 0, '02292238', 'FreeDiams::CA_HCDPD::DIN', 77758);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone For Injection Usp', 'powder for solution', 'J01DD04', false, 0, '02292262', 'FreeDiams::CA_HCDPD::DIN', 77762);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone For Injection Usp', 'powder for solution', 'J01DD04', false, 0, '02292270', 'FreeDiams::CA_HCDPD::DIN', 77763);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone For Injection Usp', 'powder for solution', 'J01DD04', false, 0, '02292289', 'FreeDiams::CA_HCDPD::DIN', 77764);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone For Injection Usp', 'powder for solution', 'J01DD04', false, 0, '02292297', 'FreeDiams::CA_HCDPD::DIN', 77765);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Seaweed Mattifying Moisture Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02292327', 'FreeDiams::CA_HCDPD::DIN', 77768);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pramipexole', 'tablet', 'N04BC05', false, 0, '02292378', 'FreeDiams::CA_HCDPD::DIN', 77772);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pramipexole', 'tablet', 'N04BC05', false, 0, '02292386', 'FreeDiams::CA_HCDPD::DIN', 77773);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pramipexole', 'tablet', 'N04BC05', false, 0, '02292394', 'FreeDiams::CA_HCDPD::DIN', 77774);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pramipexole', 'tablet', 'N04BC05', false, 0, '02292408', 'FreeDiams::CA_HCDPD::DIN', 77776);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antiseptic First Aid Spray', 'liquid', 'D08AC02', false, 0, '02292491', 'FreeDiams::CA_HCDPD::DIN', 77786);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multi-Symptom Pms Relief', 'tablet', 'N02BE51', false, 0, '02292505', 'FreeDiams::CA_HCDPD::DIN', 77787);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro-Orange', 'liquid', 'V07AV', false, 0, '02292645', 'FreeDiams::CA_HCDPD::DIN', 77801);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('3m Tb Quat Disinfectant Ready-To-Use Cleaner', 'spray', 'V07AV', false, 0, '02292653', 'FreeDiams::CA_HCDPD::DIN', 77802);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Acetaminophen 80 Mg', 'tablet', 'N02BE01', false, 0, '02292696', 'FreeDiams::CA_HCDPD::DIN', 77806);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Acetaminophen 500 Mg', 'tablet', 'N02BE01', false, 0, '02292718', 'FreeDiams::CA_HCDPD::DIN', 77807);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enteric Coated Asa 325 Mg', 'tablet (delayed-release)', 'N02BA01', false, 0, '02292726', 'FreeDiams::CA_HCDPD::DIN', 77808);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Sleep Aid', 'tablet', 'R06AA02', false, 0, '02292734', 'FreeDiams::CA_HCDPD::DIN', 77809);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antiseptic Hand Gel', 'gel', 'D08AJ01', false, 0, '02292742', 'FreeDiams::CA_HCDPD::DIN', 77810);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antiseptic Hand Wipes', 'wipe', 'D08AJ01', false, 0, '02292750', 'FreeDiams::CA_HCDPD::DIN', 77811);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin C Daily Moisturiser With Spf 15', 'lotion', 'D02BA30', false, 0, '02292769', 'FreeDiams::CA_HCDPD::DIN', 77812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kid''S Hand Gel', 'gel', 'D08AJ01', false, 0, '02292785', 'FreeDiams::CA_HCDPD::DIN', 77814);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rougier Clean Derm', 'solution', 'D08AC02', false, 0, '02292793', 'FreeDiams::CA_HCDPD::DIN', 77815);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone Sodium For Injection, Bp', 'powder for solution', 'J01DD04', false, 0, '02292815', 'FreeDiams::CA_HCDPD::DIN', 77817);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prescriptives Anywear Multipurpose Makeup Stick Spf 15', 'stick', 'D02BA30', false, 0, '02292858', 'FreeDiams::CA_HCDPD::DIN', 77820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone For Injection Usp', 'powder for solution', 'J01DD04', false, 0, '02292866', 'FreeDiams::CA_HCDPD::DIN', 77821);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone For Injection Usp', 'powder for solution', 'J01DD04', false, 0, '02292874', 'FreeDiams::CA_HCDPD::DIN', 77822);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone For Injection Usp', 'powder for solution', 'J01DD04', false, 0, '02292882', 'FreeDiams::CA_HCDPD::DIN', 77823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone For Injection Usp', 'powder for solution', 'J01DD04', false, 0, '02292904', 'FreeDiams::CA_HCDPD::DIN', 77825);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pantoprazole', 'tablet (delayed-release)', 'A02BC02', false, 0, '02292912', 'FreeDiams::CA_HCDPD::DIN', 77826);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pantoprazole', 'tablet (delayed-release)', 'A02BC02', false, 0, '02292920', 'FreeDiams::CA_HCDPD::DIN', 77827);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Floralife D.C.D. Detergent Disinfectant', 'liquid', 'V07AV', false, 0, '02292947', 'FreeDiams::CA_HCDPD::DIN', 77829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cefprozil', 'tablet', 'J01DC10', false, 0, '02292998', 'FreeDiams::CA_HCDPD::DIN', 77836);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cefprozil', 'tablet', 'J01DC10', false, 0, '02293005', 'FreeDiams::CA_HCDPD::DIN', 77837);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pamprin Ibuprofen Formula', 'tablet', 'M01AE01', false, 0, '02293013', 'FreeDiams::CA_HCDPD::DIN', 77840);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Modec Mdf-500', 'liquid', 'V07AV', false, 0, '02293064', 'FreeDiams::CA_HCDPD::DIN', 77844);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germicide-3 Surface Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02293072', 'FreeDiams::CA_HCDPD::DIN', 77845);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Daytime Cold Relief Pe', 'tablet', 'N02BE51', false, 0, '02293099', 'FreeDiams::CA_HCDPD::DIN', 77847);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Nighttime Cold Relief Pe', 'tablet', 'N02BE51', false, 0, '02293110', 'FreeDiams::CA_HCDPD::DIN', 77849);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sprycel', 'tablet', 'L01XE06', false, 0, '02293129', 'FreeDiams::CA_HCDPD::DIN', 77850);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sprycel', 'tablet', 'L01XE06', false, 0, '02293137', 'FreeDiams::CA_HCDPD::DIN', 77851);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sprycel', 'tablet', 'L01XE06', false, 0, '02293145', 'FreeDiams::CA_HCDPD::DIN', 77852);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Scalp Relief Dandruff Control (Pyrithione Zinc Shampoo)', 'shampoo', 'D11AX12', false, 0, '02293196', 'FreeDiams::CA_HCDPD::DIN', 77856);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Citalopram', 'tablet', 'N06AB04', false, 0, '02293218', 'FreeDiams::CA_HCDPD::DIN', 77858);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Citalopram', 'tablet', 'N06AB04', false, 0, '02293226', 'FreeDiams::CA_HCDPD::DIN', 77859);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reliable Mousse Foaming Antiseptic Hand Soap', 'liquid', 'D08AE04', false, 0, '02293234', 'FreeDiams::CA_HCDPD::DIN', 77860);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Campral', 'tablet (delayed-release)', 'N07BB03', false, 0, '02293269', 'FreeDiams::CA_HCDPD::DIN', 77863);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kimcare Antibacterial Luxury Foam Antibacterial Skin Cleanser', 'solution', 'D08AE04', false, 0, '02293293', 'FreeDiams::CA_HCDPD::DIN', 77866);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sani Stuff Desinfectant Et Assainisseur Sans Rincage/Sani Stuff Disinfectant And No Rinse Sanitizer', 'solution', 'V07AV', false, 0, '02293315', 'FreeDiams::CA_HCDPD::DIN', 77869);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hx2', 'spray', 'V07AV', false, 0, '02293323', 'FreeDiams::CA_HCDPD::DIN', 77870);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hx2 Ready To Use Towelettes', 'wipe', 'V07AV', false, 0, '02293331', 'FreeDiams::CA_HCDPD::DIN', 77871);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Gabapentin', 'tablet', 'N03AX12', false, 0, '02293358', 'FreeDiams::CA_HCDPD::DIN', 77872);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Gabapentin', 'tablet', 'N03AX12', false, 0, '02293366', 'FreeDiams::CA_HCDPD::DIN', 77873);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spectrasol Disinfectant', 'liquid', 'V07AV', false, 0, '02293374', 'FreeDiams::CA_HCDPD::DIN', 77874);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Clindamycin', 'capsule', 'J01FF01', false, 0, '02293382', 'FreeDiams::CA_HCDPD::DIN', 77875);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Clindamycin', 'capsule', 'J01FF01', false, 0, '02293390', 'FreeDiams::CA_HCDPD::DIN', 77876);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Posanol', 'suspension', 'J02AC04', false, 0, '02293404', 'FreeDiams::CA_HCDPD::DIN', 77877);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Brand Sunscreen Continuous Spray', 'spray', 'D02BA30', false, 0, '02293463', 'FreeDiams::CA_HCDPD::DIN', 77883);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maximum Strength Acid Reducer Without Prescription', 'tablet', 'A02BA02', false, 0, '02293471', 'FreeDiams::CA_HCDPD::DIN', 77884);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Cefprozil', 'tablet', 'J01DC10', false, 0, '02293528', 'FreeDiams::CA_HCDPD::DIN', 77887);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Cefprozil', 'tablet', 'J01DC10', false, 0, '02293536', 'FreeDiams::CA_HCDPD::DIN', 77888);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Daytime Flu Pe', 'tablet', 'N02BE51', false, 0, '02293552', 'FreeDiams::CA_HCDPD::DIN', 77891);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Nighttime Flu Pe', 'tablet', 'N02BE51', false, 0, '02293560', 'FreeDiams::CA_HCDPD::DIN', 77892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Cefprozil', 'powder for suspension', 'J01DC10', false, 0, '02293579', 'FreeDiams::CA_HCDPD::DIN', 77893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Readybath Tpc', 'wipe', 'D02AA', false, 0, '02293595', 'FreeDiams::CA_HCDPD::DIN', 77895);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Readycleanse', 'wipe', 'D02AA', false, 0, '02293609', 'FreeDiams::CA_HCDPD::DIN', 77896);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Paroxetine', 'tablet', 'N06AB05', false, 0, '02293749', 'FreeDiams::CA_HCDPD::DIN', 77913);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benefix', 'powder for solution', 'B02BD04', false, 0, '02293765', 'FreeDiams::CA_HCDPD::DIN', 77915);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benefix', 'powder for solution', 'B02BD04', false, 0, '02293773', 'FreeDiams::CA_HCDPD::DIN', 77916);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benefix', 'powder for solution', 'B02BD04', false, 0, '02293781', 'FreeDiams::CA_HCDPD::DIN', 77917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benefix', 'powder for solution', 'B02BD04', false, 0, '02293803', 'FreeDiams::CA_HCDPD::DIN', 77918);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lansoprazole', 'capsule (delayed release)', 'A02BC03', false, 0, '02293811', 'FreeDiams::CA_HCDPD::DIN', 77919);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Lansoprazole', 'capsule (delayed release)', 'A02BC03', false, 0, '02293838', 'FreeDiams::CA_HCDPD::DIN', 77920);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fludarabine Phosphate For Injection, Usp', 'powder for solution', 'L01BB05', false, 0, '02293846', 'FreeDiams::CA_HCDPD::DIN', 77921);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydrasilk Eye Cream Spf 12', 'cream', 'D02BA30', false, 0, '02293870', 'FreeDiams::CA_HCDPD::DIN', 77925);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydrasilk Day & Night Cream Spf 12', 'cream', 'D02BA30', false, 0, '02293889', 'FreeDiams::CA_HCDPD::DIN', 77926);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 15 Lotion', 'lotion', 'D02BA30', false, 0, '02293897', 'FreeDiams::CA_HCDPD::DIN', 77927);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 15 Spray Gel', 'gel', 'D02BA30', false, 0, '02293900', 'FreeDiams::CA_HCDPD::DIN', 77928);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cefprozil', 'powder for suspension', 'J01DC10', false, 0, '02293943', 'FreeDiams::CA_HCDPD::DIN', 77932);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Cefprozil', 'powder for suspension', 'J01DC10', false, 0, '02293951', 'FreeDiams::CA_HCDPD::DIN', 77933);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Psoriasin Ointment', 'ointment', 'D05AA', false, 0, '02293978', 'FreeDiams::CA_HCDPD::DIN', 77934);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neocitran Extra Strength Daytime Total', 'powder for solution', 'N02BE51', false, 0, '02293994', 'FreeDiams::CA_HCDPD::DIN', 77936);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Fluconazole', 'capsule', 'J02AC01', false, 0, '02294044', 'FreeDiams::CA_HCDPD::DIN', 77940);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Zopiclone', 'tablet', 'N05CF01', false, 0, '02294052', 'FreeDiams::CA_HCDPD::DIN', 77941);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Zopiclone', 'tablet', 'N05CF01', false, 0, '02294060', 'FreeDiams::CA_HCDPD::DIN', 77942);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Divalproex', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02294109', 'FreeDiams::CA_HCDPD::DIN', 77946);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Divalproex', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02294117', 'FreeDiams::CA_HCDPD::DIN', 77947);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Divalproex', 'tablet (enteric-coated)', 'N03AG01', false, 0, '02294125', 'FreeDiams::CA_HCDPD::DIN', 77948);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Minocycline', 'capsule', 'J01AA08', false, 0, '02294133', 'FreeDiams::CA_HCDPD::DIN', 77949);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Minocycline', 'capsule', 'J01AA08', false, 0, '02294141', 'FreeDiams::CA_HCDPD::DIN', 77950);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Td-5', 'solution', 'V07AV', false, 0, '02294168', 'FreeDiams::CA_HCDPD::DIN', 77951);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Reyataz', 'capsule', 'J05AE08', false, 0, '02294176', 'FreeDiams::CA_HCDPD::DIN', 77952);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mycamine', 'powder for solution', 'J02AX05', false, 0, '02294222', 'FreeDiams::CA_HCDPD::DIN', 77957);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Lisinopril', 'tablet', 'C09AA03', false, 0, '02294230', 'FreeDiams::CA_HCDPD::DIN', 77958);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Lisinopril', 'tablet', 'C09AA03', false, 0, '02294249', 'FreeDiams::CA_HCDPD::DIN', 77959);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Lisinopril', 'tablet', 'C09AA03', false, 0, '02294257', 'FreeDiams::CA_HCDPD::DIN', 77960);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Tamsulosin', 'capsule (sustained-release)', 'G04CA02', false, 0, '02294265', 'FreeDiams::CA_HCDPD::DIN', 77961);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Terbinafine', 'tablet', 'D01BA02', false, 0, '02294273', 'FreeDiams::CA_HCDPD::DIN', 77963);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tilex Soap Scum Remover & Disinfectant-1', 'spray', 'V07AV', false, 0, '02294303', 'FreeDiams::CA_HCDPD::DIN', 77965);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clorox Disinfecting Bathroom Cleaner-1', 'spray', 'V07AV', false, 0, '02294311', 'FreeDiams::CA_HCDPD::DIN', 77966);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lantus', 'solution', 'A10AE04', false, 0, '02294338', 'FreeDiams::CA_HCDPD::DIN', 77967);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apidra     (3ml Solostar Disposable Prefilled Pen)', 'solution', 'A10AB06', false, 0, '02294346', 'FreeDiams::CA_HCDPD::DIN', 77968);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Gliclazide', 'tablet', 'A10BB09', false, 0, '02294400', 'FreeDiams::CA_HCDPD::DIN', 77975);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Minocycline', 'capsule', 'J01AA08', false, 0, '02294419', 'FreeDiams::CA_HCDPD::DIN', 77976);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Minocycline', 'capsule', 'J01AA08', false, 0, '02294427', 'FreeDiams::CA_HCDPD::DIN', 77977);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Fosinopril', 'tablet', 'C09AA09', false, 0, '02294524', 'FreeDiams::CA_HCDPD::DIN', 77986);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Fosinopril', 'tablet', 'C09AA09', false, 0, '02294532', 'FreeDiams::CA_HCDPD::DIN', 77987);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Propafenone', 'tablet', 'C01BC03', false, 0, '02294559', 'FreeDiams::CA_HCDPD::DIN', 77991);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Propafenone', 'tablet', 'C01BC03', false, 0, '02294575', 'FreeDiams::CA_HCDPD::DIN', 77992);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lisinopril', 'tablet', 'C09AA03', false, 0, '02294583', 'FreeDiams::CA_HCDPD::DIN', 77994);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lisinopril', 'tablet', 'C09AA03', false, 0, '02294591', 'FreeDiams::CA_HCDPD::DIN', 77995);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lisinopril', 'tablet', 'C09AA03', false, 0, '02294605', 'FreeDiams::CA_HCDPD::DIN', 77996);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Lisinopril', 'tablet', 'C09AA03', false, 0, '02294613', 'FreeDiams::CA_HCDPD::DIN', 77997);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Lisinopril', 'tablet', 'C09AA03', false, 0, '02294621', 'FreeDiams::CA_HCDPD::DIN', 77998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Lisinopril', 'tablet', 'C09AA03', false, 0, '02294648', 'FreeDiams::CA_HCDPD::DIN', 77999);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Octaplex (Human Prothrombin Complex)', 'powder for solution', 'B02BD01', false, 0, '02294664', 'FreeDiams::CA_HCDPD::DIN', 78001);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Naproxen Ec', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02294702', 'FreeDiams::CA_HCDPD::DIN', 78005);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Naproxen Ec', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02294710', 'FreeDiams::CA_HCDPD::DIN', 78006);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Fluticasone', 'spray, metered dose', 'R01AD08', false, 0, '02294745', 'FreeDiams::CA_HCDPD::DIN', 78009);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accusol 35 K0', 'solution', 'B05ZA', false, 0, '02294753', 'FreeDiams::CA_HCDPD::DIN', 78010);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accusol 35 K4', 'solution', 'B05ZA', false, 0, '02294788', 'FreeDiams::CA_HCDPD::DIN', 78012);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin E Moisture Lotion Spf15', 'lotion', 'D02BA30', false, 0, '02294818', 'FreeDiams::CA_HCDPD::DIN', 78014);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Clindamycin', 'capsule', 'J01FF01', false, 0, '02294826', 'FreeDiams::CA_HCDPD::DIN', 78015);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Clindamycin', 'capsule', 'J01FF01', false, 0, '02294834', 'FreeDiams::CA_HCDPD::DIN', 78016);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cc-632', 'liquid', 'V07AV', false, 0, '02294842', 'FreeDiams::CA_HCDPD::DIN', 78017);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Gel Spf 30', 'gel', 'D02BA30', false, 0, '02294869', 'FreeDiams::CA_HCDPD::DIN', 78019);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02294877', 'FreeDiams::CA_HCDPD::DIN', 78020);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Tamsulosin', 'capsule (sustained-release)', 'G04CA02', false, 0, '02294885', 'FreeDiams::CA_HCDPD::DIN', 78022);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydraction Visible Defense Creme Legere Hydra-Protectrice Spf 20', 'emulsion', 'D02BA30', false, 0, '02294893', 'FreeDiams::CA_HCDPD::DIN', 78023);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydraction Visible Defense Creme Riche Hydra-Protectrice Spf 20', 'emulsion', 'D02BA30', false, 0, '02294907', 'FreeDiams::CA_HCDPD::DIN', 78024);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydraction Visible Defense Creme Yeux Hydra-Protectrice Spf 20', 'emulsion', 'D02BA30', false, 0, '02294915', 'FreeDiams::CA_HCDPD::DIN', 78025);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clear Eyes For Dry Eyes Plus Redness Relief', 'solution', 'S01GA51', false, 0, '02294958', 'FreeDiams::CA_HCDPD::DIN', 78028);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Instillagel', 'gel', 'N01BB52', false, 0, '02294990', 'FreeDiams::CA_HCDPD::DIN', 78032);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soluscope D', 'liquid', 'V07AV', false, 0, '02295040', 'FreeDiams::CA_HCDPD::DIN', 78037);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shaklee Get Clean Germ Off Disinfecting Wipes', 'wipe', 'V07AV', false, 0, '02295113', 'FreeDiams::CA_HCDPD::DIN', 78044);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Tamsulosin', 'capsule (sustained-release)', 'G04CA02', false, 0, '02295121', 'FreeDiams::CA_HCDPD::DIN', 78045);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Amlodipine', 'tablet', 'C08CA01', false, 0, '02295148', 'FreeDiams::CA_HCDPD::DIN', 78046);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Skintint Fx', 'cream', 'D02BA30', false, 0, '02295156', 'FreeDiams::CA_HCDPD::DIN', 78047);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlorhexidine Solution', 'solution', 'D08AC02', false, 0, '02295253', 'FreeDiams::CA_HCDPD::DIN', 78057);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02295261', 'FreeDiams::CA_HCDPD::DIN', 78058);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02295288', 'FreeDiams::CA_HCDPD::DIN', 78059);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02295296', 'FreeDiams::CA_HCDPD::DIN', 78060);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02295318', 'FreeDiams::CA_HCDPD::DIN', 78061);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol Cold Plus Mucous Relief', 'capsule', 'N02BE51', false, 0, '02295326', 'FreeDiams::CA_HCDPD::DIN', 78062);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ramipril', 'capsule', 'C09AA05', false, 0, '02295369', 'FreeDiams::CA_HCDPD::DIN', 78066);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Glimepiride', 'tablet', 'A10BB12', false, 0, '02295377', 'FreeDiams::CA_HCDPD::DIN', 78068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Glimepiride', 'tablet', 'A10BB12', false, 0, '02295385', 'FreeDiams::CA_HCDPD::DIN', 78069);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Glimepiride', 'tablet', 'A10BB12', false, 0, '02295393', 'FreeDiams::CA_HCDPD::DIN', 78070);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Ramipril', 'capsule', 'C09AA05', false, 0, '02295482', 'FreeDiams::CA_HCDPD::DIN', 78079);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Ramipril', 'capsule', 'C09AA05', false, 0, '02295490', 'FreeDiams::CA_HCDPD::DIN', 78081);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Ramipril', 'capsule', 'C09AA05', false, 0, '02295504', 'FreeDiams::CA_HCDPD::DIN', 78082);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Ramipril', 'capsule', 'C09AA05', false, 0, '02295512', 'FreeDiams::CA_HCDPD::DIN', 78083);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lowprin 80mg', 'tablet', 'N02BA01', false, 0, '02295563', 'FreeDiams::CA_HCDPD::DIN', 78087);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun Protection Spf 45', 'cream', 'D02BA30', false, 0, '02295601', 'FreeDiams::CA_HCDPD::DIN', 78091);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlorhexidine 2% Antiseptic Hand Wash', 'solution', 'D08AC02', false, 0, '02295660', 'FreeDiams::CA_HCDPD::DIN', 78101);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chlorhexidine 4% Antiseptic Hand Wash', 'solution', 'D08AC02', false, 0, '02295679', 'FreeDiams::CA_HCDPD::DIN', 78102);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clor-5 Sodium Hypochlorite', 'liquid', 'V07AV', false, 0, '02295687', 'FreeDiams::CA_HCDPD::DIN', 78103);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Suboxone', 'tablet', 'N07BC51', false, 0, '02295695', 'FreeDiams::CA_HCDPD::DIN', 78104);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Suboxone', 'tablet', 'N07BC51', false, 0, '02295709', 'FreeDiams::CA_HCDPD::DIN', 78105);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterixin 0.05%', 'solution', 'D08AC02', false, 0, '02295717', 'FreeDiams::CA_HCDPD::DIN', 78106);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Brand Sunscreen Continuous Spray Spf/Fps 15', 'spray', 'D02BA30', false, 0, '02295733', 'FreeDiams::CA_HCDPD::DIN', 78108);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra-Lift Anti-Wrinkle Firming Moisture Cream Spf 15', 'cream', 'D02BA30', false, 0, '02295768', 'FreeDiams::CA_HCDPD::DIN', 78110);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spectro-Sept', 'liquid', 'V07AV', false, 0, '02295806', 'FreeDiams::CA_HCDPD::DIN', 78114);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Valacyclovir', 'tablet', 'J05AB11', false, 0, '02295822', 'FreeDiams::CA_HCDPD::DIN', 78118);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flexitol Medicated Foot Cream', 'cream', 'D01AE18', false, 0, '02295873', 'FreeDiams::CA_HCDPD::DIN', 78123);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Lactulose', 'solution', 'A06AD11', false, 0, '02295881', 'FreeDiams::CA_HCDPD::DIN', 78124);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spectro-Sept Hc', 'liquid', 'V07AV', false, 0, '02295911', 'FreeDiams::CA_HCDPD::DIN', 78127);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Portia 21', 'tablet', 'G03AA07', false, 0, '02295946', 'FreeDiams::CA_HCDPD::DIN', 78129);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Portia 28', 'tablet', 'G03AA07', false, 0, '02295954', 'FreeDiams::CA_HCDPD::DIN', 78130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lowprin 80 Chewable Tablet', 'tablet (chewable)', 'N02BA01', false, 0, '02296004', 'FreeDiams::CA_HCDPD::DIN', 78136);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tapazole', 'tablet', 'H03BB02', false, 0, '02296039', 'FreeDiams::CA_HCDPD::DIN', 78139);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Bicalutamide', 'tablet', 'L02BB03', false, 0, '02296063', 'FreeDiams::CA_HCDPD::DIN', 78142);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Fluticasone', 'metered-dose pump', 'R01AD08', false, 0, '02296071', 'FreeDiams::CA_HCDPD::DIN', 78143);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Levetiracetam', 'tablet', 'N03AX14', false, 0, '02296101', 'FreeDiams::CA_HCDPD::DIN', 78145);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Levetiracetam', 'tablet', 'N03AX14', false, 0, '02296128', 'FreeDiams::CA_HCDPD::DIN', 78146);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Levetiracetam', 'tablet', 'N03AX14', false, 0, '02296136', 'FreeDiams::CA_HCDPD::DIN', 78147);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ergonovine Maleate Injection Usp, 0.25mg/Ml', 'solution', 'G02AB03', false, 0, '02296144', 'FreeDiams::CA_HCDPD::DIN', 78148);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ctp 30', 'tablet', 'N06AB04', false, 0, '02296152', 'FreeDiams::CA_HCDPD::DIN', 78149);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidocaine Hydrochloride Injection Usp 2%', 'liquid', 'N01BB02', false, 0, '02296187', 'FreeDiams::CA_HCDPD::DIN', 78152);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidocaine Hydrochloride Injection, Usp 1%', 'solution', 'N01BB02', false, 0, '02296195', 'FreeDiams::CA_HCDPD::DIN', 78153);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra-Fluid Body Milk Sun Protection Spf 15', 'lotion', 'D02BA30', false, 0, '02296209', 'FreeDiams::CA_HCDPD::DIN', 78154);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Face Multi-Protection Sun Cream Spf 15', 'cream', 'D02BA30', false, 0, '02296217', 'FreeDiams::CA_HCDPD::DIN', 78156);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spearmint Lip Balm', 'ointment', 'D02BA30', false, 0, '02296233', 'FreeDiams::CA_HCDPD::DIN', 78157);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eloxatin', 'powder for solution', 'L01XA03', false, 0, '02296268', 'FreeDiams::CA_HCDPD::DIN', 78159);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eloxatin', 'powder for solution', 'L01XA03', false, 0, '02296276', 'FreeDiams::CA_HCDPD::DIN', 78160);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eloxatin', 'solution', 'L01XA03', false, 0, '02296284', 'FreeDiams::CA_HCDPD::DIN', 78161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Hydra Bright Skin-Tone Perfecting Moisturizer Spf 15', 'cream', 'D02BA30', false, 0, '02296306', 'FreeDiams::CA_HCDPD::DIN', 78164);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elaprase', 'solution', 'A16AB09', false, 0, '02296314', 'FreeDiams::CA_HCDPD::DIN', 78165);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bismuth (Cherry Flavour)', 'liquid', 'A07BB', false, 0, '02296330', 'FreeDiams::CA_HCDPD::DIN', 78167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Ondansetron', 'tablet', 'A04AA01', false, 0, '02296349', 'FreeDiams::CA_HCDPD::DIN', 78168);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Ondansetron', 'tablet', 'A04AA01', false, 0, '02296357', 'FreeDiams::CA_HCDPD::DIN', 78169);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tridural', 'tablet (extended-release)', 'N02AX02', false, 0, '02296381', 'FreeDiams::CA_HCDPD::DIN', 78172);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tridural', 'tablet (extended-release)', 'N02AX02', false, 0, '02296403', 'FreeDiams::CA_HCDPD::DIN', 78173);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tridural', 'tablet (extended-release)', 'N02AX02', false, 0, '02296411', 'FreeDiams::CA_HCDPD::DIN', 78174);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Omeprazole', 'capsule (delayed release)', 'A02BC01', false, 0, '02296438', 'FreeDiams::CA_HCDPD::DIN', 78175);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Omeprazole', 'capsule (delayed release)', 'A02BC01', false, 0, '02296446', 'FreeDiams::CA_HCDPD::DIN', 78176);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Engerix-B          (Pediatric Dose)', 'suspension', 'J07BC01', false, 0, '02296454', 'FreeDiams::CA_HCDPD::DIN', 78178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advagraf', 'capsule (extended release)', 'L04AD02', false, 0, '02296462', 'FreeDiams::CA_HCDPD::DIN', 78179);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advagraf', 'capsule (extended release)', 'L04AD02', false, 0, '02296470', 'FreeDiams::CA_HCDPD::DIN', 78180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advagraf', 'capsule (extended release)', 'L04AD02', false, 0, '02296489', 'FreeDiams::CA_HCDPD::DIN', 78181);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sysco Disinfectant And Liquid Sanitizer', 'solution', 'V07AV', false, 0, '02296500', 'FreeDiams::CA_HCDPD::DIN', 78183);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bis-O-Net #6', 'liquid', 'V07AV', false, 0, '02296519', 'FreeDiams::CA_HCDPD::DIN', 78184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Quetiapine', 'tablet', 'N05AH04', false, 0, '02296551', 'FreeDiams::CA_HCDPD::DIN', 78188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Quetiapine', 'tablet', 'N05AH04', false, 0, '02296578', 'FreeDiams::CA_HCDPD::DIN', 78189);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Quetiapine', 'tablet', 'N05AH04', false, 0, '02296594', 'FreeDiams::CA_HCDPD::DIN', 78191);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Quetiapine', 'tablet', 'N05AH04', false, 0, '02296608', 'FreeDiams::CA_HCDPD::DIN', 78192);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Zopiclone', 'tablet', 'N05CF01', false, 0, '02296616', 'FreeDiams::CA_HCDPD::DIN', 78196);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paclitaxel For Injection', 'solution', 'L01CD01', false, 0, '02296624', 'FreeDiams::CA_HCDPD::DIN', 78198);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Rabeprazole Ec', 'tablet (delayed-release)', 'A02BC04', false, 0, '02296632', 'FreeDiams::CA_HCDPD::DIN', 78199);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Rabeprazole Ec', 'tablet (delayed-release)', 'A02BC04', false, 0, '02296640', 'FreeDiams::CA_HCDPD::DIN', 78200);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Seasonale', 'tablet', 'G03AA07', false, 0, '02296659', 'FreeDiams::CA_HCDPD::DIN', 78201);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterrad 100nx Cassette', 'liquid', 'V07AV', false, 0, '02296667', 'FreeDiams::CA_HCDPD::DIN', 78203);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoprolol - 25', 'tablet', 'C07AB02', false, 0, '02296713', 'FreeDiams::CA_HCDPD::DIN', 78208);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lucentis', 'solution', 'S01LA04', false, 0, '02296810', 'FreeDiams::CA_HCDPD::DIN', 78217);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra-Fluid Body Milk Sun Protection Spf 30', 'lotion', 'D02BA30', false, 0, '02296829', 'FreeDiams::CA_HCDPD::DIN', 78218);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kids Enfants Splash 50 Spf/Fps Sunscreen Spray Ecran Solaire En Vaporisateur', 'spray', 'D02BA30', false, 0, '02296837', 'FreeDiams::CA_HCDPD::DIN', 78219);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Face Multi-Protection Sun Cream Spf 30', 'cream', 'D02BA30', false, 0, '02296845', 'FreeDiams::CA_HCDPD::DIN', 78220);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Face Multi-Protection Sun Cream Spf 50', 'cream', 'D02BA30', false, 0, '02296853', 'FreeDiams::CA_HCDPD::DIN', 78221);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kids Tear Free Sans Larmes Sunscreen Spray Écran Solaire En Vaporisateur Pour Enfants Spf Fps 50', 'spray', 'D02BA30', false, 0, '02296861', 'FreeDiams::CA_HCDPD::DIN', 78222);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cialis', 'tablet', 'G04BE08', false, 0, '02296888', 'FreeDiams::CA_HCDPD::DIN', 78223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cialis', 'tablet', 'G04BE08', false, 0, '02296896', 'FreeDiams::CA_HCDPD::DIN', 78224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Surface Management & Treatment System (Smts) Part A', 'liquid', 'V07AV', false, 0, '02296950', 'FreeDiams::CA_HCDPD::DIN', 78230);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Turquoise 3', 'liquid', 'V07AV', false, 0, '02296985', 'FreeDiams::CA_HCDPD::DIN', 78233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aquamarine Disinfectant', 'liquid', 'V07AV', false, 0, '02297019', 'FreeDiams::CA_HCDPD::DIN', 78236);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quador-128 Disinfectant', 'liquid', 'V07AV', false, 0, '02297035', 'FreeDiams::CA_HCDPD::DIN', 78238);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aqua Soleil Crčme Visage Fps 30', 'cream', 'D02BA30', false, 0, '02297051', 'FreeDiams::CA_HCDPD::DIN', 78240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Almost Powder Makeup Spf 15', 'powder', 'D02BA30', false, 0, '02297183', 'FreeDiams::CA_HCDPD::DIN', 78256);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefazolin For Injection', 'powder for solution', 'J01DB04', false, 0, '02297205', 'FreeDiams::CA_HCDPD::DIN', 78258);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefazolin For Injection', 'powder for solution', 'J01DB04', false, 0, '02297213', 'FreeDiams::CA_HCDPD::DIN', 78259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tri-Tex Co Moldout Fungicide', 'liquid', 'V07AV', false, 0, '02297221', 'FreeDiams::CA_HCDPD::DIN', 78260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Liquid Nitrogen Nf', 'liquid', 'V03AN04', false, 0, '02297248', 'FreeDiams::CA_HCDPD::DIN', 78261);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mirapex', 'tablet', 'N04BC05', false, 0, '02297256', 'FreeDiams::CA_HCDPD::DIN', 78262);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Pramipexole', 'tablet', 'N04BC05', false, 0, '02297302', 'FreeDiams::CA_HCDPD::DIN', 78267);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Pramipexole', 'tablet', 'N04BC05', false, 0, '02297310', 'FreeDiams::CA_HCDPD::DIN', 78268);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Pramipexole', 'tablet', 'N04BC05', false, 0, '02297329', 'FreeDiams::CA_HCDPD::DIN', 78269);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Pramipexole', 'tablet', 'N04BC05', false, 0, '02297337', 'FreeDiams::CA_HCDPD::DIN', 78270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rescue', 'gel', 'V07AV', false, 0, '02297345', 'FreeDiams::CA_HCDPD::DIN', 78271);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Levetiracetam', 'tablet', 'N03AX14', false, 0, '02297353', 'FreeDiams::CA_HCDPD::DIN', 78272);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Levetiracetam', 'tablet', 'N03AX14', false, 0, '02297361', 'FreeDiams::CA_HCDPD::DIN', 78273);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Levetiracetam', 'tablet', 'N03AX14', false, 0, '02297388', 'FreeDiams::CA_HCDPD::DIN', 78274);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Levetiracetam', 'tablet', 'N03AX14', false, 0, '02297396', 'FreeDiams::CA_HCDPD::DIN', 78275);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Levetiracetam', 'tablet', 'N03AX14', false, 0, '02297418', 'FreeDiams::CA_HCDPD::DIN', 78276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Levetiracetam', 'tablet', 'N03AX14', false, 0, '02297426', 'FreeDiams::CA_HCDPD::DIN', 78277);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('High Definition Foundation', 'emulsion', 'D02BA30', false, 0, '02297450', 'FreeDiams::CA_HCDPD::DIN', 78278);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Loris - Bzk', 'wipe', 'D08AJ01', false, 0, '02297434', 'FreeDiams::CA_HCDPD::DIN', 78279);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Loris - I.V.', 'swab', 'D08AC52', false, 0, '02297442', 'FreeDiams::CA_HCDPD::DIN', 78280);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Amlodipine', 'tablet', 'C08CA01', false, 0, '02297477', 'FreeDiams::CA_HCDPD::DIN', 78282);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Amlodipine', 'tablet', 'C08CA01', false, 0, '02297485', 'FreeDiams::CA_HCDPD::DIN', 78283);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Amlodipine', 'tablet', 'C08CA01', false, 0, '02297493', 'FreeDiams::CA_HCDPD::DIN', 78284);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mezavant', 'tablet (delayed and extended release)', 'A07EC02', false, 0, '02297558', 'FreeDiams::CA_HCDPD::DIN', 78289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Azithromycin For Injection', 'powder for solution', 'J01FA10', false, 0, '02297566', 'FreeDiams::CA_HCDPD::DIN', 78290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Motrin Ib Liquid Gels', 'capsule', 'M01AE01', false, 0, '02297582', 'FreeDiams::CA_HCDPD::DIN', 78292);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artistry Pure White Moisturiser I', 'lotion', 'D02BA30', false, 0, '02297639', 'FreeDiams::CA_HCDPD::DIN', 78297);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Photo Finish', 'emulsion', 'D02BA30', false, 0, '02297663', 'FreeDiams::CA_HCDPD::DIN', 78301);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Opti-Free Replenish Multi-Purpose Disinfecting Solution', 'solution', 'S01XA20', false, 0, '02297671', 'FreeDiams::CA_HCDPD::DIN', 78302);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neostrata Daytime Smoothing Cream Level 1', 'cream', 'D02BA30', false, 0, '02297698', 'FreeDiams::CA_HCDPD::DIN', 78304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Lisinopril Hctz', 'tablet', 'C09BA03', false, 0, '02297736', 'FreeDiams::CA_HCDPD::DIN', 78307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Lisinopril Hctz', 'tablet', 'C09BA03', false, 0, '02297744', 'FreeDiams::CA_HCDPD::DIN', 78308);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Lisinopril Hctz', 'tablet', 'C09BA03', false, 0, '02297752', 'FreeDiams::CA_HCDPD::DIN', 78309);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02297760', 'FreeDiams::CA_HCDPD::DIN', 78310);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Spray Spf 30', 'spray', 'D02BA30', false, 0, '02297779', 'FreeDiams::CA_HCDPD::DIN', 78311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actonel', 'tablet', 'M05BA07', false, 0, '02297787', 'FreeDiams::CA_HCDPD::DIN', 78312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gliclazide Mr', 'tablet (extended-release)', 'A10BB09', false, 0, '02297795', 'FreeDiams::CA_HCDPD::DIN', 78313);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metrogel 1%', 'gel', 'D06BX01', false, 0, '02297809', 'FreeDiams::CA_HCDPD::DIN', 78314);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultimate Day Age Defying Cream Creme Defi-Age Spf/Fps 25', 'cream', 'D02BA30', false, 0, '02297833', 'FreeDiams::CA_HCDPD::DIN', 78317);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hyzaar', 'tablet', 'C09DA01', false, 0, '02297841', 'FreeDiams::CA_HCDPD::DIN', 78318);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Ondansetron', 'tablet', 'A04AA01', false, 0, '02297868', 'FreeDiams::CA_HCDPD::DIN', 78319);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Ondansetron', 'tablet', 'A04AA01', false, 0, '02297876', 'FreeDiams::CA_HCDPD::DIN', 78320);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pert Plus Dandruff Control', 'shampoo', 'D11AX12', false, 0, '02297892', 'FreeDiams::CA_HCDPD::DIN', 78321);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Priorix-Tetra', 'powder for solution', 'J07BD54', false, 0, '02297884', 'FreeDiams::CA_HCDPD::DIN', 78322);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Pioglitazone', 'tablet', 'A10BG03', false, 0, '02297906', 'FreeDiams::CA_HCDPD::DIN', 78323);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Pioglitazone', 'tablet', 'A10BG03', false, 0, '02297914', 'FreeDiams::CA_HCDPD::DIN', 78324);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Pioglitazone', 'tablet', 'A10BG03', false, 0, '02297922', 'FreeDiams::CA_HCDPD::DIN', 78325);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actif 3000 Nettoyant Degraissant Desinfectant/Cleaner Degreaser Disinfectant', 'solution', 'V07AV', false, 0, '02297930', 'FreeDiams::CA_HCDPD::DIN', 78326);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triple Antibiotic Ointment', 'ointment', 'D06AX30', false, 0, '02297949', 'FreeDiams::CA_HCDPD::DIN', 78327);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Temazepam', 'capsule', 'N05CD07', false, 0, '02297957', 'FreeDiams::CA_HCDPD::DIN', 78328);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Temazepam', 'capsule', 'N05CD07', false, 0, '02297965', 'FreeDiams::CA_HCDPD::DIN', 78329);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Terbinafine', 'tablet', 'D01BA02', false, 0, '02297973', 'FreeDiams::CA_HCDPD::DIN', 78330);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 15 Self Tanner Lotion', 'lotion', 'D02BA30', false, 0, '02297981', 'FreeDiams::CA_HCDPD::DIN', 78331);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('2% Lidocaine And Epinephrine 1:100,000 Injection Usp', 'liquid', 'N01BB52', false, 0, '02298007', 'FreeDiams::CA_HCDPD::DIN', 78332);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lice Killing Shampoo', 'shampoo', 'P03AC51', false, 0, '02298015', 'FreeDiams::CA_HCDPD::DIN', 78333);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravastatin', 'tablet', 'C10AA03', false, 0, '02301814', 'FreeDiams::CA_HCDPD::DIN', 78715);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dandruff Shampoo (Dry Scalp Or Classic 2 In 1)', 'shampoo', 'D11AX12', false, 0, '02298023', 'FreeDiams::CA_HCDPD::DIN', 78334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dandruff Shampoo (Classic Or Fresh/Cool & Fresh Or Silky Shine 2 In 1)', 'shampoo', 'D11AX12', false, 0, '02298031', 'FreeDiams::CA_HCDPD::DIN', 78335);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Rabeprazole', 'tablet (enteric-coated)', 'A02BC04', false, 0, '02298074', 'FreeDiams::CA_HCDPD::DIN', 78338);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Rabeprazole', 'tablet (enteric-coated)', 'A02BC04', false, 0, '02298082', 'FreeDiams::CA_HCDPD::DIN', 78339);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Safeway Triclosan Antibacterial Liquid Soap', 'liquid', 'D08AE04', false, 0, '02298112', 'FreeDiams::CA_HCDPD::DIN', 78342);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Beauté Initiale-Fluide Énergisant Multi-Protection', 'emulsion', 'D02BA30', false, 0, '02298120', 'FreeDiams::CA_HCDPD::DIN', 78343);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Beauté Initiale-Crčme Énergisante Multi-Protection', 'cream', 'D02BA30', false, 0, '02298147', 'FreeDiams::CA_HCDPD::DIN', 78345);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desloratadine Allergy Control', 'tablet', 'R06AX27', false, 0, '02298155', 'FreeDiams::CA_HCDPD::DIN', 78346);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Docusate Sodium', 'capsule', 'A06AA02', false, 0, '02298163', 'FreeDiams::CA_HCDPD::DIN', 78347);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nighttime Cold And Flu-In-One Extra Strength', 'tablet', 'N02BE51', false, 0, '02298171', 'FreeDiams::CA_HCDPD::DIN', 78348);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Loperamide', 'tablet', 'A07DA03', false, 0, '02298198', 'FreeDiams::CA_HCDPD::DIN', 78349);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Lorazepam', 'tablet', 'N05BA06', false, 0, '02298201', 'FreeDiams::CA_HCDPD::DIN', 78350);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Lorazepam', 'tablet', 'N05BA06', false, 0, '02298228', 'FreeDiams::CA_HCDPD::DIN', 78351);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Lorazepam', 'tablet', 'N05BA06', false, 0, '02298236', 'FreeDiams::CA_HCDPD::DIN', 78352);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02298279', 'FreeDiams::CA_HCDPD::DIN', 78357);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02298287', 'FreeDiams::CA_HCDPD::DIN', 78358);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02298295', 'FreeDiams::CA_HCDPD::DIN', 78359);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Champix', 'kit', 'N07BA03', false, 0, '02298309', 'FreeDiams::CA_HCDPD::DIN', 78360);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Risedronate', 'tablet', 'M05BA07', false, 0, '02298376', 'FreeDiams::CA_HCDPD::DIN', 78367);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Risedronate', 'tablet', 'M05BA07', false, 0, '02298384', 'FreeDiams::CA_HCDPD::DIN', 78368);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Risedronate', 'tablet', 'M05BA07', false, 0, '02298392', 'FreeDiams::CA_HCDPD::DIN', 78369);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Valacyclovir', 'tablet', 'J05AB11', false, 0, '02298457', 'FreeDiams::CA_HCDPD::DIN', 78376);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperdal Consta', 'powder for suspension, sustained-release', 'N05AX08', false, 0, '02298465', 'FreeDiams::CA_HCDPD::DIN', 78377);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clorox Disinfecting Toilet Bowl Cleaner With Bleach-1', 'liquid', 'V07AV', false, 0, '02298473', 'FreeDiams::CA_HCDPD::DIN', 78378);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diphenhydramine Hydrochloride Elixir Usp', 'elixir', 'R06AA02', false, 0, '02298503', 'FreeDiams::CA_HCDPD::DIN', 78380);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aviane 21', 'tablet', 'G03AA07', false, 0, '02298538', 'FreeDiams::CA_HCDPD::DIN', 78383);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aviane 28', 'tablet', 'G03AA07', false, 0, '02298546', 'FreeDiams::CA_HCDPD::DIN', 78384);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neostrata Daytime Smoothing Cream Level 2', 'cream', 'D02BA30', false, 0, '02298554', 'FreeDiams::CA_HCDPD::DIN', 78385);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Tamsulosin', 'capsule (extended release)', 'G04CA02', false, 0, '02298570', 'FreeDiams::CA_HCDPD::DIN', 78387);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avamys', 'spray, metered dose', 'R01AD12', false, 0, '02298589', 'FreeDiams::CA_HCDPD::DIN', 78388);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zeldox', 'capsule', 'N05AE04', false, 0, '02298597', 'FreeDiams::CA_HCDPD::DIN', 78389);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zeldox', 'capsule', 'N05AE04', false, 0, '02298600', 'FreeDiams::CA_HCDPD::DIN', 78392);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zeldox', 'capsule', 'N05AE04', false, 0, '02298619', 'FreeDiams::CA_HCDPD::DIN', 78393);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zeldox', 'capsule', 'N05AE04', false, 0, '02298627', 'FreeDiams::CA_HCDPD::DIN', 78394);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Levofloxacin', 'tablet', 'J01MA12', false, 0, '02298635', 'FreeDiams::CA_HCDPD::DIN', 78395);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Levofloxacin', 'tablet', 'J01MA12', false, 0, '02298643', 'FreeDiams::CA_HCDPD::DIN', 78396);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Levofloxacin', 'tablet', 'J01MA12', false, 0, '02298651', 'FreeDiams::CA_HCDPD::DIN', 78397);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artistry Essentials Hydrating Lotion', 'lotion', 'D02BA30', false, 0, '02298678', 'FreeDiams::CA_HCDPD::DIN', 78398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artistry Essentials Balancing Lotion', 'lotion', 'D02BA30', false, 0, '02298686', 'FreeDiams::CA_HCDPD::DIN', 78399);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quat Plus', 'liquid', 'V07AV', false, 0, '02298694', 'FreeDiams::CA_HCDPD::DIN', 78400);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 8 Lotion', 'lotion', 'D02BA30', false, 0, '02298716', 'FreeDiams::CA_HCDPD::DIN', 78402);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acid Reducer', 'tablet', 'A02BA02', false, 0, '02298740', 'FreeDiams::CA_HCDPD::DIN', 78405);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gemcitabine For Injection, Usp', 'powder for solution', 'L01BC05', false, 0, '02298775', 'FreeDiams::CA_HCDPD::DIN', 78408);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gemcitabine For Injection, Usp', 'powder for solution', 'L01BC05', false, 0, '02298783', 'FreeDiams::CA_HCDPD::DIN', 78409);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Emend', 'capsule', 'A04AD12', false, 0, '02298791', 'FreeDiams::CA_HCDPD::DIN', 78410);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Emend', 'capsule', 'A04AD12', false, 0, '02298805', 'FreeDiams::CA_HCDPD::DIN', 78411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Emend Tri-Pack', 'kit', 'A04AD12', false, 0, '02298813', 'FreeDiams::CA_HCDPD::DIN', 78412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Patriot No. 16', 'liquid', 'V07AV', false, 0, '02298856', 'FreeDiams::CA_HCDPD::DIN', 78415);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Airx 75', 'liquid', 'V07AV', false, 0, '02298864', 'FreeDiams::CA_HCDPD::DIN', 78416);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Maximum Strength Acid Reducer', 'tablet', 'A02BA02', false, 0, '02298902', 'FreeDiams::CA_HCDPD::DIN', 78429);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fix Terg-O-Cide Foaming Germicidal Cleaner', 'aerosol', 'V07AV', false, 0, '02298910', 'FreeDiams::CA_HCDPD::DIN', 78430);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ondansetron Injection, Usp', 'solution', 'A04AA01', false, 0, '02298929', 'FreeDiams::CA_HCDPD::DIN', 78432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ciclopirox', 'solution', 'D01AE14', false, 0, '02298953', 'FreeDiams::CA_HCDPD::DIN', 78435);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Quetiapine', 'tablet', 'N05AH04', false, 0, '02298996', 'FreeDiams::CA_HCDPD::DIN', 78440);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Quetiapine', 'tablet', 'N05AH04', false, 0, '02299003', 'FreeDiams::CA_HCDPD::DIN', 78441);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Quetiapine', 'tablet', 'N05AH04', false, 0, '02299038', 'FreeDiams::CA_HCDPD::DIN', 78443);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Quetiapine', 'tablet', 'N05AH04', false, 0, '02299046', 'FreeDiams::CA_HCDPD::DIN', 78444);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Quetiapine', 'tablet', 'N05AH04', false, 0, '02299054', 'FreeDiams::CA_HCDPD::DIN', 78445);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Quetiapine', 'tablet', 'N05AH04', false, 0, '02299062', 'FreeDiams::CA_HCDPD::DIN', 78446);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Quetiapine', 'tablet', 'N05AH04', false, 0, '02299089', 'FreeDiams::CA_HCDPD::DIN', 78448);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Quetiapine', 'tablet', 'N05AH04', false, 0, '02299097', 'FreeDiams::CA_HCDPD::DIN', 78449);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('20 (Meq)Mmol/L Potassium Chloride In/Et 0.9% Chlorure De Sodium/Sodium Chloride Injection Usp', 'solution', 'B05BB01', false, 0, '02299100', 'FreeDiams::CA_HCDPD::DIN', 78450);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('40(Meq)Mmol/L Potassium Chloride In/Et 0.9% Chlorure De Sodium/Sodium Chloride Injection Usp', 'solution', 'B05BB01', false, 0, '02299119', 'FreeDiams::CA_HCDPD::DIN', 78451);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('20(Meq)Mmol/L Potassium Chloride Plus 5% Dextrose & 0.9% Chlorure De Sodium/Sodium Chloride Injection Usp', 'solution', 'B05BB02', false, 0, '02299127', 'FreeDiams::CA_HCDPD::DIN', 78452);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('40 (Meq)Mmol/L Potassium Chloride Plus 5% Dextrose & 0.9% Chlorure De Sodium/Sodium Chloride Injection Usp', 'solution', 'B05BB02', false, 0, '02299135', 'FreeDiams::CA_HCDPD::DIN', 78453);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Water For Injection Usp', 'solution', 'V07AB', false, 0, '02299186', 'FreeDiams::CA_HCDPD::DIN', 78457);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ralivia', 'tablet (extended-release)', 'N02AX02', false, 0, '02299194', 'FreeDiams::CA_HCDPD::DIN', 78458);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ralivia', 'tablet (extended-release)', 'N02AX02', false, 0, '02299208', 'FreeDiams::CA_HCDPD::DIN', 78459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ralivia', 'tablet (extended-release)', 'N02AX02', false, 0, '02299216', 'FreeDiams::CA_HCDPD::DIN', 78460);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Terbinafine', 'tablet', 'D01BA02', false, 0, '02299275', 'FreeDiams::CA_HCDPD::DIN', 78466);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Oxybutynin', 'tablet', 'G04BD04', false, 0, '02299364', 'FreeDiams::CA_HCDPD::DIN', 78474);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ramipril', 'capsule', 'C09AA05', false, 0, '02299372', 'FreeDiams::CA_HCDPD::DIN', 78477);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Octreotide Injection', 'solution', 'H01CB02', false, 0, '02299437', 'FreeDiams::CA_HCDPD::DIN', 78483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Octreotide Injection', 'solution', 'H01CB02', false, 0, '02299445', 'FreeDiams::CA_HCDPD::DIN', 78484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Octreotide Injection', 'solution', 'H01CB02', false, 0, '02299453', 'FreeDiams::CA_HCDPD::DIN', 78485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pedi-Purge', 'liquid', 'V07AV', false, 0, '02299488', 'FreeDiams::CA_HCDPD::DIN', 78487);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Pantoprazole', 'tablet (delayed-release)', 'A02BC02', false, 0, '02299585', 'FreeDiams::CA_HCDPD::DIN', 78496);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Dorzo-Timop', 'solution', 'S01ED51', false, 0, '02299615', 'FreeDiams::CA_HCDPD::DIN', 78499);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piperacillin Sodium/Tazobactam Sodium Powder For Injection', 'powder for solution', 'J01CR05', false, 0, '02299623', 'FreeDiams::CA_HCDPD::DIN', 78500);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piperacillin Sodium/Tazobactam Sodium Powder For Injection', 'powder for solution', 'J01CR05', false, 0, '02299631', 'FreeDiams::CA_HCDPD::DIN', 78501);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piperacillin Sodium/Tazobactam Sodium Powder For Injection', 'powder for solution', 'J01CR05', false, 0, '02299658', 'FreeDiams::CA_HCDPD::DIN', 78502);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alendronate-Fc', 'tablet', 'M05BA04', false, 0, '02299712', 'FreeDiams::CA_HCDPD::DIN', 78508);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clobex Spray', 'solution', 'D07AD01', false, 0, '02299739', 'FreeDiams::CA_HCDPD::DIN', 78510);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Non-Aerosol Antimicrobial Foam Hand Rub', 'liquid', 'D08AJ01', false, 0, '02299747', 'FreeDiams::CA_HCDPD::DIN', 78511);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Auro-Mirtazapine Od', 'tablet (orally disintegrating)', 'N06AX11', false, 0, '02299801', 'FreeDiams::CA_HCDPD::DIN', 78516);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Auro-Mirtazapine Od', 'tablet (orally disintegrating)', 'N06AX11', false, 0, '02299828', 'FreeDiams::CA_HCDPD::DIN', 78517);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Auro-Mirtazapine Od', 'tablet (orally disintegrating)', 'N06AX11', false, 0, '02299836', 'FreeDiams::CA_HCDPD::DIN', 78518);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Celsentri', 'tablet', 'J05AX09', false, 0, '02299844', 'FreeDiams::CA_HCDPD::DIN', 78519);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Celsentri', 'tablet', 'J05AX09', false, 0, '02299852', 'FreeDiams::CA_HCDPD::DIN', 78520);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Lisinopril Z', 'tablet', 'C09AA03', false, 0, '02299879', 'FreeDiams::CA_HCDPD::DIN', 78522);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Lisinopril Z', 'tablet', 'C09AA03', false, 0, '02299887', 'FreeDiams::CA_HCDPD::DIN', 78523);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Lisinopril Z', 'tablet', 'C09AA03', false, 0, '02299895', 'FreeDiams::CA_HCDPD::DIN', 78524);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cubicin', 'powder for solution', 'J01XX09', false, 0, '02299909', 'FreeDiams::CA_HCDPD::DIN', 78525);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Scalp Relief Dandruff Control Leave-In Treatment', 'gel', 'D11AX12', false, 0, '02299917', 'FreeDiams::CA_HCDPD::DIN', 78526);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atriance', 'solution', 'L01BB07', false, 0, '02299925', 'FreeDiams::CA_HCDPD::DIN', 78527);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Enalapril', 'tablet', 'C09AA02', false, 0, '02299933', 'FreeDiams::CA_HCDPD::DIN', 78528);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Enalapril', 'tablet', 'C09AA02', false, 0, '02299941', 'FreeDiams::CA_HCDPD::DIN', 78529);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Enalapril', 'tablet', 'C09AA02', false, 0, '02299968', 'FreeDiams::CA_HCDPD::DIN', 78530);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Enalapril', 'tablet', 'C09AA02', false, 0, '02299976', 'FreeDiams::CA_HCDPD::DIN', 78531);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Enalapril', 'tablet', 'C09AA02', false, 0, '02299984', 'FreeDiams::CA_HCDPD::DIN', 78532);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Enalapril', 'tablet', 'C09AA02', false, 0, '02299992', 'FreeDiams::CA_HCDPD::DIN', 78533);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Enalapril', 'tablet', 'C09AA02', false, 0, '02300001', 'FreeDiams::CA_HCDPD::DIN', 78534);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Enalapril', 'tablet', 'C09AA02', false, 0, '02300028', 'FreeDiams::CA_HCDPD::DIN', 78535);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Enalapril', 'tablet', 'C09AA02', false, 0, '02300036', 'FreeDiams::CA_HCDPD::DIN', 78536);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Enalapril', 'tablet', 'C09AA02', false, 0, '02300044', 'FreeDiams::CA_HCDPD::DIN', 78537);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Enalapril', 'tablet', 'C09AA02', false, 0, '02300052', 'FreeDiams::CA_HCDPD::DIN', 78538);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Enalapril', 'tablet', 'C09AA02', false, 0, '02300060', 'FreeDiams::CA_HCDPD::DIN', 78539);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Enalapril', 'tablet', 'C09AA02', false, 0, '02300079', 'FreeDiams::CA_HCDPD::DIN', 78540);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Enalapril', 'tablet', 'C09AA02', false, 0, '02300087', 'FreeDiams::CA_HCDPD::DIN', 78541);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Enalapril', 'tablet', 'C09AA02', false, 0, '02300095', 'FreeDiams::CA_HCDPD::DIN', 78542);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Enalapril', 'tablet', 'C09AA02', false, 0, '02300109', 'FreeDiams::CA_HCDPD::DIN', 78543);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Enalapril', 'tablet', 'C09AA02', false, 0, '02300117', 'FreeDiams::CA_HCDPD::DIN', 78544);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Enalapril', 'tablet', 'C09AA02', false, 0, '02300125', 'FreeDiams::CA_HCDPD::DIN', 78545);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Enalapril', 'tablet', 'C09AA02', false, 0, '02300133', 'FreeDiams::CA_HCDPD::DIN', 78546);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Enalapril', 'tablet', 'C09AA02', false, 0, '02300141', 'FreeDiams::CA_HCDPD::DIN', 78547);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Seroquel Xr', 'tablet (extended-release)', 'N05AH04', false, 0, '02300184', 'FreeDiams::CA_HCDPD::DIN', 78550);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Seroquel Xr', 'tablet (extended-release)', 'N05AH04', false, 0, '02300192', 'FreeDiams::CA_HCDPD::DIN', 78551);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Seroquel Xr', 'tablet (extended-release)', 'N05AH04', false, 0, '02300206', 'FreeDiams::CA_HCDPD::DIN', 78552);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Seroquel Xr', 'tablet (extended-release)', 'N05AH04', false, 0, '02300214', 'FreeDiams::CA_HCDPD::DIN', 78553);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Enalapril/Hctz', 'tablet', 'C09BA02', false, 0, '02300222', 'FreeDiams::CA_HCDPD::DIN', 78554);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Enalapril/Hctz', 'tablet', 'C09BA02', false, 0, '02300230', 'FreeDiams::CA_HCDPD::DIN', 78555);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balminil Decongest', 'solution', 'R01AA07', false, 0, '02300257', 'FreeDiams::CA_HCDPD::DIN', 78557);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Decongest Nasal', 'solution', 'R01AA07', false, 0, '02300265', 'FreeDiams::CA_HCDPD::DIN', 78558);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Invega', 'tablet (extended-release)', 'N05AX13', false, 0, '02300273', 'FreeDiams::CA_HCDPD::DIN', 78559);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Invega', 'tablet (extended-release)', 'N05AX13', false, 0, '02300281', 'FreeDiams::CA_HCDPD::DIN', 78560);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Invega', 'tablet (extended-release)', 'N05AX13', false, 0, '02300303', 'FreeDiams::CA_HCDPD::DIN', 78561);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Detco Hd', 'liquid', 'V07AV', false, 0, '02300338', 'FreeDiams::CA_HCDPD::DIN', 78563);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Cepacol Sore Throat', 'lozenge', 'R02AA56', false, 0, '02300389', 'FreeDiams::CA_HCDPD::DIN', 78568);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dura Force Nettoyant Desinfectant', 'liquid', 'V07AV', false, 0, '02300397', 'FreeDiams::CA_HCDPD::DIN', 78569);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetylcysteine Injection 200 Mg/Ml', 'liquid', 'R05CB01', false, 0, '02300435', 'FreeDiams::CA_HCDPD::DIN', 78573);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crystapen 5m I.U.', 'powder for solution', 'J01CE01', false, 0, '02300443', 'FreeDiams::CA_HCDPD::DIN', 78574);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glumetza', 'tablet (extended-release)', 'A10BA02', false, 0, '02300451', 'FreeDiams::CA_HCDPD::DIN', 78575);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Pantoprazole', 'tablet (delayed-release)', 'A02BC02', false, 0, '02300486', 'FreeDiams::CA_HCDPD::DIN', 78576);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Beauté Initiale Eye', 'cream', 'D02BA30', false, 0, '02300494', 'FreeDiams::CA_HCDPD::DIN', 78578);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nexium', 'granules for suspension, delayed release', 'A02BC05', false, 0, '02300524', 'FreeDiams::CA_HCDPD::DIN', 78581);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dermotic Oil Ear Drops', 'solution', 'S02BA08', false, 0, '02300559', 'FreeDiams::CA_HCDPD::DIN', 78584);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Picodan', 'powder for solution', 'A06AB58', false, 0, '02300583', 'FreeDiams::CA_HCDPD::DIN', 78587);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rotarix', 'suspension', 'J07BH01', false, 0, '02300591', 'FreeDiams::CA_HCDPD::DIN', 78588);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Replenishing Moisture Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02300605', 'FreeDiams::CA_HCDPD::DIN', 78589);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimenhydrinate Injection Usp 250mg/5ml (50mg/Ml)', 'solution', 'R06AA02', false, 0, '02300648', 'FreeDiams::CA_HCDPD::DIN', 78595);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accel Hydrotherapy +', 'solution', 'V07AV', false, 0, '02300656', 'FreeDiams::CA_HCDPD::DIN', 78598);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sanidate Disinfectant', 'solution', 'V07AV', false, 0, '02300664', 'FreeDiams::CA_HCDPD::DIN', 78600);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Enalapril', 'tablet', 'C09AA02', false, 0, '02300680', 'FreeDiams::CA_HCDPD::DIN', 78601);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atripla', 'tablet', 'J05AR06', false, 0, '02300699', 'FreeDiams::CA_HCDPD::DIN', 78602);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('45 Spf High Protection Uva Uvb Cream', 'cream', 'D02BA30', false, 0, '02300710', 'FreeDiams::CA_HCDPD::DIN', 78604);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf20 Uva/Uvb', 'spray', 'D02BA30', false, 0, '02300729', 'FreeDiams::CA_HCDPD::DIN', 78605);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf40 Uva/Uvb', 'cream', 'D02BA30', false, 0, '02300737', 'FreeDiams::CA_HCDPD::DIN', 78606);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Sport Clear Continuous Spray Sunscreen Spf 50', 'aerosol', 'D02BA30', false, 0, '02300753', 'FreeDiams::CA_HCDPD::DIN', 78611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gas X Ultra Strength', 'capsule', 'A03AX13', false, 0, '02300761', 'FreeDiams::CA_HCDPD::DIN', 78612);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Enalapril', 'tablet', 'C09AA02', false, 0, '02300796', 'FreeDiams::CA_HCDPD::DIN', 78614);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Enalapril', 'tablet', 'C09AA02', false, 0, '02300818', 'FreeDiams::CA_HCDPD::DIN', 78615);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Enalapril', 'tablet', 'C09AA02', false, 0, '02300826', 'FreeDiams::CA_HCDPD::DIN', 78616);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Enalapril', 'tablet', 'C09AA02', false, 0, '02300834', 'FreeDiams::CA_HCDPD::DIN', 78617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dayquil Cold & Flu', 'liquid', 'N02BE51', false, 0, '02300842', 'FreeDiams::CA_HCDPD::DIN', 78620);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Total Effects 7-In-1 Anti-Aging Uv Moisturizer Plus Touch Of Foundation', 'suspension', 'D02BA30', false, 0, '02300850', 'FreeDiams::CA_HCDPD::DIN', 78621);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amiodarone', 'tablet', 'C01BD01', false, 0, '02300893', 'FreeDiams::CA_HCDPD::DIN', 78625);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Simvastatin', 'tablet', 'C10AA01', false, 0, '02300907', 'FreeDiams::CA_HCDPD::DIN', 78626);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Simvastatin', 'tablet', 'C10AA01', false, 0, '02300915', 'FreeDiams::CA_HCDPD::DIN', 78627);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Simvastatin', 'tablet', 'C10AA01', false, 0, '02300923', 'FreeDiams::CA_HCDPD::DIN', 78628);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Clear Continuous Spray Sunscreen Spf 50', 'aerosol', 'D02BA30', false, 0, '02300966', 'FreeDiams::CA_HCDPD::DIN', 78629);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Simvastatin', 'tablet', 'C10AA01', false, 0, '02300931', 'FreeDiams::CA_HCDPD::DIN', 78630);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Lisinopril', 'tablet', 'C09AA03', false, 0, '02300958', 'FreeDiams::CA_HCDPD::DIN', 78631);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Simvastatin', 'tablet', 'C10AA01', false, 0, '02300974', 'FreeDiams::CA_HCDPD::DIN', 78632);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Lisinopril', 'tablet', 'C09AA03', false, 0, '02300982', 'FreeDiams::CA_HCDPD::DIN', 78633);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Lisinopril', 'tablet', 'C09AA03', false, 0, '02300990', 'FreeDiams::CA_HCDPD::DIN', 78634);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Oil Free Sunscreen Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02301008', 'FreeDiams::CA_HCDPD::DIN', 78635);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epirubicin Hydrochloride For Injection', 'powder for solution', 'L01DB03', false, 0, '02301067', 'FreeDiams::CA_HCDPD::DIN', 78641);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Pantoprazole', 'tablet (delayed-release)', 'A02BC02', false, 0, '02301075', 'FreeDiams::CA_HCDPD::DIN', 78642);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Pantoprazole', 'tablet (delayed-release)', 'A02BC02', false, 0, '02301083', 'FreeDiams::CA_HCDPD::DIN', 78643);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Protection Stick', 'cream', 'D02BA30', false, 0, '02301113', 'FreeDiams::CA_HCDPD::DIN', 78646);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Regenerist Touch Of Foundation Uv Defense Moisturizer', 'lotion', 'D02BA30', false, 0, '02301121', 'FreeDiams::CA_HCDPD::DIN', 78647);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Ramipril', 'capsule', 'C09AA05', false, 0, '02301148', 'FreeDiams::CA_HCDPD::DIN', 78648);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Ramipril', 'capsule', 'C09AA05', false, 0, '02301156', 'FreeDiams::CA_HCDPD::DIN', 78649);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Ramipril', 'capsule', 'C09AA05', false, 0, '02301164', 'FreeDiams::CA_HCDPD::DIN', 78650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Ramipril', 'capsule', 'C09AA05', false, 0, '02301172', 'FreeDiams::CA_HCDPD::DIN', 78651);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Origins Rain And Shine Liptint With Spf 10 Sunscreen', 'stick', 'D02BA02', false, 0, '02301180', 'FreeDiams::CA_HCDPD::DIN', 78652);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antherpos', 'cream', 'D02BA30', false, 0, '02301229', 'FreeDiams::CA_HCDPD::DIN', 78656);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen 8-Hour', 'tablet (extended-release)', 'N02BE01', false, 0, '02301237', 'FreeDiams::CA_HCDPD::DIN', 78657);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Long Last Glosswear Spf 15', 'liquid', 'D02BA30', false, 0, '02301245', 'FreeDiams::CA_HCDPD::DIN', 78658);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ismn', 'tablet (extended-release)', 'C01DA14', false, 0, '02301288', 'FreeDiams::CA_HCDPD::DIN', 78661);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ciprofloxacin Injection', 'solution', 'J01MA02', false, 0, '02301296', 'FreeDiams::CA_HCDPD::DIN', 78663);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sol-U-Guard Botanical 2', 'liquid', 'V07AV', false, 0, '02301318', 'FreeDiams::CA_HCDPD::DIN', 78664);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lysol Disinfectant Toilet Bowl Cleaner Deep Reach', 'liquid', 'V07AV', false, 0, '02301326', 'FreeDiams::CA_HCDPD::DIN', 78665);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Brimonidine P', 'solution', 'S01EA05', false, 0, '02301334', 'FreeDiams::CA_HCDPD::DIN', 78666);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Natrecor', 'powder for solution', 'C01DX19', false, 0, '02301393', 'FreeDiams::CA_HCDPD::DIN', 78673);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Cabergoline', 'tablet', 'G02CB03', false, 0, '02301407', 'FreeDiams::CA_HCDPD::DIN', 78674);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02301423', 'FreeDiams::CA_HCDPD::DIN', 78676);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02301431', 'FreeDiams::CA_HCDPD::DIN', 78677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02301458', 'FreeDiams::CA_HCDPD::DIN', 78678);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elizabeth Arden Intervene Makeup Spf 15 Octinoxate Lotion', 'liquid', 'D02BA02', false, 0, '02301474', 'FreeDiams::CA_HCDPD::DIN', 78680);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cymbalta', 'capsule (delayed release)', 'N06AX21', false, 0, '02301482', 'FreeDiams::CA_HCDPD::DIN', 78681);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cymbalta', 'capsule (delayed release)', 'N06AX21', false, 0, '02301490', 'FreeDiams::CA_HCDPD::DIN', 78682);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Norfloxacin', 'tablet', 'J01MA06', false, 0, '02301504', 'FreeDiams::CA_HCDPD::DIN', 78683);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soleil Protexion Invisible Touch Spf 30', 'aerosol', 'D02BA30', false, 0, '02301520', 'FreeDiams::CA_HCDPD::DIN', 78685);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soleil Protexion Invisible Touch Spf 45', 'aerosol', 'D02BA30', false, 0, '02301539', 'FreeDiams::CA_HCDPD::DIN', 78686);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutrogena Ultra Sheer Body Mist Sunscreen Spf 30', 'aerosol', 'D02BA30', false, 0, '02301563', 'FreeDiams::CA_HCDPD::DIN', 78689);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutrogena Ultra Sheer Body Mist Sunscreen Spf 45', 'aerosol', 'D02BA30', false, 0, '02301571', 'FreeDiams::CA_HCDPD::DIN', 78690);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen Oral Solution Drops 80mg/Ml', 'drops', 'N02BE01', false, 0, '02301660', 'FreeDiams::CA_HCDPD::DIN', 78697);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clear Eyes Triple Action Relief', 'solution', 'S01GA52', false, 0, '02301687', 'FreeDiams::CA_HCDPD::DIN', 78699);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Brand Sunthera 3 Sport Spf/Fps 30 Continuous Spray', 'aerosol', 'D02BA30', false, 0, '02301695', 'FreeDiams::CA_HCDPD::DIN', 78700);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Brand Sunthera 3 Spf/Fps 60 Continuous Spray', 'aerosol', 'D02BA30', false, 0, '02301709', 'FreeDiams::CA_HCDPD::DIN', 78701);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dimethicone Protectant', 'cream', 'D02AA', false, 0, '02301725', 'FreeDiams::CA_HCDPD::DIN', 78703);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aleve', 'tablet', 'M01AE02', false, 0, '02301733', 'FreeDiams::CA_HCDPD::DIN', 78704);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Brand Sunthera 3 Kids/Enfants Spf/Fps 50 Continuous Spray', 'aerosol', 'D02BA30', false, 0, '02301741', 'FreeDiams::CA_HCDPD::DIN', 78709);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lisinopril/Hctz (Type Z)', 'tablet', 'C09BA03', false, 0, '02301768', 'FreeDiams::CA_HCDPD::DIN', 78710);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lisinopril/Hctz (Type Z)', 'tablet', 'C09BA03', false, 0, '02301776', 'FreeDiams::CA_HCDPD::DIN', 78711);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lisinopril/Hctz (Type Z)', 'tablet', 'C09BA03', false, 0, '02301784', 'FreeDiams::CA_HCDPD::DIN', 78712);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravastatin', 'tablet', 'C10AA03', false, 0, '02301792', 'FreeDiams::CA_HCDPD::DIN', 78713);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravastatin', 'tablet', 'C10AA03', false, 0, '02301806', 'FreeDiams::CA_HCDPD::DIN', 78714);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citalopram', 'tablet', 'N06AB04', false, 0, '02301822', 'FreeDiams::CA_HCDPD::DIN', 78716);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citalopram', 'tablet', 'N06AB04', false, 0, '02301830', 'FreeDiams::CA_HCDPD::DIN', 78717);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citalopram', 'tablet', 'N06AB04', false, 0, '02301849', 'FreeDiams::CA_HCDPD::DIN', 78718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Isentress', 'tablet', 'J05AX08', false, 0, '02301881', 'FreeDiams::CA_HCDPD::DIN', 78722);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ciprofloxacin Injection Usp', 'solution', 'J01MA02', false, 0, '02301903', 'FreeDiams::CA_HCDPD::DIN', 78723);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Osto-D2', 'capsule', 'A11CC01', false, 0, '02301911', 'FreeDiams::CA_HCDPD::DIN', 78724);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluconazole', 'tablet', 'J02AC01', false, 0, '02301938', 'FreeDiams::CA_HCDPD::DIN', 78725);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluconazole', 'tablet', 'J02AC01', false, 0, '02301946', 'FreeDiams::CA_HCDPD::DIN', 78726);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluconazole', 'capsule', 'J02AC01', false, 0, '02301954', 'FreeDiams::CA_HCDPD::DIN', 78727);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Detsan', 'liquid', 'V07AV', false, 0, '02301962', 'FreeDiams::CA_HCDPD::DIN', 78729);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Detco', 'liquid', 'V07AV', false, 0, '02301970', 'FreeDiams::CA_HCDPD::DIN', 78730);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alendronate', 'tablet', 'M05BA04', false, 0, '02302004', 'FreeDiams::CA_HCDPD::DIN', 78733);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paroxetine', 'tablet', 'N06AB05', false, 0, '02302012', 'FreeDiams::CA_HCDPD::DIN', 78734);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paroxetine', 'tablet', 'N06AB05', false, 0, '02302020', 'FreeDiams::CA_HCDPD::DIN', 78735);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paroxetine', 'tablet', 'N06AB05', false, 0, '02302039', 'FreeDiams::CA_HCDPD::DIN', 78736);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Metoprolol (Type L)', 'tablet', 'C07AB02', false, 0, '02302055', 'FreeDiams::CA_HCDPD::DIN', 78738);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rasilez', 'tablet', 'C09XA02', false, 0, '02302063', 'FreeDiams::CA_HCDPD::DIN', 78739);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rasilez', 'tablet', 'C09XA02', false, 0, '02302071', 'FreeDiams::CA_HCDPD::DIN', 78740);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gemcitabine Hydrochloride For Injection', 'powder for solution', 'L01BC05', false, 0, '02302098', 'FreeDiams::CA_HCDPD::DIN', 78741);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gemcitabine Hydrochloride For Injection', 'powder for solution', 'L01BC05', false, 0, '02302101', 'FreeDiams::CA_HCDPD::DIN', 78742);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lisinopril/Hctz (Type P)', 'tablet', 'C09BA03', false, 0, '02302136', 'FreeDiams::CA_HCDPD::DIN', 78744);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lisinopril/Hctz (Type P)', 'tablet', 'C09BA03', false, 0, '02302144', 'FreeDiams::CA_HCDPD::DIN', 78745);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lisinopril/Hctz (Type P)', 'tablet', 'C09BA03', false, 0, '02302152', 'FreeDiams::CA_HCDPD::DIN', 78746);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eraxis', 'powder for solution', 'J02AX06', false, 0, '02302160', 'FreeDiams::CA_HCDPD::DIN', 78747);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Cefprozil', 'tablet', 'J01DC10', false, 0, '02302179', 'FreeDiams::CA_HCDPD::DIN', 78751);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Cefprozil', 'tablet', 'J01DC10', false, 0, '02302187', 'FreeDiams::CA_HCDPD::DIN', 78752);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Risedronate', 'tablet', 'M05BA07', false, 0, '02302209', 'FreeDiams::CA_HCDPD::DIN', 78754);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kogenate Fs     -(With Bio-Set)', 'powder for solution', 'B02BD02', false, 0, '02302225', 'FreeDiams::CA_HCDPD::DIN', 78756);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Lisinopril Hct', 'tablet', 'C09BA03', false, 0, '02302365', 'FreeDiams::CA_HCDPD::DIN', 78769);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Lisinopril Hct', 'tablet', 'C09BA03', false, 0, '02302373', 'FreeDiams::CA_HCDPD::DIN', 78770);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Lisinopril Hct', 'tablet', 'C09BA03', false, 0, '02302381', 'FreeDiams::CA_HCDPD::DIN', 78771);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Bicalutamide', 'tablet', 'L02BB03', false, 0, '02302403', 'FreeDiams::CA_HCDPD::DIN', 78772);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine 1%', 'liquid', 'N01BB02', false, 0, '02302411', 'FreeDiams::CA_HCDPD::DIN', 78773);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine 2%', 'liquid', 'N01BB02', false, 0, '02302438', 'FreeDiams::CA_HCDPD::DIN', 78774);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aveeno Active Naturals Positively Ageless Day', 'lotion', 'D02BA30', false, 0, '02302489', 'FreeDiams::CA_HCDPD::DIN', 78779);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckeye Terminator', 'liquid', 'V07AV', false, 0, '02302527', 'FreeDiams::CA_HCDPD::DIN', 78783);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Winrho Sdf      (Liquid Formulation)', 'liquid', 'J06BB01', false, 0, '02302594', 'FreeDiams::CA_HCDPD::DIN', 78786);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Winrho Sdf      (Liquid Formulation)', 'liquid', 'J06BB01', false, 0, '02302551', 'FreeDiams::CA_HCDPD::DIN', 78787);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Winrho Sdf      (Liquid Formulation)', 'liquid', 'J06BB01', false, 0, '02302578', 'FreeDiams::CA_HCDPD::DIN', 78788);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diclofenac', 'tablet (delayed-release)', 'M01AB05', false, 0, '02302616', 'FreeDiams::CA_HCDPD::DIN', 78791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diclofenac', 'tablet (delayed-release)', 'M01AB05', false, 0, '02302624', 'FreeDiams::CA_HCDPD::DIN', 78792);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Bisoprolol', 'tablet', 'C07AB07', false, 0, '02302632', 'FreeDiams::CA_HCDPD::DIN', 78793);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Bisoprolol', 'tablet', 'C07AB07', false, 0, '02302640', 'FreeDiams::CA_HCDPD::DIN', 78794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02302659', 'FreeDiams::CA_HCDPD::DIN', 78795);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02302667', 'FreeDiams::CA_HCDPD::DIN', 78796);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02302675', 'FreeDiams::CA_HCDPD::DIN', 78797);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02302683', 'FreeDiams::CA_HCDPD::DIN', 78798);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02302691', 'FreeDiams::CA_HCDPD::DIN', 78799);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02302713', 'FreeDiams::CA_HCDPD::DIN', 78801);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylene Blue Injection Usp', 'solution', 'V03AB17', false, 0, '02302756', 'FreeDiams::CA_HCDPD::DIN', 78806);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Morphine Sr', 'tablet (extended-release)', 'N02AA01', false, 0, '02302764', 'FreeDiams::CA_HCDPD::DIN', 78808);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Morphine Sr', 'tablet (extended-release)', 'N02AA01', false, 0, '02302772', 'FreeDiams::CA_HCDPD::DIN', 78809);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Morphine Sr', 'tablet (extended-release)', 'N02AA01', false, 0, '02302780', 'FreeDiams::CA_HCDPD::DIN', 78810);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Morphine Sr', 'tablet (extended-release)', 'N02AA01', false, 0, '02302799', 'FreeDiams::CA_HCDPD::DIN', 78811);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Morphine Sr', 'tablet (extended-release)', 'N02AA01', false, 0, '02302802', 'FreeDiams::CA_HCDPD::DIN', 78812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun Protection Cream Spf 30', 'cream', 'D02BA30', false, 0, '02302810', 'FreeDiams::CA_HCDPD::DIN', 78813);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biolage Scalptherapie Antidandruff Shampoo', 'shampoo', 'D11AX12', false, 0, '02302829', 'FreeDiams::CA_HCDPD::DIN', 78814);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biolage Scalptherapie Antidandruff Treatment', 'gel', 'D11AX12', false, 0, '02302837', 'FreeDiams::CA_HCDPD::DIN', 78815);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exelon Patch 5          -(4.6 Mg/24 H)', 'patch', 'N06DA03', false, 0, '02302845', 'FreeDiams::CA_HCDPD::DIN', 78816);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exelon Patch 10         -(9.5 Mg/24 H)', 'patch', 'N06DA03', false, 0, '02302853', 'FreeDiams::CA_HCDPD::DIN', 78817);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Pioglitazone', 'tablet', 'A10BG03', false, 0, '02302861', 'FreeDiams::CA_HCDPD::DIN', 78818);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Pioglitazone', 'tablet', 'A10BG03', false, 0, '02302888', 'FreeDiams::CA_HCDPD::DIN', 78819);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Pioglitazone', 'tablet', 'A10BG03', false, 0, '02302896', 'FreeDiams::CA_HCDPD::DIN', 78820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Atenolol/Chlorthalidone', 'tablet', 'C07CB03', false, 0, '02302918', 'FreeDiams::CA_HCDPD::DIN', 78821);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Atenolol/Chlorthalidone', 'tablet', 'C07CB03', false, 0, '02302926', 'FreeDiams::CA_HCDPD::DIN', 78822);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Selectrocide 12g', 'tablet', 'V07AV', false, 0, '02302934', 'FreeDiams::CA_HCDPD::DIN', 78823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02302942', 'FreeDiams::CA_HCDPD::DIN', 78824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02302950', 'FreeDiams::CA_HCDPD::DIN', 78825);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lamotrigine-25', 'tablet', 'N03AX09', false, 0, '02302969', 'FreeDiams::CA_HCDPD::DIN', 78826);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02302977', 'FreeDiams::CA_HCDPD::DIN', 78827);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lamotrigine-100', 'tablet', 'N03AX09', false, 0, '02302985', 'FreeDiams::CA_HCDPD::DIN', 78830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lamotrigine-150', 'tablet', 'N03AX09', false, 0, '02302993', 'FreeDiams::CA_HCDPD::DIN', 78831);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fosinopril-10', 'tablet', 'C09AA09', false, 0, '02303000', 'FreeDiams::CA_HCDPD::DIN', 78832);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fosinopril-20', 'tablet', 'C09AA09', false, 0, '02303019', 'FreeDiams::CA_HCDPD::DIN', 78833);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alendronate-70', 'tablet', 'M05BA04', false, 0, '02303078', 'FreeDiams::CA_HCDPD::DIN', 78840);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Sodium Injection Usp        (Multidose Vial-With Preservative)', 'solution', 'B01AB01', false, 0, '02303086', 'FreeDiams::CA_HCDPD::DIN', 78841);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Sodium Injection Usp         (Single Use Vial-Preservative Free)', 'solution', 'B01AB01', false, 0, '02303094', 'FreeDiams::CA_HCDPD::DIN', 78842);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Heparin Sodium Injection Usp       (Multidose Vial-With Preservative)', 'solution', 'B01AB01', false, 0, '02303108', 'FreeDiams::CA_HCDPD::DIN', 78843);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Olanzapine', 'tablet', 'N05AH03', false, 0, '02303116', 'FreeDiams::CA_HCDPD::DIN', 78844);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02303124', 'FreeDiams::CA_HCDPD::DIN', 78845);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02303132', 'FreeDiams::CA_HCDPD::DIN', 78846);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02303140', 'FreeDiams::CA_HCDPD::DIN', 78847);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Olanzapine', 'tablet', 'N05AH03', false, 0, '02303159', 'FreeDiams::CA_HCDPD::DIN', 78848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Olanzapine', 'tablet', 'N05AH03', false, 0, '02303167', 'FreeDiams::CA_HCDPD::DIN', 78849);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Olanzapine', 'tablet', 'N05AH03', false, 0, '02303175', 'FreeDiams::CA_HCDPD::DIN', 78850);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Olanzapine', 'tablet', 'N05AH03', false, 0, '02303183', 'FreeDiams::CA_HCDPD::DIN', 78851);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02303191', 'FreeDiams::CA_HCDPD::DIN', 78852);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02303205', 'FreeDiams::CA_HCDPD::DIN', 78853);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02303213', 'FreeDiams::CA_HCDPD::DIN', 78854);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Citalopram', 'tablet', 'N06AB04', false, 0, '02303256', 'FreeDiams::CA_HCDPD::DIN', 78858);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Citalopram', 'tablet', 'N06AB04', false, 0, '02303264', 'FreeDiams::CA_HCDPD::DIN', 78859);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Citalopram', 'tablet', 'N06AB04', false, 0, '02303272', 'FreeDiams::CA_HCDPD::DIN', 78860);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ac&C Tablets', 'tablet', 'N02BA51', false, 0, '02303299', 'FreeDiams::CA_HCDPD::DIN', 78862);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Clonazepam', 'tablet', 'N03AE01', false, 0, '02303329', 'FreeDiams::CA_HCDPD::DIN', 78865);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Clonazepam', 'tablet', 'N03AE01', false, 0, '02303337', 'FreeDiams::CA_HCDPD::DIN', 78866);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Fluvox', 'tablet', 'N06AB08', false, 0, '02303345', 'FreeDiams::CA_HCDPD::DIN', 78867);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ranitidine', 'tablet', 'A02BA02', false, 0, '02303353', 'FreeDiams::CA_HCDPD::DIN', 78868);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Fluvox', 'tablet', 'N06AB08', false, 0, '02303361', 'FreeDiams::CA_HCDPD::DIN', 78869);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ranitidine', 'tablet', 'A02BA02', false, 0, '02303388', 'FreeDiams::CA_HCDPD::DIN', 78870);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Metoprolol Sr', 'tablet (extended-release)', 'C07AB02', false, 0, '02303396', 'FreeDiams::CA_HCDPD::DIN', 78871);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Metoprolol Sr', 'tablet (extended-release)', 'C07AB02', false, 0, '02303418', 'FreeDiams::CA_HCDPD::DIN', 78872);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Cefprozil', 'powder for suspension', 'J01DC10', false, 0, '02303426', 'FreeDiams::CA_HCDPD::DIN', 78873);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Cefprozil', 'powder for suspension', 'J01DC10', false, 0, '02303434', 'FreeDiams::CA_HCDPD::DIN', 78874);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accel Pioglitazone', 'tablet', 'A10BG03', false, 0, '02303442', 'FreeDiams::CA_HCDPD::DIN', 78875);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accel Pioglitazone', 'tablet', 'A10BG03', false, 0, '02303450', 'FreeDiams::CA_HCDPD::DIN', 78876);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accel Pioglitazone', 'tablet', 'A10BG03', false, 0, '02303469', 'FreeDiams::CA_HCDPD::DIN', 78877);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperidone', 'tablet', 'N05AX08', false, 0, '02303485', 'FreeDiams::CA_HCDPD::DIN', 78879);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperidone', 'tablet', 'N05AX08', false, 0, '02303493', 'FreeDiams::CA_HCDPD::DIN', 78880);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperidone', 'tablet', 'N05AX08', false, 0, '02303507', 'FreeDiams::CA_HCDPD::DIN', 78881);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperidone', 'tablet', 'N05AX08', false, 0, '02303515', 'FreeDiams::CA_HCDPD::DIN', 78882);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperidone', 'tablet', 'N05AX08', false, 0, '02303523', 'FreeDiams::CA_HCDPD::DIN', 78883);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperidone', 'tablet', 'N05AX08', false, 0, '02303531', 'FreeDiams::CA_HCDPD::DIN', 78884);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Verapamil Sr', 'tablet (extended-release)', 'C08DA01', false, 0, '02303558', 'FreeDiams::CA_HCDPD::DIN', 78885);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Axe Armour Anti-Dandruff', 'shampoo', 'D11AX12', false, 0, '02303574', 'FreeDiams::CA_HCDPD::DIN', 78889);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Primordiale Skin Recharge Crčme/Cream', 'cream', 'D02BA30', false, 0, '02303582', 'FreeDiams::CA_HCDPD::DIN', 78890);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Primordiale Skin Recharge Lotion', 'lotion', 'D02BA30', false, 0, '02303590', 'FreeDiams::CA_HCDPD::DIN', 78891);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vaprox Hc Sterilant', 'liquid', 'V07AV', false, 0, '02303604', 'FreeDiams::CA_HCDPD::DIN', 78892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creme Visage Fps 30', 'cream', 'D02BA30', false, 0, '02303612', 'FreeDiams::CA_HCDPD::DIN', 78893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creme Visage Fps 45', 'cream', 'D02BA30', false, 0, '02303620', 'FreeDiams::CA_HCDPD::DIN', 78894);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lait Protecteur Fps 60', 'lotion', 'D02BA30', false, 0, '02303639', 'FreeDiams::CA_HCDPD::DIN', 78895);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Atenolol', 'tablet', 'C07AB03', false, 0, '02303647', 'FreeDiams::CA_HCDPD::DIN', 78896);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Risperidone', 'tablet', 'N05AX08', false, 0, '02303655', 'FreeDiams::CA_HCDPD::DIN', 78897);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Risperidone', 'tablet', 'N05AX08', false, 0, '02303663', 'FreeDiams::CA_HCDPD::DIN', 78898);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Omnaris', 'spray, metered dose', 'R03BA08', false, 0, '02303671', 'FreeDiams::CA_HCDPD::DIN', 78899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flawless Skin Protecting Foundation Spf 25', 'cream', 'D02BA30', false, 0, '02303701', 'FreeDiams::CA_HCDPD::DIN', 78901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Ciproflox', 'tablet', 'J01MA02', false, 0, '02303728', 'FreeDiams::CA_HCDPD::DIN', 78902);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Ciproflox', 'tablet', 'J01MA02', false, 0, '02303736', 'FreeDiams::CA_HCDPD::DIN', 78903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Ciproflox', 'tablet', 'J01MA02', false, 0, '02303744', 'FreeDiams::CA_HCDPD::DIN', 78904);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sertraline', 'capsule', 'N06AB06', false, 0, '02303779', 'FreeDiams::CA_HCDPD::DIN', 78908);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sertraline', 'capsule', 'N06AB06', false, 0, '02303809', 'FreeDiams::CA_HCDPD::DIN', 78910);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sertraline', 'capsule', 'N06AB06', false, 0, '02303817', 'FreeDiams::CA_HCDPD::DIN', 78911);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euro Docusate C', 'capsule', 'A06AA02', false, 0, '02303825', 'FreeDiams::CA_HCDPD::DIN', 78912);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Allergy Total', 'tablet', 'N02BE51', false, 0, '02303833', 'FreeDiams::CA_HCDPD::DIN', 78913);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benefect Botanical Disinfectant Wipes', 'wipe', 'V07AV', false, 0, '02303841', 'FreeDiams::CA_HCDPD::DIN', 78914);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hepacide United C262', 'solution', 'V07AV', false, 0, '02303876', 'FreeDiams::CA_HCDPD::DIN', 78918);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Turquoise Non Acid Disinfectant Cleaner', 'spray', 'V07AV', false, 0, '02303884', 'FreeDiams::CA_HCDPD::DIN', 78919);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epirubicin Hydrochloride Injection', 'solution', 'L01DB03', false, 0, '02303892', 'FreeDiams::CA_HCDPD::DIN', 78921);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Januvia', 'tablet', 'A10BH01', false, 0, '02303922', 'FreeDiams::CA_HCDPD::DIN', 78924);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutrogena Ultra Sheer Face Sunscreen Spf 60', 'lotion', 'D02BA30', false, 0, '02303973', 'FreeDiams::CA_HCDPD::DIN', 78929);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutrogena Ultra Sheer Face Sunscreen Spf 45', 'lotion', 'D02BA30', false, 0, '02303981', 'FreeDiams::CA_HCDPD::DIN', 78930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Refresh Contacts', 'solution', 'S01XA20', false, 0, '02304015', 'FreeDiams::CA_HCDPD::DIN', 78932);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Opi Spa Clean Plus', 'liquid', 'V07AV', false, 0, '02304023', 'FreeDiams::CA_HCDPD::DIN', 78933);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenobarbital Sodium Injection, Usp', 'solution', 'N03AA02', false, 0, '02304082', 'FreeDiams::CA_HCDPD::DIN', 78939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenobarbital Sodium Injection, Usp', 'solution', 'N03AA02', false, 0, '02304090', 'FreeDiams::CA_HCDPD::DIN', 78940);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Torisel', 'liquid', 'L01XE09', false, 0, '02304104', 'FreeDiams::CA_HCDPD::DIN', 78941);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Wet Ones', 'wipe', 'D08AJ08', false, 0, '02304112', 'FreeDiams::CA_HCDPD::DIN', 78942);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Clonidine', 'tablet', 'C02AC01', false, 0, '02304163', 'FreeDiams::CA_HCDPD::DIN', 78947);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Benadryl Allergy Nighttime', 'capsule', 'R06AA02', false, 0, '02304244', 'FreeDiams::CA_HCDPD::DIN', 78953);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benadryl Allergy Liquigels', 'capsule', 'R06AA02', false, 0, '02304252', 'FreeDiams::CA_HCDPD::DIN', 78954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Renergie Microlift R.A.R.E.', 'cream', 'D02BA30', false, 0, '02304260', 'FreeDiams::CA_HCDPD::DIN', 78955);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prescriptives All You Need + Continuous Action 24 Hour Moisture Spf 15 For Normal Skins', 'lotion', 'D02BA30', false, 0, '02304287', 'FreeDiams::CA_HCDPD::DIN', 78957);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prescriptives All You Need + Continuous Action 24 Hour Moisture Spf 15 For Oilier Skins', 'lotion', 'D02BA30', false, 0, '02304295', 'FreeDiams::CA_HCDPD::DIN', 78958);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prescriptives All You Need + Continuous Action 24 Hour Moisture Spf 15 For Drier Skins', 'cream', 'D02BA30', false, 0, '02304309', 'FreeDiams::CA_HCDPD::DIN', 78959);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02304317', 'FreeDiams::CA_HCDPD::DIN', 78960);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02304325', 'FreeDiams::CA_HCDPD::DIN', 78961);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02304333', 'FreeDiams::CA_HCDPD::DIN', 78962);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride Injection Usp 0.9%', 'solution', 'V07AB', false, 0, '02304341', 'FreeDiams::CA_HCDPD::DIN', 78963);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Desmopressin', 'tablet', 'H01BA02', false, 0, '02304368', 'FreeDiams::CA_HCDPD::DIN', 78965);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Desmopressin', 'tablet', 'H01BA02', false, 0, '02304376', 'FreeDiams::CA_HCDPD::DIN', 78966);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nighttime Cold & Flu Relief', 'liquid', 'N02BE51', false, 0, '02304449', 'FreeDiams::CA_HCDPD::DIN', 78973);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibiotic Plus Pain Relief Cream', 'cream', 'D06AX30', false, 0, '02304457', 'FreeDiams::CA_HCDPD::DIN', 78974);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Complete Antibiotic Ointment', 'ointment', 'D06AX30', false, 0, '02304465', 'FreeDiams::CA_HCDPD::DIN', 78975);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibiotic Ointment', 'ointment', 'D06AX05', false, 0, '02304473', 'FreeDiams::CA_HCDPD::DIN', 78976);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euro Lithium', 'capsule', 'N05AN01', false, 0, '02304511', 'FreeDiams::CA_HCDPD::DIN', 78979);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Euro Lithium', 'capsule', 'N05AN01', false, 0, '02304538', 'FreeDiams::CA_HCDPD::DIN', 78980);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ciprofloxacin Intravenous Infusion, Bp', 'solution', 'J01MA02', false, 0, '02304546', 'FreeDiams::CA_HCDPD::DIN', 78981);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Privigen', 'solution', 'J06BA02', false, 0, '02304619', 'FreeDiams::CA_HCDPD::DIN', 78988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glow Face Spf 15 Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02304627', 'FreeDiams::CA_HCDPD::DIN', 78989);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bobbi Brown Oil Control Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02304635', 'FreeDiams::CA_HCDPD::DIN', 78990);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chewable Daily Low Dose Asa', 'tablet (chewable)', 'N02BA01', false, 0, '02304651', 'FreeDiams::CA_HCDPD::DIN', 78992);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Alfuzosin', 'tablet (extended-release)', 'G04CA01', false, 0, '02304678', 'FreeDiams::CA_HCDPD::DIN', 78993);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Citalopram', 'tablet', 'N06AB04', false, 0, '02304686', 'FreeDiams::CA_HCDPD::DIN', 78996);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Citalopram', 'tablet', 'N06AB04', false, 0, '02304694', 'FreeDiams::CA_HCDPD::DIN', 78997);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Granisetron Hydrochloride Injection', 'liquid', 'A04AA02', false, 0, '02304708', 'FreeDiams::CA_HCDPD::DIN', 78998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neocitran Extra Strength Chest Congestion, Cold & Mucous Relief', 'liquid', 'N02BE51', false, 0, '02304740', 'FreeDiams::CA_HCDPD::DIN', 79002);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ciprofloxacin Intravenous Infusion Bp', 'solution', 'J01MA02', false, 0, '02304759', 'FreeDiams::CA_HCDPD::DIN', 79003);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoject', 'solution', 'L01BA01', false, 0, '02304767', 'FreeDiams::CA_HCDPD::DIN', 79004);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gabapentin', 'capsule', 'N03AX12', false, 0, '02304775', 'FreeDiams::CA_HCDPD::DIN', 79005);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gabapentin', 'capsule', 'N03AX12', false, 0, '02304783', 'FreeDiams::CA_HCDPD::DIN', 79006);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gabapentin', 'capsule', 'N03AX12', false, 0, '02304791', 'FreeDiams::CA_HCDPD::DIN', 79007);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tamiflu', 'capsule', 'J05AH02', false, 0, '02304848', 'FreeDiams::CA_HCDPD::DIN', 79011);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tamiflu', 'capsule', 'J05AH02', false, 0, '02304856', 'FreeDiams::CA_HCDPD::DIN', 79012);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Revlimid', 'capsule', 'L04AX04', false, 0, '02304899', 'FreeDiams::CA_HCDPD::DIN', 79016);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Revlimid', 'capsule', 'L04AX04', false, 0, '02304902', 'FreeDiams::CA_HCDPD::DIN', 79017);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aveeno Active Naturals Sunscreen Lotion Face Spf60', 'lotion', 'D02BA30', false, 0, '02304910', 'FreeDiams::CA_HCDPD::DIN', 79018);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Obagi Clenziderm Acne Gel', 'gel', 'D10AE01', false, 0, '02304929', 'FreeDiams::CA_HCDPD::DIN', 79019);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biolage Scalpthérapie Antidandruff Conditioner', 'cream', 'D11AX12', false, 0, '02304937', 'FreeDiams::CA_HCDPD::DIN', 79020);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique High Impact Lip Colour Spf 15', 'stick', 'D02BA30', false, 0, '02304945', 'FreeDiams::CA_HCDPD::DIN', 79021);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neostrata Oil Free Daytime Smoothing Lotion Level 3', 'lotion', 'D02BA30', false, 0, '02304996', 'FreeDiams::CA_HCDPD::DIN', 79026);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gen-Clozapine', 'tablet', 'N05AH02', false, 0, '02305003', 'FreeDiams::CA_HCDPD::DIN', 79038);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gen-Clozapine', 'tablet', 'N05AH02', false, 0, '02305011', 'FreeDiams::CA_HCDPD::DIN', 79039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Pantoprazole', 'tablet (enteric-coated)', 'A02BC02', false, 0, '02305038', 'FreeDiams::CA_HCDPD::DIN', 79040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Pantoprazole', 'tablet (enteric-coated)', 'A02BC02', false, 0, '02305046', 'FreeDiams::CA_HCDPD::DIN', 79041);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soleil Protexion Velvet Moisture Quenching Cream Normal Skin', 'cream', 'D02BA30', false, 0, '02305070', 'FreeDiams::CA_HCDPD::DIN', 79044);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vivacaine (Bupivacaine Hcl 0.5% & Epinephrine 1:200,000 Inj, Usp)', 'solution', 'N01BB51', false, 0, '02305135', 'FreeDiams::CA_HCDPD::DIN', 79063);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Irinotecan Hydrochloride Trihydrate Injection', 'solution', 'L01XX19', false, 0, '02305143', 'FreeDiams::CA_HCDPD::DIN', 79064);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Premium Activated Charcoal Usp', 'capsule', 'A07BA01', false, 0, '02305151', 'FreeDiams::CA_HCDPD::DIN', 79065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Safeway Petroleum Jelly', 'gel', 'D02AC', false, 0, '02305178', 'FreeDiams::CA_HCDPD::DIN', 79066);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluide Fondant Desalterant Super Hydratant Spf 15', 'emulsion', 'D02BA30', false, 0, '02305186', 'FreeDiams::CA_HCDPD::DIN', 79067);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multi Recharge Spf 15', 'cream', 'D02BA30', false, 0, '02305194', 'FreeDiams::CA_HCDPD::DIN', 79068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coldaside Cold & Flu Extra Strength', 'tablet', 'N02BE51', false, 0, '02305216', 'FreeDiams::CA_HCDPD::DIN', 79071);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Ondansetron', 'tablet', 'A04AA01', false, 0, '02305259', 'FreeDiams::CA_HCDPD::DIN', 79079);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Ondansetron', 'tablet', 'A04AA01', false, 0, '02305267', 'FreeDiams::CA_HCDPD::DIN', 79080);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ideal Shade Cream-To-Powder Foundation Fond De Teint Creme-Poudre Spf/Fps 15', 'cream', 'D02BA30', false, 0, '02305275', 'FreeDiams::CA_HCDPD::DIN', 79081);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Balm Spf 30', 'stick', 'D02BA30', false, 0, '02305283', 'FreeDiams::CA_HCDPD::DIN', 79082);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nighttime Total Cold And Flu', 'tablet', 'N02BE51', false, 0, '02305305', 'FreeDiams::CA_HCDPD::DIN', 79084);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('For Goodness Face Antioxidant Skin Moisturizing Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02305321', 'FreeDiams::CA_HCDPD::DIN', 79086);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cold & Sinus Liquid Fastgels', 'capsule', 'N02BE51', false, 0, '02305356', 'FreeDiams::CA_HCDPD::DIN', 79088);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Spf 50', 'suspension', 'D02BA30', false, 0, '02305372', 'FreeDiams::CA_HCDPD::DIN', 79090);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Revaléskin Day Cream', 'cream', 'D02BA30', false, 0, '02305399', 'FreeDiams::CA_HCDPD::DIN', 79092);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Brimonidine', 'solution', 'S01EA05', false, 0, '02305429', 'FreeDiams::CA_HCDPD::DIN', 79097);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun Protection Cream Spf 45', 'cream', 'D02BA30', false, 0, '02305437', 'FreeDiams::CA_HCDPD::DIN', 79098);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Thymox Bâtiment Agricole Et Entrepôt', 'solution', 'V07AV', false, 0, '02305445', 'FreeDiams::CA_HCDPD::DIN', 79099);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02305461', 'FreeDiams::CA_HCDPD::DIN', 79103);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02305488', 'FreeDiams::CA_HCDPD::DIN', 79104);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin For Children All-In-One Cold & Fever', 'suspension', 'N02BE51', false, 0, '02305496', 'FreeDiams::CA_HCDPD::DIN', 79105);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutra-Stat 32', 'liquid', 'V07AV', false, 0, '02305518', 'FreeDiams::CA_HCDPD::DIN', 79106);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gemcitabine For Injection', 'powder for solution', 'L01BC05', false, 0, '02305526', 'FreeDiams::CA_HCDPD::DIN', 79107);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gemcitabine For Injection', 'powder for solution', 'L01BC05', false, 0, '02305534', 'FreeDiams::CA_HCDPD::DIN', 79108);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Levofloxacin', 'tablet', 'J01MA12', false, 0, '02305585', 'FreeDiams::CA_HCDPD::DIN', 79115);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piperacillin/Tazobactam For Injection', 'powder for solution', 'J01CR05', false, 0, '02305593', 'FreeDiams::CA_HCDPD::DIN', 79116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piperacillin/Tazobactam For Injection', 'powder for solution', 'J01CR05', false, 0, '02305607', 'FreeDiams::CA_HCDPD::DIN', 79117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piperacillin/Tazobactam For Injection', 'powder for solution', 'J01CR05', false, 0, '02305615', 'FreeDiams::CA_HCDPD::DIN', 79118);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin For Children All-In-One Cold & Fever Nightime', 'suspension', 'N02BE51', false, 0, '02305666', 'FreeDiams::CA_HCDPD::DIN', 79122);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Famciclovir', 'tablet', 'J05AB09', false, 0, '02305682', 'FreeDiams::CA_HCDPD::DIN', 79124);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Famciclovir', 'tablet', 'J05AB09', false, 0, '02305690', 'FreeDiams::CA_HCDPD::DIN', 79125);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Famciclovir', 'tablet', 'J05AB09', false, 0, '02305704', 'FreeDiams::CA_HCDPD::DIN', 79126);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marcaine 0.25%      -(Multidose Vial With Methylparaben)', 'solution', 'N01BB01', false, 0, '02305895', 'FreeDiams::CA_HCDPD::DIN', 79144);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marcaine 0.50%      -(Multidose Vial With Methylparaben)', 'solution', 'N01BB01', false, 0, '02305909', 'FreeDiams::CA_HCDPD::DIN', 79145);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol Cold Rapid Release', 'tablet', 'N02BE51', false, 0, '02305917', 'FreeDiams::CA_HCDPD::DIN', 79146);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stalevo', 'tablet', 'N04BA03', false, 0, '02305933', 'FreeDiams::CA_HCDPD::DIN', 79150);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stalevo', 'tablet', 'N04BA03', false, 0, '02305941', 'FreeDiams::CA_HCDPD::DIN', 79151);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stalevo', 'tablet', 'N04BA03', false, 0, '02305968', 'FreeDiams::CA_HCDPD::DIN', 79152);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02305984', 'FreeDiams::CA_HCDPD::DIN', 79154);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02305992', 'FreeDiams::CA_HCDPD::DIN', 79155);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02306018', 'FreeDiams::CA_HCDPD::DIN', 79156);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02306026', 'FreeDiams::CA_HCDPD::DIN', 79157);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02306034', 'FreeDiams::CA_HCDPD::DIN', 79159);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02306042', 'FreeDiams::CA_HCDPD::DIN', 79160);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02306050', 'FreeDiams::CA_HCDPD::DIN', 79161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02306069', 'FreeDiams::CA_HCDPD::DIN', 79162);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valcyte', 'powder for solution', 'J05AB14', false, 0, '02306085', 'FreeDiams::CA_HCDPD::DIN', 79164);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carmex Cherry Flavoured Lip Ointment Spf 15', 'ointment', 'D02BA30', false, 0, '02306123', 'FreeDiams::CA_HCDPD::DIN', 79168);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carmex Flavoured Lip Balm', 'ointment', 'D02BA30', false, 0, '02306131', 'FreeDiams::CA_HCDPD::DIN', 79169);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stallion', 'spray, metered dose', 'N01BB02', false, 0, '02306158', 'FreeDiams::CA_HCDPD::DIN', 79170);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ondansetron-Odan', 'tablet', 'A04AA01', false, 0, '02306212', 'FreeDiams::CA_HCDPD::DIN', 79177);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ondansetron-Odan', 'tablet', 'A04AA01', false, 0, '02306220', 'FreeDiams::CA_HCDPD::DIN', 79178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citalopram-Odan', 'tablet', 'N06AB04', false, 0, '02306239', 'FreeDiams::CA_HCDPD::DIN', 79179);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citalopram-Odan', 'tablet', 'N06AB04', false, 0, '02306247', 'FreeDiams::CA_HCDPD::DIN', 79180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('30 Spf Sunscreen Uva/Uvb Protection Delicate Skin Ultra Soothing Lotion', 'lotion', 'D02BA30', false, 0, '02306255', 'FreeDiams::CA_HCDPD::DIN', 79181);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('15 Spf Sunscreen Uva/Uvb Protection Vitalizing Age-Defying Cream', 'cream', 'D02BA30', false, 0, '02306263', 'FreeDiams::CA_HCDPD::DIN', 79182);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('30 Spf Sunscreen Uva/Uvb Protection High Protection Age-Defying Cream', 'cream', 'D02BA30', false, 0, '02306271', 'FreeDiams::CA_HCDPD::DIN', 79183);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abyssine Cream + Spf 23', 'cream', 'D02BA30', false, 0, '02306298', 'FreeDiams::CA_HCDPD::DIN', 79184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abyssine Lotion + Spf 15', 'lotion', 'D02BA30', false, 0, '02306301', 'FreeDiams::CA_HCDPD::DIN', 79185);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anew Rejuvenate 24 Hour Eye Moisturizer Hydratant Yeux 24 Heures Spf 25 Day', 'cream', 'D02BA30', false, 0, '02306336', 'FreeDiams::CA_HCDPD::DIN', 79187);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy Formula Liquid Capsules', 'capsule', 'R06AA02', false, 0, '02306352', 'FreeDiams::CA_HCDPD::DIN', 79190);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Skin Id Personalized Acne Solution Cream Cleanser/Mask', 'paste', 'D10AE01', false, 0, '02306387', 'FreeDiams::CA_HCDPD::DIN', 79193);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Skin Id Personalized Acne Solution Anti-Acne Treatment', 'gel', 'D10AE01', false, 0, '02306395', 'FreeDiams::CA_HCDPD::DIN', 79194);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Cold And Sinus Night', 'tablet', 'N02BE51', false, 0, '02306409', 'FreeDiams::CA_HCDPD::DIN', 79195);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norwegian Formula Ageless Hand Cream Spf 30', 'cream', 'D02BA30', false, 0, '02306425', 'FreeDiams::CA_HCDPD::DIN', 79197);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alimta', 'powder for solution', 'L01BA04', false, 0, '02306433', 'FreeDiams::CA_HCDPD::DIN', 79204);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Luxiva Flawless Effect Liquid Foundation Spf 15', 'lotion', 'D02BA30', false, 0, '02306441', 'FreeDiams::CA_HCDPD::DIN', 79215);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shiseido Benefiance Nutriperfect Day Cream Spf 15', 'cream', 'D02BA30', false, 0, '02306468', 'FreeDiams::CA_HCDPD::DIN', 79216);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soleil Protexion Velvet Moisture Quenching Cream Combination Skin', 'cream', 'D02BA30', false, 0, '02306476', 'FreeDiams::CA_HCDPD::DIN', 79217);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitalizing Eye Cream With Spf 15', 'cream', 'D02BA30', false, 0, '02306506', 'FreeDiams::CA_HCDPD::DIN', 79221);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Photogenic Lumessence', 'lotion', 'D02BA02', false, 0, '02306549', 'FreeDiams::CA_HCDPD::DIN', 79225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Superdefense Age Defense Moisturizer Spf 25 Combination Oily', 'cream', 'D02BA30', false, 0, '02306557', 'FreeDiams::CA_HCDPD::DIN', 79226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Skin Supplies For Men Age Defense Hydrator Spf 15', 'lotion', 'D02BA30', false, 0, '02306565', 'FreeDiams::CA_HCDPD::DIN', 79227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anew Youth-Awakening Lipstick Rouge Ŕ Lčvres Éclat Jeunesse Spf Fps 15', 'ointment', 'D02BA30', false, 0, '02306573', 'FreeDiams::CA_HCDPD::DIN', 79228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Superdefense Age Defense Moisturizer Spf 25 Dry Combination', 'cream', 'D02BA30', false, 0, '02306638', 'FreeDiams::CA_HCDPD::DIN', 79232);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Superdefense Age Defense Moisturizer Spf 25 Very Dry Combination', 'cream', 'D02BA30', false, 0, '02306646', 'FreeDiams::CA_HCDPD::DIN', 79233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exact Sunscreen Lotion Spf Fps 30', 'lotion', 'D02BA30', false, 0, '02306689', 'FreeDiams::CA_HCDPD::DIN', 79238);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Uv Essentiel', 'emulsion', 'D02BA30', false, 0, '02306700', 'FreeDiams::CA_HCDPD::DIN', 79240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pantoprazole Sodium For Injection', 'powder for solution', 'A02BC02', false, 0, '02306727', 'FreeDiams::CA_HCDPD::DIN', 79242);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anapen Junior', 'solution', 'C01CA24', false, 0, '02306743', 'FreeDiams::CA_HCDPD::DIN', 79244);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anapen', 'solution', 'C01CA24', false, 0, '02306751', 'FreeDiams::CA_HCDPD::DIN', 79245);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intelence', 'tablet', 'J05AG04', false, 0, '02306778', 'FreeDiams::CA_HCDPD::DIN', 79246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Age-Defying + Moisturizing Neck & Chest Treatment Spf 15', 'cream', 'D02BA30', false, 0, '02306808', 'FreeDiams::CA_HCDPD::DIN', 79249);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kleen-San', 'liquid', 'D08AJ08', false, 0, '02306816', 'FreeDiams::CA_HCDPD::DIN', 79250);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Sport Sunscreen Spray', 'spray', 'D02BA30', false, 0, '02306824', 'FreeDiams::CA_HCDPD::DIN', 79251);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('45 Spf Sunscreen Spray', 'spray', 'D02BA30', false, 0, '02306832', 'FreeDiams::CA_HCDPD::DIN', 79252);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 50 Sunscreen Spray', 'spray', 'D02BA30', false, 0, '02306840', 'FreeDiams::CA_HCDPD::DIN', 79253);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kids Spf 50 Sunscreen Spray', 'spray', 'D02BA30', false, 0, '02306867', 'FreeDiams::CA_HCDPD::DIN', 79255);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exact Kids'' Sunscreen Spray Spf Fps 30', 'spray', 'D02BA30', false, 0, '02306875', 'FreeDiams::CA_HCDPD::DIN', 79256);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exact Kids'' Sunscreen Lotion Spf Fps 30', 'lotion', 'D02BA30', false, 0, '02306883', 'FreeDiams::CA_HCDPD::DIN', 79257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Finasteride', 'tablet', 'G04CB01', false, 0, '02306905', 'FreeDiams::CA_HCDPD::DIN', 79259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clear', 'liquid', 'V07AV', false, 0, '02306913', 'FreeDiams::CA_HCDPD::DIN', 79260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exact Babies Sunscreen Spray Spf Fps 45', 'spray', 'D02BA30', false, 0, '02306948', 'FreeDiams::CA_HCDPD::DIN', 79262);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exact Babies Sunscreen Lotion Spf Fps 45', 'spray', 'D02BA30', false, 0, '02306956', 'FreeDiams::CA_HCDPD::DIN', 79263);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Definity Colour Recapture', 'suspension', 'D02BA30', false, 0, '02306972', 'FreeDiams::CA_HCDPD::DIN', 79265);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Bisoprolol - 5', 'tablet', 'C07AB07', false, 0, '02306999', 'FreeDiams::CA_HCDPD::DIN', 79267);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Bisoprolol - 10', 'tablet', 'C07AB07', false, 0, '02307006', 'FreeDiams::CA_HCDPD::DIN', 79268);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckleys Nighttime Cold And Sinus', 'capsule', 'N02BE51', false, 0, '02307014', 'FreeDiams::CA_HCDPD::DIN', 79269);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Raspberry-Lemonade Blast With Spf 15', 'stick', 'D02BA30', false, 0, '02307030', 'FreeDiams::CA_HCDPD::DIN', 79271);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Volibris', 'tablet', 'C02KX02', false, 0, '02307065', 'FreeDiams::CA_HCDPD::DIN', 79274);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Volibris', 'tablet', 'C02KX02', false, 0, '02307073', 'FreeDiams::CA_HCDPD::DIN', 79275);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sheer Focus Tinted Moisturizer With Uva/Uvb Spf 15', 'emulsion', 'D02BA30', false, 0, '02307081', 'FreeDiams::CA_HCDPD::DIN', 79276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckleys Daytime Cold And Sinus', 'capsule', 'N02BE51', false, 0, '02307111', 'FreeDiams::CA_HCDPD::DIN', 79278);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('T/Gel Therapeutic Shampoo Extra Strength', 'shampoo', 'D05AA', false, 0, '02307146', 'FreeDiams::CA_HCDPD::DIN', 79280);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Merle Norman Dual Spectrum Spf 30', 'lotion', 'D02BA30', false, 0, '02307286', 'FreeDiams::CA_HCDPD::DIN', 79294);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxy Daily Moisturizer With Spf 15', 'lotion', 'D02BA30', false, 0, '02307294', 'FreeDiams::CA_HCDPD::DIN', 79295);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Olanzapine', 'tablet', 'N05AH03', false, 0, '02307405', 'FreeDiams::CA_HCDPD::DIN', 79308);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Olanzapine', 'tablet', 'N05AH03', false, 0, '02307413', 'FreeDiams::CA_HCDPD::DIN', 79309);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Olanzapine', 'tablet', 'N05AH03', false, 0, '02307421', 'FreeDiams::CA_HCDPD::DIN', 79310);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Olanzapine', 'tablet', 'N05AH03', false, 0, '02307448', 'FreeDiams::CA_HCDPD::DIN', 79311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Olanzapine', 'tablet', 'N05AH03', false, 0, '02307456', 'FreeDiams::CA_HCDPD::DIN', 79312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02307464', 'FreeDiams::CA_HCDPD::DIN', 79313);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02307472', 'FreeDiams::CA_HCDPD::DIN', 79314);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02307480', 'FreeDiams::CA_HCDPD::DIN', 79315);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exact Kids Clear Continuous Spray Sunscreen Spf/Fps 50', 'spray', 'D02BA30', false, 0, '02307510', 'FreeDiams::CA_HCDPD::DIN', 79319);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exact Cooling And Refreshing Clear Continuous Spray Sunscreen Spf/Fps 45', 'spray', 'D02BA30', false, 0, '02307529', 'FreeDiams::CA_HCDPD::DIN', 79320);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exact Sport Clear Continuous Spray Sunscreen Spf/Fps 30', 'spray', 'D02BA30', false, 0, '02307537', 'FreeDiams::CA_HCDPD::DIN', 79321);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exact Clear Continuous Spray Sunscreen Spf/Fps 30', 'spray', 'D02BA30', false, 0, '02307545', 'FreeDiams::CA_HCDPD::DIN', 79322);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02307634', 'FreeDiams::CA_HCDPD::DIN', 79332);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02307642', 'FreeDiams::CA_HCDPD::DIN', 79333);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02307650', 'FreeDiams::CA_HCDPD::DIN', 79334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02307669', 'FreeDiams::CA_HCDPD::DIN', 79335);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02307677', 'FreeDiams::CA_HCDPD::DIN', 79336);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02307723', 'FreeDiams::CA_HCDPD::DIN', 79341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sojourn Sevoflurane', 'liquid', 'N01AB08', false, 0, '02307766', 'FreeDiams::CA_HCDPD::DIN', 79344);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02307774', 'FreeDiams::CA_HCDPD::DIN', 79345);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02307782', 'FreeDiams::CA_HCDPD::DIN', 79346);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02307790', 'FreeDiams::CA_HCDPD::DIN', 79347);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Quetiapine', 'tablet', 'N05AH04', false, 0, '02307804', 'FreeDiams::CA_HCDPD::DIN', 79348);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Quetiapine', 'tablet', 'N05AH04', false, 0, '02307812', 'FreeDiams::CA_HCDPD::DIN', 79349);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Quetiapine', 'tablet', 'N05AH04', false, 0, '02307839', 'FreeDiams::CA_HCDPD::DIN', 79351);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Quetiapine', 'tablet', 'N05AH04', false, 0, '02307847', 'FreeDiams::CA_HCDPD::DIN', 79352);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pantoprazole', 'tablet (delayed-release)', 'A02BC02', false, 0, '02307863', 'FreeDiams::CA_HCDPD::DIN', 79354);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Pantoprazole', 'tablet (delayed-release)', 'A02BC02', false, 0, '02307871', 'FreeDiams::CA_HCDPD::DIN', 79355);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Oxycodone/Acetaminophen', 'tablet', 'N02BE51', false, 0, '02307898', 'FreeDiams::CA_HCDPD::DIN', 79356);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Valacyclovir', 'tablet', 'J05AB11', false, 0, '02307936', 'FreeDiams::CA_HCDPD::DIN', 79359);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Valacyclovir', 'tablet', 'J05AB11', false, 0, '02307944', 'FreeDiams::CA_HCDPD::DIN', 79360);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Almay Tlc Truly Lasting Color Pressed Powder Poudre Pressee', 'powder', 'D02BA02', false, 0, '02308207', 'FreeDiams::CA_HCDPD::DIN', 79387);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Relistor', 'solution', 'A06AH01', false, 0, '02308215', 'FreeDiams::CA_HCDPD::DIN', 79388);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Bisoprolol', 'tablet', 'C07AB07', false, 0, '02308339', 'FreeDiams::CA_HCDPD::DIN', 79399);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Bisoprolol', 'tablet', 'C07AB07', false, 0, '02308347', 'FreeDiams::CA_HCDPD::DIN', 79400);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Ramipril', 'capsule', 'C09AA05', false, 0, '02308363', 'FreeDiams::CA_HCDPD::DIN', 79402);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Ramipril', 'capsule', 'C09AA05', false, 0, '02308371', 'FreeDiams::CA_HCDPD::DIN', 79403);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dynamic Skin Spf 30', 'cream', 'D02BA30', false, 0, '02308436', 'FreeDiams::CA_HCDPD::DIN', 79407);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piperacillin And Tazobactam For Injection', 'powder for solution', 'J01CR05', false, 0, '02308444', 'FreeDiams::CA_HCDPD::DIN', 79408);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piperacillin And Tazobactam For Injection', 'powder for solution', 'J01CR05', false, 0, '02308452', 'FreeDiams::CA_HCDPD::DIN', 79409);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piperacillin And Tazobactam For Injection', 'powder for solution', 'J01CR05', false, 0, '02308460', 'FreeDiams::CA_HCDPD::DIN', 79410);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vectibix', 'solution', 'L01XC08', false, 0, '02308487', 'FreeDiams::CA_HCDPD::DIN', 79412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exact Lip Balm Moisturizing', 'stick', 'D02BA30', false, 0, '02308517', 'FreeDiams::CA_HCDPD::DIN', 79415);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exact Lip Balm Conditioning Formula', 'ointment', 'D02BA30', false, 0, '02308525', 'FreeDiams::CA_HCDPD::DIN', 79416);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Terminator 5', 'cream', 'D10AE01', false, 0, '02323427', 'FreeDiams::CA_HCDPD::DIN', 80893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exact Spf 15 Fps Fruit Flavours', 'stick', 'D02BA30', false, 0, '02308533', 'FreeDiams::CA_HCDPD::DIN', 79417);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Deep Moisture Renewal With Spf 15', 'stick', 'D02BA30', false, 0, '02308576', 'FreeDiams::CA_HCDPD::DIN', 79420);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neostrata Intense Daytime Total Anti Age Complex', 'cream', 'D02BA30', false, 0, '02308584', 'FreeDiams::CA_HCDPD::DIN', 79421);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Helixate Fs', 'powder for solution', 'B02BD02', false, 0, '02308592', 'FreeDiams::CA_HCDPD::DIN', 79422);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multi-Age Correction', 'cream', 'D02BA30', false, 0, '02308606', 'FreeDiams::CA_HCDPD::DIN', 79423);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gentle Rain Antibacterial', 'liquid', 'D08AE04', false, 0, '02308673', 'FreeDiams::CA_HCDPD::DIN', 79431);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Pantoprazole', 'tablet (delayed-release)', 'A02BC02', false, 0, '02308681', 'FreeDiams::CA_HCDPD::DIN', 79432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Pantoprazole', 'tablet (delayed-release)', 'A02BC02', false, 0, '02308703', 'FreeDiams::CA_HCDPD::DIN', 79433);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exact Lip Balm Regular', 'stick', 'D02BA30', false, 0, '02308770', 'FreeDiams::CA_HCDPD::DIN', 79439);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Exact Lip Balm Year-Round Protection', 'stick', 'D02BA30', false, 0, '02308789', 'FreeDiams::CA_HCDPD::DIN', 79440);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Granisetron', 'tablet', 'A04AA02', false, 0, '02308894', 'FreeDiams::CA_HCDPD::DIN', 79450);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diovan-Hct', 'tablet', 'C09DA03', false, 0, '02308908', 'FreeDiams::CA_HCDPD::DIN', 79451);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diovan-Hct', 'tablet', 'C09DA03', false, 0, '02308916', 'FreeDiams::CA_HCDPD::DIN', 79452);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefazolin For Injection Usp', 'powder for solution', 'J01DB04', false, 0, '02308932', 'FreeDiams::CA_HCDPD::DIN', 79454);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intense Clear', 'shampoo', 'D11AX12', false, 0, '02308940', 'FreeDiams::CA_HCDPD::DIN', 79455);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefazolin For Injection Usp', 'powder for solution', 'J01DB04', false, 0, '02308959', 'FreeDiams::CA_HCDPD::DIN', 79456);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefazolin For Injection Usp', 'powder for solution', 'J01DB04', false, 0, '02308967', 'FreeDiams::CA_HCDPD::DIN', 79457);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisture Restore Day Protective Lotion Spf 15 Normal To Dry Skin', 'lotion', 'D02BA30', false, 0, '02308975', 'FreeDiams::CA_HCDPD::DIN', 79458);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nevanac', 'suspension', 'S01BC10', false, 0, '02308983', 'FreeDiams::CA_HCDPD::DIN', 79459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biore Nourish Nourrit Moisture Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02308991', 'FreeDiams::CA_HCDPD::DIN', 79460);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Activelle Ld', 'tablet', 'G03FA01', false, 0, '02309009', 'FreeDiams::CA_HCDPD::DIN', 79461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Magix Face Perfector Perfecteur Visage Spf/Fps 20', 'gel', 'D02BA30', false, 0, '02309068', 'FreeDiams::CA_HCDPD::DIN', 79466);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tpr20', 'cream', 'D04AB51', false, 0, '02309076', 'FreeDiams::CA_HCDPD::DIN', 79467);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Time Zone Line And Wrinkle Reducing Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02309084', 'FreeDiams::CA_HCDPD::DIN', 79468);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Time Zone Line And Wrinkle Reducing Creme Spf 15 For Dry Skin', 'cream', 'D02BA30', false, 0, '02309092', 'FreeDiams::CA_HCDPD::DIN', 79469);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Time Zone Line And Wrinkle Reducing Creme Spf 15 For Normal/Combination Skin', 'cream', 'D02BA30', false, 0, '02309106', 'FreeDiams::CA_HCDPD::DIN', 79470);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Letrozole', 'tablet', 'L02BG04', false, 0, '02309114', 'FreeDiams::CA_HCDPD::DIN', 79471);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Pramipexole', 'tablet', 'N04BC05', false, 0, '02309122', 'FreeDiams::CA_HCDPD::DIN', 79472);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Pramipexole', 'tablet', 'N04BC05', false, 0, '02309130', 'FreeDiams::CA_HCDPD::DIN', 79473);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Pramipexole', 'tablet', 'N04BC05', false, 0, '02309149', 'FreeDiams::CA_HCDPD::DIN', 79474);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Pramipexole', 'tablet', 'N04BC05', false, 0, '02309157', 'FreeDiams::CA_HCDPD::DIN', 79475);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Brevibloc Premixed Injection', 'solution', 'C07AB09', false, 0, '02309238', 'FreeDiams::CA_HCDPD::DIN', 79483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arbonne Lip Saver Sunscreen Spf 30', 'stick', 'D02BA30', false, 0, '02309246', 'FreeDiams::CA_HCDPD::DIN', 79484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Niaspan Fct', 'tablet (extended-release)', 'C10AD02', false, 0, '02309254', 'FreeDiams::CA_HCDPD::DIN', 79485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Niaspan Fct', 'tablet (extended-release)', 'C10AD02', false, 0, '02309262', 'FreeDiams::CA_HCDPD::DIN', 79486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Niaspan Fct', 'tablet (extended-release)', 'C10AD02', false, 0, '02309289', 'FreeDiams::CA_HCDPD::DIN', 79488);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Windex Antibacterial Disinfectant', 'solution', 'V07AV', false, 0, '02309297', 'FreeDiams::CA_HCDPD::DIN', 79490);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aerius Dual Action 12 Hour', 'tablet (extended-release)', 'R01BA52', false, 0, '02309300', 'FreeDiams::CA_HCDPD::DIN', 79491);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Leflunomide', 'tablet', 'L04AA13', false, 0, '02309327', 'FreeDiams::CA_HCDPD::DIN', 79493);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Leflunomide', 'tablet', 'L04AA13', false, 0, '02309335', 'FreeDiams::CA_HCDPD::DIN', 79494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Cilazapril', 'tablet', 'C09AA08', false, 0, '02309378', 'FreeDiams::CA_HCDPD::DIN', 79497);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Cilazapril', 'tablet', 'C09AA08', false, 0, '02309386', 'FreeDiams::CA_HCDPD::DIN', 79498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Cilazapril', 'tablet', 'C09AA08', false, 0, '02309394', 'FreeDiams::CA_HCDPD::DIN', 79499);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coldaside Cough & Cold', 'tablet', 'R05DA20', false, 0, '02309440', 'FreeDiams::CA_HCDPD::DIN', 79504);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xyntha', 'kit', 'B02BD02', false, 0, '02309483', 'FreeDiams::CA_HCDPD::DIN', 79508);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xyntha', 'kit', 'B02BD02', false, 0, '02309491', 'FreeDiams::CA_HCDPD::DIN', 79509);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xyntha', 'kit', 'B02BD02', false, 0, '02309505', 'FreeDiams::CA_HCDPD::DIN', 79510);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xyntha', 'kit', 'B02BD02', false, 0, '02309513', 'FreeDiams::CA_HCDPD::DIN', 79511);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Clobetasol', 'ointment', 'D07AD01', false, 0, '02309548', 'FreeDiams::CA_HCDPD::DIN', 79513);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cyproterone/Ethinyl Estradiol', 'tablet', 'G03HB01', false, 0, '02309556', 'FreeDiams::CA_HCDPD::DIN', 79517);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('With 6 Spf Sunscreen Uva/Uvb Protection Self Tanning Ultra Natural Bronze Care', 'emulsion', 'D02BA30', false, 0, '02309602', 'FreeDiams::CA_HCDPD::DIN', 79524);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('No. 7 Protect And Perfect Day Cream', 'cream', 'D02BA30', false, 0, '02309653', 'FreeDiams::CA_HCDPD::DIN', 79531);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Amiodarone - 200', 'tablet', 'C01BD01', false, 0, '02309661', 'FreeDiams::CA_HCDPD::DIN', 79532);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aqua Soleil Creme Visage Et Corps Fps 35', 'cream', 'D02BA30', false, 0, '02309688', 'FreeDiams::CA_HCDPD::DIN', 79533);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arbonne Liquid Sunshine Tan Enhancer With Spf 15', 'cream', 'D02BA30', false, 0, '02309734', 'FreeDiams::CA_HCDPD::DIN', 79540);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Night Cough Liquid Fastgels', 'capsule', 'R06AA02', false, 0, '02309742', 'FreeDiams::CA_HCDPD::DIN', 79541);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bobbi Brown Natural Finish Long Lasting Foundation Spf 15', 'liquid', 'D02BA30', false, 0, '02309793', 'FreeDiams::CA_HCDPD::DIN', 79546);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen', 'solution', 'N02BE01', false, 0, '02309807', 'FreeDiams::CA_HCDPD::DIN', 79547);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetaminophen', 'solution', 'N02BE01', false, 0, '02309815', 'FreeDiams::CA_HCDPD::DIN', 79548);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Risedronate', 'tablet', 'M05BA07', false, 0, '02309831', 'FreeDiams::CA_HCDPD::DIN', 79553);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pantoprazole', 'tablet (delayed-release)', 'A02BC02', false, 0, '02309858', 'FreeDiams::CA_HCDPD::DIN', 79554);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pantoprazole', 'tablet (delayed-release)', 'A02BC02', false, 0, '02309866', 'FreeDiams::CA_HCDPD::DIN', 79555);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio-San', 'solution', 'V07AV', false, 0, '02309920', 'FreeDiams::CA_HCDPD::DIN', 79561);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutral Fresh', 'liquid', 'V07AV', false, 0, '02309939', 'FreeDiams::CA_HCDPD::DIN', 79562);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rescue Sporicidal Wipes', 'wipe', 'V07AV', false, 0, '02309955', 'FreeDiams::CA_HCDPD::DIN', 79564);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('One Step Foaming Antiseptic Wash', 'liquid', 'D08AJ01', false, 0, '02309971', 'FreeDiams::CA_HCDPD::DIN', 79566);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Finasteride', 'tablet', 'G04CB01', false, 0, '02310112', 'FreeDiams::CA_HCDPD::DIN', 79578);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arbonne Save Face & Body Sunscreen Spf 15', 'cream', 'D02BA30', false, 0, '02310120', 'FreeDiams::CA_HCDPD::DIN', 79579);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('American Crew Classic Anti-Dandruff Shampoo', 'shampoo', 'D11AX12', false, 0, '02310155', 'FreeDiams::CA_HCDPD::DIN', 79582);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pantoprazole', 'tablet (delayed-release)', 'A02BC02', false, 0, '02310201', 'FreeDiams::CA_HCDPD::DIN', 79586);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Feno-Super - 100', 'tablet', 'C10AB05', false, 0, '02310228', 'FreeDiams::CA_HCDPD::DIN', 79587);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Feno-Super - 160', 'tablet', 'C10AB05', false, 0, '02310236', 'FreeDiams::CA_HCDPD::DIN', 79588);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Omeprazole Dr', 'tablet (delayed-release)', 'A02BC01', false, 0, '02310252', 'FreeDiams::CA_HCDPD::DIN', 79590);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Omeprazole Dr', 'tablet (delayed-release)', 'A02BC01', false, 0, '02310260', 'FreeDiams::CA_HCDPD::DIN', 79591);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02310279', 'FreeDiams::CA_HCDPD::DIN', 79592);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02310287', 'FreeDiams::CA_HCDPD::DIN', 79593);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02310295', 'FreeDiams::CA_HCDPD::DIN', 79594);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Regenerist Superstructure Cream', 'lotion', 'D02BA30', false, 0, '02310309', 'FreeDiams::CA_HCDPD::DIN', 79595);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02310317', 'FreeDiams::CA_HCDPD::DIN', 79596);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02310325', 'FreeDiams::CA_HCDPD::DIN', 79597);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02310333', 'FreeDiams::CA_HCDPD::DIN', 79598);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Olanzapine', 'tablet', 'N05AH03', false, 0, '02310341', 'FreeDiams::CA_HCDPD::DIN', 79599);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Olanzapine', 'tablet', 'N05AH03', false, 0, '02310368', 'FreeDiams::CA_HCDPD::DIN', 79600);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Olanzapine', 'tablet', 'N05AH03', false, 0, '02310376', 'FreeDiams::CA_HCDPD::DIN', 79601);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Olanzapine', 'tablet', 'N05AH03', false, 0, '02310384', 'FreeDiams::CA_HCDPD::DIN', 79602);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Olanzapine', 'tablet', 'N05AH03', false, 0, '02310392', 'FreeDiams::CA_HCDPD::DIN', 79603);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Professional Pro-X Age Protection Lotion With Spf 30', 'lotion', 'D02BA30', false, 0, '02310414', 'FreeDiams::CA_HCDPD::DIN', 79605);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Benzydamine', 'kit', 'A01AD02', false, 0, '02310422', 'FreeDiams::CA_HCDPD::DIN', 79606);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bobbi Brown Skin Foundation Spf 15', 'lotion', 'D02BA30', false, 0, '02310430', 'FreeDiams::CA_HCDPD::DIN', 79607);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Gabapentin', 'capsule', 'N03AX12', false, 0, '02310449', 'FreeDiams::CA_HCDPD::DIN', 79608);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Gabapentin', 'capsule', 'N03AX12', false, 0, '02310457', 'FreeDiams::CA_HCDPD::DIN', 79609);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Gabapentin', 'capsule', 'N03AX12', false, 0, '02310465', 'FreeDiams::CA_HCDPD::DIN', 79610);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Gabapentin', 'tablet', 'N03AX12', false, 0, '02310473', 'FreeDiams::CA_HCDPD::DIN', 79611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Gabapentin', 'tablet', 'N03AX12', false, 0, '02310481', 'FreeDiams::CA_HCDPD::DIN', 79612);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Ramipril', 'capsule', 'C09AA05', false, 0, '02310503', 'FreeDiams::CA_HCDPD::DIN', 79613);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Ramipril', 'capsule', 'C09AA05', false, 0, '02310511', 'FreeDiams::CA_HCDPD::DIN', 79614);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Ramipril', 'capsule', 'C09AA05', false, 0, '02310538', 'FreeDiams::CA_HCDPD::DIN', 79615);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Ramipril', 'capsule', 'C09AA05', false, 0, '02310546', 'FreeDiams::CA_HCDPD::DIN', 79616);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chirogesic', 'cream', 'M02AC', false, 0, '02310554', 'FreeDiams::CA_HCDPD::DIN', 79617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arbonne Water-Resistant Sunscreen Spf 30', 'cream', 'D02BA30', false, 0, '02310562', 'FreeDiams::CA_HCDPD::DIN', 79618);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Parismist Day Cream', 'cream', 'D02BA30', false, 0, '02310570', 'FreeDiams::CA_HCDPD::DIN', 79620);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Azithromycine', 'tablet', 'J01FA10', false, 0, '02310600', 'FreeDiams::CA_HCDPD::DIN', 79623);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Fluconazole', 'tablet', 'J02AC01', false, 0, '02310686', 'FreeDiams::CA_HCDPD::DIN', 79630);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Fluconazole', 'capsule', 'J02AC01', false, 0, '02310694', 'FreeDiams::CA_HCDPD::DIN', 79631);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Rabeprazole Ec', 'tablet (enteric-coated)', 'A02BC04', false, 0, '02310805', 'FreeDiams::CA_HCDPD::DIN', 79643);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Rabeprazole Ec', 'tablet (enteric-coated)', 'A02BC04', false, 0, '02310813', 'FreeDiams::CA_HCDPD::DIN', 79644);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisturizing Lip Balm', 'stick', 'D02BA30', false, 0, '02310821', 'FreeDiams::CA_HCDPD::DIN', 79645);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 15 Fps Lip Balm', 'stick', 'D02BA30', false, 0, '02310848', 'FreeDiams::CA_HCDPD::DIN', 79646);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('All Seasons Lip Balm', 'stick', 'D02BA30', false, 0, '02310856', 'FreeDiams::CA_HCDPD::DIN', 79647);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Flavours Lip Balm', 'stick', 'D02BA30', false, 0, '02310864', 'FreeDiams::CA_HCDPD::DIN', 79648);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Comfort On Call', 'cream', 'D02AA', false, 0, '02310872', 'FreeDiams::CA_HCDPD::DIN', 79649);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Ibuprofen Liquid Filled Capsules', 'capsule', 'M01AE01', false, 0, '02310880', 'FreeDiams::CA_HCDPD::DIN', 79650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Atorvastatin', 'tablet', 'C10AA05', false, 0, '02310899', 'FreeDiams::CA_HCDPD::DIN', 79651);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Atorvastatin', 'tablet', 'C10AA05', false, 0, '02310902', 'FreeDiams::CA_HCDPD::DIN', 79652);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Atorvastatin', 'tablet', 'C10AA05', false, 0, '02310910', 'FreeDiams::CA_HCDPD::DIN', 79653);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Atorvastatin', 'tablet', 'C10AA05', false, 0, '02310929', 'FreeDiams::CA_HCDPD::DIN', 79654);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Naproxen Ec - 375', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02310945', 'FreeDiams::CA_HCDPD::DIN', 79656);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Naproxen Ec - 500', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02310953', 'FreeDiams::CA_HCDPD::DIN', 79657);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Lisinopril - 5', 'tablet', 'C09AA03', false, 0, '02310961', 'FreeDiams::CA_HCDPD::DIN', 79658);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Lisinopril - 10', 'tablet', 'C09AA03', false, 0, '02310988', 'FreeDiams::CA_HCDPD::DIN', 79659);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Lisinopril - 20', 'tablet', 'C09AA03', false, 0, '02310996', 'FreeDiams::CA_HCDPD::DIN', 79660);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Hydroxyquine - 200', 'tablet', 'P01BA02', false, 0, '02311011', 'FreeDiams::CA_HCDPD::DIN', 79662);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Bicalutamide - 50', 'tablet', 'L02BB03', false, 0, '02311038', 'FreeDiams::CA_HCDPD::DIN', 79663);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mycamine', 'powder for solution', 'J02AX05', false, 0, '02311054', 'FreeDiams::CA_HCDPD::DIN', 79665);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Cefadroxil - 500', 'capsule', 'J01DB05', false, 0, '02311062', 'FreeDiams::CA_HCDPD::DIN', 79666);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mac Studio Sculpt Spf 15 Foundation', 'cream', 'D02BA30', false, 0, '02311143', 'FreeDiams::CA_HCDPD::DIN', 79674);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Levocarb - 100/25', 'tablet', 'N04BA02', false, 0, '02311178', 'FreeDiams::CA_HCDPD::DIN', 79676);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Ramipril', 'capsule', 'C09AA05', false, 0, '02311194', 'FreeDiams::CA_HCDPD::DIN', 79678);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Acetaminophen', 'tablet', 'N02BE01', false, 0, '02311208', 'FreeDiams::CA_HCDPD::DIN', 79679);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Quinine - 200', 'capsule', 'P01BC01', false, 0, '02311216', 'FreeDiams::CA_HCDPD::DIN', 79680);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Quinine - 300', 'capsule', 'P01BC01', false, 0, '02311224', 'FreeDiams::CA_HCDPD::DIN', 79681);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Dexamethasone - 4', 'tablet', 'H02AB02', false, 0, '02311267', 'FreeDiams::CA_HCDPD::DIN', 79685);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02311283', 'FreeDiams::CA_HCDPD::DIN', 79687);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02311291', 'FreeDiams::CA_HCDPD::DIN', 79688);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02311305', 'FreeDiams::CA_HCDPD::DIN', 79689);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02311313', 'FreeDiams::CA_HCDPD::DIN', 79690);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Ismn - 60', 'tablet (extended-release)', 'C01DA14', false, 0, '02311321', 'FreeDiams::CA_HCDPD::DIN', 79692);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Levetiracetam - 500', 'tablet', 'N03AX14', false, 0, '02311380', 'FreeDiams::CA_HCDPD::DIN', 79696);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Levetiracetam - 750', 'tablet', 'N03AX14', false, 0, '02311399', 'FreeDiams::CA_HCDPD::DIN', 79697);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Enalapril - 2.5', 'tablet', 'C09AA02', false, 0, '02311402', 'FreeDiams::CA_HCDPD::DIN', 79698);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Enalapril - 5', 'tablet', 'C09AA02', false, 0, '02311410', 'FreeDiams::CA_HCDPD::DIN', 79699);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Enalapril - 10', 'tablet', 'C09AA02', false, 0, '02311429', 'FreeDiams::CA_HCDPD::DIN', 79700);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Enalapril - 20', 'tablet', 'C09AA02', false, 0, '02311437', 'FreeDiams::CA_HCDPD::DIN', 79701);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Diclo Rapide - 50', 'tablet', 'M01AB05', false, 0, '02311461', 'FreeDiams::CA_HCDPD::DIN', 79703);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Cefuroxime - 500', 'tablet', 'J01DC02', false, 0, '02311453', 'FreeDiams::CA_HCDPD::DIN', 79704);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Infinite Bronze Easy Face Bronzer Brush With 12 Spf Sunscreen', 'lotion', 'D02BA02', false, 0, '02311488', 'FreeDiams::CA_HCDPD::DIN', 79705);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Aas Ec - 80', 'tablet (delayed-release)', 'N02BA01', false, 0, '02311496', 'FreeDiams::CA_HCDPD::DIN', 79706);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Aas - 80 (Croquable)', 'tablet (chewable)', 'N02BA01', false, 0, '02311518', 'FreeDiams::CA_HCDPD::DIN', 79707);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Bacterial Moisturizing Hand Lotion', 'lotion', 'D08AE04', false, 0, '02311534', 'FreeDiams::CA_HCDPD::DIN', 79709);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Bacterial Moisturizing Hand Soap', 'liquid', 'D08AE04', false, 0, '02311542', 'FreeDiams::CA_HCDPD::DIN', 79710);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Bacterial Gentle Foaming Hand Soap', 'liquid', 'D08AE04', false, 0, '02311550', 'FreeDiams::CA_HCDPD::DIN', 79711);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Clonazepam', 'tablet', 'N03AE01', false, 0, '02311593', 'FreeDiams::CA_HCDPD::DIN', 79715);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Clonazepam', 'tablet', 'N03AE01', false, 0, '02311607', 'FreeDiams::CA_HCDPD::DIN', 79716);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Clonazepam', 'tablet', 'N03AE01', false, 0, '02311615', 'FreeDiams::CA_HCDPD::DIN', 79718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Positively Ageless Sunscreen Lotion Spf 60 Face', 'lotion', 'D02BA30', false, 0, '02311631', 'FreeDiams::CA_HCDPD::DIN', 79719);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atacand', 'tablet', 'C09CA06', false, 0, '02311658', 'FreeDiams::CA_HCDPD::DIN', 79720);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Canesoral', 'capsule', 'J02AC01', false, 0, '02311690', 'FreeDiams::CA_HCDPD::DIN', 79724);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Quetiapine', 'tablet', 'N05AH04', false, 0, '02311704', 'FreeDiams::CA_HCDPD::DIN', 79725);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Quetiapine', 'tablet', 'N05AH04', false, 0, '02311712', 'FreeDiams::CA_HCDPD::DIN', 79726);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Canesten External Cream', 'cream', 'D01AC01', false, 0, '02311720', 'FreeDiams::CA_HCDPD::DIN', 79727);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Canesoral Combi-Pak', 'kit', 'J02AC01', false, 0, '02311739', 'FreeDiams::CA_HCDPD::DIN', 79728);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Quetiapine', 'tablet', 'N05AH04', false, 0, '02311747', 'FreeDiams::CA_HCDPD::DIN', 79729);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Quetiapine', 'tablet', 'N05AH04', false, 0, '02311755', 'FreeDiams::CA_HCDPD::DIN', 79730);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Deep Wrinkle Moisture', 'cream', 'D02BA30', false, 0, '02311763', 'FreeDiams::CA_HCDPD::DIN', 79731);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride Injection Usp', 'solution', 'B05XA03', false, 0, '02311798', 'FreeDiams::CA_HCDPD::DIN', 79733);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibiotic Cream', 'cream', 'D06AX30', false, 0, '02311844', 'FreeDiams::CA_HCDPD::DIN', 79738);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Marcaine', 'solution', 'N01BB51', false, 0, '02311887', 'FreeDiams::CA_HCDPD::DIN', 79742);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Fentanyl', 'patch', 'N02AB03', false, 0, '02311925', 'FreeDiams::CA_HCDPD::DIN', 79746);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('With 6 Spf Sunscreen Uva/Uvb Protection Self Tanning Essential Bronze Milk', 'emulsion', 'D02BA30', false, 0, '02311933', 'FreeDiams::CA_HCDPD::DIN', 79747);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Plumping Treatment', 'spray', 'D02BA30', false, 0, '02311941', 'FreeDiams::CA_HCDPD::DIN', 79748);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olanzapine', 'tablet', 'N05AH03', false, 0, '02311968', 'FreeDiams::CA_HCDPD::DIN', 79749);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olanzapine', 'tablet', 'N05AH03', false, 0, '02311976', 'FreeDiams::CA_HCDPD::DIN', 79750);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olanzapine', 'tablet', 'N05AH03', false, 0, '02311984', 'FreeDiams::CA_HCDPD::DIN', 79751);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olanzapine', 'tablet', 'N05AH03', false, 0, '02311992', 'FreeDiams::CA_HCDPD::DIN', 79752);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olanzapine', 'tablet', 'N05AH03', false, 0, '02312018', 'FreeDiams::CA_HCDPD::DIN', 79753);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02312050', 'FreeDiams::CA_HCDPD::DIN', 79757);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02312069', 'FreeDiams::CA_HCDPD::DIN', 79758);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02312077', 'FreeDiams::CA_HCDPD::DIN', 79759);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Topiramate', 'tablet', 'N03AX11', false, 0, '02312085', 'FreeDiams::CA_HCDPD::DIN', 79760);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epirubicin Hydrochloride Injection', 'solution', 'L01DB03', false, 0, '02312093', 'FreeDiams::CA_HCDPD::DIN', 79761);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Custom Care Body Aches', 'liquid', 'N02BE01', false, 0, '02312107', 'FreeDiams::CA_HCDPD::DIN', 79762);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Custom Care Cough & Cold Pm', 'liquid', 'N02BE51', false, 0, '02312115', 'FreeDiams::CA_HCDPD::DIN', 79763);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prairie Oxygen Usp', 'gas', 'V03AN01', false, 0, '02312131', 'FreeDiams::CA_HCDPD::DIN', 79765);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultimate Sport Sunscreen', 'lotion', 'D02BA30', false, 0, '02312158', 'FreeDiams::CA_HCDPD::DIN', 79766);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf Fps 15 Mentha Lip Balm Stick', 'stick', 'D02BA30', false, 0, '02312190', 'FreeDiams::CA_HCDPD::DIN', 79770);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Firming Moisture', 'lotion', 'D02BA30', false, 0, '02312204', 'FreeDiams::CA_HCDPD::DIN', 79773);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Ondansetron', 'tablet', 'A04AA01', false, 0, '02312247', 'FreeDiams::CA_HCDPD::DIN', 79776);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Ondansetron', 'tablet', 'A04AA01', false, 0, '02312255', 'FreeDiams::CA_HCDPD::DIN', 79777);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cesamet', 'capsule', 'A04AD11', false, 0, '02312263', 'FreeDiams::CA_HCDPD::DIN', 79778);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Raloxifene', 'tablet', 'G03XC01', false, 0, '02312298', 'FreeDiams::CA_HCDPD::DIN', 79780);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kaletra', 'tablet', 'J05AE06', false, 0, '02312301', 'FreeDiams::CA_HCDPD::DIN', 79781);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Citalopram', 'tablet', 'N06AB04', false, 0, '02312336', 'FreeDiams::CA_HCDPD::DIN', 79783);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aqualia Thermal Uv', 'cream', 'D02BA30', false, 0, '02312344', 'FreeDiams::CA_HCDPD::DIN', 79784);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy Formula', 'tablet', 'R06AA02', false, 0, '02312360', 'FreeDiams::CA_HCDPD::DIN', 79786);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Irinotecan For Injection', 'solution', 'L01XX19', false, 0, '02312409', 'FreeDiams::CA_HCDPD::DIN', 79791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pradax', 'capsule', 'B01AE07', false, 0, '02312433', 'FreeDiams::CA_HCDPD::DIN', 79794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pradax', 'capsule', 'B01AE07', false, 0, '02312441', 'FreeDiams::CA_HCDPD::DIN', 79795);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun Defense Spf 15', 'spray', 'D02BA30', false, 0, '02312484', 'FreeDiams::CA_HCDPD::DIN', 79798);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Indapamide', 'tablet', 'C03BA11', false, 0, '02312530', 'FreeDiams::CA_HCDPD::DIN', 79803);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Indapamide', 'tablet', 'C03BA11', false, 0, '02312549', 'FreeDiams::CA_HCDPD::DIN', 79804);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Boostrix-Polio', 'suspension', 'J07CA02', false, 0, '02312557', 'FreeDiams::CA_HCDPD::DIN', 79806);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Bacterial Waterless Hand Foam', 'liquid', 'D08AJ51', false, 0, '02312581', 'FreeDiams::CA_HCDPD::DIN', 79811);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Refresh Trial Pack (Refresh Tears, Refresh Liquigel And Refresh Ultra)', 'kit', 'S01XA20', false, 0, '02312662', 'FreeDiams::CA_HCDPD::DIN', 79819);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Lovastatin', 'tablet', 'C10AA02', false, 0, '02312670', 'FreeDiams::CA_HCDPD::DIN', 79820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Lovastatin', 'tablet', 'C10AA02', false, 0, '02312689', 'FreeDiams::CA_HCDPD::DIN', 79821);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Verapamil Sr', 'tablet (extended-release)', 'C08DA01', false, 0, '02312697', 'FreeDiams::CA_HCDPD::DIN', 79822);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Risperidone', 'tablet', 'N05AX08', false, 0, '02312700', 'FreeDiams::CA_HCDPD::DIN', 79823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Risperidone', 'tablet', 'N05AX08', false, 0, '02312719', 'FreeDiams::CA_HCDPD::DIN', 79824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Risperidone', 'tablet', 'N05AX08', false, 0, '02312727', 'FreeDiams::CA_HCDPD::DIN', 79825);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Risperidone', 'tablet', 'N05AX08', false, 0, '02312735', 'FreeDiams::CA_HCDPD::DIN', 79826);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Risperidone', 'tablet', 'N05AX08', false, 0, '02312743', 'FreeDiams::CA_HCDPD::DIN', 79827);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Risperidone', 'tablet', 'N05AX08', false, 0, '02312751', 'FreeDiams::CA_HCDPD::DIN', 79828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Mirtazapine', 'tablet', 'N06AX11', false, 0, '02312778', 'FreeDiams::CA_HCDPD::DIN', 79829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Mirtazapine', 'tablet', 'N06AX11', false, 0, '02312786', 'FreeDiams::CA_HCDPD::DIN', 79830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Temodal', 'capsule', 'L01AX03', false, 0, '02312794', 'FreeDiams::CA_HCDPD::DIN', 79831);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sanispray', 'spray', 'V07AV', false, 0, '02312808', 'FreeDiams::CA_HCDPD::DIN', 79832);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydra Bain/Bath', 'wipe', 'D08AJ01', false, 0, '02312824', 'FreeDiams::CA_HCDPD::DIN', 79837);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neo-San Ii', 'solution', 'V07AV', false, 0, '02312859', 'FreeDiams::CA_HCDPD::DIN', 79842);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Restore S520 (Mold)', 'liquid', 'V07AV', false, 0, '02312883', 'FreeDiams::CA_HCDPD::DIN', 79843);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neu Quat', 'solution', 'V07AV', false, 0, '02312875', 'FreeDiams::CA_HCDPD::DIN', 79844);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Wetcide 804', 'liquid', 'V07AV', false, 0, '02312891', 'FreeDiams::CA_HCDPD::DIN', 79845);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro Quat', 'liquid', 'V07AV', false, 0, '02312905', 'FreeDiams::CA_HCDPD::DIN', 79846);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mr. Clean Disinfecting Floor Cleaner', 'liquid', 'V07AV', false, 0, '02312913', 'FreeDiams::CA_HCDPD::DIN', 79847);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clean & Clear Advantage Plus 3-In-1 Cleanser', 'cream', 'D10AE01', false, 0, '02312921', 'FreeDiams::CA_HCDPD::DIN', 79848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Positively Radiant Tinted Moisturizer Spf 30 Light', 'lotion', 'D02BA30', false, 0, '02312948', 'FreeDiams::CA_HCDPD::DIN', 79849);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Positively Radiant Tinted Moisturizer Spf 30 Medium', 'lotion', 'D02BA30', false, 0, '02312956', 'FreeDiams::CA_HCDPD::DIN', 79850);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aveeno Active Naturals Sunscreen Spray Spf 30', 'spray', 'D02BA30', false, 0, '02312964', 'FreeDiams::CA_HCDPD::DIN', 79851);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stbc Sporicidal Toilet Bowl Cleaner', 'gel', 'V07AV', false, 0, '02313022', 'FreeDiams::CA_HCDPD::DIN', 79857);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simple Green D Pro 3', 'liquid', 'V07AV', false, 0, '02313030', 'FreeDiams::CA_HCDPD::DIN', 79858);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dyna Quat Plus', 'liquid', 'V07AV', false, 0, '02313057', 'FreeDiams::CA_HCDPD::DIN', 79860);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Zopiclone', 'tablet', 'N05CF01', false, 0, '02313065', 'FreeDiams::CA_HCDPD::DIN', 79861);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Zopiclone', 'tablet', 'N05CF01', false, 0, '02313073', 'FreeDiams::CA_HCDPD::DIN', 79862);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Acetaminophen E', 'tablet', 'N02BE01', false, 0, '02313081', 'FreeDiams::CA_HCDPD::DIN', 79863);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advate', 'powder for solution', 'B02BD02', false, 0, '02313111', 'FreeDiams::CA_HCDPD::DIN', 79865);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Iodasan', 'solution', 'V07AV', false, 0, '02313138', 'FreeDiams::CA_HCDPD::DIN', 79866);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cuvex', 'solution', 'V07AV', false, 0, '02313146', 'FreeDiams::CA_HCDPD::DIN', 79867);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Waterguard Kids', 'lotion', 'D02BA30', false, 0, '02313154', 'FreeDiams::CA_HCDPD::DIN', 79868);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bismuth Subsalicylate Liquid', 'liquid', 'A07BB', false, 0, '02313162', 'FreeDiams::CA_HCDPD::DIN', 79869);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daily Defense Spf 15', 'cream', 'D02BA30', false, 0, '02313189', 'FreeDiams::CA_HCDPD::DIN', 79871);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kayquat', 'solution', 'V07AV', false, 0, '02313235', 'FreeDiams::CA_HCDPD::DIN', 79876);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pcs Sodium Hypochlorite Disinfectant/Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02313278', 'FreeDiams::CA_HCDPD::DIN', 79879);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citrex', 'liquid', 'V07AV', false, 0, '02313294', 'FreeDiams::CA_HCDPD::DIN', 79881);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crypton Super Fabrics Disinfectant & Deodorizer', 'solution', 'V07AV', false, 0, '02313308', 'FreeDiams::CA_HCDPD::DIN', 79882);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antiseptic Skin Cleanser', 'liquid', 'D08AC02', false, 0, '02313391', 'FreeDiams::CA_HCDPD::DIN', 79892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Citalopram', 'tablet', 'N06AB04', false, 0, '02313405', 'FreeDiams::CA_HCDPD::DIN', 79893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Citalopram', 'tablet', 'N06AB04', false, 0, '02313413', 'FreeDiams::CA_HCDPD::DIN', 79894);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02313448', 'FreeDiams::CA_HCDPD::DIN', 79895);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Bupropion Sr', 'tablet (extended-release)', 'N06AX12', false, 0, '02313421', 'FreeDiams::CA_HCDPD::DIN', 79896);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02313456', 'FreeDiams::CA_HCDPD::DIN', 79897);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02313464', 'FreeDiams::CA_HCDPD::DIN', 79898);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02313472', 'FreeDiams::CA_HCDPD::DIN', 79899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Scrubs Do-It All Disinfectant Cleaner Wipes', 'wipe', 'V07AV', false, 0, '02313499', 'FreeDiams::CA_HCDPD::DIN', 79901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lift Lumiere', 'emulsion', 'D02BA30', false, 0, '02313634', 'FreeDiams::CA_HCDPD::DIN', 79913);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Topiramate', 'tablet', 'N03AX11', false, 0, '02313650', 'FreeDiams::CA_HCDPD::DIN', 79915);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Topiramate', 'tablet', 'N03AX11', false, 0, '02313669', 'FreeDiams::CA_HCDPD::DIN', 79916);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Topiramate', 'tablet', 'N03AX11', false, 0, '02313677', 'FreeDiams::CA_HCDPD::DIN', 79917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Ondansetron', 'tablet', 'A04AA01', false, 0, '02313685', 'FreeDiams::CA_HCDPD::DIN', 79919);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Ondansetron', 'tablet', 'A04AA01', false, 0, '02313693', 'FreeDiams::CA_HCDPD::DIN', 79920);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02313707', 'FreeDiams::CA_HCDPD::DIN', 79921);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02313715', 'FreeDiams::CA_HCDPD::DIN', 79922);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02313723', 'FreeDiams::CA_HCDPD::DIN', 79923);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Cilazapril/Hctz', 'tablet', 'C09BA08', false, 0, '02313731', 'FreeDiams::CA_HCDPD::DIN', 79924);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02313758', 'FreeDiams::CA_HCDPD::DIN', 79925);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adalat Xl Plus', 'kit', 'C08CA55', false, 0, '02313766', 'FreeDiams::CA_HCDPD::DIN', 79926);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adalat Xl Plus', 'kit', 'C08CA55', false, 0, '02313774', 'FreeDiams::CA_HCDPD::DIN', 79927);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adalat Xl Plus', 'kit', 'C08CA55', false, 0, '02313782', 'FreeDiams::CA_HCDPD::DIN', 79928);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ocean Potion Sunscreen Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02313790', 'FreeDiams::CA_HCDPD::DIN', 79930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ocean Potion Sunscreen Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02313804', 'FreeDiams::CA_HCDPD::DIN', 79931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Scandonest 2% With Levonordefrin', 'solution', 'N01BB53', false, 0, '02313863', 'FreeDiams::CA_HCDPD::DIN', 79940);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Control-Bac', 'liquid', 'D08AJ01', false, 0, '02313871', 'FreeDiams::CA_HCDPD::DIN', 79941);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Quetiapine', 'tablet', 'N05AH04', false, 0, '02313901', 'FreeDiams::CA_HCDPD::DIN', 79943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Quetiapine', 'tablet', 'N05AH04', false, 0, '02313928', 'FreeDiams::CA_HCDPD::DIN', 79944);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Quetiapine', 'tablet', 'N05AH04', false, 0, '02313936', 'FreeDiams::CA_HCDPD::DIN', 79945);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Quetiapine', 'tablet', 'N05AH04', false, 0, '02313944', 'FreeDiams::CA_HCDPD::DIN', 79946);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Zolmitriptan', 'tablet', 'N02CC03', false, 0, '02313960', 'FreeDiams::CA_HCDPD::DIN', 79948);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Levofloxacin', 'tablet', 'J01MA12', false, 0, '02313979', 'FreeDiams::CA_HCDPD::DIN', 79949);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Levofloxacin', 'tablet', 'J01MA12', false, 0, '02313987', 'FreeDiams::CA_HCDPD::DIN', 79950);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Quetiapine', 'tablet', 'N05AH04', false, 0, '02313995', 'FreeDiams::CA_HCDPD::DIN', 79951);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Quetiapine', 'tablet', 'N05AH04', false, 0, '02314002', 'FreeDiams::CA_HCDPD::DIN', 79952);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Quetiapine', 'tablet', 'N05AH04', false, 0, '02314010', 'FreeDiams::CA_HCDPD::DIN', 79953);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Quetiapine', 'tablet', 'N05AH04', false, 0, '02314029', 'FreeDiams::CA_HCDPD::DIN', 79954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Ropinirole', 'tablet', 'N04BC04', false, 0, '02314037', 'FreeDiams::CA_HCDPD::DIN', 79955);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Ropinirole', 'tablet', 'N04BC04', false, 0, '02314053', 'FreeDiams::CA_HCDPD::DIN', 79957);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Ropinirole', 'tablet', 'N04BC04', false, 0, '02314061', 'FreeDiams::CA_HCDPD::DIN', 79958);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Ropinirole', 'tablet', 'N04BC04', false, 0, '02314088', 'FreeDiams::CA_HCDPD::DIN', 79959);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ocean Potion Kids Sunscreen Lotion Spf 50', 'lotion', 'D02BA30', false, 0, '02314096', 'FreeDiams::CA_HCDPD::DIN', 79960);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phenrex Mvd', 'solution', 'D08AE05', false, 0, '02314126', 'FreeDiams::CA_HCDPD::DIN', 79962);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('T36 Disinfex Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02314134', 'FreeDiams::CA_HCDPD::DIN', 79967);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pab-14', 'liquid', 'V07AV', false, 0, '02314142', 'FreeDiams::CA_HCDPD::DIN', 79968);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Catena', 'tablet', 'N06BX13', false, 0, '02314150', 'FreeDiams::CA_HCDPD::DIN', 79969);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artistry Tinted Moisturiser Spf 15', 'cream', 'D02BA30', false, 0, '02314169', 'FreeDiams::CA_HCDPD::DIN', 79971);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Rabeprazole', 'tablet (enteric-coated)', 'A02BC04', false, 0, '02314177', 'FreeDiams::CA_HCDPD::DIN', 79974);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Rabeprazole', 'tablet (enteric-coated)', 'A02BC04', false, 0, '02314185', 'FreeDiams::CA_HCDPD::DIN', 79975);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Full Spectrum Disinfectant Wipes', 'wipe', 'V07AV', false, 0, '02314193', 'FreeDiams::CA_HCDPD::DIN', 79976);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Servicemaster Clean Sanimaster 6', 'liquid', 'V07AV', false, 0, '02314207', 'FreeDiams::CA_HCDPD::DIN', 79977);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solutions Am Total Radiance Day Cream', 'cream', 'D02BA30', false, 0, '02314231', 'FreeDiams::CA_HCDPD::DIN', 79980);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mesoestetic Sun Protection Spf 25', 'spray', 'D02BA30', false, 0, '02314266', 'FreeDiams::CA_HCDPD::DIN', 79982);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aveeno Active Naturals Sunscreen Spray Spf 45', 'spray', 'D02BA30', false, 0, '02314274', 'FreeDiams::CA_HCDPD::DIN', 79983);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Alfuzosin Pr', 'tablet (extended-release)', 'G04CA01', false, 0, '02314282', 'FreeDiams::CA_HCDPD::DIN', 79984);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Naratriptan', 'tablet', 'N02CC02', false, 0, '02314290', 'FreeDiams::CA_HCDPD::DIN', 79985);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Naratriptan', 'tablet', 'N02CC02', false, 0, '02314304', 'FreeDiams::CA_HCDPD::DIN', 79986);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bismuth', 'tablet', 'A07BB', false, 0, '02314312', 'FreeDiams::CA_HCDPD::DIN', 79987);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('T36 Antiseptic Hand Sanitizer', 'gel', 'D08AJ51', false, 0, '02314320', 'FreeDiams::CA_HCDPD::DIN', 79988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solutions A.M. Ageless Results Day Cream', 'cream', 'D02BA30', false, 0, '02314339', 'FreeDiams::CA_HCDPD::DIN', 79989);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antiseptic Oral Rinse With Cpc', 'solution', 'R02AA06', false, 0, '02314347', 'FreeDiams::CA_HCDPD::DIN', 79990);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ocean Potion Sport Xtreme Sunscreen Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02314363', 'FreeDiams::CA_HCDPD::DIN', 79992);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fini-Tech Nettoyant Désinfectant', 'spray', 'V07AV', false, 0, '02314401', 'FreeDiams::CA_HCDPD::DIN', 79995);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Fentanyl 25', 'patch', 'N02AB03', false, 0, '02314630', 'FreeDiams::CA_HCDPD::DIN', 80018);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Fentanyl 50', 'patch', 'N02AB03', false, 0, '02314649', 'FreeDiams::CA_HCDPD::DIN', 80019);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Fentanyl 75', 'patch', 'N02AB03', false, 0, '02314657', 'FreeDiams::CA_HCDPD::DIN', 80020);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Fentanyl 100', 'patch', 'N02AB03', false, 0, '02314665', 'FreeDiams::CA_HCDPD::DIN', 80021);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Kids Sunscreen Lotion Spf 60', 'lotion', 'D02BA30', false, 0, '02314673', 'FreeDiams::CA_HCDPD::DIN', 80022);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Waterbabies Sunscreen Lotion Spf 60', 'lotion', 'D02BA30', false, 0, '02314681', 'FreeDiams::CA_HCDPD::DIN', 80023);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone General Protection Sunscreen Lotion Spf 60', 'lotion', 'D02BA30', false, 0, '02314703', 'FreeDiams::CA_HCDPD::DIN', 80024);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Oil Free Faces Sunscreen Lotion Spf 60', 'lotion', 'D02BA30', false, 0, '02314711', 'FreeDiams::CA_HCDPD::DIN', 80025);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sport Performance Spray Sunscreen Ecran Solaire En Vaporisateur Spf/Fps 15', 'aerosol', 'D02BA30', false, 0, '02314738', 'FreeDiams::CA_HCDPD::DIN', 80026);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sport Performance Spray Sunscreen Ecran Solaire En Vaporisateur Spf Fps 30', 'aerosol', 'D02BA30', false, 0, '02314746', 'FreeDiams::CA_HCDPD::DIN', 80027);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ibuprofen', 'tablet', 'M01AE01', false, 0, '02314754', 'FreeDiams::CA_HCDPD::DIN', 80029);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ibuprofen', 'tablet', 'M01AE01', false, 0, '02314762', 'FreeDiams::CA_HCDPD::DIN', 80030);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Ibuprofen', 'tablet', 'M01AE01', false, 0, '02314770', 'FreeDiams::CA_HCDPD::DIN', 80031);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clorox Commercial Solutions Pine-Sol All-Purpose Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02314789', 'FreeDiams::CA_HCDPD::DIN', 80032);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Complete All Day Moisture Cream', 'cream', 'D02BA30', false, 0, '02314800', 'FreeDiams::CA_HCDPD::DIN', 80034);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Complete All Day Moisturizer', 'lotion', 'D02BA30', false, 0, '02314819', 'FreeDiams::CA_HCDPD::DIN', 80035);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quatricide Pv-15 Second Generation', 'liquid', 'V07AV', false, 0, '02314827', 'FreeDiams::CA_HCDPD::DIN', 80036);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quatricide Pv Second Generation', 'liquid', 'V07AV', false, 0, '02314835', 'FreeDiams::CA_HCDPD::DIN', 80037);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pcs 250 Oxidizing Disinfectant/Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02314843', 'FreeDiams::CA_HCDPD::DIN', 80038);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pcs 1000 Oxidizing Disinfectant/Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02314851', 'FreeDiams::CA_HCDPD::DIN', 80039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pcs 7000 Oxidizing Disinfectant/Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02314878', 'FreeDiams::CA_HCDPD::DIN', 80040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pcs 7500 Oxidizing Disinfectant/Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02314886', 'FreeDiams::CA_HCDPD::DIN', 80041);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Metformin', 'tablet', 'A10BA02', false, 0, '02314894', 'FreeDiams::CA_HCDPD::DIN', 80042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Metformin', 'tablet', 'A10BA02', false, 0, '02314908', 'FreeDiams::CA_HCDPD::DIN', 80043);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eltamd Skincare Uv Sport Spf 50', 'cream', 'D02BA30', false, 0, '02314924', 'FreeDiams::CA_HCDPD::DIN', 80045);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fosavance', 'tablet', 'M05BB03', false, 0, '02314940', 'FreeDiams::CA_HCDPD::DIN', 80047);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anew Rejuvenate Day Revitalizing Cream/Creme Revitalisante Spf/Fps 25', 'cream', 'D02BA30', false, 0, '02314959', 'FreeDiams::CA_HCDPD::DIN', 80049);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Defense Sunscreen Lotion Ecran Solaire Spf/Fps 15', 'lotion', 'D02BA30', false, 0, '02314967', 'FreeDiams::CA_HCDPD::DIN', 80050);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Defense Sunscreen Lotion Ecran Solaire Spf/Fps 30', 'lotion', 'D02BA30', false, 0, '02314975', 'FreeDiams::CA_HCDPD::DIN', 80051);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Defense Spray Sunscreen Ecran Solaire En Vaporisateur Spf/Fps 30', 'aerosol', 'D02BA30', false, 0, '02314983', 'FreeDiams::CA_HCDPD::DIN', 80052);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02314991', 'FreeDiams::CA_HCDPD::DIN', 80053);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Fluoxetine', 'capsule', 'N06AB03', false, 0, '02315009', 'FreeDiams::CA_HCDPD::DIN', 80054);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sport Performance Sunscreen Lotion Ecran Solaire Spf/Fps 50', 'lotion', 'D02BA30', false, 0, '02315017', 'FreeDiams::CA_HCDPD::DIN', 80055);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sport Performance Sunscreen Lotion Ecran Solaire Spf/Fps 30', 'lotion', 'D02BA30', false, 0, '02315025', 'FreeDiams::CA_HCDPD::DIN', 80056);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibiotic Cream For Kids', 'cream', 'D06AX30', false, 0, '02315033', 'FreeDiams::CA_HCDPD::DIN', 80057);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Kids Continuous Spray Spf 60', 'aerosol', 'D02BA30', false, 0, '02315041', 'FreeDiams::CA_HCDPD::DIN', 80061);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Methylphenidate Er-C', 'tablet (extended-release)', 'N06BA04', false, 0, '02315068', 'FreeDiams::CA_HCDPD::DIN', 80062);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Methylphenidate Er-C', 'tablet (extended-release)', 'N06BA04', false, 0, '02315076', 'FreeDiams::CA_HCDPD::DIN', 80063);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Methylphenidate Er-C', 'tablet (extended-release)', 'N06BA04', false, 0, '02315084', 'FreeDiams::CA_HCDPD::DIN', 80064);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Methylphenidate Er-C', 'tablet (extended-release)', 'N06BA04', false, 0, '02315092', 'FreeDiams::CA_HCDPD::DIN', 80065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoprolol-L', 'tablet', 'C07AB02', false, 0, '02315106', 'FreeDiams::CA_HCDPD::DIN', 80066);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoprolol-L', 'tablet', 'C07AB02', false, 0, '02315114', 'FreeDiams::CA_HCDPD::DIN', 80067);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoprolol-L', 'tablet', 'C07AB02', false, 0, '02315122', 'FreeDiams::CA_HCDPD::DIN', 80068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('14-Day Skin Rescue Spf 30', 'cream', 'D02BA30', false, 0, '02315130', 'FreeDiams::CA_HCDPD::DIN', 80069);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solutions A.M. Total Radiance Day Lotion', 'lotion', 'D02BA30', false, 0, '02315149', 'FreeDiams::CA_HCDPD::DIN', 80070);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Azithromycin Pediatric', 'powder for suspension', 'J01FA10', false, 0, '02315157', 'FreeDiams::CA_HCDPD::DIN', 80071);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Azithromycin Pediatric', 'powder for suspension', 'J01FA10', false, 0, '02315165', 'FreeDiams::CA_HCDPD::DIN', 80072);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Valacyclovir', 'tablet', 'J05AB11', false, 0, '02315173', 'FreeDiams::CA_HCDPD::DIN', 80073);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Rabeprazole', 'tablet (enteric-coated)', 'A02BC04', false, 0, '02315181', 'FreeDiams::CA_HCDPD::DIN', 80074);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Rabeprazole', 'tablet (enteric-coated)', 'A02BC04', false, 0, '02315203', 'FreeDiams::CA_HCDPD::DIN', 80075);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Purifying Cleanser', 'solution', 'D10AE01', false, 0, '02315211', 'FreeDiams::CA_HCDPD::DIN', 80076);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Pramipexole', 'tablet', 'N04BC05', false, 0, '02315262', 'FreeDiams::CA_HCDPD::DIN', 80080);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Pramipexole', 'tablet', 'N04BC05', false, 0, '02315270', 'FreeDiams::CA_HCDPD::DIN', 80081);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Pramipexole', 'tablet', 'N04BC05', false, 0, '02315289', 'FreeDiams::CA_HCDPD::DIN', 80082);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Pramipexole', 'tablet', 'N04BC05', false, 0, '02315297', 'FreeDiams::CA_HCDPD::DIN', 80083);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Metoprolol L', 'tablet', 'C07AB02', false, 0, '02315300', 'FreeDiams::CA_HCDPD::DIN', 80085);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Metoprolol L', 'tablet', 'C07AB02', false, 0, '02315319', 'FreeDiams::CA_HCDPD::DIN', 80086);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Metoprolol L', 'tablet', 'C07AB02', false, 0, '02315327', 'FreeDiams::CA_HCDPD::DIN', 80087);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Continuous Spray General Protection Spf 60', 'aerosol', 'D02BA30', false, 0, '02315335', 'FreeDiams::CA_HCDPD::DIN', 80088);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lysol Disinfectant Power Bathroom Cleaner', 'spray', 'V07AV', false, 0, '02315386', 'FreeDiams::CA_HCDPD::DIN', 80092);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cc-633', 'liquid', 'V07AV', false, 0, '02315416', 'FreeDiams::CA_HCDPD::DIN', 80095);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Levofloxacin', 'tablet', 'J01MA12', false, 0, '02315424', 'FreeDiams::CA_HCDPD::DIN', 80096);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Levofloxacin', 'tablet', 'J01MA12', false, 0, '02315432', 'FreeDiams::CA_HCDPD::DIN', 80097);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Levofloxacin', 'tablet', 'J01MA12', false, 0, '02315440', 'FreeDiams::CA_HCDPD::DIN', 80098);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Continuous Spray General Protection Spf 30', 'aerosol', 'D02BA30', false, 0, '02315459', 'FreeDiams::CA_HCDPD::DIN', 80099);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cold Liquid Grape Flavour', 'liquid', 'R01BA53', false, 0, '02315475', 'FreeDiams::CA_HCDPD::DIN', 80101);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm Cough And Cold Liquid Cherry Flavour', 'liquid', 'R05DA20', false, 0, '02315483', 'FreeDiams::CA_HCDPD::DIN', 80102);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dm Cough And Cold Relief', 'liquid', 'R05DA20', false, 0, '02315491', 'FreeDiams::CA_HCDPD::DIN', 80103);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tc Spray Soap Antibacterial Soap', 'liquid', 'D08AE04', false, 0, '02315505', 'FreeDiams::CA_HCDPD::DIN', 80104);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tc Enriched Foam Antibacterial Soap', 'liquid', 'D08AE04', false, 0, '02315513', 'FreeDiams::CA_HCDPD::DIN', 80105);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rub A535 Arthritis Extra Strength Roll-On', 'lotion', 'M02AC', false, 0, '02315548', 'FreeDiams::CA_HCDPD::DIN', 80107);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('30 Spf Sunscreen Uva/Uvb Protection Oil-Free Milky Spray', 'emulsion', 'D02BA30', false, 0, '02315572', 'FreeDiams::CA_HCDPD::DIN', 80110);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('15 Spf Sunscreen Uva/Uvb Protection Oil-Free Milky Spray', 'emulsion', 'D02BA30', false, 0, '02315580', 'FreeDiams::CA_HCDPD::DIN', 80111);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Youth Surge Spf 15 Age Decelerating Moisturizer Combination Oily', 'cream', 'D02BA30', false, 0, '02315599', 'FreeDiams::CA_HCDPD::DIN', 80112);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Youth Surge Spf 15 Age Decelerating Moisturizer Very Dry/Dry', 'cream', 'D02BA30', false, 0, '02315602', 'FreeDiams::CA_HCDPD::DIN', 80113);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Youth Surge Spf 15 Age Decelerating Moisturizer Dry Combination', 'cream', 'D02BA30', false, 0, '02315610', 'FreeDiams::CA_HCDPD::DIN', 80114);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tc Enriched Foam - Alcohol Free Hand Sanitizer', 'liquid', 'D08AJ01', false, 0, '02315637', 'FreeDiams::CA_HCDPD::DIN', 80116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Topiramate', 'tablet', 'N03AX11', false, 0, '02315645', 'FreeDiams::CA_HCDPD::DIN', 80117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Topiramate', 'tablet', 'N03AX11', false, 0, '02315653', 'FreeDiams::CA_HCDPD::DIN', 80118);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Topiramate', 'tablet', 'N03AX11', false, 0, '02315661', 'FreeDiams::CA_HCDPD::DIN', 80119);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Sport Sunscreen Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02315769', 'FreeDiams::CA_HCDPD::DIN', 80128);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baza Protect Ii', 'cream', 'D02AB', false, 0, '02315793', 'FreeDiams::CA_HCDPD::DIN', 80131);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cetaphil Daily Facial Moisturizer     (Spf 50)', 'lotion', 'D02BA30', false, 0, '02315831', 'FreeDiams::CA_HCDPD::DIN', 80135);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Alfuzosin', 'tablet (extended-release)', 'G04CA01', false, 0, '02315866', 'FreeDiams::CA_HCDPD::DIN', 80137);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tasigna', 'capsule', 'L01XE08', false, 0, '02315874', 'FreeDiams::CA_HCDPD::DIN', 80138);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Refresh Eye Allergy Relief', 'solution', 'S01GA51', false, 0, '02315890', 'FreeDiams::CA_HCDPD::DIN', 80140);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Refresh Redness Relief', 'solution', 'S01GA01', false, 0, '02315920', 'FreeDiams::CA_HCDPD::DIN', 80143);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zostavax', 'powder for suspension', 'J07BK02', false, 0, '02315939', 'FreeDiams::CA_HCDPD::DIN', 80146);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Allergy Relief', 'tablet', 'R06AE07', false, 0, '02315955', 'FreeDiams::CA_HCDPD::DIN', 80148);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Cetirizine', 'tablet', 'R06AE07', false, 0, '02315963', 'FreeDiams::CA_HCDPD::DIN', 80149);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Irbesartan', 'tablet', 'C09CA04', false, 0, '02315971', 'FreeDiams::CA_HCDPD::DIN', 80150);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Irbesartan', 'tablet', 'C09CA04', false, 0, '02315998', 'FreeDiams::CA_HCDPD::DIN', 80151);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Irbesartan', 'tablet', 'C09CA04', false, 0, '02316005', 'FreeDiams::CA_HCDPD::DIN', 80152);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Irbesartan/Hctz', 'tablet', 'C09DA04', false, 0, '02316013', 'FreeDiams::CA_HCDPD::DIN', 80153);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Irbesartan/Hctz', 'tablet', 'C09DA04', false, 0, '02316021', 'FreeDiams::CA_HCDPD::DIN', 80154);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Irbesartan/Hctz', 'tablet', 'C09DA04', false, 0, '02316048', 'FreeDiams::CA_HCDPD::DIN', 80155);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Quetiapine', 'tablet', 'N05AH04', false, 0, '02316080', 'FreeDiams::CA_HCDPD::DIN', 80161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Quetiapine', 'tablet', 'N05AH04', false, 0, '02316099', 'FreeDiams::CA_HCDPD::DIN', 80162);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Quetiapine', 'tablet', 'N05AH04', false, 0, '02316110', 'FreeDiams::CA_HCDPD::DIN', 80164);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Quetiapine', 'tablet', 'N05AH04', false, 0, '02316129', 'FreeDiams::CA_HCDPD::DIN', 80165);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Di-San 7', 'liquid', 'V07AV', false, 0, '02316196', 'FreeDiams::CA_HCDPD::DIN', 80171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creme Solaire Fondante Protection Minimale 10 Spf', 'cream', 'D02BA30', false, 0, '02316226', 'FreeDiams::CA_HCDPD::DIN', 80173);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Spf 25 Body Spray', 'spray', 'D02BA30', false, 0, '02316234', 'FreeDiams::CA_HCDPD::DIN', 80174);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Spf 30 Body Cream', 'cream', 'D02BA30', false, 0, '02316242', 'FreeDiams::CA_HCDPD::DIN', 80175);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Spf 50 Body Cream', 'cream', 'D02BA30', false, 0, '02316250', 'FreeDiams::CA_HCDPD::DIN', 80176);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daily Moisturizer Oil Free', 'lotion', 'D02BA30', false, 0, '02316269', 'FreeDiams::CA_HCDPD::DIN', 80177);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ddf Ultra Lite Oil Free Moisturizing Dew Uv Moisturizer', 'lotion', 'D02BA30', false, 0, '02316277', 'FreeDiams::CA_HCDPD::DIN', 80178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Dorzolamide', 'solution', 'S01EC03', false, 0, '02316307', 'FreeDiams::CA_HCDPD::DIN', 80181);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Irbesartan', 'tablet', 'C09CA04', false, 0, '02316390', 'FreeDiams::CA_HCDPD::DIN', 80190);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Irbesartan', 'tablet', 'C09CA04', false, 0, '02316404', 'FreeDiams::CA_HCDPD::DIN', 80191);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Irbesartan', 'tablet', 'C09CA04', false, 0, '02316412', 'FreeDiams::CA_HCDPD::DIN', 80192);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Valacyclovir', 'tablet', 'J05AB11', false, 0, '02316447', 'FreeDiams::CA_HCDPD::DIN', 80195);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Pantoprazole', 'tablet (delayed-release)', 'A02BC02', false, 0, '02316463', 'FreeDiams::CA_HCDPD::DIN', 80197);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Spf 30 Face Cream', 'cream', 'D02BA30', false, 0, '02316471', 'FreeDiams::CA_HCDPD::DIN', 80198);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Spf 50 Face Cream', 'cream', 'D02BA30', false, 0, '02316498', 'FreeDiams::CA_HCDPD::DIN', 80199);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Spf 15 Face/Body Cream', 'cream', 'D02BA30', false, 0, '02316501', 'FreeDiams::CA_HCDPD::DIN', 80200);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Sotalol', 'tablet', 'C07AA07', false, 0, '02316528', 'FreeDiams::CA_HCDPD::DIN', 80201);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Sotalol', 'tablet', 'C07AA07', false, 0, '02316536', 'FreeDiams::CA_HCDPD::DIN', 80202);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Glyburide', 'tablet', 'A10BB01', false, 0, '02316544', 'FreeDiams::CA_HCDPD::DIN', 80203);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nabc Non-Acid Disinfectant Bathroom Cleaner', 'liquid', 'V07AV', false, 0, '02316641', 'FreeDiams::CA_HCDPD::DIN', 80216);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-690', 'solution', 'B05ZA', false, 0, '02316668', 'FreeDiams::CA_HCDPD::DIN', 80217);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-661', 'solution', 'B05ZA', false, 0, '02316676', 'FreeDiams::CA_HCDPD::DIN', 80218);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Spf 45 Targeted Protection Stick', 'stick', 'D02BA30', false, 0, '02316684', 'FreeDiams::CA_HCDPD::DIN', 80219);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Quetiapine', 'tablet', 'N05AH04', false, 0, '02316692', 'FreeDiams::CA_HCDPD::DIN', 80220);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Quetiapine', 'tablet', 'N05AH04', false, 0, '02316706', 'FreeDiams::CA_HCDPD::DIN', 80221);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Quetiapine', 'tablet', 'N05AH04', false, 0, '02316722', 'FreeDiams::CA_HCDPD::DIN', 80223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Quetiapine', 'tablet', 'N05AH04', false, 0, '02316730', 'FreeDiams::CA_HCDPD::DIN', 80224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('X-Pur Chlorhexidine', 'liquid', 'A01AB03', false, 0, '02316749', 'FreeDiams::CA_HCDPD::DIN', 80225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artistry Ideal Dual Powder Foundation Refill', 'powder', 'D02BA30', false, 0, '02316757', 'FreeDiams::CA_HCDPD::DIN', 80226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ocean Potion Instant Dry Spf 50 Mist Kids', 'spray, bag-on-valve', 'D02BA30', false, 0, '02316765', 'FreeDiams::CA_HCDPD::DIN', 80227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ocean Potion Instant Dry Spf 30 Mist Sport', 'spray, bag-on-valve', 'D02BA30', false, 0, '02316773', 'FreeDiams::CA_HCDPD::DIN', 80228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 15 High Resolution Refill 3x', 'cream', 'D02BA30', false, 0, '02316803', 'FreeDiams::CA_HCDPD::DIN', 80230);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actonel', 'tablet', 'M05BA07', false, 0, '02316838', 'FreeDiams::CA_HCDPD::DIN', 80233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Ropinirole', 'tablet', 'N04BC04', false, 0, '02316846', 'FreeDiams::CA_HCDPD::DIN', 80234);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Ropinirole', 'tablet', 'N04BC04', false, 0, '02316854', 'FreeDiams::CA_HCDPD::DIN', 80235);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Ropinirole', 'tablet', 'N04BC04', false, 0, '02316862', 'FreeDiams::CA_HCDPD::DIN', 80236);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Ropinirole', 'tablet', 'N04BC04', false, 0, '02316870', 'FreeDiams::CA_HCDPD::DIN', 80237);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aspirin Stomach Guard With Calcium Carbonate', 'tablet', 'N02BA01', false, 0, '02316889', 'FreeDiams::CA_HCDPD::DIN', 80238);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aspirin Extra Strength Stomach Guard With Calcium Carbonate', 'tablet', 'N02BA01', false, 0, '02316897', 'FreeDiams::CA_HCDPD::DIN', 80239);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pat-Galantamine Er', 'capsule (extended release)', 'N06DA04', false, 0, '02316943', 'FreeDiams::CA_HCDPD::DIN', 80244);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pat-Galantamine Er', 'capsule (extended release)', 'N06DA04', false, 0, '02316951', 'FreeDiams::CA_HCDPD::DIN', 80245);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pat-Galantamine Er', 'capsule (extended release)', 'N06DA04', false, 0, '02316978', 'FreeDiams::CA_HCDPD::DIN', 80246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xarelto', 'tablet', 'B01AX06', false, 0, '02316986', 'FreeDiams::CA_HCDPD::DIN', 80247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advanced Revitalift Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02317001', 'FreeDiams::CA_HCDPD::DIN', 80252);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sport Performance Sunscreen Stick Ecran Solaire En Bâtonnet Spf Fps 50', 'stick', 'D02BA30', false, 0, '02317036', 'FreeDiams::CA_HCDPD::DIN', 80254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Defense Sunscreen Lotion Écran Solaire Spf Fps 50', 'lotion', 'D02BA30', false, 0, '02317052', 'FreeDiams::CA_HCDPD::DIN', 80256);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Irbesartan', 'tablet', 'C09CA04', false, 0, '02317060', 'FreeDiams::CA_HCDPD::DIN', 80257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Irbesartan', 'tablet', 'C09CA04', false, 0, '02317079', 'FreeDiams::CA_HCDPD::DIN', 80258);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Irbesartan', 'tablet', 'C09CA04', false, 0, '02317087', 'FreeDiams::CA_HCDPD::DIN', 80259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apri 21', 'tablet', 'G03AA09', false, 0, '02317192', 'FreeDiams::CA_HCDPD::DIN', 80270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apri 28', 'tablet', 'G03AA09', false, 0, '02317206', 'FreeDiams::CA_HCDPD::DIN', 80272);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daily Defense Spf 45', 'cream', 'D02BA30', false, 0, '02317265', 'FreeDiams::CA_HCDPD::DIN', 80281);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bio Glo', 'strip', 'S01JA01', false, 0, '02317281', 'FreeDiams::CA_HCDPD::DIN', 80283);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Cefprozil', 'tablet', 'J01DC10', false, 0, '02317303', 'FreeDiams::CA_HCDPD::DIN', 80284);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Cefprozil', 'tablet', 'J01DC10', false, 0, '02317311', 'FreeDiams::CA_HCDPD::DIN', 80285);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ibuprofen Caplets', 'tablet', 'M01AE01', false, 0, '02317338', 'FreeDiams::CA_HCDPD::DIN', 80286);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Quetiapine', 'tablet', 'N05AH04', false, 0, '02317346', 'FreeDiams::CA_HCDPD::DIN', 80287);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Quetiapine', 'tablet', 'N05AH04', false, 0, '02317354', 'FreeDiams::CA_HCDPD::DIN', 80288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Quetiapine', 'tablet', 'N05AH04', false, 0, '02317362', 'FreeDiams::CA_HCDPD::DIN', 80289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Quetiapine', 'tablet', 'N05AH04', false, 0, '02317370', 'FreeDiams::CA_HCDPD::DIN', 80290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Lisinopril', 'tablet', 'C09AA03', false, 0, '02317397', 'FreeDiams::CA_HCDPD::DIN', 80292);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Lisinopril', 'tablet', 'C09AA03', false, 0, '02317400', 'FreeDiams::CA_HCDPD::DIN', 80293);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Lisinopril', 'tablet', 'C09AA03', false, 0, '02317419', 'FreeDiams::CA_HCDPD::DIN', 80294);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02317427', 'FreeDiams::CA_HCDPD::DIN', 80295);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02317435', 'FreeDiams::CA_HCDPD::DIN', 80296);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02317443', 'FreeDiams::CA_HCDPD::DIN', 80297);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Pravastatin', 'tablet', 'C10AA03', false, 0, '02317451', 'FreeDiams::CA_HCDPD::DIN', 80298);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Pravastatin', 'tablet', 'C10AA03', false, 0, '02317478', 'FreeDiams::CA_HCDPD::DIN', 80299);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Pravastatin', 'tablet', 'C10AA03', false, 0, '02317486', 'FreeDiams::CA_HCDPD::DIN', 80300);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aveeno Active Naturals Daily Moisturizing Lotion', 'lotion', 'D02BA30', false, 0, '02317508', 'FreeDiams::CA_HCDPD::DIN', 80302);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sanis Multipurpose Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02317516', 'FreeDiams::CA_HCDPD::DIN', 80303);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro-Kleen 3 Surface Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02317524', 'FreeDiams::CA_HCDPD::DIN', 80304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Brand Disinfectant Wipes', 'wipe', 'V07AV', false, 0, '02317532', 'FreeDiams::CA_HCDPD::DIN', 80305);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Luxiva Sheer Defense M50 Spf15', 'lotion', 'D02BA30', false, 0, '02317591', 'FreeDiams::CA_HCDPD::DIN', 80309);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Luxiva Sheer Defense Ml40 Spf15', 'lotion', 'D02BA30', false, 0, '02317605', 'FreeDiams::CA_HCDPD::DIN', 80312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Luxiva Sheer Defense Ml30 Spf15', 'lotion', 'D02BA30', false, 0, '02317613', 'FreeDiams::CA_HCDPD::DIN', 80313);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Luxiva Sheer Defense L20 Spf15', 'lotion', 'D02BA30', false, 0, '02317621', 'FreeDiams::CA_HCDPD::DIN', 80314);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Luxiva Sheer Defense L10 Spf15', 'lotion', 'D02BA30', false, 0, '02317648', 'FreeDiams::CA_HCDPD::DIN', 80315);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Original Antibiotic Cream', 'cream', 'D06AX30', false, 0, '02317656', 'FreeDiams::CA_HCDPD::DIN', 80317);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Aging Foundation An Emulsion Spf 15', 'emulsion', 'D02BA02', false, 0, '02317664', 'FreeDiams::CA_HCDPD::DIN', 80319);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lax-A-Day', 'powder for solution', 'A06AD15', false, 0, '02317680', 'FreeDiams::CA_HCDPD::DIN', 80321);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Revlimid', 'capsule', 'L04AX04', false, 0, '02317699', 'FreeDiams::CA_HCDPD::DIN', 80322);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Revlimid', 'capsule', 'L04AX04', false, 0, '02317710', 'FreeDiams::CA_HCDPD::DIN', 80324);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baby Sunscreen Stick Écran Solaire En Bâtonnet Spf Fps 50', 'stick', 'D02BA30', false, 0, '02317737', 'FreeDiams::CA_HCDPD::DIN', 80327);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Gabapentin', 'capsule', 'N03AX12', false, 0, '02319063', 'FreeDiams::CA_HCDPD::DIN', 80455);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kids Sunscreen Stick Écran Solaire En Bâtonnet Pour Enfants Spf Fps 50', 'stick', 'D02BA30', false, 0, '02317745', 'FreeDiams::CA_HCDPD::DIN', 80328);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pert Plus Dandruff Dismissed', 'shampoo', 'D11AX12', false, 0, '02317753', 'FreeDiams::CA_HCDPD::DIN', 80329);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02317796', 'FreeDiams::CA_HCDPD::DIN', 80332);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02317818', 'FreeDiams::CA_HCDPD::DIN', 80333);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibiotic Cream Plus Pain Relief', 'cream', 'D06AX30', false, 0, '02317834', 'FreeDiams::CA_HCDPD::DIN', 80335);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germicide 3 Surface Wipes', 'wipe', 'V07AV', false, 0, '02317842', 'FreeDiams::CA_HCDPD::DIN', 80336);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Super Strength Motrin 1b Liquid Gels', 'capsule', 'M01AE01', false, 0, '02317850', 'FreeDiams::CA_HCDPD::DIN', 80337);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quetiapine', 'tablet', 'N05AH04', false, 0, '02317893', 'FreeDiams::CA_HCDPD::DIN', 80341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quetiapine', 'tablet', 'N05AH04', false, 0, '02317907', 'FreeDiams::CA_HCDPD::DIN', 80342);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quetiapine', 'tablet', 'N05AH04', false, 0, '02317923', 'FreeDiams::CA_HCDPD::DIN', 80344);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quetiapine', 'tablet', 'N05AH04', false, 0, '02317931', 'FreeDiams::CA_HCDPD::DIN', 80345);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Purg-Odan', 'powder for solution', 'A06AB58', false, 0, '02317966', 'FreeDiams::CA_HCDPD::DIN', 80347);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ibuprofen Menstrual Pain Relief', 'tablet', 'M01AE01', false, 0, '02317982', 'FreeDiams::CA_HCDPD::DIN', 80349);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aloe Vera Aločs Sunscreen Stick Écran Solaire En Bâtonnet Spf Fps 45', 'stick', 'D02BA30', false, 0, '02317990', 'FreeDiams::CA_HCDPD::DIN', 80350);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Travatan Z', 'solution', 'S01EE04', false, 0, '02318008', 'FreeDiams::CA_HCDPD::DIN', 80351);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Atomoxetine', 'capsule', 'N06BA09', false, 0, '02318024', 'FreeDiams::CA_HCDPD::DIN', 80353);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Atomoxetine', 'capsule', 'N06BA09', false, 0, '02318032', 'FreeDiams::CA_HCDPD::DIN', 80354);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Atomoxetine', 'capsule', 'N06BA09', false, 0, '02318040', 'FreeDiams::CA_HCDPD::DIN', 80355);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Atomoxetine', 'capsule', 'N06BA09', false, 0, '02318059', 'FreeDiams::CA_HCDPD::DIN', 80356);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Atomoxetine', 'capsule', 'N06BA09', false, 0, '02318067', 'FreeDiams::CA_HCDPD::DIN', 80357);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Atomoxetine', 'capsule', 'N06BA09', false, 0, '02318075', 'FreeDiams::CA_HCDPD::DIN', 80358);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Atomoxetine', 'capsule', 'N06BA09', false, 0, '02318083', 'FreeDiams::CA_HCDPD::DIN', 80359);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisturizing Lip Gloss Brillant A Levres Hydratant', 'liquid', 'D02BA30', false, 0, '02318113', 'FreeDiams::CA_HCDPD::DIN', 80362);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rocuronium Bromide Injection', 'liquid', 'M03AC09', false, 0, '02318121', 'FreeDiams::CA_HCDPD::DIN', 80363);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Denti-Care Denti-Freeze Topical Anesthetic Gel', 'gel', 'A01AD11', false, 0, '02318148', 'FreeDiams::CA_HCDPD::DIN', 80364);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Restoralax', 'powder for solution', 'A06AD15', false, 0, '02318164', 'FreeDiams::CA_HCDPD::DIN', 80366);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alcohol-Free Foaming Hand Sanitizer/Assainisseur Moussant Sans Alcool Pour Les Mains', 'solution', 'D08AJ01', false, 0, '02318237', 'FreeDiams::CA_HCDPD::DIN', 80374);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rebif', 'solution', 'L03AB07', false, 0, '02318253', 'FreeDiams::CA_HCDPD::DIN', 80376);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rebif', 'solution', 'L03AB07', false, 0, '02318261', 'FreeDiams::CA_HCDPD::DIN', 80377);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('X3 Clean Alcohol-Free Foaming Hand Sanitizer/ X3 Clean Assainisseur Moussant Sans Alcool Pour Les Mains', 'solution', 'D08AJ01', false, 0, '02318296', 'FreeDiams::CA_HCDPD::DIN', 80379);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Brand Sunthera 3 Spf/Fps 30 Sun Protection Lotion Face', 'lotion', 'D02BA30', false, 0, '02318318', 'FreeDiams::CA_HCDPD::DIN', 80380);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisture Restore Day Protective Mattefying Lotion Spf 15 Combination To Oily Skin', 'lotion', 'D02BA30', false, 0, '02318334', 'FreeDiams::CA_HCDPD::DIN', 80382);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ombrelle Kids Spf 60', 'lotion', 'D02BA30', false, 0, '02318342', 'FreeDiams::CA_HCDPD::DIN', 80383);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rapicide Pa High Level Disinfectant', 'liquid', 'V07AV', false, 0, '02318377', 'FreeDiams::CA_HCDPD::DIN', 80386);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gluquat 2', 'solution', 'V07AV', false, 0, '02318393', 'FreeDiams::CA_HCDPD::DIN', 80388);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rocuronium Bromide Injection', 'solution', 'M03AC09', false, 0, '02318415', 'FreeDiams::CA_HCDPD::DIN', 80390);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Itch Relief Lotion', 'lotion', 'D04AB07', false, 0, '02318423', 'FreeDiams::CA_HCDPD::DIN', 80391);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Welcome Matte Spf 15', 'lotion', 'D02BA30', false, 0, '02318431', 'FreeDiams::CA_HCDPD::DIN', 80392);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ombrelle Sport Spray Spf15', 'aerosol', 'D02BA30', false, 0, '02318458', 'FreeDiams::CA_HCDPD::DIN', 80393);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dandruff', 'shampoo', 'D11AX12', false, 0, '02318474', 'FreeDiams::CA_HCDPD::DIN', 80396);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gold Bond Anti-Itch Lotion', 'lotion', 'D04AB07', false, 0, '02318482', 'FreeDiams::CA_HCDPD::DIN', 80397);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ddf Daily Protective Moisturizer Uv Moisturizer Spf 15', 'lotion', 'D02BA30', false, 0, '02318490', 'FreeDiams::CA_HCDPD::DIN', 80398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ddf Mattifying Oil-Control Uv Moisturizer Spf 15', 'lotion', 'D02BA30', false, 0, '02318512', 'FreeDiams::CA_HCDPD::DIN', 80400);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Safetec Disinfecting Towlettes', 'wipe', 'V07AV', false, 0, '02318547', 'FreeDiams::CA_HCDPD::DIN', 80403);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Generation V', 'liquid', 'V07AV', false, 0, '02318571', 'FreeDiams::CA_HCDPD::DIN', 80406);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Auro-Nevirapine', 'tablet', 'J05AG01', false, 0, '02318601', 'FreeDiams::CA_HCDPD::DIN', 80408);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Complete Ageless Skin Renewing Uv Lotion', 'lotion', 'D02BA30', false, 0, '02318636', 'FreeDiams::CA_HCDPD::DIN', 80411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olmetec', 'tablet', 'C09CA08', false, 0, '02318660', 'FreeDiams::CA_HCDPD::DIN', 80414);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olmetec', 'tablet', 'C09CA08', false, 0, '02318679', 'FreeDiams::CA_HCDPD::DIN', 80415);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pantoprazole', 'tablet (delayed-release)', 'A02BC02', false, 0, '02318695', 'FreeDiams::CA_HCDPD::DIN', 80417);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micardis Plus', 'tablet', 'C09DA07', false, 0, '02318709', 'FreeDiams::CA_HCDPD::DIN', 80418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibacterial Gel Hand Soap', 'gel', 'D08AE05', false, 0, '02318717', 'FreeDiams::CA_HCDPD::DIN', 80419);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibacterial Foaming Hand Soap', 'liquid', 'D08AJ01', false, 0, '02318725', 'FreeDiams::CA_HCDPD::DIN', 80420);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibacterial Spray Hand Soap', 'spray', 'D08AE04', false, 0, '02318733', 'FreeDiams::CA_HCDPD::DIN', 80421);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gemcitabine For Injection, Usp', 'powder for solution', 'L01BC05', false, 0, '02318741', 'FreeDiams::CA_HCDPD::DIN', 80422);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Magix Tinted Face Perfector Perfecteur Visage Teinte Spf/Fps 15', 'gel', 'D02BA30', false, 0, '02318768', 'FreeDiams::CA_HCDPD::DIN', 80424);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ddf Advanced Moisture Defense Uv Cream Spf 15', 'cream', 'D02BA30', false, 0, '02318776', 'FreeDiams::CA_HCDPD::DIN', 80425);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('University Medical Pharmaceuticals Cleansing Shampoo', 'shampoo', 'D11AX12', false, 0, '02318784', 'FreeDiams::CA_HCDPD::DIN', 80426);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Face And Body Lotion Spf 50', 'lotion', 'D02BA30', false, 0, '02318857', 'FreeDiams::CA_HCDPD::DIN', 80435);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Continuous Hydration Spf 25', 'lotion', 'D02BA30', false, 0, '02318865', 'FreeDiams::CA_HCDPD::DIN', 80436);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mesoestetic Sun Protection Spf 30', 'cream', 'D02BA30', false, 0, '02318911', 'FreeDiams::CA_HCDPD::DIN', 80438);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Virasept Rtu', 'liquid', 'V07AV', false, 0, '02318938', 'FreeDiams::CA_HCDPD::DIN', 80441);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polysporin Poly To Go', 'spray', 'D04AB07', false, 0, '02318946', 'FreeDiams::CA_HCDPD::DIN', 80442);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mesoestetic Sun Protection Spf 50', 'cream', 'D02BA30', false, 0, '02318954', 'FreeDiams::CA_HCDPD::DIN', 80443);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xamiol', 'gel', 'D07XC01', false, 0, '02319012', 'FreeDiams::CA_HCDPD::DIN', 80450);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefepime For Injection', 'powder for solution', 'J01DE01', false, 0, '02319039', 'FreeDiams::CA_HCDPD::DIN', 80452);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neostrata Hq Plus Lightening Cream', 'cream', 'D11AX11', false, 0, '02319047', 'FreeDiams::CA_HCDPD::DIN', 80453);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Gabapentin', 'capsule', 'N03AX12', false, 0, '02319055', 'FreeDiams::CA_HCDPD::DIN', 80454);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Gabapentin', 'capsule', 'N03AX12', false, 0, '02319071', 'FreeDiams::CA_HCDPD::DIN', 80456);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aqua Spf 50', 'lotion', 'D02BA30', false, 0, '02319098', 'FreeDiams::CA_HCDPD::DIN', 80457);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Micro-Kleen 3 Disinfectant Surface Wipes', 'wipe', 'V07AV', false, 0, '02319101', 'FreeDiams::CA_HCDPD::DIN', 80458);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tc Antibacterial Lotion Soap', 'lotion', 'D08AE04', false, 0, '02319128', 'FreeDiams::CA_HCDPD::DIN', 80459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf/Fps 30 Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02319136', 'FreeDiams::CA_HCDPD::DIN', 80460);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antimicrobial Foaming Hand Soap / Savon Ŕ Mains Moussant Antimicrobien', 'solution', 'D08AE04', false, 0, '02319144', 'FreeDiams::CA_HCDPD::DIN', 80461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rescue Sporicidal Liquid', 'liquid', 'V07AV', false, 0, '02319160', 'FreeDiams::CA_HCDPD::DIN', 80463);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gl-100 Nettoyant-Degraissant-Desinfectant/Gl-100 Cleaner-Degreaser-Disinfectant', 'solution', 'V07AV', false, 0, '02319179', 'FreeDiams::CA_HCDPD::DIN', 80464);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dg-194 Cleaner, Degreaser, Disinfectant, Sanitizer, Fungicide, Deodorizer/Dg-194 Nettoyant, Dégraissant, Désinfectant, Assainisseur, Fongicide, Désodorisant', 'liquid', 'V07AV', false, 0, '02319187', 'FreeDiams::CA_HCDPD::DIN', 80465);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Neocitran Total Symptom Relief - Sugar Free', 'powder', 'N02BE51', false, 0, '02319195', 'FreeDiams::CA_HCDPD::DIN', 80466);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Tickly Throat Cough', 'syrup', 'R05DA09', false, 0, '02319209', 'FreeDiams::CA_HCDPD::DIN', 80467);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Leflunomide', 'tablet', 'L04AA13', false, 0, '02319225', 'FreeDiams::CA_HCDPD::DIN', 80469);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Leflunomide', 'tablet', 'L04AA13', false, 0, '02319233', 'FreeDiams::CA_HCDPD::DIN', 80470);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tinactin Chill Deodorant Powder Spray', 'aerosol', 'D01AE18', false, 0, '02319276', 'FreeDiams::CA_HCDPD::DIN', 80475);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benzalkonium Chloride Antiseptic Towelette', 'wipe', 'D08AJ01', false, 0, '02319284', 'FreeDiams::CA_HCDPD::DIN', 80476);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 50 Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02319306', 'FreeDiams::CA_HCDPD::DIN', 80478);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tinactin Chill Liquid Spray', 'aerosol', 'D01AE18', false, 0, '02319314', 'FreeDiams::CA_HCDPD::DIN', 80479);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ddf Protective Eye Cream Uv Moisturizer Spf 15', 'cream', 'D02BA30', false, 0, '02319322', 'FreeDiams::CA_HCDPD::DIN', 80480);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ali-Flex Pręt Ŕ Utiliser', 'liquid', 'V07AV', false, 0, '02319330', 'FreeDiams::CA_HCDPD::DIN', 80481);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Get A Tint Tinted Moisturizer Lotion Lotion Hydratante Teintee Spf/Fps 15', 'lotion', 'D02BA30', false, 0, '02319349', 'FreeDiams::CA_HCDPD::DIN', 80484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Spf/Fps 30', 'lotion', 'D02BA30', false, 0, '02319373', 'FreeDiams::CA_HCDPD::DIN', 80487);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Spf/Fps 50', 'lotion', 'D02BA30', false, 0, '02319381', 'FreeDiams::CA_HCDPD::DIN', 80488);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clorox Commercial Solutions Clorox Clean-Up Disinfectant Dilutable Bleach Cleaner', 'solution', 'V07AV', false, 0, '02319470', 'FreeDiams::CA_HCDPD::DIN', 80494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clorox Commercial Solutions Clorox Disinfecting Wipes', 'wipe', 'V07AV', false, 0, '02319462', 'FreeDiams::CA_HCDPD::DIN', 80495);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clorox Commercial Solutions Clorox Disinfecting Cleaner Degreaser', 'spray', 'V07AV', false, 0, '02319497', 'FreeDiams::CA_HCDPD::DIN', 80496);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clorox Commercial Solutions Clorox Clean-Up Disinfectant Bleach Cleaner', 'spray', 'V07AV', false, 0, '02319489', 'FreeDiams::CA_HCDPD::DIN', 80497);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Sildenafil R', 'tablet', 'G04BE03', false, 0, '02319500', 'FreeDiams::CA_HCDPD::DIN', 80498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Spf/Fps 30 Continuous Spray', 'spray', 'D02BA30', false, 0, '02319551', 'FreeDiams::CA_HCDPD::DIN', 80503);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Spf/Fps 50 Continuous Spray', 'spray', 'D02BA30', false, 0, '02319578', 'FreeDiams::CA_HCDPD::DIN', 80504);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olmetec Plus', 'tablet', 'C09DA08', false, 0, '02319616', 'FreeDiams::CA_HCDPD::DIN', 80508);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olmetec Plus', 'tablet', 'C09DA08', false, 0, '02319624', 'FreeDiams::CA_HCDPD::DIN', 80509);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olmetec Plus', 'tablet', 'C09DA08', false, 0, '02319632', 'FreeDiams::CA_HCDPD::DIN', 80510);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Sport Spf/Fps 15', 'lotion', 'D02BA30', false, 0, '02319683', 'FreeDiams::CA_HCDPD::DIN', 80515);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Sport Spf/Fps 30', 'lotion', 'D02BA30', false, 0, '02319691', 'FreeDiams::CA_HCDPD::DIN', 80516);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Sport Spf/Fps 50', 'lotion', 'D02BA30', false, 0, '02319705', 'FreeDiams::CA_HCDPD::DIN', 80517);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biosentry 904 Disinfectant', 'liquid', 'V07AV', false, 0, '02319756', 'FreeDiams::CA_HCDPD::DIN', 80521);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Sport Spf/Fps 15 Continuous Spray', 'spray', 'D02BA30', false, 0, '02319772', 'FreeDiams::CA_HCDPD::DIN', 80524);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Sport Spf/Fps 30 Continuous Spray', 'spray', 'D02BA30', false, 0, '02319780', 'FreeDiams::CA_HCDPD::DIN', 80525);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Sport Spf/Fps 50 Continuous Spray', 'spray', 'D02BA30', false, 0, '02319799', 'FreeDiams::CA_HCDPD::DIN', 80526);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Brighten Up Spf 15', 'lotion', 'D02BA30', false, 0, '02319802', 'FreeDiams::CA_HCDPD::DIN', 80527);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Obagi Clenziderm Acne Lotion', 'lotion', 'D10AE01', false, 0, '02319837', 'FreeDiams::CA_HCDPD::DIN', 80530);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neostrata Intense Crčme De Jour Réparides', 'cream', 'D02BA30', false, 0, '02319845', 'FreeDiams::CA_HCDPD::DIN', 80531);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biolav Desinfectant 166', 'solution', 'V07AV', false, 0, '02319853', 'FreeDiams::CA_HCDPD::DIN', 80532);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Risedronate', 'tablet', 'M05BA07', false, 0, '02319861', 'FreeDiams::CA_HCDPD::DIN', 80533);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chewable Bismuth Tablets With Calcium Carbonate', 'tablet (chewable)', 'A02AX', false, 0, '02319888', 'FreeDiams::CA_HCDPD::DIN', 80534);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cladribine For Injection', 'solution', 'L01BB04', false, 0, '02319918', 'FreeDiams::CA_HCDPD::DIN', 80536);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sport Lotion 50 Spf', 'lotion', 'D02BA30', false, 0, '02319926', 'FreeDiams::CA_HCDPD::DIN', 80537);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 50 Fps', 'lotion', 'D02BA30', false, 0, '02319950', 'FreeDiams::CA_HCDPD::DIN', 80539);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rapid Action', 'tablet', 'N02BE01', false, 0, '02319942', 'FreeDiams::CA_HCDPD::DIN', 80540);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Defend', 'liquid', 'V07AV', false, 0, '02319969', 'FreeDiams::CA_HCDPD::DIN', 80541);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Oxycodone', 'tablet', 'N02AA05', false, 0, '02319977', 'FreeDiams::CA_HCDPD::DIN', 80542);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Oxycodone', 'tablet', 'N02AA05', false, 0, '02319985', 'FreeDiams::CA_HCDPD::DIN', 80543);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Oxycodone', 'tablet', 'N02AA05', false, 0, '02319993', 'FreeDiams::CA_HCDPD::DIN', 80544);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paclitaxel For Injection Usp', 'solution', 'L01CD01', false, 0, '02320010', 'FreeDiams::CA_HCDPD::DIN', 80546);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoject', 'solution', 'L01BA01', false, 0, '02320029', 'FreeDiams::CA_HCDPD::DIN', 80549);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoject', 'solution', 'L01BA01', false, 0, '02320037', 'FreeDiams::CA_HCDPD::DIN', 80550);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoject', 'solution', 'L01BA01', false, 0, '02320045', 'FreeDiams::CA_HCDPD::DIN', 80551);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoject', 'solution', 'L01BA01', false, 0, '02320053', 'FreeDiams::CA_HCDPD::DIN', 80552);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Auro-Terbinafine', 'tablet', 'D01BA02', false, 0, '02320134', 'FreeDiams::CA_HCDPD::DIN', 80558);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Finasteride', 'tablet', 'D11AX10', false, 0, '02320169', 'FreeDiams::CA_HCDPD::DIN', 80561);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sprycel', 'tablet', 'L01XE06', false, 0, '02320193', 'FreeDiams::CA_HCDPD::DIN', 80564);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fruit Of The Earth Kids Spf/Fps 50', 'lotion', 'D02BA30', false, 0, '02320207', 'FreeDiams::CA_HCDPD::DIN', 80565);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutrogena Ultra Sheer Dry-Touch Sunscreen Spf 70', 'lotion', 'D02BA30', false, 0, '02320215', 'FreeDiams::CA_HCDPD::DIN', 80566);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Liftactiv Cxp Uv Spf 20', 'cream', 'D02BA30', false, 0, '02320223', 'FreeDiams::CA_HCDPD::DIN', 80567);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutrogena Ultra Sheer Dry-Touch Sunscreen Spf 85', 'lotion', 'D02BA30', false, 0, '02320231', 'FreeDiams::CA_HCDPD::DIN', 80568);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hands Fresh Alcohol-Free Foam Sanitizer', 'liquid', 'D08AJ01', false, 0, '02320258', 'FreeDiams::CA_HCDPD::DIN', 80569);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Methylphenidate Sr', 'tablet (extended-release)', 'N06BA04', false, 0, '02320312', 'FreeDiams::CA_HCDPD::DIN', 80575);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Selsun Blue Anti-Dandruff Shampoo', 'shampoo', 'D11AX12', false, 0, '02320320', 'FreeDiams::CA_HCDPD::DIN', 80576);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 15 Sunscreen Continuous Spray', 'spray', 'D02BA30', false, 0, '02320339', 'FreeDiams::CA_HCDPD::DIN', 80577);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sheer Lustre Day Moisture Spf 15', 'lotion', 'D02BA30', false, 0, '02320363', 'FreeDiams::CA_HCDPD::DIN', 80580);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Revelage Arbonne Brightening Moisture Hand Cream With Spf 30', 'cream', 'D02BA30', false, 0, '02320533', 'FreeDiams::CA_HCDPD::DIN', 80595);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Synflorix', 'suspension', 'J07AL02', false, 0, '02320541', 'FreeDiams::CA_HCDPD::DIN', 80596);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rabeprazole Ec', 'tablet (enteric-coated)', 'A02BC04', false, 0, '02320592', 'FreeDiams::CA_HCDPD::DIN', 80600);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rabeprazole Ec', 'tablet (enteric-coated)', 'A02BC04', false, 0, '02320606', 'FreeDiams::CA_HCDPD::DIN', 80601);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rabeprazole Ec', 'tablet (enteric-coated)', 'A02BC04', false, 0, '02320614', 'FreeDiams::CA_HCDPD::DIN', 80602);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rabeprazole Ec', 'tablet (enteric-coated)', 'A02BC04', false, 0, '02320622', 'FreeDiams::CA_HCDPD::DIN', 80603);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stelara', 'solution', 'L04AC05', false, 0, '02320673', 'FreeDiams::CA_HCDPD::DIN', 80608);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Terminator', 'gel', 'D10AE01', false, 0, '02320703', 'FreeDiams::CA_HCDPD::DIN', 80610);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Odourless Arthritis Relief', 'cream', 'M02AC', false, 0, '02320746', 'FreeDiams::CA_HCDPD::DIN', 80615);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02320754', 'FreeDiams::CA_HCDPD::DIN', 80616);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02320762', 'FreeDiams::CA_HCDPD::DIN', 80617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02320770', 'FreeDiams::CA_HCDPD::DIN', 80618);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy', 'liquid', 'R06AA02', false, 0, '02320789', 'FreeDiams::CA_HCDPD::DIN', 80619);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('White Petroleum Jelly Ultra Moisturizer', 'ointment', 'D02AC', false, 0, '02320797', 'FreeDiams::CA_HCDPD::DIN', 80620);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('White Petroleum Jelly Baby Fresh Scent', 'ointment', 'D02AC', false, 0, '02320800', 'FreeDiams::CA_HCDPD::DIN', 80621);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Omeprazole', 'capsule (delayed release)', 'A02BC01', false, 0, '02320851', 'FreeDiams::CA_HCDPD::DIN', 80626);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stericide', 'liquid', 'V07AV', false, 0, '02320886', 'FreeDiams::CA_HCDPD::DIN', 80630);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mary Kay Tinted Lip Balm Sunscreen Spf 15', 'stick', 'D02BA30', false, 0, '02320894', 'FreeDiams::CA_HCDPD::DIN', 80631);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Memantine', 'tablet', 'N06DX01', false, 0, '02320908', 'FreeDiams::CA_HCDPD::DIN', 80632);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alrex', 'suspension', 'S01BA14', false, 0, '02320924', 'FreeDiams::CA_HCDPD::DIN', 80634);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Extra Strength Mucus & Phlegm', 'solution', 'R05CA03', false, 0, '02320940', 'FreeDiams::CA_HCDPD::DIN', 80636);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Extra Strength Mucous And Phlegm Relief Plus Cough Control', 'solution', 'R05FA02', false, 0, '02320959', 'FreeDiams::CA_HCDPD::DIN', 80637);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Strepsils Cool', 'lozenge', 'R02AA03', false, 0, '02320983', 'FreeDiams::CA_HCDPD::DIN', 80640);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crčme Montagne Et Grand Froid', 'cream', 'D02BA30', false, 0, '02320991', 'FreeDiams::CA_HCDPD::DIN', 80641);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutricide-256', 'liquid', 'V07AV', false, 0, '02321009', 'FreeDiams::CA_HCDPD::DIN', 80642);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Husky 891 Arena Disinfectant', 'liquid', 'V07AV', false, 0, '02321033', 'FreeDiams::CA_HCDPD::DIN', 80645);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutricide-64', 'liquid', 'V07AV', false, 0, '02321041', 'FreeDiams::CA_HCDPD::DIN', 80646);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pristiq', 'tablet (extended-release)', 'N06AX23', false, 0, '02321092', 'FreeDiams::CA_HCDPD::DIN', 80650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pristiq', 'tablet (extended-release)', 'N06AX23', false, 0, '02321106', 'FreeDiams::CA_HCDPD::DIN', 80651);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lotemax', 'suspension', 'S01BA14', false, 0, '02321114', 'FreeDiams::CA_HCDPD::DIN', 80652);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Memantine', 'tablet', 'N06DX01', false, 0, '02321130', 'FreeDiams::CA_HCDPD::DIN', 80653);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Nifedipine Extended Release', 'tablet (extended-release)', 'C08CA05', false, 0, '02321149', 'FreeDiams::CA_HCDPD::DIN', 80655);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Yaz', 'tablet', 'G03AA12', false, 0, '02321157', 'FreeDiams::CA_HCDPD::DIN', 80656);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Auro-Gabapentin', 'capsule', 'N03AX12', false, 0, '02321203', 'FreeDiams::CA_HCDPD::DIN', 80660);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Auro-Gabapentin', 'capsule', 'N03AX12', false, 0, '02321211', 'FreeDiams::CA_HCDPD::DIN', 80661);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Auro-Gabapentin', 'capsule', 'N03AX12', false, 0, '02321238', 'FreeDiams::CA_HCDPD::DIN', 80662);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Temodal', 'powder for solution', 'L01AX03', false, 0, '02321262', 'FreeDiams::CA_HCDPD::DIN', 80666);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Allergy Formula Liquid Capsules', 'capsule', 'R06AA02', false, 0, '02321270', 'FreeDiams::CA_HCDPD::DIN', 80667);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oil-Absorbing Day Lotion With Spf 20', 'lotion', 'D02BA30', false, 0, '02321297', 'FreeDiams::CA_HCDPD::DIN', 80669);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nurturing Day Lotion With Spf 20', 'lotion', 'D02BA30', false, 0, '02321300', 'FreeDiams::CA_HCDPD::DIN', 80670);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun Smart Levres Fps 15', 'stick', 'D02BA30', false, 0, '02321319', 'FreeDiams::CA_HCDPD::DIN', 80671);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Creme Aquamucine Cream Fps 15 Spf', 'cream', 'D02BA30', false, 0, '02321335', 'FreeDiams::CA_HCDPD::DIN', 80673);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Olanzapine Od', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02321343', 'FreeDiams::CA_HCDPD::DIN', 80674);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Olanzapine Od', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02321351', 'FreeDiams::CA_HCDPD::DIN', 80675);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Olanzapine Od', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02321378', 'FreeDiams::CA_HCDPD::DIN', 80676);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Olanzapine Od', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02321386', 'FreeDiams::CA_HCDPD::DIN', 80677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('T36 The Liquid Antiseptic Hand Sanitizer', 'liquid', 'D08AJ51', false, 0, '02321424', 'FreeDiams::CA_HCDPD::DIN', 80681);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Extra Strength All-In-One Cold And Flu With Warming Sensation', 'syrup', 'N02BE51', false, 0, '02321432', 'FreeDiams::CA_HCDPD::DIN', 80682);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Repaglinide', 'tablet', 'A10BX02', false, 0, '02321475', 'FreeDiams::CA_HCDPD::DIN', 80688);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Repaglinide', 'tablet', 'A10BX02', false, 0, '02321483', 'FreeDiams::CA_HCDPD::DIN', 80689);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Repaglinide', 'tablet', 'A10BX02', false, 0, '02321491', 'FreeDiams::CA_HCDPD::DIN', 80690);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cachet', 'aerosol', 'V07AV', false, 0, '02321505', 'FreeDiams::CA_HCDPD::DIN', 80691);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Seroquel Xr', 'tablet (extended-release)', 'N05AH04', false, 0, '02321513', 'FreeDiams::CA_HCDPD::DIN', 80692);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zopiclone', 'tablet', 'N05CF01', false, 0, '02321521', 'FreeDiams::CA_HCDPD::DIN', 80693);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zopiclone', 'tablet', 'N05CF01', false, 0, '02321548', 'FreeDiams::CA_HCDPD::DIN', 80694);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bisoprolol', 'tablet', 'C07AB07', false, 0, '02321556', 'FreeDiams::CA_HCDPD::DIN', 80695);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diamond Radiance Rejuvenating Cream Spf 15', 'cream', 'D02BA30', false, 0, '02321564', 'FreeDiams::CA_HCDPD::DIN', 80696);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bisoprolol', 'tablet', 'C07AB07', false, 0, '02321572', 'FreeDiams::CA_HCDPD::DIN', 80697);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lisinopril', 'tablet', 'C09AA03', false, 0, '02321580', 'FreeDiams::CA_HCDPD::DIN', 80698);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lisinopril', 'tablet', 'C09AA03', false, 0, '02321610', 'FreeDiams::CA_HCDPD::DIN', 80699);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lisinopril', 'tablet', 'C09AA03', false, 0, '02321629', 'FreeDiams::CA_HCDPD::DIN', 80702);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coversyl Plus Hd', 'tablet', 'C09BA04', false, 0, '02321653', 'FreeDiams::CA_HCDPD::DIN', 80705);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint Glaze Fx', 'liquid', 'D02BA30', false, 0, '02321688', 'FreeDiams::CA_HCDPD::DIN', 80707);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lubricant Eye Drops/ Artificial Tears', 'drops', 'S01XA20', false, 0, '02321696', 'FreeDiams::CA_HCDPD::DIN', 80709);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abbott Axsym System Tubing Decontamination Solution', 'liquid', 'V07AV', false, 0, '02321742', 'FreeDiams::CA_HCDPD::DIN', 80714);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asa 80', 'tablet (chewable)', 'N02BA01', false, 0, '02321750', 'FreeDiams::CA_HCDPD::DIN', 80715);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asa Ec 80', 'tablet (delayed-release)', 'N02BA01', false, 0, '02321769', 'FreeDiams::CA_HCDPD::DIN', 80717);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kemsol Airx 44 Plus Detergent/Disinfectant', 'liquid', 'V07AV', false, 0, '02321785', 'FreeDiams::CA_HCDPD::DIN', 80719);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.A.C Studio Moisture Tint Spf 15', 'liquid', 'D02BA02', false, 0, '02321793', 'FreeDiams::CA_HCDPD::DIN', 80720);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.A.C Suntints Spf 20 Liquid Lip Balm', 'liquid', 'D02BA30', false, 0, '02321823', 'FreeDiams::CA_HCDPD::DIN', 80723);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Amlodipine', 'tablet', 'C08CA01', false, 0, '02321858', 'FreeDiams::CA_HCDPD::DIN', 80726);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Amlodipine', 'tablet', 'C08CA01', false, 0, '02321866', 'FreeDiams::CA_HCDPD::DIN', 80727);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Emergency Acne Vanishing Facial Cleanser', 'lotion', 'D10AE01', false, 0, '02321874', 'FreeDiams::CA_HCDPD::DIN', 80728);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Repair Lotion', 'lotion', 'D10AE01', false, 0, '02321882', 'FreeDiams::CA_HCDPD::DIN', 80729);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('T36 The Wipe Antiseptic Hand Sanitizer', 'wipe', 'D08AJ51', false, 0, '02321947', 'FreeDiams::CA_HCDPD::DIN', 80735);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quatromyicide Ii', 'liquid', 'V07AV', false, 0, '02321963', 'FreeDiams::CA_HCDPD::DIN', 80737);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Triple Action', 'liquid', 'V07AV', false, 0, '02322110', 'FreeDiams::CA_HCDPD::DIN', 80738);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Windex Multi-Surface Antibacterial Disinfectant', 'solution', 'V07AV', false, 0, '02321998', 'FreeDiams::CA_HCDPD::DIN', 80740);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aveeno Active Naturals Ultra-Calming Daily Moisturizer Spf 30', 'lotion', 'D02BA30', false, 0, '02322064', 'FreeDiams::CA_HCDPD::DIN', 80747);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Even Better Skin Tone Correcting Moisturizer Spf 20', 'cream', 'D02BA30', false, 0, '02322072', 'FreeDiams::CA_HCDPD::DIN', 80748);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Saniquat', 'solution', 'D08AJ01', false, 0, '02322080', 'FreeDiams::CA_HCDPD::DIN', 80749);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('3-D', 'liquid', 'V07AV', false, 0, '02322129', 'FreeDiams::CA_HCDPD::DIN', 80754);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('T36 Antiseptic Hand Sanitizer Spray', 'spray', 'D08AJ51', false, 0, '02322153', 'FreeDiams::CA_HCDPD::DIN', 80764);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Medroxyprogesterone Acetate Injectable Suspension Usp', 'suspension', 'G03AC06', false, 0, '02322250', 'FreeDiams::CA_HCDPD::DIN', 80771);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eltamd Skincare Uv Facial Spf 30', 'cream', 'D02BA30', false, 0, '02322277', 'FreeDiams::CA_HCDPD::DIN', 80773);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soliris', 'solution', 'L04AA25', false, 0, '02322285', 'FreeDiams::CA_HCDPD::DIN', 80774);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eltamd Skincare Uv Defense Spf 45', 'lotion', 'D02BA30', false, 0, '02322293', 'FreeDiams::CA_HCDPD::DIN', 80775);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eltamd Skincare Uv Daily Spf 40', 'lotion', 'D02BA30', false, 0, '02322307', 'FreeDiams::CA_HCDPD::DIN', 80776);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Med-Letrozole', 'tablet', 'L02BG04', false, 0, '02322315', 'FreeDiams::CA_HCDPD::DIN', 80777);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Naratriptan', 'tablet', 'N02CC02', false, 0, '02322323', 'FreeDiams::CA_HCDPD::DIN', 80778);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abilify', 'tablet', 'N05AX12', false, 0, '02322374', 'FreeDiams::CA_HCDPD::DIN', 80782);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abilify', 'tablet', 'N05AX12', false, 0, '02322382', 'FreeDiams::CA_HCDPD::DIN', 80783);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abilify', 'tablet', 'N05AX12', false, 0, '02322390', 'FreeDiams::CA_HCDPD::DIN', 80784);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abilify', 'tablet', 'N05AX12', false, 0, '02322404', 'FreeDiams::CA_HCDPD::DIN', 80785);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abilify', 'tablet', 'N05AX12', false, 0, '02322412', 'FreeDiams::CA_HCDPD::DIN', 80786);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abilify', 'tablet', 'N05AX12', false, 0, '02322455', 'FreeDiams::CA_HCDPD::DIN', 80790);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 15 Lotion', 'lotion', 'D02BA30', false, 0, '02322463', 'FreeDiams::CA_HCDPD::DIN', 80791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Testosterone', 'capsule', 'G03BA03', false, 0, '02322498', 'FreeDiams::CA_HCDPD::DIN', 80793);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('T36 Medicated Cleanser', 'liquid', 'D08AE04', false, 0, '02322501', 'FreeDiams::CA_HCDPD::DIN', 80794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydramax + Active Teinté', 'emulsion', 'D02BA30', false, 0, '02322552', 'FreeDiams::CA_HCDPD::DIN', 80800);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topicaine 5', 'gel', 'C05AD01', false, 0, '02322560', 'FreeDiams::CA_HCDPD::DIN', 80801);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Finasteride', 'tablet', 'G04CB01', false, 0, '02322579', 'FreeDiams::CA_HCDPD::DIN', 80802);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adrien Gagnon Charbon Activé/Activated Charcoal Capsules', 'capsule', 'A07BA01', false, 0, '02322633', 'FreeDiams::CA_HCDPD::DIN', 80809);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Massage', 'stick', 'D02BA30', false, 0, '02322641', 'FreeDiams::CA_HCDPD::DIN', 80810);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ondansetron Injection, Usp', 'solution', 'A04AA01', false, 0, '02322668', 'FreeDiams::CA_HCDPD::DIN', 80811);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soins Soleil Crčme Teintée Anti-Rides Age-Defying Tinted Cream Faible/Low Protection Uva/Uvb Spf10', 'cream', 'D02BA30', false, 0, '02322722', 'FreeDiams::CA_HCDPD::DIN', 80820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soins Soleil Crčme Visage Face Cream Haute/High Protection Uva/Uvb Spf 30', 'cream', 'D02BA30', false, 0, '02322730', 'FreeDiams::CA_HCDPD::DIN', 80821);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acne Therapy Cleansing Wash', 'solution', 'D10AE01', false, 0, '02322749', 'FreeDiams::CA_HCDPD::DIN', 80822);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Granisetron Hydrochloride Injection', 'liquid', 'A04AA02', false, 0, '02322765', 'FreeDiams::CA_HCDPD::DIN', 80824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soins Soleil Lait Corps Body Lotion Moyenne/Medium Protection Uva/Uvb Spf 20', 'lotion', 'D02BA30', false, 0, '02322811', 'FreeDiams::CA_HCDPD::DIN', 80828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tylenol Cold Nightime Rapid Release', 'tablet', 'N02BE51', false, 0, '02322838', 'FreeDiams::CA_HCDPD::DIN', 80829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dandruff Conditioner', 'suspension', 'D11AX12', false, 0, '02322846', 'FreeDiams::CA_HCDPD::DIN', 80831);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nplate', 'powder for solution', 'B02BX04', false, 0, '02322854', 'FreeDiams::CA_HCDPD::DIN', 80832);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nplate', 'powder for solution', 'B02BX04', false, 0, '02322862', 'FreeDiams::CA_HCDPD::DIN', 80833);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vyvanse', 'capsule', 'N06BA12', false, 0, '02322951', 'FreeDiams::CA_HCDPD::DIN', 80843);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vyvanse', 'capsule', 'N06BA12', false, 0, '02322978', 'FreeDiams::CA_HCDPD::DIN', 80844);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multi-Purpose Solution', 'solution', 'S01XA20', false, 0, '02323044', 'FreeDiams::CA_HCDPD::DIN', 80854);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Inspra', 'tablet', 'C03DA04', false, 0, '02323052', 'FreeDiams::CA_HCDPD::DIN', 80855);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Inspra', 'tablet', 'C03DA04', false, 0, '02323060', 'FreeDiams::CA_HCDPD::DIN', 80856);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sani Hands For Kids Antibacterial Hands And Face Wipes', 'wipe', 'D08AJ01', false, 0, '02323079', 'FreeDiams::CA_HCDPD::DIN', 80857);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Hydrationist Maximum Moisture Creme Spf 15', 'cream', 'D02BA30', false, 0, '02323087', 'FreeDiams::CA_HCDPD::DIN', 80858);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Brite Prep Fx', 'cream', 'D02BA30', false, 0, '02323095', 'FreeDiams::CA_HCDPD::DIN', 80859);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elizabeth Arden Ceramide Plump Perfect Ultra Lift And Firm Moisture Cream Spf 30', 'cream', 'D02BA30', false, 0, '02323141', 'FreeDiams::CA_HCDPD::DIN', 80864);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elizabeth Arden Ceramide Plump Perfect Ultra Lift And Firm Moisture Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02323168', 'FreeDiams::CA_HCDPD::DIN', 80865);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Attitude', 'solution', 'V07AV', false, 0, '02323176', 'FreeDiams::CA_HCDPD::DIN', 80866);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxycontin', 'tablet (extended-release)', 'N02AA05', false, 0, '02323192', 'FreeDiams::CA_HCDPD::DIN', 80868);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxycontin', 'tablet (extended-release)', 'N02AA05', false, 0, '02323206', 'FreeDiams::CA_HCDPD::DIN', 80869);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxycontin', 'tablet (extended-release)', 'N02AA05', false, 0, '02323214', 'FreeDiams::CA_HCDPD::DIN', 80870);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metvix', 'cream', 'L01XD03', false, 0, '02323273', 'FreeDiams::CA_HCDPD::DIN', 80876);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dial Complete Moisturizing Antibacterial Foaming Hand Wash', 'solution', 'D08AE04', false, 0, '02323281', 'FreeDiams::CA_HCDPD::DIN', 80877);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tropiques Minérale', 'powder', 'D02BA02', false, 0, '02323303', 'FreeDiams::CA_HCDPD::DIN', 80878);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glazewear Spf/Fps 15 Lip Gloss', 'gel', 'D02BA30', false, 0, '02323311', 'FreeDiams::CA_HCDPD::DIN', 80879);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergy Formula', 'tablet', 'R06AA02', false, 0, '02323346', 'FreeDiams::CA_HCDPD::DIN', 80881);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enviro Solutions 128', 'liquid', 'V07AV', false, 0, '02323397', 'FreeDiams::CA_HCDPD::DIN', 80887);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Fluconazole-150', 'capsule', 'J02AC01', false, 0, '02323419', 'FreeDiams::CA_HCDPD::DIN', 80890);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sig-Enalapril', 'tablet', 'C09AA02', false, 0, '02323478', 'FreeDiams::CA_HCDPD::DIN', 80898);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sig-Enalapril', 'tablet', 'C09AA02', false, 0, '02323486', 'FreeDiams::CA_HCDPD::DIN', 80899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sig-Enalapril', 'tablet', 'C09AA02', false, 0, '02323494', 'FreeDiams::CA_HCDPD::DIN', 80900);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sig-Enalapril', 'tablet', 'C09AA02', false, 0, '02323508', 'FreeDiams::CA_HCDPD::DIN', 80901);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chest Congestion', 'liquid', 'R05CA03', false, 0, '02323796', 'FreeDiams::CA_HCDPD::DIN', 80928);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Dayquil Mucus Control', 'liquid', 'R05CA03', false, 0, '02323885', 'FreeDiams::CA_HCDPD::DIN', 80935);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vicks Dayquil Mucus Control Dm', 'liquid', 'R05FA02', false, 0, '02323907', 'FreeDiams::CA_HCDPD::DIN', 80938);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nite Time Cold And Cough', 'liquid', 'R01BA53', false, 0, '02323915', 'FreeDiams::CA_HCDPD::DIN', 80939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Liquid Oxygen', 'gas', 'V03AN01', false, 0, '02323974', 'FreeDiams::CA_HCDPD::DIN', 80944);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prezista', 'tablet', 'J05AE10', false, 0, '02324016', 'FreeDiams::CA_HCDPD::DIN', 80949);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prezista', 'tablet', 'J05AE10', false, 0, '02324024', 'FreeDiams::CA_HCDPD::DIN', 80950);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xeomin', 'powder for solution', 'M03AX01', false, 0, '02324032', 'FreeDiams::CA_HCDPD::DIN', 80952);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Memantine', 'tablet', 'N06DX01', false, 0, '02324067', 'FreeDiams::CA_HCDPD::DIN', 80955);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epirubicin For Injection', 'solution', 'L01DB03', false, 0, '02324091', 'FreeDiams::CA_HCDPD::DIN', 80958);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lysol Brand Iii Disinfectant All Purpose Cleaner', 'spray', 'V07AV', false, 0, '02324105', 'FreeDiams::CA_HCDPD::DIN', 80959);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultraquin 4% Hydroquinone Cream With Sunscreens', 'cream', 'D11AX11', false, 0, '02324113', 'FreeDiams::CA_HCDPD::DIN', 80960);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Verapamil Sr', 'tablet (extended-release)', 'C08DA01', false, 0, '02324156', 'FreeDiams::CA_HCDPD::DIN', 80963);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pro-Verapamil Sr', 'tablet (extended-release)', 'C08DA01', false, 0, '02324164', 'FreeDiams::CA_HCDPD::DIN', 80964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cefprozil', 'tablet', 'J01DC10', false, 0, '02324180', 'FreeDiams::CA_HCDPD::DIN', 80966);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Etidronatecal', 'kit', 'M05BB01', false, 0, '02324199', 'FreeDiams::CA_HCDPD::DIN', 80967);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gemcitabine For Injection', 'powder for solution', 'L01BC05', false, 0, '02324210', 'FreeDiams::CA_HCDPD::DIN', 80969);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Zolmitriptan', 'tablet', 'N02CC03', false, 0, '02324229', 'FreeDiams::CA_HCDPD::DIN', 80970);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pure Eyes Multi-Purpose Solution', 'solution', 'S01XA20', false, 0, '02324237', 'FreeDiams::CA_HCDPD::DIN', 80971);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ct-25', 'spray', 'V07AV', false, 0, '02324245', 'FreeDiams::CA_HCDPD::DIN', 80972);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Hydrocodone', 'syrup', 'R05DA03', false, 0, '02324253', 'FreeDiams::CA_HCDPD::DIN', 80973);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ecolav Desinfectant 480', 'solution', 'V07AV', false, 0, '02324296', 'FreeDiams::CA_HCDPD::DIN', 80976);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Resilience Lift Extreme Liquid Makeup Spf 15', 'liquid', 'D02BA30', false, 0, '02324318', 'FreeDiams::CA_HCDPD::DIN', 80977);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Meloxicam', 'tablet', 'M01AC06', false, 0, '02324326', 'FreeDiams::CA_HCDPD::DIN', 80978);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Meloxicam', 'tablet', 'M01AC06', false, 0, '02324334', 'FreeDiams::CA_HCDPD::DIN', 80979);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vaseline Aloe Fresh Hydrating + Spf Body Lotion With Aloe And Sunscreen', 'lotion', 'D02BA30', false, 0, '02324385', 'FreeDiams::CA_HCDPD::DIN', 80985);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Motrin Cold & Sinus Pain', 'tablet', 'M01AE51', false, 0, '02324423', 'FreeDiams::CA_HCDPD::DIN', 80988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Balance Plus Cleaner Disinfectant/ Balance Plus Nettoyant Désinfectant', 'liquid', 'V07AV', false, 0, '02324458', 'FreeDiams::CA_HCDPD::DIN', 80990);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crc Hydro Force Disinfectant Surface Cleaner', 'aerosol', 'V07AV', false, 0, '02324466', 'FreeDiams::CA_HCDPD::DIN', 80991);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clarithromycin', 'tablet', 'J01FA09', false, 0, '02324482', 'FreeDiams::CA_HCDPD::DIN', 80993);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clarithromycin', 'tablet', 'J01FA09', false, 0, '02324490', 'FreeDiams::CA_HCDPD::DIN', 80994);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carvedilol', 'tablet', 'C07AG02', false, 0, '02324504', 'FreeDiams::CA_HCDPD::DIN', 80995);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carvedilol', 'tablet', 'C07AG02', false, 0, '02324512', 'FreeDiams::CA_HCDPD::DIN', 80996);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carvedilol', 'tablet', 'C07AG02', false, 0, '02324520', 'FreeDiams::CA_HCDPD::DIN', 80997);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carvedilol', 'tablet', 'C07AG02', false, 0, '02324539', 'FreeDiams::CA_HCDPD::DIN', 80998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Rivastigmine', 'capsule', 'N06DA03', false, 0, '02324563', 'FreeDiams::CA_HCDPD::DIN', 81001);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Rivastigmine', 'capsule', 'N06DA03', false, 0, '02324571', 'FreeDiams::CA_HCDPD::DIN', 81002);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Rivastigmine', 'capsule', 'N06DA03', false, 0, '02324598', 'FreeDiams::CA_HCDPD::DIN', 81003);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Rivastigmine', 'capsule', 'N06DA03', false, 0, '02324601', 'FreeDiams::CA_HCDPD::DIN', 81004);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Oxycodone/Acet', 'tablet', 'N02BE51', false, 0, '02324628', 'FreeDiams::CA_HCDPD::DIN', 81005);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diorskin Nude', 'liquid', 'D02BA30', false, 0, '02324636', 'FreeDiams::CA_HCDPD::DIN', 81007);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sumatriptan', 'tablet', 'N02CC01', false, 0, '02324652', 'FreeDiams::CA_HCDPD::DIN', 81009);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sumatriptan', 'tablet', 'N02CC01', false, 0, '02324660', 'FreeDiams::CA_HCDPD::DIN', 81010);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Venusan Cleaner, Degreaser, Disinfectant, Sanitizer, Fungicide, Deodorizer', 'liquid', 'V07AV', false, 0, '02324695', 'FreeDiams::CA_HCDPD::DIN', 81013);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Brillex Cleaner, Degreaser, Disinfectant, Sanitizer, Fungicide, Deodorizer', 'liquid', 'V07AV', false, 0, '02324709', 'FreeDiams::CA_HCDPD::DIN', 81014);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Axe Freeze Itch Relief 2-In-1 Cooling Anti-Dandruff', 'shampoo', 'D11AX12', false, 0, '02324717', 'FreeDiams::CA_HCDPD::DIN', 81015);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baléa Face Lip Balm Spf 15', 'stick', 'D02BA30', false, 0, '02324725', 'FreeDiams::CA_HCDPD::DIN', 81016);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baléa Face Lip Balm Spf 30', 'stick', 'D02BA30', false, 0, '02324733', 'FreeDiams::CA_HCDPD::DIN', 81017);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Zolmitriptan Odt', 'tablet (orally disintegrating)', 'N02CC03', false, 0, '02324768', 'FreeDiams::CA_HCDPD::DIN', 81019);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simponi', 'solution', 'L04AB06', false, 0, '02324776', 'FreeDiams::CA_HCDPD::DIN', 81020);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simponi', 'solution', 'L04AB06', false, 0, '02324784', 'FreeDiams::CA_HCDPD::DIN', 81021);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Famciclovir', 'tablet', 'J05AB09', false, 0, '02324865', 'FreeDiams::CA_HCDPD::DIN', 81030);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Famciclovir', 'tablet', 'J05AB09', false, 0, '02324873', 'FreeDiams::CA_HCDPD::DIN', 81031);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Famciclovir', 'tablet', 'J05AB09', false, 0, '02324881', 'FreeDiams::CA_HCDPD::DIN', 81032);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydraphase Uv Eyes', 'cream', 'D02BA02', false, 0, '02324903', 'FreeDiams::CA_HCDPD::DIN', 81033);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Future Solution Lx Daytime Protective Cream Spf 15', 'cream', 'D02BA30', false, 0, '02324911', 'FreeDiams::CA_HCDPD::DIN', 81034);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Atorvastatin', 'tablet', 'C10AA05', false, 0, '02324946', 'FreeDiams::CA_HCDPD::DIN', 81036);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Atorvastatin', 'tablet', 'C10AA05', false, 0, '02324954', 'FreeDiams::CA_HCDPD::DIN', 81037);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Atorvastatin', 'tablet', 'C10AA05', false, 0, '02324962', 'FreeDiams::CA_HCDPD::DIN', 81038);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Atorvastatin', 'tablet', 'C10AA05', false, 0, '02324970', 'FreeDiams::CA_HCDPD::DIN', 81039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clearlax', 'powder for solution', 'A06AD15', false, 0, '02324989', 'FreeDiams::CA_HCDPD::DIN', 81040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lumigan Rc', 'solution', 'S01EE03', false, 0, '02324997', 'FreeDiams::CA_HCDPD::DIN', 81041);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('85 Spf Cream', 'cream', 'D02BA30', false, 0, '02325012', 'FreeDiams::CA_HCDPD::DIN', 81043);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('70 Spf Cream', 'cream', 'D02BA30', false, 0, '02325020', 'FreeDiams::CA_HCDPD::DIN', 81044);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citalopram-10', 'tablet', 'N06AB04', false, 0, '02325047', 'FreeDiams::CA_HCDPD::DIN', 81046);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Omnitrope', 'solution', 'H01AC01', false, 0, '02325063', 'FreeDiams::CA_HCDPD::DIN', 81048);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Omnitrope', 'solution', 'H01AC01', false, 0, '02325071', 'FreeDiams::CA_HCDPD::DIN', 81049);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Trazodone', 'tablet', 'N06AX05', false, 0, '02325101', 'FreeDiams::CA_HCDPD::DIN', 81051);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Trazodone', 'tablet', 'N06AX05', false, 0, '02325128', 'FreeDiams::CA_HCDPD::DIN', 81052);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Topiramate', 'tablet', 'N03AX11', false, 0, '02325136', 'FreeDiams::CA_HCDPD::DIN', 81053);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Topiramate', 'tablet', 'N03AX11', false, 0, '02325144', 'FreeDiams::CA_HCDPD::DIN', 81054);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Topiramate', 'tablet', 'N03AX11', false, 0, '02325152', 'FreeDiams::CA_HCDPD::DIN', 81055);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ondansetron', 'tablet', 'A04AA01', false, 0, '02325160', 'FreeDiams::CA_HCDPD::DIN', 81057);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Mirtazapine', 'tablet', 'N06AX11', false, 0, '02325179', 'FreeDiams::CA_HCDPD::DIN', 81058);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Mirtazapine', 'tablet', 'N06AX11', false, 0, '02325187', 'FreeDiams::CA_HCDPD::DIN', 81059);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyclobenzaprine', 'tablet', 'M03BX08', false, 0, '02325195', 'FreeDiams::CA_HCDPD::DIN', 81060);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sotalol', 'tablet', 'C07AA07', false, 0, '02325209', 'FreeDiams::CA_HCDPD::DIN', 81061);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sotalol', 'tablet', 'C07AA07', false, 0, '02325217', 'FreeDiams::CA_HCDPD::DIN', 81062);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Epinephrine Injection Usp 1 Mg/Ml', 'solution', 'C01CA24', false, 0, '02325225', 'FreeDiams::CA_HCDPD::DIN', 81063);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bicalutamide', 'tablet', 'L02BB03', false, 0, '02325233', 'FreeDiams::CA_HCDPD::DIN', 81064);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Collagen Moisture Filler', 'lotion', 'D02BA30', false, 0, '02325268', 'FreeDiams::CA_HCDPD::DIN', 81066);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Sheer Dry-Touch Sunscreen Spf 110', 'lotion', 'D02BA30', false, 0, '02325292', 'FreeDiams::CA_HCDPD::DIN', 81069);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diltiazem Tz', 'capsule (extended release)', 'C08DB01', false, 0, '02325306', 'FreeDiams::CA_HCDPD::DIN', 81070);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diltiazem Tz', 'capsule (extended release)', 'C08DB01', false, 0, '02325314', 'FreeDiams::CA_HCDPD::DIN', 81071);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diltiazem Tz', 'capsule (extended release)', 'C08DB01', false, 0, '02325322', 'FreeDiams::CA_HCDPD::DIN', 81072);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diltiazem Tz', 'capsule (extended release)', 'C08DB01', false, 0, '02325330', 'FreeDiams::CA_HCDPD::DIN', 81073);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diltiazem Tz', 'capsule (extended release)', 'C08DB01', false, 0, '02325349', 'FreeDiams::CA_HCDPD::DIN', 81074);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bupropion Sr', 'tablet (extended-release)', 'N06AX12', false, 0, '02325357', 'FreeDiams::CA_HCDPD::DIN', 81075);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Sheer Dry-Touch Sunscreen Spf 100', 'lotion', 'D02BA30', false, 0, '02325365', 'FreeDiams::CA_HCDPD::DIN', 81076);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Bupropion Sr', 'tablet (extended-release)', 'N06AX12', false, 0, '02325373', 'FreeDiams::CA_HCDPD::DIN', 81077);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Ramipril', 'capsule', 'C09AA05', false, 0, '02325381', 'FreeDiams::CA_HCDPD::DIN', 81078);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized June Grass Pollen', 'liquid', 'V01AA02', false, 0, '02325454', 'FreeDiams::CA_HCDPD::DIN', 81083);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vagifem 10', 'vaginal tablet', 'G03CA03', false, 0, '02325462', 'FreeDiams::CA_HCDPD::DIN', 81084);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized Timothy Grass Pollen', 'liquid', 'V01AA02', false, 0, '02325470', 'FreeDiams::CA_HCDPD::DIN', 81085);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized Orchard Grass Pollen', 'liquid', 'V01AA02', false, 0, '02325489', 'FreeDiams::CA_HCDPD::DIN', 81086);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized Redtop Grass Pollen', 'liquid', 'V01AA02', false, 0, '02325497', 'FreeDiams::CA_HCDPD::DIN', 81087);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized Perennnial Rye Grass Pollen', 'liquid', 'V01AA02', false, 0, '02325500', 'FreeDiams::CA_HCDPD::DIN', 81088);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized Sweet Vernal Grass Pollen', 'liquid', 'V01AA02', false, 0, '02325519', 'FreeDiams::CA_HCDPD::DIN', 81089);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized Meadow Fescue Grass Pollen', 'liquid', 'V01AA02', false, 0, '02325527', 'FreeDiams::CA_HCDPD::DIN', 81090);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Mixture Of 4 Standardized Grass Pollen', 'liquid', 'V01AA02', false, 0, '02325535', 'FreeDiams::CA_HCDPD::DIN', 81091);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Mixture Of 5 Standardized Grass Pollen', 'liquid', 'V01AA02', false, 0, '02325543', 'FreeDiams::CA_HCDPD::DIN', 81092);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Protective Ointment', 'ointment', 'D02AC', false, 0, '02325578', 'FreeDiams::CA_HCDPD::DIN', 81094);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bibag', 'powder for solution', 'B05ZA', false, 0, '02325586', 'FreeDiams::CA_HCDPD::DIN', 81095);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone Sodium For Injection Bp', 'powder for solution', 'J01DD04', false, 0, '02325594', 'FreeDiams::CA_HCDPD::DIN', 81096);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone Sodium For Injection Bp', 'powder for solution', 'J01DD04', false, 0, '02325616', 'FreeDiams::CA_HCDPD::DIN', 81098);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone Sodium For Injection Bp', 'powder for solution', 'J01DD04', false, 0, '02325624', 'FreeDiams::CA_HCDPD::DIN', 81099);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceftriaxone Sodium For Injection Bp', 'powder for solution', 'J01DD04', false, 0, '02325632', 'FreeDiams::CA_HCDPD::DIN', 81100);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Olanzapine', 'tablet', 'N05AH03', false, 0, '02325659', 'FreeDiams::CA_HCDPD::DIN', 81102);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Olanzapine', 'tablet', 'N05AH03', false, 0, '02325667', 'FreeDiams::CA_HCDPD::DIN', 81103);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Olanzapine', 'tablet', 'N05AH03', false, 0, '02325675', 'FreeDiams::CA_HCDPD::DIN', 81104);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Olanzapine', 'tablet', 'N05AH03', false, 0, '02325683', 'FreeDiams::CA_HCDPD::DIN', 81105);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Olanzapine', 'tablet', 'N05AH03', false, 0, '02325691', 'FreeDiams::CA_HCDPD::DIN', 81106);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Olanzapine', 'tablet', 'N05AH03', false, 0, '02325713', 'FreeDiams::CA_HCDPD::DIN', 81107);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hemacart', 'powder for solution', 'B05ZA', false, 0, '02325772', 'FreeDiams::CA_HCDPD::DIN', 81113);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pramipexole', 'tablet', 'N04BC05', false, 0, '02325802', 'FreeDiams::CA_HCDPD::DIN', 81116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pramipexole', 'tablet', 'N04BC05', false, 0, '02325810', 'FreeDiams::CA_HCDPD::DIN', 81117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pramipexole', 'tablet', 'N04BC05', false, 0, '02325829', 'FreeDiams::CA_HCDPD::DIN', 81118);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pramipexole', 'tablet', 'N04BC05', false, 0, '02325837', 'FreeDiams::CA_HCDPD::DIN', 81119);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hertel Household Bathroom Disinfectant Cleaner With La Parisienne Bleach', 'liquid', 'V07AV', false, 0, '02325845', 'FreeDiams::CA_HCDPD::DIN', 81120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Certainty Disinfectant Wipes', 'wipe', 'V07AV', false, 0, '02325853', 'FreeDiams::CA_HCDPD::DIN', 81121);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pepto-Bismol With Instacool', 'tablet (chewable)', 'A07BB', false, 0, '02325896', 'FreeDiams::CA_HCDPD::DIN', 81124);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nimotop', 'tablet', 'C08CA06', false, 0, '02325926', 'FreeDiams::CA_HCDPD::DIN', 81127);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Levofloxacin', 'tablet', 'J01MA12', false, 0, '02325942', 'FreeDiams::CA_HCDPD::DIN', 81129);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxycodone', 'tablet', 'N02AA05', false, 0, '02325950', 'FreeDiams::CA_HCDPD::DIN', 81130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxycodone', 'tablet', 'N02AA05', false, 0, '02325969', 'FreeDiams::CA_HCDPD::DIN', 81131);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxycodone', 'tablet', 'N02AA05', false, 0, '02325977', 'FreeDiams::CA_HCDPD::DIN', 81132);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bicalutamide Tablets', 'tablet', 'L02BB03', false, 0, '02325985', 'FreeDiams::CA_HCDPD::DIN', 81133);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Docusate Sodium', 'capsule', 'A06AA02', false, 0, '02326086', 'FreeDiams::CA_HCDPD::DIN', 81142);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Capture Totale Anti-Aging Emulsion Uva/Uvb Protection', 'emulsion', 'D02BA30', false, 0, '02326108', 'FreeDiams::CA_HCDPD::DIN', 81144);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Lip Sheen Spf 15', 'stick', 'D02BA02', false, 0, '02326116', 'FreeDiams::CA_HCDPD::DIN', 81145);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tisseel', 'solution', 'B02BC30', false, 0, '02326175', 'FreeDiams::CA_HCDPD::DIN', 81151);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylphenidate', 'tablet', 'N06BA04', false, 0, '02326221', 'FreeDiams::CA_HCDPD::DIN', 81157);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylphenidate', 'tablet', 'N06BA04', false, 0, '02326248', 'FreeDiams::CA_HCDPD::DIN', 81158);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Methylphenidate', 'tablet', 'N06BA04', false, 0, '02326256', 'FreeDiams::CA_HCDPD::DIN', 81159);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bi-Peglyte', 'kit', 'A06AB52', false, 0, '02326302', 'FreeDiams::CA_HCDPD::DIN', 81164);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Swish Clean & Green Disinfectant', 'liquid', 'V07AV', false, 0, '02326310', 'FreeDiams::CA_HCDPD::DIN', 81165);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prevage Day Ultra Protection Anti-Aging Moisture Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02326426', 'FreeDiams::CA_HCDPD::DIN', 81175);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tykerb', 'tablet', 'L01XE07', false, 0, '02326442', 'FreeDiams::CA_HCDPD::DIN', 81179);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Novo-Salbutamol Hfa', 'metered-dose (aerosol)', 'R03AC02', false, 0, '02326450', 'FreeDiams::CA_HCDPD::DIN', 81180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02326477', 'FreeDiams::CA_HCDPD::DIN', 81184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02326485', 'FreeDiams::CA_HCDPD::DIN', 81185);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02326493', 'FreeDiams::CA_HCDPD::DIN', 81186);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amoxi-Clav', 'tablet', 'J01CR02', false, 0, '02326515', 'FreeDiams::CA_HCDPD::DIN', 81188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amoxi-Clav', 'tablet', 'J01CR02', false, 0, '02326523', 'FreeDiams::CA_HCDPD::DIN', 81189);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bismuth Subsalicylate Caplets', 'tablet', 'A07BB', false, 0, '02326582', 'FreeDiams::CA_HCDPD::DIN', 81194);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ropinirole', 'tablet', 'N04BC04', false, 0, '02326590', 'FreeDiams::CA_HCDPD::DIN', 81195);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ropinirole', 'tablet', 'N04BC04', false, 0, '02326612', 'FreeDiams::CA_HCDPD::DIN', 81197);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ropinirole', 'tablet', 'N04BC04', false, 0, '02326620', 'FreeDiams::CA_HCDPD::DIN', 81198);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ropinirole', 'tablet', 'N04BC04', false, 0, '02326639', 'FreeDiams::CA_HCDPD::DIN', 81199);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Onguent Ophtalmique D''Erythromycine Usp', 'ointment', 'S01AA17', false, 0, '02326663', 'FreeDiams::CA_HCDPD::DIN', 81202);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atenolol', 'tablet', 'C07AB03', false, 0, '02326701', 'FreeDiams::CA_HCDPD::DIN', 81205);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Amlodipine', 'tablet', 'C08CA01', false, 0, '02326760', 'FreeDiams::CA_HCDPD::DIN', 81210);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Amlodipine', 'tablet', 'C08CA01', false, 0, '02326779', 'FreeDiams::CA_HCDPD::DIN', 81211);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Phl-Amlodipine', 'tablet', 'C08CA01', false, 0, '02326787', 'FreeDiams::CA_HCDPD::DIN', 81212);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amlodipine', 'tablet', 'C08CA01', false, 0, '02326795', 'FreeDiams::CA_HCDPD::DIN', 81213);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amlodipine', 'tablet', 'C08CA01', false, 0, '02326809', 'FreeDiams::CA_HCDPD::DIN', 81214);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amlodipine', 'tablet', 'C08CA01', false, 0, '02326817', 'FreeDiams::CA_HCDPD::DIN', 81215);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Amlodipine', 'tablet', 'C08CA01', false, 0, '02326825', 'FreeDiams::CA_HCDPD::DIN', 81216);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Amlodipine', 'tablet', 'C08CA01', false, 0, '02326833', 'FreeDiams::CA_HCDPD::DIN', 81217);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Amlodipine', 'tablet', 'C08CA01', false, 0, '02326841', 'FreeDiams::CA_HCDPD::DIN', 81218);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-252', 'solution', 'B05ZA', false, 0, '02326892', 'FreeDiams::CA_HCDPD::DIN', 81222);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-702', 'solution', 'B05ZA', false, 0, '02326914', 'FreeDiams::CA_HCDPD::DIN', 81224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-617', 'solution', 'B05ZA', false, 0, '02326922', 'FreeDiams::CA_HCDPD::DIN', 81225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-321', 'solution', 'B05ZA', false, 0, '02326930', 'FreeDiams::CA_HCDPD::DIN', 81226);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-229', 'solution', 'B05ZA', false, 0, '02326949', 'FreeDiams::CA_HCDPD::DIN', 81227);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Candesartan', 'tablet', 'C09CA06', false, 0, '02326957', 'FreeDiams::CA_HCDPD::DIN', 81228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Candesartan', 'tablet', 'C09CA06', false, 0, '02326965', 'FreeDiams::CA_HCDPD::DIN', 81229);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Candesartan', 'tablet', 'C09CA06', false, 0, '02326973', 'FreeDiams::CA_HCDPD::DIN', 81230);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Formulab Treat For Young Adult Acne', 'cream', 'D10AE01', false, 0, '02327015', 'FreeDiams::CA_HCDPD::DIN', 81233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Formulab Treat For Adult Acne', 'cream', 'D10AE01', false, 0, '02327023', 'FreeDiams::CA_HCDPD::DIN', 81234);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-625', 'solution', 'B05ZA', false, 0, '02327031', 'FreeDiams::CA_HCDPD::DIN', 81236);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-706', 'solution', 'B05ZA', false, 0, '02327058', 'FreeDiams::CA_HCDPD::DIN', 81237);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-616', 'solution', 'B05ZA', false, 0, '02327066', 'FreeDiams::CA_HCDPD::DIN', 81238);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-400', 'solution', 'B05ZA', false, 0, '02327074', 'FreeDiams::CA_HCDPD::DIN', 81239);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-602', 'solution', 'B05ZA', false, 0, '02327082', 'FreeDiams::CA_HCDPD::DIN', 81240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-631', 'solution', 'B05ZA', false, 0, '02327090', 'FreeDiams::CA_HCDPD::DIN', 81241);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-228', 'solution', 'B05ZA', false, 0, '02327104', 'FreeDiams::CA_HCDPD::DIN', 81242);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Fentanyl Patch', 'patch', 'N02AB03', false, 0, '02327112', 'FreeDiams::CA_HCDPD::DIN', 81243);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Fentanyl Patch', 'patch', 'N02AB03', false, 0, '02327120', 'FreeDiams::CA_HCDPD::DIN', 81244);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Fentanyl Patch', 'patch', 'N02AB03', false, 0, '02327139', 'FreeDiams::CA_HCDPD::DIN', 81245);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Fentanyl Patch', 'patch', 'N02AB03', false, 0, '02327147', 'FreeDiams::CA_HCDPD::DIN', 81246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Fentanyl Patch', 'patch', 'N02AB03', false, 0, '02327155', 'FreeDiams::CA_HCDPD::DIN', 81247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Fentanyl Patch', 'patch', 'N02AB03', false, 0, '02327163', 'FreeDiams::CA_HCDPD::DIN', 81248);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxycodone-Acet', 'tablet', 'N02BE51', false, 0, '02327171', 'FreeDiams::CA_HCDPD::DIN', 81249);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Strepsils Warm', 'lozenge', 'R02AA03', false, 0, '02327198', 'FreeDiams::CA_HCDPD::DIN', 81250);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('A + D Diaper Rash Cream', 'cream', 'D02AB', false, 0, '02327201', 'FreeDiams::CA_HCDPD::DIN', 81251);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pucker Up Lip Balm', 'stick', 'D02BA30', false, 0, '02327228', 'FreeDiams::CA_HCDPD::DIN', 81252);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Risedronate', 'tablet', 'M05BA07', false, 0, '02327295', 'FreeDiams::CA_HCDPD::DIN', 81259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-401', 'solution', 'B05ZA', false, 0, '02327309', 'FreeDiams::CA_HCDPD::DIN', 81262);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-332', 'solution', 'B05ZA', false, 0, '02327333', 'FreeDiams::CA_HCDPD::DIN', 81265);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Spf 50', 'lotion', 'D02BA30', false, 0, '02327341', 'FreeDiams::CA_HCDPD::DIN', 81266);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anew Reversalist Day Renewal Cream Spf Fps 25 Uva Uvb', 'cream', 'D02BA30', false, 0, '02327368', 'FreeDiams::CA_HCDPD::DIN', 81268);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-260', 'solution', 'B05ZA', false, 0, '02327384', 'FreeDiams::CA_HCDPD::DIN', 81270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-407', 'solution', 'B05ZA', false, 0, '02327392', 'FreeDiams::CA_HCDPD::DIN', 81271);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-226', 'solution', 'B05ZA', false, 0, '02327406', 'FreeDiams::CA_HCDPD::DIN', 81272);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('All Purpose Disinfectant And Cleaner', 'liquid', 'V07AV', false, 0, '02327414', 'FreeDiams::CA_HCDPD::DIN', 81274);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-402', 'solution', 'B05ZA', false, 0, '02327422', 'FreeDiams::CA_HCDPD::DIN', 81275);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mr. Clean With Febreze Freshness Disinfectant Spray', 'spray', 'V07AV', false, 0, '02327449', 'FreeDiams::CA_HCDPD::DIN', 81277);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mr. Clean With Febreze Freshness Disinfectant', 'liquid', 'V07AV', false, 0, '02327457', 'FreeDiams::CA_HCDPD::DIN', 81278);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-225', 'solution', 'B05ZA', false, 0, '02327465', 'FreeDiams::CA_HCDPD::DIN', 81279);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-615', 'solution', 'B05ZA', false, 0, '02327473', 'FreeDiams::CA_HCDPD::DIN', 81280);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-224', 'solution', 'B05ZA', false, 0, '02327481', 'FreeDiams::CA_HCDPD::DIN', 81281);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-330', 'solution', 'B05ZA', false, 0, '02327503', 'FreeDiams::CA_HCDPD::DIN', 81282);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-410', 'solution', 'B05ZA', false, 0, '02327511', 'FreeDiams::CA_HCDPD::DIN', 81283);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-408', 'solution', 'B05ZA', false, 0, '02327538', 'FreeDiams::CA_HCDPD::DIN', 81284);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Foaming Hand Sanitizer', 'liquid', 'D08AJ01', false, 0, '02327546', 'FreeDiams::CA_HCDPD::DIN', 81286);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dior Bronze Matte Sunshine', 'powder', 'D02BA30', false, 0, '02327554', 'FreeDiams::CA_HCDPD::DIN', 81287);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02327562', 'FreeDiams::CA_HCDPD::DIN', 81288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02327570', 'FreeDiams::CA_HCDPD::DIN', 81289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02327589', 'FreeDiams::CA_HCDPD::DIN', 81290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02327597', 'FreeDiams::CA_HCDPD::DIN', 81291);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Re9 Advanced Restorative Day Crčme With Spf 20', 'cream', 'D02BA30', false, 0, '02327600', 'FreeDiams::CA_HCDPD::DIN', 81293);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zolinza', 'capsule', 'L01XX38', false, 0, '02327619', 'FreeDiams::CA_HCDPD::DIN', 81300);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Island Sport Sunscreen Lotion Écran Solaire 30', 'lotion', 'D02BA30', false, 0, '02327627', 'FreeDiams::CA_HCDPD::DIN', 81301);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('V Wipes Disinfectant', 'wipe', 'V07AV', false, 0, '02327635', 'FreeDiams::CA_HCDPD::DIN', 81303);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Av-Mixx Balance Plus', 'solution', 'V07AV', false, 0, '02327651', 'FreeDiams::CA_HCDPD::DIN', 81305);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chemspec Dfc Sodium Hypochlorite Disinfectant/Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02327686', 'FreeDiams::CA_HCDPD::DIN', 81309);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chemspec Dfc 7000 Oxidizing Disinfectant/Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02327694', 'FreeDiams::CA_HCDPD::DIN', 81310);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chemspec Dfc 7500 Oxidizing Disinfectant/Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02327708', 'FreeDiams::CA_HCDPD::DIN', 81311);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chemspec Dfc 1000 Oxidizing Disinfectant/Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02327716', 'FreeDiams::CA_HCDPD::DIN', 81312);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Chemspec Dfc 250 Oxidizing Disinfectant/Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02327724', 'FreeDiams::CA_HCDPD::DIN', 81313);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02327775', 'FreeDiams::CA_HCDPD::DIN', 81318);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02327783', 'FreeDiams::CA_HCDPD::DIN', 81319);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02327791', 'FreeDiams::CA_HCDPD::DIN', 81320);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02327805', 'FreeDiams::CA_HCDPD::DIN', 81321);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Hydro', 'tablet', 'C03AA03', false, 0, '02327856', 'FreeDiams::CA_HCDPD::DIN', 81335);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Sheer Touch Toucher Soyeux Lotion Sunscreen Ecran Solaire 30', 'lotion', 'D02BA30', false, 0, '02327872', 'FreeDiams::CA_HCDPD::DIN', 81337);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.A.C Mineralize Foundation  Spf 15', 'cream', 'D02BA02', false, 0, '02328046', 'FreeDiams::CA_HCDPD::DIN', 81352);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Irbesartan', 'tablet', 'C09CA04', false, 0, '02328070', 'FreeDiams::CA_HCDPD::DIN', 81358);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Irbesartan', 'tablet', 'C09CA04', false, 0, '02328089', 'FreeDiams::CA_HCDPD::DIN', 81359);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Irbesartan', 'tablet', 'C09CA04', false, 0, '02328100', 'FreeDiams::CA_HCDPD::DIN', 81361);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gas Relief Tablets', 'tablet (chewable)', 'A03AX13', false, 0, '02328127', 'FreeDiams::CA_HCDPD::DIN', 81363);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Bacterial Deep Cleansing Hand Soap', 'liquid', 'D08AE54', false, 0, '02328143', 'FreeDiams::CA_HCDPD::DIN', 81365);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Dry Oil Huile Sčche Sunscreen Spray Écran Solaire En Vaporisateur 10', 'aerosol', 'D02BA30', false, 0, '02328151', 'FreeDiams::CA_HCDPD::DIN', 81366);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Sheer Touch Toucher Soyeux Oil-Free Sunscreen Écran Solaire Sans Huile 15 Spf/Fps', 'lotion', 'D02BA30', false, 0, '02328178', 'FreeDiams::CA_HCDPD::DIN', 81367);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Sheer Touch Toucher Soyeux Clear Sunscreen Spray Écran Solaire Transparent En Vaporisateur 30', 'aerosol', 'D02BA30', false, 0, '02328186', 'FreeDiams::CA_HCDPD::DIN', 81370);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Sheer Touch Toucher Soyeux Clear Sunscreen Spray Écran Solaire Transparent En Vaporisateur 60', 'aerosol', 'D02BA30', false, 0, '02328194', 'FreeDiams::CA_HCDPD::DIN', 81371);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Sensitive Skin Peau Sensible Face Visage Sunscreen Lotion Écran Solaire 30', 'lotion', 'D02BA30', false, 0, '02328208', 'FreeDiams::CA_HCDPD::DIN', 81372);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pegalax', 'powder for solution', 'A06AD15', false, 0, '02328232', 'FreeDiams::CA_HCDPD::DIN', 81376);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.A.C Studio Fix Fluid Spf 15', 'liquid', 'D02BA02', false, 0, '02328259', 'FreeDiams::CA_HCDPD::DIN', 81378);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Correction Lift Crčme De Jour Lift Fermeté', 'cream', 'D02BA30', false, 0, '02328267', 'FreeDiams::CA_HCDPD::DIN', 81379);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rbx-Risperidone', 'tablet', 'N05AX08', false, 0, '02328305', 'FreeDiams::CA_HCDPD::DIN', 81383);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rbx-Risperidone', 'tablet', 'N05AX08', false, 0, '02328313', 'FreeDiams::CA_HCDPD::DIN', 81384);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rbx-Risperidone', 'tablet', 'N05AX08', false, 0, '02328321', 'FreeDiams::CA_HCDPD::DIN', 81385);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rbx-Risperidone', 'tablet', 'N05AX08', false, 0, '02328348', 'FreeDiams::CA_HCDPD::DIN', 81386);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rbx-Risperidone', 'tablet', 'N05AX08', false, 0, '02328364', 'FreeDiams::CA_HCDPD::DIN', 81388);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rbx-Risperidone', 'tablet', 'N05AX08', false, 0, '02328372', 'FreeDiams::CA_HCDPD::DIN', 81389);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cough & Cold', 'liquid', 'R05DA20', false, 0, '02328380', 'FreeDiams::CA_HCDPD::DIN', 81390);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Visine Advance Cool', 'drops', 'S01GA52', false, 0, '02328399', 'FreeDiams::CA_HCDPD::DIN', 81391);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cold & Stuffy Nose', 'liquid', 'R01BA53', false, 0, '02328402', 'FreeDiams::CA_HCDPD::DIN', 81392);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daytime Cough & Cold', 'liquid', 'R05DA20', false, 0, '02328410', 'FreeDiams::CA_HCDPD::DIN', 81394);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Junior Strength Advil Fever From Colds Or Flu', 'tablet (chewable)', 'M01AE01', false, 0, '02328429', 'FreeDiams::CA_HCDPD::DIN', 81395);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Advil Fever From Colds Or Flu', 'suspension', 'M01AE01', false, 0, '02328437', 'FreeDiams::CA_HCDPD::DIN', 81396);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advil Pediatric Drops Fever From Colds Or Flu', 'suspension', 'M01AE01', false, 0, '02328445', 'FreeDiams::CA_HCDPD::DIN', 81397);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Bismuth Subsalicylate Liquid', 'liquid', 'A07BB', false, 0, '02328453', 'FreeDiams::CA_HCDPD::DIN', 81398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Irbesartan', 'tablet', 'C09CA04', false, 0, '02328461', 'FreeDiams::CA_HCDPD::DIN', 81399);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Irbesartan', 'tablet', 'C09CA04', false, 0, '02328488', 'FreeDiams::CA_HCDPD::DIN', 81400);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Irbesartan', 'tablet', 'C09CA04', false, 0, '02328496', 'FreeDiams::CA_HCDPD::DIN', 81401);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Irbesartan-Hctz', 'tablet', 'C09DA04', false, 0, '02328518', 'FreeDiams::CA_HCDPD::DIN', 81403);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Irbesartan-Hctz', 'tablet', 'C09DA04', false, 0, '02328526', 'FreeDiams::CA_HCDPD::DIN', 81404);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Irbesartan-Hctz', 'tablet', 'C09DA04', false, 0, '02328534', 'FreeDiams::CA_HCDPD::DIN', 81405);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Oil Free Spf 30', 'lotion', 'D02BA30', false, 0, '02328542', 'FreeDiams::CA_HCDPD::DIN', 81406);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisture Extreme Spf 15 Sunscreen', 'stick', 'D02BA02', false, 0, '02328585', 'FreeDiams::CA_HCDPD::DIN', 81410);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Island Sport Clear Sunscreen Spray Ecran Solaire Transparent En Vaporisateur 30', 'aerosol', 'D02BA30', false, 0, '02328615', 'FreeDiams::CA_HCDPD::DIN', 81413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Creme Continuous Flow Sunscreen Ecran Solaire A Ecoulement Continu 10', 'spray, bag-on-valve', 'D02BA30', false, 0, '02328631', 'FreeDiams::CA_HCDPD::DIN', 81415);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Runny Nose And Cough', 'liquid', 'R05DA20', false, 0, '02328658', 'FreeDiams::CA_HCDPD::DIN', 81416);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydra-C/ Radiance 24h Plus Spf 15 Fps/ Moisturizing Cream Normal Skin/Crčme Hydratante Peaux Normales', 'cream', 'D02BA30', false, 0, '02328844', 'FreeDiams::CA_HCDPD::DIN', 81450);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riche Crčme Spf/Fps 20 Fluide Bienfaisant Anti-Rides Jour', 'lotion', 'D02BA30', false, 0, '02328852', 'FreeDiams::CA_HCDPD::DIN', 81451);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Baby Lotion Sunscreen Écran Solaire Pour Bébés 60', 'lotion', 'D02BA30', false, 0, '02328879', 'FreeDiams::CA_HCDPD::DIN', 81454);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Junior Strength Allergy Formula', 'tablet', 'R06AA02', false, 0, '02328895', 'FreeDiams::CA_HCDPD::DIN', 81456);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Correction Lift Fluide De Jour Lift Fermete', 'lotion', 'D02BA30', false, 0, '02328909', 'FreeDiams::CA_HCDPD::DIN', 81457);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Simvastatin', 'tablet', 'C10AA01', false, 0, '02329131', 'FreeDiams::CA_HCDPD::DIN', 81483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Simvastatin', 'tablet', 'C10AA01', false, 0, '02329158', 'FreeDiams::CA_HCDPD::DIN', 81484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Simvastatin', 'tablet', 'C10AA01', false, 0, '02329166', 'FreeDiams::CA_HCDPD::DIN', 81485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Simvastatin', 'tablet', 'C10AA01', false, 0, '02329174', 'FreeDiams::CA_HCDPD::DIN', 81486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Simvastatin', 'tablet', 'C10AA01', false, 0, '02329182', 'FreeDiams::CA_HCDPD::DIN', 81487);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Defense Spray Sunscreen / Écran Solaire En Vaporisateur Spf/Fps 60', 'spray', 'D02BA30', false, 0, '02329190', 'FreeDiams::CA_HCDPD::DIN', 81488);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Cefprozil', 'powder for suspension', 'J01DC10', false, 0, '02329204', 'FreeDiams::CA_HCDPD::DIN', 81489);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Sunscreen Lotion Écran Solaire 4', 'lotion', 'D02BA30', false, 0, '02329212', 'FreeDiams::CA_HCDPD::DIN', 81490);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Sunscreen Lotion Écran Solaire 8', 'lotion', 'D02BA30', false, 0, '02329220', 'FreeDiams::CA_HCDPD::DIN', 81491);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Omeprazole', 'capsule (delayed release)', 'A02BC01', false, 0, '02329425', 'FreeDiams::CA_HCDPD::DIN', 81517);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Omeprazole', 'capsule (delayed release)', 'A02BC01', false, 0, '02329433', 'FreeDiams::CA_HCDPD::DIN', 81518);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Universal Anti-Aging Daily Moisturizing Cream Spf 30', 'cream', 'D02BA30', false, 0, '02329832', 'FreeDiams::CA_HCDPD::DIN', 81557);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cayston', 'powder for solution', 'J01DF01', false, 0, '02329840', 'FreeDiams::CA_HCDPD::DIN', 81558);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Klere', 'solution', 'D08AJ01', false, 0, '02329891', 'FreeDiams::CA_HCDPD::DIN', 81564);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-223', 'solution', 'B05ZA', false, 0, '02329972', 'FreeDiams::CA_HCDPD::DIN', 81573);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-208', 'solution', 'B05ZA', false, 0, '02329980', 'FreeDiams::CA_HCDPD::DIN', 81574);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-202', 'solution', 'B05ZA', false, 0, '02330008', 'FreeDiams::CA_HCDPD::DIN', 81576);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-623', 'solution', 'B05ZA', false, 0, '02330016', 'FreeDiams::CA_HCDPD::DIN', 81577);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-201', 'solution', 'B05ZA', false, 0, '02330024', 'FreeDiams::CA_HCDPD::DIN', 81578);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-624', 'solution', 'B05ZA', false, 0, '02330032', 'FreeDiams::CA_HCDPD::DIN', 81579);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-630', 'solution', 'B05ZA', false, 0, '02330040', 'FreeDiams::CA_HCDPD::DIN', 81580);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dalcam Mint Quat', 'liquid', 'V07AV', false, 0, '02330067', 'FreeDiams::CA_HCDPD::DIN', 81582);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Rabeprazole Ec', 'tablet (enteric-coated)', 'A02BC04', false, 0, '02330083', 'FreeDiams::CA_HCDPD::DIN', 81584);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Rabeprazole Ec', 'tablet (enteric-coated)', 'A02BC04', false, 0, '02330091', 'FreeDiams::CA_HCDPD::DIN', 81585);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Fentanyl Matrix Patch', 'patch', 'N02AB03', false, 0, '02330105', 'FreeDiams::CA_HCDPD::DIN', 81586);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Fentanyl Matrix Patch', 'patch', 'N02AB03', false, 0, '02330113', 'FreeDiams::CA_HCDPD::DIN', 81587);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Fentanyl Matrix Patch', 'patch', 'N02AB03', false, 0, '02330121', 'FreeDiams::CA_HCDPD::DIN', 81588);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Fentanyl Matrix Patch', 'patch', 'N02AB03', false, 0, '02330148', 'FreeDiams::CA_HCDPD::DIN', 81589);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Fentanyl Matrix Patch', 'patch', 'N02AB03', false, 0, '02330156', 'FreeDiams::CA_HCDPD::DIN', 81590);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-608', 'solution', 'B05ZA', false, 0, '02330164', 'FreeDiams::CA_HCDPD::DIN', 81592);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-200', 'solution', 'B05ZA', false, 0, '02330172', 'FreeDiams::CA_HCDPD::DIN', 81593);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-230', 'solution', 'B05ZA', false, 0, '02330180', 'FreeDiams::CA_HCDPD::DIN', 81594);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-206', 'solution', 'B05ZA', false, 0, '02330199', 'FreeDiams::CA_HCDPD::DIN', 81595);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-331', 'solution', 'B05ZA', false, 0, '02330202', 'FreeDiams::CA_HCDPD::DIN', 81596);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-320', 'solution', 'B05ZA', false, 0, '02330229', 'FreeDiams::CA_HCDPD::DIN', 81598);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-251', 'solution', 'B05ZA', false, 0, '02330245', 'FreeDiams::CA_HCDPD::DIN', 81600);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-232', 'solution', 'B05ZA', false, 0, '02330253', 'FreeDiams::CA_HCDPD::DIN', 81601);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturalyte H-227', 'solution', 'B05ZA', false, 0, '02330261', 'FreeDiams::CA_HCDPD::DIN', 81602);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Sheer Touch Toucher Soyeux Lotion Sunscreen Écran Solaire 60', 'lotion', 'D02BA30', false, 0, '02330296', 'FreeDiams::CA_HCDPD::DIN', 81604);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Clear Sunscreen Oil Free Continuous Spray Spf 50', 'spray, bag-on-valve', 'D02BA30', false, 0, '02330318', 'FreeDiams::CA_HCDPD::DIN', 81605);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polylax', 'powder for solution', 'A06AD15', false, 0, '02330326', 'FreeDiams::CA_HCDPD::DIN', 81606);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clolar', 'solution', 'L01BB06', false, 0, '02330407', 'FreeDiams::CA_HCDPD::DIN', 81614);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Quetiapine', 'tablet', 'N05AH04', false, 0, '02330415', 'FreeDiams::CA_HCDPD::DIN', 81615);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Quetiapine', 'tablet', 'N05AH04', false, 0, '02330423', 'FreeDiams::CA_HCDPD::DIN', 81616);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Quetiapine', 'tablet', 'N05AH04', false, 0, '02330458', 'FreeDiams::CA_HCDPD::DIN', 81618);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Quetiapine', 'tablet', 'N05AH04', false, 0, '02330466', 'FreeDiams::CA_HCDPD::DIN', 81619);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Amlodipine', 'tablet', 'C08CA01', false, 0, '02330474', 'FreeDiams::CA_HCDPD::DIN', 81620);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Irbesartan Hctz', 'tablet', 'C09DA04', false, 0, '02330512', 'FreeDiams::CA_HCDPD::DIN', 81624);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Irbesartan Hctz', 'tablet', 'C09DA04', false, 0, '02330520', 'FreeDiams::CA_HCDPD::DIN', 81625);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Irbesartan Hctz', 'tablet', 'C09DA04', false, 0, '02330539', 'FreeDiams::CA_HCDPD::DIN', 81626);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Piperacillin Sodium/Tazobactam Sodium Powder For Injection', 'powder for solution', 'J01CR05', false, 0, '02330547', 'FreeDiams::CA_HCDPD::DIN', 81627);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Plavix', 'tablet', 'B01AC04', false, 0, '02330555', 'FreeDiams::CA_HCDPD::DIN', 81628);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Enalapril', 'tablet', 'C09AA02', false, 0, '02330601', 'FreeDiams::CA_HCDPD::DIN', 81632);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisture Therapy Intensive Treatment Traitement Intensif Tratamiento Intensivo Lip Ointment Spf 15 Onguent Pour Les Lčvres Fps 15 Pomada Para Los Labios Spf 15', 'ointment', 'D02BA30', false, 0, '02330628', 'FreeDiams::CA_HCDPD::DIN', 81635);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diorskin Forever', 'emulsion', 'D02BA30', false, 0, '02330652', 'FreeDiams::CA_HCDPD::DIN', 81638);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diorskin Forever Compact', 'powder', 'D02BA30', false, 0, '02330660', 'FreeDiams::CA_HCDPD::DIN', 81639);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tropical Vanilla Body Spf 32', 'cream', 'D02BA30', false, 0, '02330679', 'FreeDiams::CA_HCDPD::DIN', 81642);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tropical Vanilla Sun Cream', 'cream', 'D02BA30', false, 0, '02330687', 'FreeDiams::CA_HCDPD::DIN', 81643);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eraxis               (Note-Without Solvent)', 'powder for solution', 'J02AX06', false, 0, '02330695', 'FreeDiams::CA_HCDPD::DIN', 81644);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('3% Polocaine Dental', 'liquid', 'N01BB03', false, 0, '02330733', 'FreeDiams::CA_HCDPD::DIN', 81649);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pain And Fever', 'suspension', 'N02BE01', false, 0, '02330741', 'FreeDiams::CA_HCDPD::DIN', 81650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gc2 Neutral Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02330768', 'FreeDiams::CA_HCDPD::DIN', 81651);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rebel', 'liquid', 'V07AV', false, 0, '02330784', 'FreeDiams::CA_HCDPD::DIN', 81653);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rosaliac Uv Spf 15 Cream', 'cream', 'D02BA30', false, 0, '02330792', 'FreeDiams::CA_HCDPD::DIN', 81654);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clearskin Professional Oil Free Lotion Spf 15 Lotion Sans Huile Fps 15', 'lotion', 'D02BA30', false, 0, '02330814', 'FreeDiams::CA_HCDPD::DIN', 81656);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daytime Cold Medication Liquid Fastgels', 'capsule', 'N02BE51', false, 0, '02330822', 'FreeDiams::CA_HCDPD::DIN', 81657);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rosaliac Uv Riche', 'cream', 'D02BA30', false, 0, '02330857', 'FreeDiams::CA_HCDPD::DIN', 81660);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun Radiance Spf 15 Crystal Gloss', 'gel', 'D02BA30', false, 0, '02330865', 'FreeDiams::CA_HCDPD::DIN', 81661);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Azithromycin', 'tablet', 'J01FA10', false, 0, '02330881', 'FreeDiams::CA_HCDPD::DIN', 81664);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Azithromycin', 'tablet', 'J01FA10', false, 0, '02330911', 'FreeDiams::CA_HCDPD::DIN', 81666);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Pravastatin', 'tablet', 'C10AA03', false, 0, '02330954', 'FreeDiams::CA_HCDPD::DIN', 81669);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Pravastatin', 'tablet', 'C10AA03', false, 0, '02330962', 'FreeDiams::CA_HCDPD::DIN', 81670);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Pravastatin', 'tablet', 'C10AA03', false, 0, '02330970', 'FreeDiams::CA_HCDPD::DIN', 81671);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Multaq', 'tablet', 'C01BD07', false, 0, '02330989', 'FreeDiams::CA_HCDPD::DIN', 81672);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Fosinopril', 'tablet', 'C09AA09', false, 0, '02331004', 'FreeDiams::CA_HCDPD::DIN', 81674);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Fosinopril', 'tablet', 'C09AA09', false, 0, '02331012', 'FreeDiams::CA_HCDPD::DIN', 81675);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Simvastatin', 'tablet', 'C10AA01', false, 0, '02331020', 'FreeDiams::CA_HCDPD::DIN', 81676);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Simvastatin', 'tablet', 'C10AA01', false, 0, '02331039', 'FreeDiams::CA_HCDPD::DIN', 81677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Simvastatin', 'tablet', 'C10AA01', false, 0, '02331047', 'FreeDiams::CA_HCDPD::DIN', 81678);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Simvastatin', 'tablet', 'C10AA01', false, 0, '02331055', 'FreeDiams::CA_HCDPD::DIN', 81679);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Simvastatin', 'tablet', 'C10AA01', false, 0, '02331063', 'FreeDiams::CA_HCDPD::DIN', 81680);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Amlodipine', 'tablet', 'C08CA01', false, 0, '02331071', 'FreeDiams::CA_HCDPD::DIN', 81681);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Amlodipine', 'tablet', 'C08CA01', false, 0, '02331098', 'FreeDiams::CA_HCDPD::DIN', 81682);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Ramipril', 'capsule', 'C09AA05', false, 0, '02331101', 'FreeDiams::CA_HCDPD::DIN', 81683);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Ramipril', 'capsule', 'C09AA05', false, 0, '02331128', 'FreeDiams::CA_HCDPD::DIN', 81684);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Ramipril', 'capsule', 'C09AA05', false, 0, '02331136', 'FreeDiams::CA_HCDPD::DIN', 81685);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Ramipril', 'capsule', 'C09AA05', false, 0, '02331144', 'FreeDiams::CA_HCDPD::DIN', 81686);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amlodipine', 'tablet', 'C08CA01', false, 0, '02331284', 'FreeDiams::CA_HCDPD::DIN', 81699);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amlodipine', 'tablet', 'C08CA01', false, 0, '02331292', 'FreeDiams::CA_HCDPD::DIN', 81700);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Color Rich Mega Impact Lipstick Spf 15 Rouge A Levres Mega Impact Fps 15', 'ointment', 'D02BA30', false, 0, '02331365', 'FreeDiams::CA_HCDPD::DIN', 81707);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Sheer Water Light', 'lotion', 'D02BA30', false, 0, '02331373', 'FreeDiams::CA_HCDPD::DIN', 81708);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutrogena Ultra Sheer Water Light', 'lotion', 'D02BA30', false, 0, '02331381', 'FreeDiams::CA_HCDPD::DIN', 81709);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Otrivin Complete Nasal Care', 'spray', 'R01AA07', false, 0, '02331403', 'FreeDiams::CA_HCDPD::DIN', 81710);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artistry Hydrating Foundation', 'cream', 'D02BA30', false, 0, '02331454', 'FreeDiams::CA_HCDPD::DIN', 81714);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artistry Balancing Foundation', 'lotion', 'D02BA30', false, 0, '02331462', 'FreeDiams::CA_HCDPD::DIN', 81715);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hand And Décolleté Cream Sunscreen Spf 15', 'cream', 'D02BA30', false, 0, '02331470', 'FreeDiams::CA_HCDPD::DIN', 81716);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Amlodipine', 'tablet', 'C08CA01', false, 0, '02331489', 'FreeDiams::CA_HCDPD::DIN', 81717);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Amlodipine', 'tablet', 'C08CA01', false, 0, '02331497', 'FreeDiams::CA_HCDPD::DIN', 81718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Amlodipine', 'tablet', 'C08CA01', false, 0, '02331500', 'FreeDiams::CA_HCDPD::DIN', 81719);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Lactulose', 'solution', 'A06AD11', false, 0, '02331551', 'FreeDiams::CA_HCDPD::DIN', 81724);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bupropion Sr', 'tablet (extended-release)', 'N06AX12', false, 0, '02331616', 'FreeDiams::CA_HCDPD::DIN', 81729);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Azarga', 'suspension', 'S01ED51', false, 0, '02331624', 'FreeDiams::CA_HCDPD::DIN', 81730);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine Dental Lidocaine Hcl 2% And Epinephrine 1:100,000', 'solution', 'N01BB52', false, 0, '02331640', 'FreeDiams::CA_HCDPD::DIN', 81732);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advagraf', 'capsule (extended release)', 'L04AD02', false, 0, '02331667', 'FreeDiams::CA_HCDPD::DIN', 81736);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cimzia', 'solution', 'L04AB05', false, 0, '02331675', 'FreeDiams::CA_HCDPD::DIN', 81737);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flupentixol Decanoate Injection Bp', 'solution', 'N05AF01', false, 0, '02331721', 'FreeDiams::CA_HCDPD::DIN', 81742);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Valacyclovir', 'tablet', 'J05AB11', false, 0, '02331748', 'FreeDiams::CA_HCDPD::DIN', 81743);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Radiant Day Spf 22', 'lotion', 'D02BA30', false, 0, '02332124', 'FreeDiams::CA_HCDPD::DIN', 81779);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyproheptadine 4mg Tablets', 'tablet', 'R06AX02', false, 0, '02332248', 'FreeDiams::CA_HCDPD::DIN', 81790);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Azithromycin', 'powder for suspension', 'J01FA10', false, 0, '02332388', 'FreeDiams::CA_HCDPD::DIN', 81804);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Azithromycin', 'powder for suspension', 'J01FA10', false, 0, '02332396', 'FreeDiams::CA_HCDPD::DIN', 81805);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anacin Tablets', 'tablet', 'N02BA51', false, 0, '02332450', 'FreeDiams::CA_HCDPD::DIN', 81810);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anacin Extra Strength Tablets', 'tablet', 'N02BA51', false, 0, '02332469', 'FreeDiams::CA_HCDPD::DIN', 81813);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Auralgan Solution', 'solution', 'S02DA30', false, 0, '02332477', 'FreeDiams::CA_HCDPD::DIN', 81814);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Docusate Sodium', 'syrup', 'A06AA02', false, 0, '02332485', 'FreeDiams::CA_HCDPD::DIN', 81816);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solutions A.M. Complete Balance Day Cream Crčme De Jour', 'cream', 'D02BA30', false, 0, '02332620', 'FreeDiams::CA_HCDPD::DIN', 81829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ideal Shade Tinted Moisturizer Hydratant Teinté Spf/Fps 15', 'lotion', 'D02BA30', false, 0, '02332639', 'FreeDiams::CA_HCDPD::DIN', 81830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rasilez Hct', 'tablet', 'C09XA52', false, 0, '02332728', 'FreeDiams::CA_HCDPD::DIN', 81838);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rasilez Hct', 'tablet', 'C09XA52', false, 0, '02332736', 'FreeDiams::CA_HCDPD::DIN', 81839);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rasilez Hct', 'tablet', 'C09XA52', false, 0, '02332744', 'FreeDiams::CA_HCDPD::DIN', 81840);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rasilez Hct', 'tablet', 'C09XA52', false, 0, '02332752', 'FreeDiams::CA_HCDPD::DIN', 81841);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Sunscreen Lotion Oil Free Spf 50', 'lotion', 'D02BA30', false, 0, '02332760', 'FreeDiams::CA_HCDPD::DIN', 81842);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Concentrated Quaternary Disinfectant And Sanitizer', 'liquid', 'V07AV', false, 0, '02332787', 'FreeDiams::CA_HCDPD::DIN', 81844);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dalcam 3ooq', 'liquid', 'V07AV', false, 0, '02332795', 'FreeDiams::CA_HCDPD::DIN', 81845);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02332809', 'FreeDiams::CA_HCDPD::DIN', 81846);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02332817', 'FreeDiams::CA_HCDPD::DIN', 81847);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02332825', 'FreeDiams::CA_HCDPD::DIN', 81848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02332833', 'FreeDiams::CA_HCDPD::DIN', 81849);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Genbact', 'spray', 'V07AV', false, 0, '02332892', 'FreeDiams::CA_HCDPD::DIN', 81854);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doribax', 'powder for solution', 'J01DH04', false, 0, '02332906', 'FreeDiams::CA_HCDPD::DIN', 81855);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eco-Quat', 'liquid', 'V07AV', false, 0, '02332914', 'FreeDiams::CA_HCDPD::DIN', 81857);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atacand Plus', 'tablet', 'C09DA06', false, 0, '02332922', 'FreeDiams::CA_HCDPD::DIN', 81858);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atacand Plus', 'tablet', 'C09DA06', false, 0, '02332957', 'FreeDiams::CA_HCDPD::DIN', 81859);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Correction Line Repair - Crčme De Jour Anti-Rides', 'cream', 'D02BA30', false, 0, '02332930', 'FreeDiams::CA_HCDPD::DIN', 81860);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Correction Line Repair - Fluide De Jour Anti-Rides', 'lotion', 'D02BA30', false, 0, '02332949', 'FreeDiams::CA_HCDPD::DIN', 81861);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxivir Five 16 Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02332965', 'FreeDiams::CA_HCDPD::DIN', 81862);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aqua-Fx', 'liquid', 'V07AV', false, 0, '02332973', 'FreeDiams::CA_HCDPD::DIN', 81863);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ibuprofen Capsules, 400mg', 'capsule', 'M01AE01', false, 0, '02332981', 'FreeDiams::CA_HCDPD::DIN', 81864);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clorox Commercial Solutions Ultra Clorox Disinfecting Bleach', 'solution', 'V07AV', false, 0, '02333007', 'FreeDiams::CA_HCDPD::DIN', 81865);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Olanzapine', 'tablet', 'N05AH03', false, 0, '02333015', 'FreeDiams::CA_HCDPD::DIN', 81866);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle Aches & Body Pain', 'tablet (extended-release)', 'N02BE01', false, 0, '02333171', 'FreeDiams::CA_HCDPD::DIN', 81882);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ablavar', 'solution', 'V08CA11', false, 0, '02333236', 'FreeDiams::CA_HCDPD::DIN', 81886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ixiaro', 'suspension', 'J07BA02', false, 0, '02333279', 'FreeDiams::CA_HCDPD::DIN', 81890);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Sheer Touch Toucher Soyeux Lotion Sunscreen Écran Solaire 45', 'lotion', 'D02BA30', false, 0, '02333295', 'FreeDiams::CA_HCDPD::DIN', 81892);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Kids Lotion Sunscreen Écran Solaire Pour Enfants 60', 'lotion', 'D02BA30', false, 0, '02333309', 'FreeDiams::CA_HCDPD::DIN', 81893);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sport Performance Spray Sunscreen / Écran Solaire En Vaporisateur Spf/Fps 60', 'spray, bag-on-valve', 'D02BA30', false, 0, '02333317', 'FreeDiams::CA_HCDPD::DIN', 81894);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydra-Seal Spf 25 / Hydra-Scellante Spf 25', 'cream', 'D02BA30', false, 0, '02333465', 'FreeDiams::CA_HCDPD::DIN', 81909);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pc Spf Fps 60 Kids Sunscreen Continuous Spray', 'spray, bag-on-valve', 'D02BA30', false, 0, '02333473', 'FreeDiams::CA_HCDPD::DIN', 81911);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pc Spf Fps 30 Sport Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02333481', 'FreeDiams::CA_HCDPD::DIN', 81912);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pc Spf Fps 60 Kids Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02333503', 'FreeDiams::CA_HCDPD::DIN', 81913);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pc Spf Fps 15 Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02333511', 'FreeDiams::CA_HCDPD::DIN', 81914);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pc Spf Fps 30 Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02333538', 'FreeDiams::CA_HCDPD::DIN', 81915);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pc Spf Fps 50 Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02333546', 'FreeDiams::CA_HCDPD::DIN', 81916);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Onglyza', 'tablet', 'A10BH03', false, 0, '02333554', 'FreeDiams::CA_HCDPD::DIN', 81917);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pc Spf Fps 15 Sunscreen Continuous Spray', 'spray, bag-on-valve', 'D02BA30', false, 0, '02333570', 'FreeDiams::CA_HCDPD::DIN', 81919);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pc Spf Fps 30 Sunscreen Continuous Spray', 'spray, bag-on-valve', 'D02BA30', false, 0, '02333589', 'FreeDiams::CA_HCDPD::DIN', 81920);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pc Spf Fps 50 Sunscreen Continuous Spray', 'spray, bag-on-valve', 'D02BA30', false, 0, '02333597', 'FreeDiams::CA_HCDPD::DIN', 81921);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glucagen', 'kit', 'H04AA01', false, 0, '02333619', 'FreeDiams::CA_HCDPD::DIN', 81923);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glucagen Hypokit', 'kit', 'H04AA01', false, 0, '02333627', 'FreeDiams::CA_HCDPD::DIN', 81924);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kids Spf 60 Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02333635', 'FreeDiams::CA_HCDPD::DIN', 81926);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 15 Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02333643', 'FreeDiams::CA_HCDPD::DIN', 81927);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02333651', 'FreeDiams::CA_HCDPD::DIN', 81928);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 60 Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02333678', 'FreeDiams::CA_HCDPD::DIN', 81929);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 60 Sport Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02333686', 'FreeDiams::CA_HCDPD::DIN', 81930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rosa Graf Suntime Special', 'cream', 'D02BA30', false, 0, '02333694', 'FreeDiams::CA_HCDPD::DIN', 81931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gloves Off', 'solution', 'V07AV', false, 0, '02333775', 'FreeDiams::CA_HCDPD::DIN', 81942);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Thymox Agroalimentaire', 'solution', 'V07AV', false, 0, '02333783', 'FreeDiams::CA_HCDPD::DIN', 81943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Janumet', 'tablet', 'A10BD07', false, 0, '02333856', 'FreeDiams::CA_HCDPD::DIN', 81954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Janumet', 'tablet', 'A10BD07', false, 0, '02333864', 'FreeDiams::CA_HCDPD::DIN', 81955);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Janumet', 'tablet', 'A10BD07', false, 0, '02333872', 'FreeDiams::CA_HCDPD::DIN', 81956);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topotecan For Injection', 'powder for solution', 'L01XX17', false, 0, '02333880', 'FreeDiams::CA_HCDPD::DIN', 81957);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alcavis Bleach Wipe 1:10', 'wipe', 'V07AV', false, 0, '02333899', 'FreeDiams::CA_HCDPD::DIN', 81958);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Oil Huile Sunscreen Spray Écran Solaire En Vaporisateur 4', 'spray', 'D02BA02', false, 0, '02334151', 'FreeDiams::CA_HCDPD::DIN', 81984);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Duragesic Mat', 'patch', 'N02AB03', false, 0, '02334186', 'FreeDiams::CA_HCDPD::DIN', 81986);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dr 200', 'liquid', 'V07AV', false, 0, '02334240', 'FreeDiams::CA_HCDPD::DIN', 81992);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pure Nettoyant Désinfectant Et Désodorisant', 'spray', 'V07AV', false, 0, '02334267', 'FreeDiams::CA_HCDPD::DIN', 81994);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sanex', 'liquid', 'V07AV', false, 0, '02334275', 'FreeDiams::CA_HCDPD::DIN', 81995);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Virudex-7', 'liquid', 'V07AV', false, 0, '02334283', 'FreeDiams::CA_HCDPD::DIN', 81996);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Disinfectant Cleaner 2.0', 'liquid', 'V07AV', false, 0, '02334291', 'FreeDiams::CA_HCDPD::DIN', 81997);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic After Sun Aprčs Soleil Sunburn Relief Soulagement Des Coups De Soleil', 'gel', 'D04AB01', false, 0, '02334453', 'FreeDiams::CA_HCDPD::DIN', 82012);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intensive 3-In-1 Day Cream Spf 30', 'cream', 'D02BA30', false, 0, '02334461', 'FreeDiams::CA_HCDPD::DIN', 82013);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Origins A Perfect World Spf 25 Age-Defense Moisturizer With White Tea', 'cream', 'D02BA30', false, 0, '02334488', 'FreeDiams::CA_HCDPD::DIN', 82014);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 50 Kids Continuous Spray Sunscreen', 'spray, bag-on-valve', 'D02BA30', false, 0, '02334496', 'FreeDiams::CA_HCDPD::DIN', 82015);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Sport Continuous Spray Sunscreen', 'spray, bag-on-valve', 'D02BA30', false, 0, '02334518', 'FreeDiams::CA_HCDPD::DIN', 82016);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Waterguard Kids Sunscreen Clear Spray', 'aerosol', 'D02BA30', false, 0, '02334534', 'FreeDiams::CA_HCDPD::DIN', 82017);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultimate Sport Sunscreen Spray Spf 60', 'aerosol', 'D02BA30', false, 0, '02334526', 'FreeDiams::CA_HCDPD::DIN', 82018);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutrogena Ultra Sheer Body Mist Sunscreen Spf 60', 'aerosol', 'D02BA30', false, 0, '02334542', 'FreeDiams::CA_HCDPD::DIN', 82019);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutrogena Fresh Cooling Body Mist Sunscreen Spf 60', 'aerosol', 'D02BA30', false, 0, '02334550', 'FreeDiams::CA_HCDPD::DIN', 82020);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norditropin Simplexx', 'solution', 'H01AC01', false, 0, '02334968', 'FreeDiams::CA_HCDPD::DIN', 82055);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norditropin Simplexx', 'solution', 'H01AC01', false, 0, '02334941', 'FreeDiams::CA_HCDPD::DIN', 82056);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norditropin Simplexx', 'solution', 'H01AC01', false, 0, '02334925', 'FreeDiams::CA_HCDPD::DIN', 82057);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kids Tear Free/ Sans Larmes Sunscreen Spray Écran Solaire En Vaporisateur Pour Enfants Spf Fps 60', 'spray, bag-on-valve', 'D02BA30', false, 0, '02334984', 'FreeDiams::CA_HCDPD::DIN', 82060);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Endometrin', 'vaginal tablet, effervescent', 'G03DA04', false, 0, '02334992', 'FreeDiams::CA_HCDPD::DIN', 82061);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kids Tear Free/ Sans Larmes Sunscreen Lotion/Lotion Écran Solaire Pour Enfants Spf Fps 60', 'lotion', 'D02BA30', false, 0, '02335018', 'FreeDiams::CA_HCDPD::DIN', 82062);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Continuous Spray Spf 30', 'spray, bag-on-valve', 'D02BA30', false, 0, '02335026', 'FreeDiams::CA_HCDPD::DIN', 82063);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Continuous Spray Spf 50', 'spray, bag-on-valve', 'D02BA30', false, 0, '02335042', 'FreeDiams::CA_HCDPD::DIN', 82065);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baby Tear Free/Sans Larmes Sunscreen Lotion/Lotion Écran Solaire Pour Bébés Spf Fps 60', 'lotion', 'D02BA30', false, 0, '02335050', 'FreeDiams::CA_HCDPD::DIN', 82066);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baby Tear Free/Sans Larmes Sunscreen Spray/Écran Solaire En Vaporisateur Pour Bebes Spf Fps 60', 'spray, bag-on-valve', 'D02BA30', false, 0, '02335069', 'FreeDiams::CA_HCDPD::DIN', 82067);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dosolax', 'capsule', 'A06AA02', false, 0, '02335077', 'FreeDiams::CA_HCDPD::DIN', 82068);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp Docusate Sodium 250mg Softgels', 'capsule', 'A06AA02', false, 0, '02335085', 'FreeDiams::CA_HCDPD::DIN', 82069);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prevnar 13', 'suspension', 'J07AL02', false, 0, '02335204', 'FreeDiams::CA_HCDPD::DIN', 82074);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Swish Silver Supreme', 'solution', 'V07AV', false, 0, '02335212', 'FreeDiams::CA_HCDPD::DIN', 82082);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckley''S Complete Nighttime Softgels', 'capsule', 'N02BE51', false, 0, '02335239', 'FreeDiams::CA_HCDPD::DIN', 82084);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Capture Totale Fond De Teint Concentré Éclat Haute Défintion', 'emulsion', 'D02BA30', false, 0, '02335522', 'FreeDiams::CA_HCDPD::DIN', 82113);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Disinfectant All-Purpose Cleaner/Nettoyant Tout-Usage Désinfectant', 'solution', 'V07AV', false, 0, '02335530', 'FreeDiams::CA_HCDPD::DIN', 82114);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mr. Clean Disinfectant Multi-Surfaces Spray', 'spray', 'V07AV', false, 0, '02335549', 'FreeDiams::CA_HCDPD::DIN', 82115);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mr. Clean  Disinfectant Multi-Surfaces', 'liquid', 'V07AV', false, 0, '02335557', 'FreeDiams::CA_HCDPD::DIN', 82116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bt Surface Disinfectant And Deodorizing Spray', 'aerosol', 'V07AV', false, 0, '02335565', 'FreeDiams::CA_HCDPD::DIN', 82117);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bt Disinfectant Foaming Cleaner', 'aerosol', 'V07AV', false, 0, '02335603', 'FreeDiams::CA_HCDPD::DIN', 82120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Color Rich Cool Bliss Lipstick/Rouge Ŕ Lčvres Spf 15/Fps 15', 'stick', 'D02BA02', false, 0, '02335697', 'FreeDiams::CA_HCDPD::DIN', 82128);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Toloxin', 'tablet', 'C01AA05', false, 0, '02335700', 'FreeDiams::CA_HCDPD::DIN', 82129);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Toloxin', 'tablet', 'C01AA05', false, 0, '02335719', 'FreeDiams::CA_HCDPD::DIN', 82130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Toloxin', 'tablet', 'C01AA05', false, 0, '02335727', 'FreeDiams::CA_HCDPD::DIN', 82131);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckley''S Complete Daytime Plus Mucus Relief Softgels', 'capsule', 'N02BE51', false, 0, '02335948', 'FreeDiams::CA_HCDPD::DIN', 82152);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elizabeth Arden Pure Finish Mineral Tinted Moisture Cream Spf 15', 'cream', 'D02BA30', false, 0, '02335964', 'FreeDiams::CA_HCDPD::DIN', 82154);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Healthy Defense Daily Moisturizer Spf 30', 'lotion', 'D02BA30', false, 0, '02336030', 'FreeDiams::CA_HCDPD::DIN', 82161);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rosa Graf Forty Plus Protect', 'cream', 'D02BA30', false, 0, '02336073', 'FreeDiams::CA_HCDPD::DIN', 82167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Ranitidine', 'tablet', 'A02BA02', false, 0, '02336480', 'FreeDiams::CA_HCDPD::DIN', 82205);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 50 Sunscreen Continuous Spray Lotion', 'spray, bag-on-valve', 'D02BA30', false, 0, '02336499', 'FreeDiams::CA_HCDPD::DIN', 82206);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Ranitidine', 'tablet', 'A02BA02', false, 0, '02336502', 'FreeDiams::CA_HCDPD::DIN', 82207);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Sunscreen Continuous Spray Solution For Kids', 'spray, bag-on-valve', 'D02BA30', false, 0, '02336537', 'FreeDiams::CA_HCDPD::DIN', 82210);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kimtech Brand Disinfectant Wipe', 'wipe', 'V07AV', false, 0, '02336642', 'FreeDiams::CA_HCDPD::DIN', 82224);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arepanrix H1n1', 'emulsion', 'J07BB02', false, 0, '02336650', 'FreeDiams::CA_HCDPD::DIN', 82225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vidaza', 'powder for suspension', 'L01BC07', false, 0, '02336707', 'FreeDiams::CA_HCDPD::DIN', 82233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02336715', 'FreeDiams::CA_HCDPD::DIN', 82234);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02336723', 'FreeDiams::CA_HCDPD::DIN', 82235);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02336731', 'FreeDiams::CA_HCDPD::DIN', 82236);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Rivastigmine', 'capsule', 'N06DA03', false, 0, '02336758', 'FreeDiams::CA_HCDPD::DIN', 82237);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Tramadol/Acet', 'tablet', 'N02AX52', false, 0, '02336790', 'FreeDiams::CA_HCDPD::DIN', 82241);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('70 Spf Body Mist', 'spray', 'D02BA30', false, 0, '02336804', 'FreeDiams::CA_HCDPD::DIN', 82242);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acne Treatment Lotion', 'lotion', 'D10AE01', false, 0, '02336812', 'FreeDiams::CA_HCDPD::DIN', 82243);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydra Moisturizing Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02336820', 'FreeDiams::CA_HCDPD::DIN', 82244);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 50 Funscreen Spray-On Sunscreen For Kids', 'spray', 'D02BA30', false, 0, '02336839', 'FreeDiams::CA_HCDPD::DIN', 82245);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Besivance', 'suspension', 'S01AX23', false, 0, '02336847', 'FreeDiams::CA_HCDPD::DIN', 82246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Firmagon', 'powder for solution', 'L02BX02', false, 0, '02337029', 'FreeDiams::CA_HCDPD::DIN', 82263);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Firmagon', 'powder for solution', 'L02BX02', false, 0, '02337037', 'FreeDiams::CA_HCDPD::DIN', 82264);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ener-C Moisturizing Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02337053', 'FreeDiams::CA_HCDPD::DIN', 82268);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clarifying Calming Oil-Control Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02337061', 'FreeDiams::CA_HCDPD::DIN', 82269);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eye Contour Multi-Protection Sun Care Spf 30', 'cream', 'D02BA30', false, 0, '02337088', 'FreeDiams::CA_HCDPD::DIN', 82270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lysol Healthy Touch Antibacterial Hand Soap', 'liquid', 'D08AJ08', false, 0, '02337096', 'FreeDiams::CA_HCDPD::DIN', 82271);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Olanzapine', 'tablet', 'N05AH03', false, 0, '02337126', 'FreeDiams::CA_HCDPD::DIN', 82273);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Olanzapine', 'tablet', 'N05AH03', false, 0, '02337134', 'FreeDiams::CA_HCDPD::DIN', 82274);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Olanzapine', 'tablet', 'N05AH03', false, 0, '02337142', 'FreeDiams::CA_HCDPD::DIN', 82275);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Olanzapine', 'tablet', 'N05AH03', false, 0, '02337150', 'FreeDiams::CA_HCDPD::DIN', 82276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Olanzapine', 'tablet', 'N05AH03', false, 0, '02337169', 'FreeDiams::CA_HCDPD::DIN', 82277);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allstar Vortex', 'solution', 'V07AV', false, 0, '02337185', 'FreeDiams::CA_HCDPD::DIN', 82279);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advate', 'powder for solution', 'B02BD02', false, 0, '02337193', 'FreeDiams::CA_HCDPD::DIN', 82280);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Revlon Age Defying Moisturizing Concealer', 'cream', 'D02BA30', false, 0, '02337223', 'FreeDiams::CA_HCDPD::DIN', 82283);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jurnista', 'tablet (extended-release)', 'N02AA03', false, 0, '02337266', 'FreeDiams::CA_HCDPD::DIN', 82286);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jurnista', 'tablet (extended-release)', 'N02AA03', false, 0, '02337274', 'FreeDiams::CA_HCDPD::DIN', 82287);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jurnista', 'tablet (extended-release)', 'N02AA03', false, 0, '02337282', 'FreeDiams::CA_HCDPD::DIN', 82288);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jurnista', 'tablet (extended-release)', 'N02AA03', false, 0, '02337290', 'FreeDiams::CA_HCDPD::DIN', 82289);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Irbesartan Hct', 'tablet', 'C09DA04', false, 0, '02337428', 'FreeDiams::CA_HCDPD::DIN', 82301);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Irbesartan Hct', 'tablet', 'C09DA04', false, 0, '02337436', 'FreeDiams::CA_HCDPD::DIN', 82302);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Irbesartan Hct', 'tablet', 'C09DA04', false, 0, '02337444', 'FreeDiams::CA_HCDPD::DIN', 82303);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diaper Rash Cream', 'cream', 'D02AB', false, 0, '02337452', 'FreeDiams::CA_HCDPD::DIN', 82304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advanced Marine Biology Day Cream', 'cream', 'D02BA30', false, 0, '02337460', 'FreeDiams::CA_HCDPD::DIN', 82305);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Analgesic And Muscle Relaxant Caplets', 'tablet', 'M03BA53', false, 0, '02337479', 'FreeDiams::CA_HCDPD::DIN', 82306);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Valsartan', 'tablet', 'C09CA03', false, 0, '02337487', 'FreeDiams::CA_HCDPD::DIN', 82307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Valsartan', 'tablet', 'C09CA03', false, 0, '02337495', 'FreeDiams::CA_HCDPD::DIN', 82308);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Valsartan', 'tablet', 'C09CA03', false, 0, '02337509', 'FreeDiams::CA_HCDPD::DIN', 82309);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Valsartan', 'tablet', 'C09CA03', false, 0, '02337517', 'FreeDiams::CA_HCDPD::DIN', 82310);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Swisstec Global Protect Spf 30', 'lotion', 'D02BA30', false, 0, '02337541', 'FreeDiams::CA_HCDPD::DIN', 82313);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Super Sheer Sunscreen Lotion Spf 50', 'lotion', 'D02BA30', false, 0, '02337576', 'FreeDiams::CA_HCDPD::DIN', 82315);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Idarubicin Hydrochloride Injection', 'solution', 'L01DB06', false, 0, '02337584', 'FreeDiams::CA_HCDPD::DIN', 82316);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Toctino', 'capsule', 'D11AX19', false, 0, '02337630', 'FreeDiams::CA_HCDPD::DIN', 82321);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Toctino', 'capsule', 'D11AX19', false, 0, '02337649', 'FreeDiams::CA_HCDPD::DIN', 82322);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extavia', 'powder for solution', 'L03AB08', false, 0, '02337819', 'FreeDiams::CA_HCDPD::DIN', 82345);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stalevo', 'tablet', 'N04BA03', false, 0, '02337827', 'FreeDiams::CA_HCDPD::DIN', 82347);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stalevo', 'tablet', 'N04BA03', false, 0, '02337835', 'FreeDiams::CA_HCDPD::DIN', 82348);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 4 Sunscreen Lotion', 'lotion', 'D02BA02', false, 0, '02337843', 'FreeDiams::CA_HCDPD::DIN', 82349);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 8 Sunscreen Uva/Uvb Protection Lotion', 'lotion', 'D02BA30', false, 0, '02337851', 'FreeDiams::CA_HCDPD::DIN', 82350);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Olanzapine', 'tablet', 'N05AH03', false, 0, '02337878', 'FreeDiams::CA_HCDPD::DIN', 82351);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Olanzapine', 'tablet', 'N05AH03', false, 0, '02337886', 'FreeDiams::CA_HCDPD::DIN', 82352);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Olanzapine', 'tablet', 'N05AH03', false, 0, '02337894', 'FreeDiams::CA_HCDPD::DIN', 82353);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Olanzapine', 'tablet', 'N05AH03', false, 0, '02337908', 'FreeDiams::CA_HCDPD::DIN', 82354);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Olanzapine', 'tablet', 'N05AH03', false, 0, '02337916', 'FreeDiams::CA_HCDPD::DIN', 82355);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Olanzapine', 'tablet', 'N05AH03', false, 0, '02337924', 'FreeDiams::CA_HCDPD::DIN', 82356);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 60 Sunscreen Stick', 'stick', 'D02BA30', false, 0, '02338025', 'FreeDiams::CA_HCDPD::DIN', 82367);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 15 Sunburn Protection Lotion', 'lotion', 'D02BA30', false, 0, '02338033', 'FreeDiams::CA_HCDPD::DIN', 82368);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Carvedilol', 'tablet', 'C07AG02', false, 0, '02338068', 'FreeDiams::CA_HCDPD::DIN', 82370);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Carvedilol', 'tablet', 'C07AG02', false, 0, '02338092', 'FreeDiams::CA_HCDPD::DIN', 82371);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Kids Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02338076', 'FreeDiams::CA_HCDPD::DIN', 82372);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 50 Kids Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02338084', 'FreeDiams::CA_HCDPD::DIN', 82373);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Carvedilol', 'tablet', 'C07AG02', false, 0, '02338106', 'FreeDiams::CA_HCDPD::DIN', 82374);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Carvedilol', 'tablet', 'C07AG02', false, 0, '02338114', 'FreeDiams::CA_HCDPD::DIN', 82375);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 60 Baby Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02338165', 'FreeDiams::CA_HCDPD::DIN', 82380);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 60 Face Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02338173', 'FreeDiams::CA_HCDPD::DIN', 82381);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydra-C Radiance 24h + Spf 15 Fps Hydrating Lotion Lotion Hydratante', 'lotion', 'D02BA30', false, 0, '02338181', 'FreeDiams::CA_HCDPD::DIN', 82382);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mousse Exquise Auto-Bronzante 15 Spf', 'cream', 'D02BA30', false, 0, '02338203', 'FreeDiams::CA_HCDPD::DIN', 82383);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adcirca', 'tablet', 'C02KX', false, 0, '02338327', 'FreeDiams::CA_HCDPD::DIN', 82395);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desloratadine Tablets', 'tablet', 'R06AX27', false, 0, '02338424', 'FreeDiams::CA_HCDPD::DIN', 82406);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prezista', 'tablet', 'J05AE10', false, 0, '02338432', 'FreeDiams::CA_HCDPD::DIN', 82408);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Letrozole Tablets Usp', 'tablet', 'L02BG04', false, 0, '02338459', 'FreeDiams::CA_HCDPD::DIN', 82411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Final Rinse', 'liquid', 'V07AV', false, 0, '02338475', 'FreeDiams::CA_HCDPD::DIN', 82413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biosan Wipes', 'wipe', 'V07AV', false, 0, '02338483', 'FreeDiams::CA_HCDPD::DIN', 82414);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Solar Screen Spf 12', 'lotion', 'D02BA30', false, 0, '02338491', 'FreeDiams::CA_HCDPD::DIN', 82415);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Likewise Disinfecting Wipes', 'wipe', 'V07AV', false, 0, '02338505', 'FreeDiams::CA_HCDPD::DIN', 82416);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Good And Clean Disinfectant Wipes', 'wipe', 'V07AV', false, 0, '02338513', 'FreeDiams::CA_HCDPD::DIN', 82417);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Wahl Spray On Disinfectant', 'liquid', 'V07AV', false, 0, '02338521', 'FreeDiams::CA_HCDPD::DIN', 82418);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Silkis', 'ointment', 'D05AX03', false, 0, '02338572', 'FreeDiams::CA_HCDPD::DIN', 82422);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Voltaren Emulgel - Joint Pain', 'gel', 'M02AA15', false, 0, '02338580', 'FreeDiams::CA_HCDPD::DIN', 82423);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Great Value Disinfectant Wipes', 'wipe', 'V07AV', false, 0, '02338610', 'FreeDiams::CA_HCDPD::DIN', 82428);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02338645', 'FreeDiams::CA_HCDPD::DIN', 82431);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02338653', 'FreeDiams::CA_HCDPD::DIN', 82432);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02338661', 'FreeDiams::CA_HCDPD::DIN', 82433);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Essentials 1st Wrinkles 1čres Rides Day Cream Spf 15 Crčme De Jour Spf 15', 'cream', 'D02BA30', false, 0, '02338963', 'FreeDiams::CA_HCDPD::DIN', 82461);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultimate Sport Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02338971', 'FreeDiams::CA_HCDPD::DIN', 82462);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pear Antibacterial Hand Soap', 'liquid', 'D08AE04', false, 0, '02339013', 'FreeDiams::CA_HCDPD::DIN', 82465);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Esomeprazole', 'tablet (delayed-release)', 'A02BC05', false, 0, '02339102', 'FreeDiams::CA_HCDPD::DIN', 82473);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Smooth Minerals Avon Lip Gloss Gloss Levres Spf 15 Fps 15', 'ointment', 'D02BA30', false, 0, '02339234', 'FreeDiams::CA_HCDPD::DIN', 82484);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02339242', 'FreeDiams::CA_HCDPD::DIN', 82485);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02339250', 'FreeDiams::CA_HCDPD::DIN', 82486);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02339269', 'FreeDiams::CA_HCDPD::DIN', 82487);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Recothrom', 'powder for solution', 'B02BD30', false, 0, '02339277', 'FreeDiams::CA_HCDPD::DIN', 82488);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Sport Sunscreen Lotion Face Spf 50', 'lotion', 'D02BA30', false, 0, '02339323', 'FreeDiams::CA_HCDPD::DIN', 82493);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Sport Sunscreen Lotion Spf 50', 'lotion', 'D02BA30', false, 0, '02339331', 'FreeDiams::CA_HCDPD::DIN', 82494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Plasma-Lyte A Injection', 'solution', 'B05BB01', false, 0, '02339358', 'FreeDiams::CA_HCDPD::DIN', 82495);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Precedex', 'solution', 'N05CM18', false, 0, '02339366', 'FreeDiams::CA_HCDPD::DIN', 82498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Galantamine Er', 'capsule (extended release)', 'N06DA04', false, 0, '02339439', 'FreeDiams::CA_HCDPD::DIN', 82505);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Galantamine Er', 'capsule (extended release)', 'N06DA04', false, 0, '02339447', 'FreeDiams::CA_HCDPD::DIN', 82506);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Galantamine Er', 'capsule (extended release)', 'N06DA04', false, 0, '02339455', 'FreeDiams::CA_HCDPD::DIN', 82507);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ocean Potion Sunscreen Spf 60 Lotion', 'lotion', 'D02BA30', false, 0, '02339463', 'FreeDiams::CA_HCDPD::DIN', 82508);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Finasteride A', 'tablet', 'D11AX10', false, 0, '02339471', 'FreeDiams::CA_HCDPD::DIN', 82509);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Afinitor', 'tablet', 'L04AA18', false, 0, '02339501', 'FreeDiams::CA_HCDPD::DIN', 82511);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Afinitor', 'tablet', 'L04AA18', false, 0, '02339528', 'FreeDiams::CA_HCDPD::DIN', 82512);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Karticaine', 'solution', 'N01BB58', false, 0, '02339536', 'FreeDiams::CA_HCDPD::DIN', 82513);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Karticaine Forte', 'solution', 'N01BB58', false, 0, '02339544', 'FreeDiams::CA_HCDPD::DIN', 82514);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ocean Potion Instant Dry Spf 60 Mist', 'spray', 'D02BA30', false, 0, '02339552', 'FreeDiams::CA_HCDPD::DIN', 82515);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pioglitazone Hydrochloride Tablets', 'tablet', 'A10BG03', false, 0, '02339587', 'FreeDiams::CA_HCDPD::DIN', 82518);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pioglitazone Hydrochloride Tablets', 'tablet', 'A10BG03', false, 0, '02339595', 'FreeDiams::CA_HCDPD::DIN', 82519);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Targin', 'tablet (extended-release)', 'N02AA55', false, 0, '02339609', 'FreeDiams::CA_HCDPD::DIN', 82520);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Targin', 'tablet (extended-release)', 'N02AA55', false, 0, '02339617', 'FreeDiams::CA_HCDPD::DIN', 82521);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Targin', 'tablet (extended-release)', 'N02AA55', false, 0, '02339625', 'FreeDiams::CA_HCDPD::DIN', 82522);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Covergirl Natureluxe Silk Foundation Spf10', 'emulsion', 'D02BA30', false, 0, '02339633', 'FreeDiams::CA_HCDPD::DIN', 82523);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kleenex Luxury Foam Antibacterial Skin Cleanser', 'liquid', 'D08AE04', false, 0, '02339641', 'FreeDiams::CA_HCDPD::DIN', 82524);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Revlon Photoready Concealer', 'stick', 'D02BA30', false, 0, '02339668', 'FreeDiams::CA_HCDPD::DIN', 82525);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sanctura Xr', 'capsule (extended release)', 'G04BD09', false, 0, '02339706', 'FreeDiams::CA_HCDPD::DIN', 82529);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Climatik Spf 30 Fps Lip Balm Baume A Levres', 'stick', 'D02BA30', false, 0, '02339714', 'FreeDiams::CA_HCDPD::DIN', 82530);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ep51b Quaternary Disinfectant / Désinfectant Quaternaire', 'liquid', 'V07AV', false, 0, '02339730', 'FreeDiams::CA_HCDPD::DIN', 82532);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ep51b Av-Mixx Quaternary Disinfectant / Désinfectant Quaternaire', 'liquid', 'V07AV', false, 0, '02339749', 'FreeDiams::CA_HCDPD::DIN', 82533);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02339811', 'FreeDiams::CA_HCDPD::DIN', 82535);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02339838', 'FreeDiams::CA_HCDPD::DIN', 82540);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Olanzapine Odt', 'tablet (orally disintegrating)', 'N05AH03', false, 0, '02339846', 'FreeDiams::CA_HCDPD::DIN', 82541);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Brighter By Nature Spf 35 Skin Tone Correcting Moisturizer', 'cream', 'D02BA30', false, 0, '02339862', 'FreeDiams::CA_HCDPD::DIN', 82543);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kemsol Airx 75 Detergent Disinfectant Pump Spray', 'spray', 'V07AV', false, 0, '02339870', 'FreeDiams::CA_HCDPD::DIN', 82544);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fix Disinfectant Cleaner Wipes', 'wipe', 'V07AV', false, 0, '02339919', 'FreeDiams::CA_HCDPD::DIN', 82548);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Omeprazole', 'capsule (delayed release)', 'A02BC01', false, 0, '02339927', 'FreeDiams::CA_HCDPD::DIN', 82550);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Paul Davis Systems Benefect Botanical Disinfectant', 'spray', 'V07AV', false, 0, '02339943', 'FreeDiams::CA_HCDPD::DIN', 82551);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Facilipro Disinfectant Cleaner 2.0', 'liquid', 'V07AV', false, 0, '02339951', 'FreeDiams::CA_HCDPD::DIN', 82554);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dyna Quat Plus Fragrance Free', 'liquid', 'V07AV', false, 0, '02339986', 'FreeDiams::CA_HCDPD::DIN', 82556);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Disaster Kleenup Canada Benefect Botanical Disinfectant', 'spray', 'V07AV', false, 0, '02340011', 'FreeDiams::CA_HCDPD::DIN', 82559);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Tamsulosin Cr', 'tablet (extended-release)', 'G04CA02', false, 0, '02340208', 'FreeDiams::CA_HCDPD::DIN', 82577);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ep50 Av-Mixx Nettoyant Désinfectant/Ep50 Av-Mixx Cleaner Disinfectant', 'solution', 'V07AV', false, 0, '02340305', 'FreeDiams::CA_HCDPD::DIN', 82588);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ep50 Nettoyant Désinfectant/Ep50 Cleaner Disinfectant', 'solution', 'V07AV', false, 0, '02340321', 'FreeDiams::CA_HCDPD::DIN', 82590);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Face Oasis Hydrating Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02340356', 'FreeDiams::CA_HCDPD::DIN', 82592);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Sunburn Protection Lotion', 'lotion', 'D02BA30', false, 0, '02340437', 'FreeDiams::CA_HCDPD::DIN', 82602);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zyclara', 'cream', 'D06BB10', false, 0, '02340445', 'FreeDiams::CA_HCDPD::DIN', 82603);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shaklee Basic-G', 'liquid', 'V07AV', false, 0, '02340453', 'FreeDiams::CA_HCDPD::DIN', 82604);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Limitless Long Wear Lip Gloss Spf 15', 'emulsion', 'D02BA30', false, 0, '02340526', 'FreeDiams::CA_HCDPD::DIN', 82610);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daily Defense Spf 30', 'lotion', 'D02BA30', false, 0, '02340593', 'FreeDiams::CA_HCDPD::DIN', 82617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Do The Right Thing Smoothing Body Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02340631', 'FreeDiams::CA_HCDPD::DIN', 82621);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Soins Soleil-Crčme Visage Et Corps/ Face And Body Cream Faible/Low Protection Uva/Uvb Spf10', 'cream', 'D02BA30', false, 0, '02340658', 'FreeDiams::CA_HCDPD::DIN', 82622);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Primovist', 'solution', 'V08CA10', false, 0, '02340666', 'FreeDiams::CA_HCDPD::DIN', 82625);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Risedronate', 'tablet', 'M05BA07', false, 0, '02341077', 'FreeDiams::CA_HCDPD::DIN', 82662);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accel-Amlodipine', 'tablet', 'C08CA01', false, 0, '02341093', 'FreeDiams::CA_HCDPD::DIN', 82664);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Accel-Amlodipine', 'tablet', 'C08CA01', false, 0, '02341107', 'FreeDiams::CA_HCDPD::DIN', 82666);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Butrans 5', 'patch', 'N02AE01', false, 0, '02341174', 'FreeDiams::CA_HCDPD::DIN', 82671);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Butrans 10', 'patch', 'N02AE01', false, 0, '02341212', 'FreeDiams::CA_HCDPD::DIN', 82675);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Butrans 20', 'patch', 'N02AE01', false, 0, '02341220', 'FreeDiams::CA_HCDPD::DIN', 82676);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fentanyl Mtx', 'patch', 'N02AB03', false, 0, '02341379', 'FreeDiams::CA_HCDPD::DIN', 82689);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fentanyl Mtx', 'patch', 'N02AB03', false, 0, '02341387', 'FreeDiams::CA_HCDPD::DIN', 82690);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fentanyl Mtx', 'patch', 'N02AB03', false, 0, '02341395', 'FreeDiams::CA_HCDPD::DIN', 82691);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fentanyl Mtx', 'patch', 'N02AB03', false, 0, '02341409', 'FreeDiams::CA_HCDPD::DIN', 82692);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Fentanyl Mtx', 'patch', 'N02AB03', false, 0, '02341417', 'FreeDiams::CA_HCDPD::DIN', 82693);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Revatio', 'solution', 'G04BE03', false, 0, '02341611', 'FreeDiams::CA_HCDPD::DIN', 82711);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Clorox Disinfecting Bleach', 'solution', 'V07AV', false, 0, '02342065', 'FreeDiams::CA_HCDPD::DIN', 82758);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('After Sun Burn Relief Lidocaine Continuous Spray', 'solution', 'D04AB01', false, 0, '02342073', 'FreeDiams::CA_HCDPD::DIN', 82759);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('La Parisienne', 'liquid', 'V07AV', false, 0, '02342081', 'FreeDiams::CA_HCDPD::DIN', 82760);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ramipril-Hctz', 'tablet', 'C09BA05', false, 0, '02342138', 'FreeDiams::CA_HCDPD::DIN', 82763);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ramipril-Hctz', 'tablet', 'C09BA05', false, 0, '02342146', 'FreeDiams::CA_HCDPD::DIN', 82764);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ramipril-Hctz', 'tablet', 'C09BA05', false, 0, '02342154', 'FreeDiams::CA_HCDPD::DIN', 82765);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ramipril-Hctz', 'tablet', 'C09BA05', false, 0, '02342162', 'FreeDiams::CA_HCDPD::DIN', 82766);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ramipril-Hctz', 'tablet', 'C09BA05', false, 0, '02342170', 'FreeDiams::CA_HCDPD::DIN', 82767);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Axum', 'tablet', 'M03BA53', false, 0, '02342197', 'FreeDiams::CA_HCDPD::DIN', 82770);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Muscle & Back Pain Relief With Ibuprofen', 'tablet', 'M03BA53', false, 0, '02342219', 'FreeDiams::CA_HCDPD::DIN', 82772);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cervarix', 'suspension', 'J07BM02', false, 0, '02342227', 'FreeDiams::CA_HCDPD::DIN', 82773);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neck + Chest Perfector', 'cream', 'D02BA30', false, 0, '02342294', 'FreeDiams::CA_HCDPD::DIN', 82779);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Age Shield Face Sunscreen Spf 85', 'lotion', 'D02BA30', false, 0, '02342308', 'FreeDiams::CA_HCDPD::DIN', 82780);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vinoxx Ready To Use Towelettes', 'wipe', 'V07AV', false, 0, '02342316', 'FreeDiams::CA_HCDPD::DIN', 82781);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hmts Sterilant Agent', 'solution', 'V07AV', false, 0, '02342413', 'FreeDiams::CA_HCDPD::DIN', 82791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Everything Butt', 'cream', 'D02AB', false, 0, '02342421', 'FreeDiams::CA_HCDPD::DIN', 82792);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('L''Absolu Rouge', 'stick', 'D02BA02', false, 0, '02342537', 'FreeDiams::CA_HCDPD::DIN', 82802);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Zolmitriptan Od', 'tablet (orally disintegrating)', 'N02CC03', false, 0, '02342545', 'FreeDiams::CA_HCDPD::DIN', 82803);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kogenate Fs     -(With Bio-Set)', 'powder for solution', 'B02BD02', false, 0, '02342758', 'FreeDiams::CA_HCDPD::DIN', 82824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Amlodipine', 'tablet', 'C08CA01', false, 0, '02342790', 'FreeDiams::CA_HCDPD::DIN', 82829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Amlodipine', 'tablet', 'C08CA01', false, 0, '02342804', 'FreeDiams::CA_HCDPD::DIN', 82830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Uv Bed Cleaner', 'spray', 'V07AV', false, 0, '02342812', 'FreeDiams::CA_HCDPD::DIN', 82831);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Armstrong Detergent Disinfectant Pump Spray', 'spray', 'V07AV', false, 0, '02342839', 'FreeDiams::CA_HCDPD::DIN', 82833);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cross-Terrain Spf 50', 'ointment', 'D02BA30', false, 0, '02342847', 'FreeDiams::CA_HCDPD::DIN', 82834);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Val-Vancomycin', 'powder for solution', 'J01XA01', false, 0, '02342855', 'FreeDiams::CA_HCDPD::DIN', 82835);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Val-Vancomycin', 'powder for solution', 'J01XA01', false, 0, '02342863', 'FreeDiams::CA_HCDPD::DIN', 82836);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Renew Face Dry Touch Sun Protection Broad Spectrum Uva/Uvb Sunscreen Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02342901', 'FreeDiams::CA_HCDPD::DIN', 82839);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Lotion Spf 50', 'lotion', 'D02BA30', false, 0, '02342952', 'FreeDiams::CA_HCDPD::DIN', 82843);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Azathioprine', 'tablet', 'L04AX01', false, 0, '02343002', 'FreeDiams::CA_HCDPD::DIN', 82849);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lamotrigine', 'tablet', 'N03AX09', false, 0, '02343010', 'FreeDiams::CA_HCDPD::DIN', 82850);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lamotrigine', 'tablet', 'N03AX09', false, 0, '02343029', 'FreeDiams::CA_HCDPD::DIN', 82851);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lamotrigine', 'tablet', 'N03AX09', false, 0, '02343037', 'FreeDiams::CA_HCDPD::DIN', 82852);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ticlopidine', 'tablet', 'B01AC05', false, 0, '02343045', 'FreeDiams::CA_HCDPD::DIN', 82853);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Propafenone', 'tablet', 'C01BC03', false, 0, '02343053', 'FreeDiams::CA_HCDPD::DIN', 82854);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Propafenone', 'tablet', 'C01BC03', false, 0, '02343061', 'FreeDiams::CA_HCDPD::DIN', 82855);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydroxyurea', 'capsule', 'L01XX05', false, 0, '02343096', 'FreeDiams::CA_HCDPD::DIN', 82857);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simvastatin', 'tablet', 'C10AA01', false, 0, '02343142', 'FreeDiams::CA_HCDPD::DIN', 82861);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simvastatin', 'tablet', 'C10AA01', false, 0, '02343150', 'FreeDiams::CA_HCDPD::DIN', 82862);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simvastatin', 'tablet', 'C10AA01', false, 0, '02343169', 'FreeDiams::CA_HCDPD::DIN', 82863);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simvastatin', 'tablet', 'C10AA01', false, 0, '02343177', 'FreeDiams::CA_HCDPD::DIN', 82864);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simvastatin', 'tablet', 'C10AA01', false, 0, '02343185', 'FreeDiams::CA_HCDPD::DIN', 82865);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amlodipine', 'tablet', 'C08CA01', false, 0, '02343193', 'FreeDiams::CA_HCDPD::DIN', 82866);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amlodipine', 'tablet', 'C08CA01', false, 0, '02343207', 'FreeDiams::CA_HCDPD::DIN', 82867);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amlodipine', 'tablet', 'C08CA01', false, 0, '02343215', 'FreeDiams::CA_HCDPD::DIN', 82868);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nabumetone', 'tablet', 'M01AX01', false, 0, '02343282', 'FreeDiams::CA_HCDPD::DIN', 82875);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp Acetaminophen 500 Mg F.C. Tablets', 'tablet', 'N02BE01', false, 0, '02343371', 'FreeDiams::CA_HCDPD::DIN', 82884);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prolia', 'solution', 'M05BX04', false, 0, '02343541', 'FreeDiams::CA_HCDPD::DIN', 82897);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anthelios Spf 45', 'lotion', 'D02BA30', false, 0, '02343894', 'FreeDiams::CA_HCDPD::DIN', 82930);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anthelios Spray Spf 45', 'spray', 'D02BA30', false, 0, '02343908', 'FreeDiams::CA_HCDPD::DIN', 82931);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Ramipril', 'capsule', 'C09AA05', false, 0, '02343932', 'FreeDiams::CA_HCDPD::DIN', 82934);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topotecan Hydrochloride For Injection', 'powder for solution', 'L01XX17', false, 0, '02344009', 'FreeDiams::CA_HCDPD::DIN', 82941);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Warfarin', 'tablet', 'B01AA03', false, 0, '02344025', 'FreeDiams::CA_HCDPD::DIN', 82943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Warfarin', 'tablet', 'B01AA03', false, 0, '02344033', 'FreeDiams::CA_HCDPD::DIN', 82944);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Warfarin', 'tablet', 'B01AA03', false, 0, '02344041', 'FreeDiams::CA_HCDPD::DIN', 82945);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Warfarin', 'tablet', 'B01AA03', false, 0, '02344068', 'FreeDiams::CA_HCDPD::DIN', 82946);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Warfarin', 'tablet', 'B01AA03', false, 0, '02344076', 'FreeDiams::CA_HCDPD::DIN', 82947);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Warfarin', 'tablet', 'B01AA03', false, 0, '02344084', 'FreeDiams::CA_HCDPD::DIN', 82948);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Warfarin', 'tablet', 'B01AA03', false, 0, '02344092', 'FreeDiams::CA_HCDPD::DIN', 82949);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Warfarin', 'tablet', 'B01AA03', false, 0, '02344106', 'FreeDiams::CA_HCDPD::DIN', 82950);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Warfarin', 'tablet', 'B01AA03', false, 0, '02344114', 'FreeDiams::CA_HCDPD::DIN', 82951);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zopiclone', 'tablet', 'N05CF01', false, 0, '02344122', 'FreeDiams::CA_HCDPD::DIN', 82952);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluoxetine', 'capsule', 'N06AB03', false, 0, '02344149', 'FreeDiams::CA_HCDPD::DIN', 82954);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluoxetine', 'capsule', 'N06AB03', false, 0, '02344157', 'FreeDiams::CA_HCDPD::DIN', 82955);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glysomed Face Moisturizer', 'cream', 'D02BA30', false, 0, '02344262', 'FreeDiams::CA_HCDPD::DIN', 82964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advanced Relief Eye Drops', 'drops', 'S01GA52', false, 0, '02344319', 'FreeDiams::CA_HCDPD::DIN', 82979);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Dorzolamide/Timolol', 'solution', 'S01ED51', false, 0, '02344351', 'FreeDiams::CA_HCDPD::DIN', 82984);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rederm Moisturizing Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02344394', 'FreeDiams::CA_HCDPD::DIN', 82987);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Ondansetron', 'tablet', 'A04AA01', false, 0, '02344440', 'FreeDiams::CA_HCDPD::DIN', 82995);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Ondansetron', 'tablet', 'A04AA01', false, 0, '02344459', 'FreeDiams::CA_HCDPD::DIN', 82996);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf/Fps 50 Fragrance-Free Spray Sunscreen', 'spray', 'D02BA30', false, 0, '02344505', 'FreeDiams::CA_HCDPD::DIN', 83001);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Night Time Total Extra Strength', 'powder', 'N02BE51', false, 0, '02344548', 'FreeDiams::CA_HCDPD::DIN', 83004);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clonazepam', 'tablet', 'N03AE01', false, 0, '02344602', 'FreeDiams::CA_HCDPD::DIN', 83010);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clonazepam', 'tablet', 'N03AE01', false, 0, '02344610', 'FreeDiams::CA_HCDPD::DIN', 83011);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clonazepam-R', 'tablet', 'N03AE01', false, 0, '02344629', 'FreeDiams::CA_HCDPD::DIN', 83012);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carvedilol', 'tablet', 'C07AG02', false, 0, '02344637', 'FreeDiams::CA_HCDPD::DIN', 83013);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carvedilol', 'tablet', 'C07AG02', false, 0, '02344645', 'FreeDiams::CA_HCDPD::DIN', 83014);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carvedilol', 'tablet', 'C07AG02', false, 0, '02344653', 'FreeDiams::CA_HCDPD::DIN', 83015);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Memantine', 'tablet', 'N06DX01', false, 0, '02344807', 'FreeDiams::CA_HCDPD::DIN', 83026);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Letrozole', 'tablet', 'L02BG04', false, 0, '02344815', 'FreeDiams::CA_HCDPD::DIN', 83029);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Saniblend Rtu Lemon Cleaner-Disinfectant-Detergent-Deodorizer-Fungicide/Saniblend Citron Pręt Ŕ Utiliser Nettoyant-Désinfectant-Détergent-Désodorisant-Contrôle De Moisissures-Fongicide', 'spray', 'V07AV', false, 0, '02344904', 'FreeDiams::CA_HCDPD::DIN', 83037);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Saniblend 64 Lemon Cleaner-Disinfectant-Detergent-Deodorizer-Fungicide/Saniblend 64 Citron Nettoyant-Désinfectant-Détergent-Désodorisant-Contrôle De Moisissures-Fongicide', 'liquid', 'V07AV', false, 0, '02344912', 'FreeDiams::CA_HCDPD::DIN', 83038);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Saniblend 32 Lemon Cleaner-Disinfectant-Detergent-Deodorizer-Fungicide/Saniblend 32 Citron Nettoyant-Désinfectant-Détergent-Désodorisant-Contrôle De Moisissures-Fongicide', 'liquid', 'V07AV', false, 0, '02344920', 'FreeDiams::CA_HCDPD::DIN', 83039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ilaris', 'powder for solution', 'L04AC08', false, 0, '02344939', 'FreeDiams::CA_HCDPD::DIN', 83040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Proseries Green Disinfectant', 'liquid', 'V07AV', false, 0, '02344947', 'FreeDiams::CA_HCDPD::DIN', 83041);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Eco-Pro Disinfectant Ep 500', 'liquid', 'V07AV', false, 0, '02344955', 'FreeDiams::CA_HCDPD::DIN', 83042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sea Results Line Resolution Cream Spf 30', 'cream', 'D02BA30', false, 0, '02345056', 'FreeDiams::CA_HCDPD::DIN', 83050);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bactra-Clean Hand Sanitizer', 'spray', 'D08AJ01', false, 0, '02345064', 'FreeDiams::CA_HCDPD::DIN', 83051);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xylocaine Dental Lidocaine Hydrochloride 2% And Epinephrine 1:50,000', 'solution', 'N01BB52', false, 0, '02345072', 'FreeDiams::CA_HCDPD::DIN', 83052);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Irinotecan Hydrochloride Trihydrate For Injection', 'solution', 'L01XX19', false, 0, '02345080', 'FreeDiams::CA_HCDPD::DIN', 83053);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin All-In-One Cold And Flu Liquid Gels', 'capsule', 'N02BE51', false, 0, '02345110', 'FreeDiams::CA_HCDPD::DIN', 83056);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutrogena Men Sensitive Skin Oil-Free Moisture', 'cream', 'D02BA30', false, 0, '02345293', 'FreeDiams::CA_HCDPD::DIN', 83072);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pioglitazone', 'tablet', 'A10BG03', false, 0, '02345366', 'FreeDiams::CA_HCDPD::DIN', 83078);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pioglitazone', 'tablet', 'A10BG03', false, 0, '02345374', 'FreeDiams::CA_HCDPD::DIN', 83079);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pioglitazone', 'tablet', 'A10BG03', false, 0, '02345382', 'FreeDiams::CA_HCDPD::DIN', 83080);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teint Idole Fresh Wear', 'lotion', 'D02BA02', false, 0, '02345390', 'FreeDiams::CA_HCDPD::DIN', 83081);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Safeway Disinfecting Wipes', 'wipe', 'V07AV', false, 0, '02345404', 'FreeDiams::CA_HCDPD::DIN', 83084);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topiramate', 'tablet', 'N03AX11', false, 0, '02345412', 'FreeDiams::CA_HCDPD::DIN', 83085);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topiramate', 'tablet', 'N03AX11', false, 0, '02345439', 'FreeDiams::CA_HCDPD::DIN', 83087);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topiramate', 'tablet', 'N03AX11', false, 0, '02345447', 'FreeDiams::CA_HCDPD::DIN', 83088);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Revitalift Spf 30', 'lotion', 'D02BA30', false, 0, '02345560', 'FreeDiams::CA_HCDPD::DIN', 83098);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisture Oil-Free Spf 30', 'cream', 'D02BA30', false, 0, '02345595', 'FreeDiams::CA_HCDPD::DIN', 83101);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zym-Clonazepam', 'tablet', 'N03AE01', false, 0, '02345676', 'FreeDiams::CA_HCDPD::DIN', 83110);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ocean Potion Spray Gel Spf 8', 'gel', 'D02BA30', false, 0, '02345684', 'FreeDiams::CA_HCDPD::DIN', 83111);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ocean Potion Oil Spf 4', 'liquid', 'D02BA30', false, 0, '02345692', 'FreeDiams::CA_HCDPD::DIN', 83112);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rose Skin Care Anti-Aging Spf 30', 'cream', 'D02BA30', false, 0, '02345722', 'FreeDiams::CA_HCDPD::DIN', 83116);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Healthy Makeup Lip Conditioner / Revita-Lčvres Spf/Fps 15', 'stick', 'D02BA02', false, 0, '02345765', 'FreeDiams::CA_HCDPD::DIN', 83120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pramipexole', 'tablet', 'N04BC05', false, 0, '02367645', 'FreeDiams::CA_HCDPD::DIN', 85248);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Healthy Makeup Lipstick/Rouge Ŕ Lčvres Spf/Fps 15', 'stick', 'D02BA02', false, 0, '02345773', 'FreeDiams::CA_HCDPD::DIN', 83121);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cover Girl Natureluxe Gloss Balm', 'stick', 'D02BA02', false, 0, '02346036', 'FreeDiams::CA_HCDPD::DIN', 83146);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ondansetron', 'tablet', 'A04AA01', false, 0, '02346095', 'FreeDiams::CA_HCDPD::DIN', 83152);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturals Antibacterial Liquid Soap Vanilla', 'liquid', 'D08AE04', false, 0, '02346125', 'FreeDiams::CA_HCDPD::DIN', 83155);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ondansetron', 'tablet', 'A04AA01', false, 0, '02346168', 'FreeDiams::CA_HCDPD::DIN', 83158);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Seasonique', 'tablet', 'G03AA', false, 0, '02346176', 'FreeDiams::CA_HCDPD::DIN', 83160);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mr. Clean Disinfecting Bath Cleaner', 'liquid', 'V07AV', false, 0, '02346206', 'FreeDiams::CA_HCDPD::DIN', 83163);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Re9 Advanced For Men Facial Moisturizer With Spf 20', 'lotion', 'D02BA30', false, 0, '02346257', 'FreeDiams::CA_HCDPD::DIN', 83168);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atorvastatin', 'tablet', 'C10AA05', false, 0, '02346486', 'FreeDiams::CA_HCDPD::DIN', 83185);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Buckley''S Cough, Mucous & Phlegm', 'liquid', 'R05CA03', false, 0, '02346451', 'FreeDiams::CA_HCDPD::DIN', 83190);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atorvastatin', 'tablet', 'C10AA05', false, 0, '02346494', 'FreeDiams::CA_HCDPD::DIN', 83192);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atorvastatin', 'tablet', 'C10AA05', false, 0, '02346508', 'FreeDiams::CA_HCDPD::DIN', 83193);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atorvastatin', 'tablet', 'C10AA05', false, 0, '02346516', 'FreeDiams::CA_HCDPD::DIN', 83194);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Clarithromycin', 'tablet', 'J01FA09', false, 0, '02346524', 'FreeDiams::CA_HCDPD::DIN', 83195);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Clarithromycin', 'tablet', 'J01FA09', false, 0, '02346532', 'FreeDiams::CA_HCDPD::DIN', 83196);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Relaxa', 'powder for suspension', 'A06AD15', false, 0, '02346672', 'FreeDiams::CA_HCDPD::DIN', 83209);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Polyquat 5', 'liquid', 'V07AV', false, 0, '02346729', 'FreeDiams::CA_HCDPD::DIN', 83214);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desmopressin', 'tablet', 'H01BA02', false, 0, '02346788', 'FreeDiams::CA_HCDPD::DIN', 83219);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Desmopressin', 'tablet', 'H01BA02', false, 0, '02346796', 'FreeDiams::CA_HCDPD::DIN', 83220);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Agriflu', 'suspension', 'J07BB02', false, 0, '02346850', 'FreeDiams::CA_HCDPD::DIN', 83225);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Saniscrubz', 'wipe', 'D08AJ01', false, 0, '02346982', 'FreeDiams::CA_HCDPD::DIN', 83237);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baléa Men Facial Lotion', 'lotion', 'D02BA30', false, 0, '02347016', 'FreeDiams::CA_HCDPD::DIN', 83240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Niastase Rt', 'kit', 'B02BD08', false, 0, '02347113', 'FreeDiams::CA_HCDPD::DIN', 83251);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Niastase Rt', 'kit', 'B02BD08', false, 0, '02347121', 'FreeDiams::CA_HCDPD::DIN', 83252);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Niastase Rt', 'kit', 'B02BD08', false, 0, '02347148', 'FreeDiams::CA_HCDPD::DIN', 83253);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vyvanse', 'capsule', 'N06BA12', false, 0, '02347156', 'FreeDiams::CA_HCDPD::DIN', 83254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vyvanse', 'capsule', 'N06BA12', false, 0, '02347164', 'FreeDiams::CA_HCDPD::DIN', 83255);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vyvanse', 'capsule', 'N06BA12', false, 0, '02347172', 'FreeDiams::CA_HCDPD::DIN', 83256);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin For Children All-In-One Cold And Fever', 'tablet (chewable)', 'N02BE51', false, 0, '02347199', 'FreeDiams::CA_HCDPD::DIN', 83258);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Menveo', 'kit', 'J07AH08', false, 0, '02347393', 'FreeDiams::CA_HCDPD::DIN', 83276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Arbonne Abc Arbonne Baby Care Water-Resistant Sunscreen Spf 30', 'lotion', 'D02BA30', false, 0, '02347385', 'FreeDiams::CA_HCDPD::DIN', 83278);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risedronate', 'tablet', 'M05BA07', false, 0, '02347474', 'FreeDiams::CA_HCDPD::DIN', 83286);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Carvedilol', 'tablet', 'C07AG02', false, 0, '02347512', 'FreeDiams::CA_HCDPD::DIN', 83290);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Carvedilol', 'tablet', 'C07AG02', false, 0, '02347520', 'FreeDiams::CA_HCDPD::DIN', 83292);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Carvedilol', 'tablet', 'C07AG02', false, 0, '02347555', 'FreeDiams::CA_HCDPD::DIN', 83294);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Carvedilol', 'tablet', 'C07AG02', false, 0, '02347571', 'FreeDiams::CA_HCDPD::DIN', 83296);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benylin Extra Strength Cold, Mucus & Phlegm Relief', 'tablet', 'N02BE51', false, 0, '02347652', 'FreeDiams::CA_HCDPD::DIN', 83303);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Complete Cold, Cough & Flu', 'tablet', 'N02BE51', false, 0, '02347660', 'FreeDiams::CA_HCDPD::DIN', 83304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('4% Citanest Forte Dental With Epinephrine 1:200,000', 'liquid', 'N01BB54', false, 0, '02347695', 'FreeDiams::CA_HCDPD::DIN', 83307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Junior Strength Tylenol Fastmelts', 'tablet (chewable)', 'N02BE01', false, 0, '02347792', 'FreeDiams::CA_HCDPD::DIN', 83316);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Healthy Makeup Lip Cream/Crčme Pour Les Lčvres Spf/Fps 15', 'cream', 'D02BA02', false, 0, '02347806', 'FreeDiams::CA_HCDPD::DIN', 83317);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ropivacaine Hydrochloride Injection Usp', 'solution', 'N01BB09', false, 0, '02347822', 'FreeDiams::CA_HCDPD::DIN', 83319);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ropivacaine Hydrochloride Injection Usp', 'solution', 'N01BB09', false, 0, '02347830', 'FreeDiams::CA_HCDPD::DIN', 83320);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hand Sanitizing Moisturizer', 'lotion', 'D08AJ08', false, 0, '02347881', 'FreeDiams::CA_HCDPD::DIN', 83325);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Letrozole', 'tablet', 'L02BG04', false, 0, '02347997', 'FreeDiams::CA_HCDPD::DIN', 83335);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturals Pomegranate & Mango Anti-Bacterial Hand Soap', 'liquid', 'D08AE04', false, 0, '02348039', 'FreeDiams::CA_HCDPD::DIN', 83339);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturals Cucumber & Melon Anti-Bacterial Hand Soap', 'liquid', 'D08AE04', false, 0, '02348047', 'FreeDiams::CA_HCDPD::DIN', 83340);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naturals Lime Blossom & Verbena Anti-Bacterial Hand Soap', 'liquid', 'D08AE04', false, 0, '02348055', 'FreeDiams::CA_HCDPD::DIN', 83341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Cold & Sinus Daytime', 'tablet', 'N02BE51', false, 0, '02348071', 'FreeDiams::CA_HCDPD::DIN', 83343);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Cold & Sinus Nighttime', 'tablet', 'N02BE51', false, 0, '02348098', 'FreeDiams::CA_HCDPD::DIN', 83344);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lidocaine Hcl Injection Usp 1% (50mg/5ml)', 'solution', 'N01BB02', false, 0, '02348195', 'FreeDiams::CA_HCDPD::DIN', 83355);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxymaxx Cleaner Disinfectant/Oxymaxx Nettoyant Désinfectant', 'solution', 'V07AV', false, 0, '02348217', 'FreeDiams::CA_HCDPD::DIN', 83358);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxymaxx Av-Mixx Cleaner Disinfectant/Oxymaxx Av-Mixx Nettoyant Désinfectant', 'solution', 'V07AV', false, 0, '02348225', 'FreeDiams::CA_HCDPD::DIN', 83359);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bmr Désinfectant Concentré', 'solution', 'V07AV', false, 0, '02348446', 'FreeDiams::CA_HCDPD::DIN', 83379);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Verdeso', 'aerosol, foam', 'D07AB08', false, 0, '02348489', 'FreeDiams::CA_HCDPD::DIN', 83384);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Evicel', 'kit', 'B02BC30', false, 0, '02348497', 'FreeDiams::CA_HCDPD::DIN', 83385);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Finasteride', 'tablet', 'G04CB01', false, 0, '02348500', 'FreeDiams::CA_HCDPD::DIN', 83386);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Defense Sunscreen Lotion Lotion Écran Solaire Spf Fps 60', 'lotion', 'D02BA30', false, 0, '02348527', 'FreeDiams::CA_HCDPD::DIN', 83388);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sport Performance Sunscreen Lotion Lotion Écran Solaire Spf Fps 60', 'lotion', 'D02BA30', false, 0, '02348535', 'FreeDiams::CA_HCDPD::DIN', 83389);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('100 Spf Cream', 'cream', 'D02BA30', false, 0, '02348551', 'FreeDiams::CA_HCDPD::DIN', 83391);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sleep-Eze', 'tablet', 'R06AA02', false, 0, '02348608', 'FreeDiams::CA_HCDPD::DIN', 83395);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atorvastatin', 'tablet', 'C10AA05', false, 0, '02348624', 'FreeDiams::CA_HCDPD::DIN', 83397);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atorvastatin', 'tablet', 'C10AA05', false, 0, '02348632', 'FreeDiams::CA_HCDPD::DIN', 83398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atorvastatin', 'tablet', 'C10AA05', false, 0, '02348640', 'FreeDiams::CA_HCDPD::DIN', 83399);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atorvastatin', 'tablet', 'C10AA05', false, 0, '02348659', 'FreeDiams::CA_HCDPD::DIN', 83400);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hand Sanitizing Sheer Moisturizer', 'lotion', 'D08AJ08', false, 0, '02348667', 'FreeDiams::CA_HCDPD::DIN', 83401);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Super Fluid Uv Defense Spf 50', 'lotion', 'D02BA30', false, 0, '02348683', 'FreeDiams::CA_HCDPD::DIN', 83403);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Omeprazole', 'capsule (delayed release)', 'A02BC01', false, 0, '02348691', 'FreeDiams::CA_HCDPD::DIN', 83404);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atorvastatin', 'tablet', 'C10AA05', false, 0, '02348705', 'FreeDiams::CA_HCDPD::DIN', 83405);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atorvastatin', 'tablet', 'C10AA05', false, 0, '02348713', 'FreeDiams::CA_HCDPD::DIN', 83406);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atorvastatin', 'tablet', 'C10AA05', false, 0, '02348721', 'FreeDiams::CA_HCDPD::DIN', 83407);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atorvastatin', 'tablet', 'C10AA05', false, 0, '02348748', 'FreeDiams::CA_HCDPD::DIN', 83408);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intanza', 'suspension', 'J07BB02', false, 0, '02348756', 'FreeDiams::CA_HCDPD::DIN', 83409);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trazodone', 'tablet', 'N06AX05', false, 0, '02348772', 'FreeDiams::CA_HCDPD::DIN', 83411);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trazodone', 'tablet', 'N06AX05', false, 0, '02348780', 'FreeDiams::CA_HCDPD::DIN', 83412);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Trazodone', 'tablet', 'N06AX05', false, 0, '02348799', 'FreeDiams::CA_HCDPD::DIN', 83413);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Auro-Cyclobenzaprine', 'tablet', 'M03BX08', false, 0, '02348853', 'FreeDiams::CA_HCDPD::DIN', 83419);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anti-Aging Facial Moisturizer Spf/Fps 70', 'lotion', 'D02BA30', false, 0, '02348861', 'FreeDiams::CA_HCDPD::DIN', 83420);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Finasteride', 'tablet', 'G04CB01', false, 0, '02348888', 'FreeDiams::CA_HCDPD::DIN', 83421);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Letrozole', 'tablet', 'L02BG04', false, 0, '02348969', 'FreeDiams::CA_HCDPD::DIN', 83427);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Riva-Memantine', 'tablet', 'N06DX01', false, 0, '02348950', 'FreeDiams::CA_HCDPD::DIN', 83428);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Memantine', 'tablet', 'N06DX01', false, 0, '02349116', 'FreeDiams::CA_HCDPD::DIN', 83442);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Effient', 'tablet', 'B01AC22', false, 0, '02349124', 'FreeDiams::CA_HCDPD::DIN', 83444);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Nifedipine Extended Release', 'tablet (extended-release)', 'C08CA05', false, 0, '02349167', 'FreeDiams::CA_HCDPD::DIN', 83448);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alprazolam', 'tablet', 'N05BA12', false, 0, '02349191', 'FreeDiams::CA_HCDPD::DIN', 83451);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alprazolam', 'tablet', 'N05BA12', false, 0, '02349205', 'FreeDiams::CA_HCDPD::DIN', 83452);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clorox Commercial Solutions Clorox Professional Disinfecting Bleach Wipes', 'wipe', 'V07AV', false, 0, '02349272', 'FreeDiams::CA_HCDPD::DIN', 83458);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultram', 'tablet', 'N02AX02', false, 0, '02349469', 'FreeDiams::CA_HCDPD::DIN', 83476);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Smart-San Alcohol-Free Hand Sanitizer Foam', 'liquid', 'D08AJ01', false, 0, '02349655', 'FreeDiams::CA_HCDPD::DIN', 83493);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra-Lift Day Cream Spf 15', 'cream', 'D02BA30', false, 0, '02349663', 'FreeDiams::CA_HCDPD::DIN', 83494);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sterile Water For Injection Usp', 'liquid', 'V07AB', false, 0, '02349760', 'FreeDiams::CA_HCDPD::DIN', 83498);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Brand Essentials Disinfecting Wipes', 'wipe', 'V07AV', false, 0, '02349868', 'FreeDiams::CA_HCDPD::DIN', 83511);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Penquat Fd', 'liquid', 'V07AV', false, 0, '02350009', 'FreeDiams::CA_HCDPD::DIN', 83525);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actemra', 'solution', 'L04AC07', false, 0, '02350092', 'FreeDiams::CA_HCDPD::DIN', 83533);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actemra', 'solution', 'L04AC07', false, 0, '02350106', 'FreeDiams::CA_HCDPD::DIN', 83534);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actemra', 'solution', 'L04AC07', false, 0, '02350114', 'FreeDiams::CA_HCDPD::DIN', 83535);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Saizen', 'solution', 'H01AC01', false, 0, '02350122', 'FreeDiams::CA_HCDPD::DIN', 83536);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Saizen', 'solution', 'H01AC01', false, 0, '02350130', 'FreeDiams::CA_HCDPD::DIN', 83537);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Saizen', 'solution', 'H01AC01', false, 0, '02350149', 'FreeDiams::CA_HCDPD::DIN', 83538);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxybutynin', 'tablet', 'G04BD04', false, 0, '02350238', 'FreeDiams::CA_HCDPD::DIN', 83545);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Finasteride', 'tablet', 'G04CB01', false, 0, '02350270', 'FreeDiams::CA_HCDPD::DIN', 83549);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02350297', 'FreeDiams::CA_HCDPD::DIN', 83551);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02350319', 'FreeDiams::CA_HCDPD::DIN', 83553);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02350327', 'FreeDiams::CA_HCDPD::DIN', 83554);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ratio-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02350335', 'FreeDiams::CA_HCDPD::DIN', 83555);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sodium Chloride Injection Usp 0.9%', 'solution', 'B05XA03', false, 0, '02350351', 'FreeDiams::CA_HCDPD::DIN', 83557);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rub A 535 No Odour Antiphlogistine Ultra Strength', 'cream', 'M02AC', false, 0, '02350386', 'FreeDiams::CA_HCDPD::DIN', 83559);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoprolol', 'tablet', 'C07AB02', false, 0, '02350394', 'FreeDiams::CA_HCDPD::DIN', 83560);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoprolol', 'tablet', 'C07AB02', false, 0, '02350408', 'FreeDiams::CA_HCDPD::DIN', 83561);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Spf 30', 'lotion', 'D02BA30', false, 0, '02350432', 'FreeDiams::CA_HCDPD::DIN', 83564);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Domperidone', 'tablet', 'A03FA03', false, 0, '02350440', 'FreeDiams::CA_HCDPD::DIN', 83565);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glyburide', 'tablet', 'A10BB01', false, 0, '02350459', 'FreeDiams::CA_HCDPD::DIN', 83566);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glyburide', 'tablet', 'A10BB01', false, 0, '02350467', 'FreeDiams::CA_HCDPD::DIN', 83567);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Terazosin', 'tablet', 'G04CA03', false, 0, '02350475', 'FreeDiams::CA_HCDPD::DIN', 83568);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Terazosin', 'tablet', 'G04CA03', false, 0, '02350483', 'FreeDiams::CA_HCDPD::DIN', 83569);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Terazosin', 'tablet', 'G04CA03', false, 0, '02350491', 'FreeDiams::CA_HCDPD::DIN', 83570);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Terazosin', 'tablet', 'G04CA03', false, 0, '02350505', 'FreeDiams::CA_HCDPD::DIN', 83571);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kuvan', 'tablet', 'A16AX07', false, 0, '02350580', 'FreeDiams::CA_HCDPD::DIN', 83577);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moldex', 'spray', 'V07AV', false, 0, '02350572', 'FreeDiams::CA_HCDPD::DIN', 83578);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advance Techniques Keep Clear 2-In-1 Anti-Dandruff Shampoo', 'lotion', 'D11AX12', false, 0, '02350599', 'FreeDiams::CA_HCDPD::DIN', 83579);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Balm Spf 30', 'stick', 'D02BA30', false, 0, '02350602', 'FreeDiams::CA_HCDPD::DIN', 83580);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisturizing Face Shield', 'stick', 'D02BA30', false, 0, '02350610', 'FreeDiams::CA_HCDPD::DIN', 83581);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fructis Anti-Dandruff Shampoo Clean & Fresh', 'shampoo', 'D11AX12', false, 0, '02350831', 'FreeDiams::CA_HCDPD::DIN', 83582);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Life Combat Anti-Dandruff', 'shampoo', 'D11AX12', false, 0, '02350637', 'FreeDiams::CA_HCDPD::DIN', 83584);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advance Techniques Keep Clear Anti-Dandruff Treatment', 'lotion', 'D11AX12', false, 0, '02350645', 'FreeDiams::CA_HCDPD::DIN', 83585);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Onsolis', 'film, soluble', 'N02AB03', false, 0, '02350661', 'FreeDiams::CA_HCDPD::DIN', 83587);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Onsolis', 'film, soluble', 'N02AB03', false, 0, '02350688', 'FreeDiams::CA_HCDPD::DIN', 83588);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Onsolis', 'film, soluble', 'N02AB03', false, 0, '02350696', 'FreeDiams::CA_HCDPD::DIN', 83589);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Onsolis', 'film, soluble', 'N02AB03', false, 0, '02350718', 'FreeDiams::CA_HCDPD::DIN', 83590);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Onsolis', 'film, soluble', 'N02AB03', false, 0, '02350726', 'FreeDiams::CA_HCDPD::DIN', 83591);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naproxen', 'tablet', 'M01AE02', false, 0, '02350750', 'FreeDiams::CA_HCDPD::DIN', 83596);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naproxen', 'tablet', 'M01AE02', false, 0, '02350769', 'FreeDiams::CA_HCDPD::DIN', 83597);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naproxen', 'tablet', 'M01AE02', false, 0, '02350777', 'FreeDiams::CA_HCDPD::DIN', 83598);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naproxen Ec', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02350785', 'FreeDiams::CA_HCDPD::DIN', 83599);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naproxen Ec', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02350793', 'FreeDiams::CA_HCDPD::DIN', 83600);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naproxen Ec', 'tablet (enteric-coated)', 'M01AE02', false, 0, '02350807', 'FreeDiams::CA_HCDPD::DIN', 83601);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sr', 'tablet (extended-release)', 'N02AA01', false, 0, '02350815', 'FreeDiams::CA_HCDPD::DIN', 83602);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fructis Anti-Dandruff Shampoo Dry Scalp', 'shampoo', 'D11AX12', false, 0, '02350858', 'FreeDiams::CA_HCDPD::DIN', 83604);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fructis Anti-Dandruff Shampoo Intense Cleanse', 'shampoo', 'D11AX12', false, 0, '02350866', 'FreeDiams::CA_HCDPD::DIN', 83605);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fructis Anti-Dandruff Shampoo Clean & Fresh 2 In 1', 'shampoo', 'D11AX12', false, 0, '02350874', 'FreeDiams::CA_HCDPD::DIN', 83606);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sr', 'tablet (extended-release)', 'N02AA01', false, 0, '02350890', 'FreeDiams::CA_HCDPD::DIN', 83608);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sr', 'tablet (extended-release)', 'N02AA01', false, 0, '02350912', 'FreeDiams::CA_HCDPD::DIN', 83610);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valsartan', 'tablet', 'C09CA03', false, 0, '02367726', 'FreeDiams::CA_HCDPD::DIN', 85256);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sr', 'tablet (extended-release)', 'N02AA01', false, 0, '02350920', 'FreeDiams::CA_HCDPD::DIN', 83611);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Latisse', 'solution', 'S01EE03', false, 0, '02350939', 'FreeDiams::CA_HCDPD::DIN', 83612);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Morphine Sr', 'tablet (extended-release)', 'N02AA01', false, 0, '02350947', 'FreeDiams::CA_HCDPD::DIN', 83613);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cilazapril', 'tablet', 'C09AA08', false, 0, '02350963', 'FreeDiams::CA_HCDPD::DIN', 83615);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cilazapril', 'tablet', 'C09AA08', false, 0, '02350971', 'FreeDiams::CA_HCDPD::DIN', 83616);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cilazapril', 'tablet', 'C09AA08', false, 0, '02350998', 'FreeDiams::CA_HCDPD::DIN', 83617);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Clarithromycin', 'tablet', 'J01FA09', false, 0, '02351005', 'FreeDiams::CA_HCDPD::DIN', 83618);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naproxen Sodium', 'tablet', 'M01AE02', false, 0, '02351013', 'FreeDiams::CA_HCDPD::DIN', 83619);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naproxen Sodium Ds', 'tablet', 'M01AE02', false, 0, '02351021', 'FreeDiams::CA_HCDPD::DIN', 83620);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Western Family Disinfecting Wipes', 'wipe', 'V07AV', false, 0, '02351048', 'FreeDiams::CA_HCDPD::DIN', 83623);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Victoza', 'solution', 'A10BX07', false, 0, '02351064', 'FreeDiams::CA_HCDPD::DIN', 83627);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lorazepam', 'tablet', 'N05BA06', false, 0, '02351072', 'FreeDiams::CA_HCDPD::DIN', 83628);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lorazepam', 'tablet', 'N05BA06', false, 0, '02351080', 'FreeDiams::CA_HCDPD::DIN', 83629);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lorazepam', 'tablet', 'N05BA06', false, 0, '02351099', 'FreeDiams::CA_HCDPD::DIN', 83630);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Famotidine Tablets', 'tablet', 'A02BA03', false, 0, '02351102', 'FreeDiams::CA_HCDPD::DIN', 83631);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Famotidine Tablets', 'tablet', 'A02BA03', false, 0, '02351110', 'FreeDiams::CA_HCDPD::DIN', 83632);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Community Soft Touch', 'cream', 'D08AJ01', false, 0, '02351129', 'FreeDiams::CA_HCDPD::DIN', 83633);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doxycycline Capsules', 'capsule', 'J01AA02', false, 0, '02351234', 'FreeDiams::CA_HCDPD::DIN', 83642);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Doxycycline Tablets', 'tablet', 'J01AA02', false, 0, '02351242', 'FreeDiams::CA_HCDPD::DIN', 83643);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atenolol', 'tablet', 'C07AB03', false, 0, '02351331', 'FreeDiams::CA_HCDPD::DIN', 83656);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atenolol', 'tablet', 'C07AB03', false, 0, '02351358', 'FreeDiams::CA_HCDPD::DIN', 83657);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Atenolol', 'tablet', 'C07AB03', false, 0, '02351366', 'FreeDiams::CA_HCDPD::DIN', 83658);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoprolol Sr', 'tablet (extended-release)', 'C07AB02', false, 0, '02351404', 'FreeDiams::CA_HCDPD::DIN', 83667);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metoprolol Sr', 'tablet (extended-release)', 'C07AB02', false, 0, '02351412', 'FreeDiams::CA_HCDPD::DIN', 83668);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Furosemide', 'tablet', 'C03CA01', false, 0, '02351420', 'FreeDiams::CA_HCDPD::DIN', 83669);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Furosemide', 'tablet', 'C03CA01', false, 0, '02351439', 'FreeDiams::CA_HCDPD::DIN', 83670);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Furosemide', 'tablet', 'C03CA01', false, 0, '02351447', 'FreeDiams::CA_HCDPD::DIN', 83671);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Origins Vitazing Spf 15 Energy-Boosting Moisturizer', 'cream', 'D02BA30', false, 0, '02351455', 'FreeDiams::CA_HCDPD::DIN', 83672);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('5-Asa', 'tablet (enteric-coated)', 'A07EC02', false, 0, '02351463', 'FreeDiams::CA_HCDPD::DIN', 83673);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('President''S Choice Ultra Bleach Disinfectant', 'liquid', 'V07AV', false, 0, '02351471', 'FreeDiams::CA_HCDPD::DIN', 83676);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitamin C Daily Moisture Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02351498', 'FreeDiams::CA_HCDPD::DIN', 83677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Yondelis', 'powder for solution', 'L01CX01', false, 0, '02351528', 'FreeDiams::CA_HCDPD::DIN', 83679);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('No Name Disinfectant Wipes', 'wipe', 'V07AV', false, 0, '02351552', 'FreeDiams::CA_HCDPD::DIN', 83682);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Valacyclovir', 'tablet', 'J05AB11', false, 0, '02351579', 'FreeDiams::CA_HCDPD::DIN', 83683);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Valacyclovir', 'tablet', 'J05AB11', false, 0, '02351560', 'FreeDiams::CA_HCDPD::DIN', 83684);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Leflunomide', 'tablet', 'L04AA13', false, 0, '02351668', 'FreeDiams::CA_HCDPD::DIN', 83692);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Leflunomide', 'tablet', 'L04AA13', false, 0, '02351676', 'FreeDiams::CA_HCDPD::DIN', 83693);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diclofenac K', 'tablet', 'M01AB05', false, 0, '02351684', 'FreeDiams::CA_HCDPD::DIN', 83694);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Imipenem-Cilastatin', 'powder for solution', 'J01DH51', false, 0, '02351692', 'FreeDiams::CA_HCDPD::DIN', 83695);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Imipenem-Cilastatin', 'powder for solution', 'J01DH51', false, 0, '02351706', 'FreeDiams::CA_HCDPD::DIN', 83696);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Bacitracine', 'ointment', 'D06AX05', false, 0, '02351714', 'FreeDiams::CA_HCDPD::DIN', 83697);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fludarabine Phosphate Injection, Ppc Std.', 'solution', 'L01BB05', false, 0, '02351722', 'FreeDiams::CA_HCDPD::DIN', 83698);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moderate Protection Emulsion', 'emulsion', 'D02BA30', false, 0, '02351803', 'FreeDiams::CA_HCDPD::DIN', 83705);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('High Protection Emulsion', 'emulsion', 'D02BA30', false, 0, '02351811', 'FreeDiams::CA_HCDPD::DIN', 83706);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('High Protection Lotion', 'lotion', 'D02BA30', false, 0, '02351862', 'FreeDiams::CA_HCDPD::DIN', 83710);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sani Hands Foam - Af', 'liquid', 'D08AJ01', false, 0, '02351935', 'FreeDiams::CA_HCDPD::DIN', 83718);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Adacel-Polio', 'suspension', 'J07CA02', false, 0, '02352044', 'FreeDiams::CA_HCDPD::DIN', 83726);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ideal Shade Custom Shade Foundation Lotion', 'lotion', 'D02BA30', false, 0, '02352060', 'FreeDiams::CA_HCDPD::DIN', 83728);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('First Aid Antibiotic Ointment', 'ointment', 'D06AX05', false, 0, '02352079', 'FreeDiams::CA_HCDPD::DIN', 83729);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Selection Dandruff Shampoo-Classic', 'shampoo', 'D11AX12', false, 0, '02352095', 'FreeDiams::CA_HCDPD::DIN', 83733);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Selection Dandruff Shampoo 2 In 1', 'shampoo', 'D11AX12', false, 0, '02352109', 'FreeDiams::CA_HCDPD::DIN', 83734);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Selection Dandruff Shampoo Dry Hair', 'shampoo', 'D11AX12', false, 0, '02352117', 'FreeDiams::CA_HCDPD::DIN', 83735);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clinique Moisture Surge Tinted Moisturizer Spf 15', 'cream', 'D02BA30', false, 0, '02352125', 'FreeDiams::CA_HCDPD::DIN', 83737);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fluconazole 150', 'capsule', 'J02AC01', false, 0, '02352133', 'FreeDiams::CA_HCDPD::DIN', 83738);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risedronate', 'tablet', 'M05BA07', false, 0, '02352141', 'FreeDiams::CA_HCDPD::DIN', 83739);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spor-Klenz Ready To Use Cold Sterilant', 'liquid', 'V07AV', false, 0, '02352206', 'FreeDiams::CA_HCDPD::DIN', 83744);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pantoprazole For Injection', 'powder for solution', 'A02BC02', false, 0, '02352214', 'FreeDiams::CA_HCDPD::DIN', 83745);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Enalapril', 'tablet', 'C09AA02', false, 0, '02352230', 'FreeDiams::CA_HCDPD::DIN', 83747);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Enalapril', 'tablet', 'C09AA02', false, 0, '02352249', 'FreeDiams::CA_HCDPD::DIN', 83748);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Enalapril', 'tablet', 'C09AA02', false, 0, '02352257', 'FreeDiams::CA_HCDPD::DIN', 83749);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Enalapril', 'tablet', 'C09AA02', false, 0, '02352265', 'FreeDiams::CA_HCDPD::DIN', 83750);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cold + Sinus', 'tablet', 'M01AE51', false, 0, '02352281', 'FreeDiams::CA_HCDPD::DIN', 83757);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Votrient', 'tablet', 'L01XE11', false, 0, '02352303', 'FreeDiams::CA_HCDPD::DIN', 83758);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Ropinirole', 'tablet', 'N04BC04', false, 0, '02352338', 'FreeDiams::CA_HCDPD::DIN', 83760);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Ropinirole', 'tablet', 'N04BC04', false, 0, '02352346', 'FreeDiams::CA_HCDPD::DIN', 83761);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Ropinirole', 'tablet', 'N04BC04', false, 0, '02352354', 'FreeDiams::CA_HCDPD::DIN', 83762);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Ropinirole', 'tablet', 'N04BC04', false, 0, '02352362', 'FreeDiams::CA_HCDPD::DIN', 83763);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diclofenac Ec', 'tablet (enteric-coated)', 'M01AB05', false, 0, '02352397', 'FreeDiams::CA_HCDPD::DIN', 83766);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diclofenac Sr', 'tablet (extended-release)', 'M01AB05', false, 0, '02352400', 'FreeDiams::CA_HCDPD::DIN', 83767);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Tamsulosin', 'capsule (sustained-release)', 'G04CA02', false, 0, '02352419', 'FreeDiams::CA_HCDPD::DIN', 83768);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asatab Ec 325mg', 'tablet (delayed-release)', 'N02BA01', false, 0, '02352427', 'FreeDiams::CA_HCDPD::DIN', 83769);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Asatab Ec 650mg', 'tablet (delayed-release)', 'N02BA01', false, 0, '02352435', 'FreeDiams::CA_HCDPD::DIN', 83770);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Sheer Touch Toucher Soyeux Oil-Free Sunscreen Écran Solaire Sans Huile 30 Spf/Fps', 'lotion', 'D02BA30', false, 0, '02352451', 'FreeDiams::CA_HCDPD::DIN', 83772);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Sheer Touch Toucher Soyeux Oil-Free Sunscreen Écran Solaire Sans Huile 60 Spf/Fps', 'lotion', 'D02BA30', false, 0, '02352478', 'FreeDiams::CA_HCDPD::DIN', 83773);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Periolimel 2.5% E', 'emulsion', 'B05BA10', false, 0, '02352494', 'FreeDiams::CA_HCDPD::DIN', 83774);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Sheer Touch Toucher Soyeux Oil-Free Sunscreen Écran Solaire Sans Huile 45 Spf/Fps', 'lotion', 'D02BA30', false, 0, '02352486', 'FreeDiams::CA_HCDPD::DIN', 83775);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olimel 4.4% E', 'emulsion', 'B05BA10', false, 0, '02352516', 'FreeDiams::CA_HCDPD::DIN', 83777);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olimel 5.7% E', 'emulsion', 'B05BA10', false, 0, '02352532', 'FreeDiams::CA_HCDPD::DIN', 83779);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olimel 5.7%', 'emulsion', 'B05BA10', false, 0, '02352540', 'FreeDiams::CA_HCDPD::DIN', 83780);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Berinert', 'powder for solution', 'B02AB03', false, 0, '02352575', 'FreeDiams::CA_HCDPD::DIN', 83783);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Daywear Sheer Tint Release Advanced Multi-Protection Moisturizer Spf 15', 'cream', 'D02BA30', false, 0, '02352591', 'FreeDiams::CA_HCDPD::DIN', 83785);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Daywear Advanced Multi-Protection Creme Spf 15 For Normal/Combination Skin', 'cream', 'D02BA30', false, 0, '02352605', 'FreeDiams::CA_HCDPD::DIN', 83786);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Daywear Advanced Multi-Protection Creme Spf 15 For Dry Skin', 'cream', 'D02BA30', false, 0, '02352613', 'FreeDiams::CA_HCDPD::DIN', 83787);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Flumist', 'spray', 'J07BB03', false, 0, '02352621', 'FreeDiams::CA_HCDPD::DIN', 83789);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fragmin 7500iu(Anti-Xa)/0.3ml', 'solution', 'B01AB04', false, 0, '02352648', 'FreeDiams::CA_HCDPD::DIN', 83790);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fragmin 10000iu(Anti-Xa)/0.4ml', 'solution', 'B01AB04', false, 0, '02352656', 'FreeDiams::CA_HCDPD::DIN', 83791);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fragmin 12500iu(Anti-Xa)/0.5ml', 'solution', 'B01AB04', false, 0, '02352664', 'FreeDiams::CA_HCDPD::DIN', 83792);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fragmin 15000iu(Anti-Xa)/0.6ml', 'solution', 'B01AB04', false, 0, '02352672', 'FreeDiams::CA_HCDPD::DIN', 83793);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fragmin 18000iu(Anti-Xa)/0.72ml', 'solution', 'B01AB04', false, 0, '02352680', 'FreeDiams::CA_HCDPD::DIN', 83794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Baby Life Brand Extra Strength Diaper Rash Ointment', 'ointment', 'D02AB', false, 0, '02352702', 'FreeDiams::CA_HCDPD::DIN', 83796);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amoxicillin', 'capsule', 'J01CA04', false, 0, '02352710', 'FreeDiams::CA_HCDPD::DIN', 83797);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amoxicillin', 'capsule', 'J01CA04', false, 0, '02352729', 'FreeDiams::CA_HCDPD::DIN', 83798);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amoxicillin', 'tablet (chewable)', 'J01CA04', false, 0, '02352737', 'FreeDiams::CA_HCDPD::DIN', 83799);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amoxicillin', 'granules for suspension', 'J01CA04', false, 0, '02352745', 'FreeDiams::CA_HCDPD::DIN', 83800);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amoxicillin', 'granules for suspension', 'J01CA04', false, 0, '02352753', 'FreeDiams::CA_HCDPD::DIN', 83801);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amoxicillin', 'granules for suspension', 'J01CA04', false, 0, '02352761', 'FreeDiams::CA_HCDPD::DIN', 83802);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amoxicillin', 'granules for suspension', 'J01CA04', false, 0, '02352788', 'FreeDiams::CA_HCDPD::DIN', 83803);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Enalapril Maleate/Hctz', 'tablet', 'C09BA02', false, 0, '02352923', 'FreeDiams::CA_HCDPD::DIN', 83816);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Enalapril Maleate/Hctz', 'tablet', 'C09BA02', false, 0, '02352931', 'FreeDiams::CA_HCDPD::DIN', 83817);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alendronate', 'tablet', 'M05BA04', false, 0, '02352966', 'FreeDiams::CA_HCDPD::DIN', 83819);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ranitidine', 'tablet', 'A02BA02', false, 0, '02353016', 'FreeDiams::CA_HCDPD::DIN', 83824);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ranitidine', 'tablet', 'A02BA02', false, 0, '02353024', 'FreeDiams::CA_HCDPD::DIN', 83825);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ropinirole', 'tablet', 'N04BC04', false, 0, '02353040', 'FreeDiams::CA_HCDPD::DIN', 83827);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ropinirole', 'tablet', 'N04BC04', false, 0, '02353059', 'FreeDiams::CA_HCDPD::DIN', 83828);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ropinirole', 'tablet', 'N04BC04', false, 0, '02353067', 'FreeDiams::CA_HCDPD::DIN', 83829);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ropinirole', 'tablet', 'N04BC04', false, 0, '02353075', 'FreeDiams::CA_HCDPD::DIN', 83830);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Terbinafine', 'tablet', 'D01BA02', false, 0, '02353121', 'FreeDiams::CA_HCDPD::DIN', 83835);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Meloxicam', 'tablet', 'M01AC06', false, 0, '02353148', 'FreeDiams::CA_HCDPD::DIN', 83836);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Meloxicam', 'tablet', 'M01AC06', false, 0, '02353156', 'FreeDiams::CA_HCDPD::DIN', 83837);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quetiapine', 'tablet', 'N05AH04', false, 0, '02353164', 'FreeDiams::CA_HCDPD::DIN', 83838);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quetiapine', 'tablet', 'N05AH04', false, 0, '02353172', 'FreeDiams::CA_HCDPD::DIN', 83839);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quetiapine', 'tablet', 'N05AH04', false, 0, '02353199', 'FreeDiams::CA_HCDPD::DIN', 83841);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quetiapine', 'tablet', 'N05AH04', false, 0, '02353202', 'FreeDiams::CA_HCDPD::DIN', 83842);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Etidrocal', 'tablet', 'M05BB01', false, 0, '02353210', 'FreeDiams::CA_HCDPD::DIN', 83843);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lovastatin', 'tablet', 'C10AA02', false, 0, '02353229', 'FreeDiams::CA_HCDPD::DIN', 83844);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lovastatin', 'tablet', 'C10AA02', false, 0, '02353237', 'FreeDiams::CA_HCDPD::DIN', 83845);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gabapentin', 'capsule', 'N03AX12', false, 0, '02353245', 'FreeDiams::CA_HCDPD::DIN', 83846);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gabapentin', 'capsule', 'N03AX12', false, 0, '02353253', 'FreeDiams::CA_HCDPD::DIN', 83847);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gabapentin', 'capsule', 'N03AX12', false, 0, '02353261', 'FreeDiams::CA_HCDPD::DIN', 83848);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02353318', 'FreeDiams::CA_HCDPD::DIN', 83851);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02353326', 'FreeDiams::CA_HCDPD::DIN', 83852);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ciprofloxacin', 'tablet', 'J01MA02', false, 0, '02353334', 'FreeDiams::CA_HCDPD::DIN', 83853);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levetiracetam', 'tablet', 'N03AX14', false, 0, '02353342', 'FreeDiams::CA_HCDPD::DIN', 83854);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levetiracetam', 'tablet', 'N03AX14', false, 0, '02353350', 'FreeDiams::CA_HCDPD::DIN', 83855);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Levetiracetam', 'tablet', 'N03AX14', false, 0, '02353369', 'FreeDiams::CA_HCDPD::DIN', 83856);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metformin', 'tablet', 'A10BA02', false, 0, '02353377', 'FreeDiams::CA_HCDPD::DIN', 83857);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Metformin', 'tablet', 'A10BA02', false, 0, '02353385', 'FreeDiams::CA_HCDPD::DIN', 83858);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultimate Sport Sunscreen Spray Spf 30', 'aerosol', 'D02BA30', false, 0, '02353393', 'FreeDiams::CA_HCDPD::DIN', 83859);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Age Shield + Moisturizing Repair Sunscreen', 'cream', 'D02BA30', false, 0, '02353431', 'FreeDiams::CA_HCDPD::DIN', 83866);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Lotion Spf/Fps 70', 'lotion', 'D02BA30', false, 0, '02353474', 'FreeDiams::CA_HCDPD::DIN', 83869);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sertraline', 'capsule', 'N06AB06', false, 0, '02353520', 'FreeDiams::CA_HCDPD::DIN', 83874);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sertraline', 'capsule', 'N06AB06', false, 0, '02353539', 'FreeDiams::CA_HCDPD::DIN', 83875);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sertraline', 'capsule', 'N06AB06', false, 0, '02353547', 'FreeDiams::CA_HCDPD::DIN', 83876);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Origins Brighter By Nature Spf 30 Skin Tone Correcting Makeup', 'powder', 'D02BA30', false, 0, '02353555', 'FreeDiams::CA_HCDPD::DIN', 83877);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Mucous Relief Cough', 'tablet', 'R05FA02', false, 0, '02353563', 'FreeDiams::CA_HCDPD::DIN', 83878);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Mucous Relief Chest', 'tablet', 'R05CA03', false, 0, '02353571', 'FreeDiams::CA_HCDPD::DIN', 83879);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Regular Strength Mucous Relief Chest', 'tablet', 'R05CA03', false, 0, '02353598', 'FreeDiams::CA_HCDPD::DIN', 83880);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Sunscreen Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02353601', 'FreeDiams::CA_HCDPD::DIN', 83881);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citalopram', 'tablet', 'N06AB04', false, 0, '02353660', 'FreeDiams::CA_HCDPD::DIN', 83886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citalopram', 'tablet', 'N06AB04', false, 0, '02353679', 'FreeDiams::CA_HCDPD::DIN', 83887);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Risedronate', 'tablet', 'M05BA07', false, 0, '02353687', 'FreeDiams::CA_HCDPD::DIN', 83888);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisture Rescue Lightweight Spf 15-Lotion', 'lotion', 'D02BA30', false, 0, '02353784', 'FreeDiams::CA_HCDPD::DIN', 83899);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bobbi Brown Illuminating Finish Powder Compact Foundation Spf 12', 'powder', 'D02BA30', false, 0, '02353792', 'FreeDiams::CA_HCDPD::DIN', 83900);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Daywear Advanced Multi-Protection Lotion Spf 15 For Oily Skin', 'lotion', 'D02BA30', false, 0, '02353814', 'FreeDiams::CA_HCDPD::DIN', 83902);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Five Star Lip Protection', 'stick', 'D02BA30', false, 0, '02353822', 'FreeDiams::CA_HCDPD::DIN', 83903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Lansoprazole', 'capsule (delayed release)', 'A02BC03', false, 0, '02353830', 'FreeDiams::CA_HCDPD::DIN', 83904);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Lansoprazole', 'capsule (delayed release)', 'A02BC03', false, 0, '02353849', 'FreeDiams::CA_HCDPD::DIN', 83905);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Simple Essentials Protect', 'stick', 'D02BA30', false, 0, '02353857', 'FreeDiams::CA_HCDPD::DIN', 83906);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anew Platinum Day Cream', 'cream', 'D02BA30', false, 0, '02353873', 'FreeDiams::CA_HCDPD::DIN', 83908);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Feiba Nf', 'kit', 'B02BD03', false, 0, '02353903', 'FreeDiams::CA_HCDPD::DIN', 83912);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Climatik Spf 30 Fps Protective Cream Crčme Protectrice', 'cream', 'D02BA30', false, 0, '02353946', 'FreeDiams::CA_HCDPD::DIN', 83915);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Climatik Spf 30 Fps Protective Lotion Lotion Protectrice', 'lotion', 'D02BA30', false, 0, '02353954', 'FreeDiams::CA_HCDPD::DIN', 83916);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Urocit-K', 'tablet (extended-release)', 'A12BA02', false, 0, '02353997', 'FreeDiams::CA_HCDPD::DIN', 83921);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Metoprolol (Type L)', 'tablet', 'C07AB02', false, 0, '02354187', 'FreeDiams::CA_HCDPD::DIN', 83938);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Metoprolol (Type L)', 'tablet', 'C07AB02', false, 0, '02354195', 'FreeDiams::CA_HCDPD::DIN', 83939);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Invega Sustenna', 'suspension (extended-release)', 'N05AX13', false, 0, '02354217', 'FreeDiams::CA_HCDPD::DIN', 83941);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Invega Sustenna', 'suspension (extended-release)', 'N05AX13', false, 0, '02354225', 'FreeDiams::CA_HCDPD::DIN', 83942);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Invega Sustenna', 'suspension (extended-release)', 'N05AX13', false, 0, '02354233', 'FreeDiams::CA_HCDPD::DIN', 83943);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Invega Sustenna', 'suspension (extended-release)', 'N05AX13', false, 0, '02354241', 'FreeDiams::CA_HCDPD::DIN', 83944);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hospiseptic', 'aerosol', 'V07AV', false, 0, '02354268', 'FreeDiams::CA_HCDPD::DIN', 83945);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Disinfectafoam', 'aerosol', 'V07AV', false, 0, '02354276', 'FreeDiams::CA_HCDPD::DIN', 83946);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Car Interior Disinfectant/Sanitizer', 'liquid', 'V07AV', false, 0, '02354314', 'FreeDiams::CA_HCDPD::DIN', 83950);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('3m Surface Disinfectant Cleaner', 'solution', 'V07AV', false, 0, '02354373', 'FreeDiams::CA_HCDPD::DIN', 83956);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('3m Surface Disinfectant Cleaner Wipes', 'wipe', 'V07AV', false, 0, '02354381', 'FreeDiams::CA_HCDPD::DIN', 83957);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Selection Antibacterial All Purpose Cleaner', 'liquid', 'V07AV', false, 0, '02354454', 'FreeDiams::CA_HCDPD::DIN', 83962);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Finasteride', 'tablet', 'G04CB01', false, 0, '02354462', 'FreeDiams::CA_HCDPD::DIN', 83963);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ceramide Plump Perfect Ultra Lift And Firm Eye Cream Spf 15', 'cream', 'D02BA30', false, 0, '02354470', 'FreeDiams::CA_HCDPD::DIN', 83964);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Artificial Tears', 'solution', 'S01XA20', false, 0, '02354535', 'FreeDiams::CA_HCDPD::DIN', 83970);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Renvela', 'tablet', 'V03AE02', false, 0, '02354586', 'FreeDiams::CA_HCDPD::DIN', 83974);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sanidate 5.0 Sanitizer/Disinfectant', 'solution', 'V07AV', false, 0, '02354594', 'FreeDiams::CA_HCDPD::DIN', 83975);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Waterbabies Sunscreen Mousse Spf 60', 'aerosol', 'D02BA30', false, 0, '02354667', 'FreeDiams::CA_HCDPD::DIN', 83983);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Coppertone Oil Free Sunscreen Mousse Spf 60', 'aerosol', 'D02BA30', false, 0, '02354675', 'FreeDiams::CA_HCDPD::DIN', 83984);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02354713', 'FreeDiams::CA_HCDPD::DIN', 83988);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02354721', 'FreeDiams::CA_HCDPD::DIN', 83989);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Venlafaxine Xr', 'capsule (extended release)', 'N06AX16', false, 0, '02354748', 'FreeDiams::CA_HCDPD::DIN', 83990);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zuacta', 'cream', 'M02AB02', false, 0, '02354772', 'FreeDiams::CA_HCDPD::DIN', 83993);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fragrance Foam', 'solution', 'D08AJ01', false, 0, '02354780', 'FreeDiams::CA_HCDPD::DIN', 83994);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Children''S Europrofen', 'suspension', 'M01AE01', false, 0, '02354799', 'FreeDiams::CA_HCDPD::DIN', 83995);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zmax Sr', 'granules for suspension,extended release', 'J01FA10', false, 0, '02354802', 'FreeDiams::CA_HCDPD::DIN', 83998);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Wet Skin Kids', 'spray', 'D02BA30', false, 0, '02354853', 'FreeDiams::CA_HCDPD::DIN', 84003);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Wet Skin Spf 30', 'spray', 'D02BA30', false, 0, '02354861', 'FreeDiams::CA_HCDPD::DIN', 84004);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Wet Skin Spf 60', 'spray', 'D02BA30', false, 0, '02354896', 'FreeDiams::CA_HCDPD::DIN', 84006);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Foot Works Therapeutic Cracked Heel Relief Cream', 'cream', 'D04AB01', false, 0, '02354918', 'FreeDiams::CA_HCDPD::DIN', 84010);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Repaglinide', 'tablet', 'A10BX02', false, 0, '02354926', 'FreeDiams::CA_HCDPD::DIN', 84011);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Repaglinide', 'tablet', 'A10BX02', false, 0, '02354934', 'FreeDiams::CA_HCDPD::DIN', 84012);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Repaglinide', 'tablet', 'A10BX02', false, 0, '02354942', 'FreeDiams::CA_HCDPD::DIN', 84013);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexilant', 'capsule (delayed release)', 'A02BC06', false, 0, '02354950', 'FreeDiams::CA_HCDPD::DIN', 84014);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dexilant', 'capsule (delayed release)', 'A02BC06', false, 0, '02354969', 'FreeDiams::CA_HCDPD::DIN', 84015);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Finasteride Tablets Usp', 'tablet', 'G04CB01', false, 0, '02355043', 'FreeDiams::CA_HCDPD::DIN', 84031);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nivea Visage Rich Moisturizing Day Care', 'cream', 'D02BA30', false, 0, '02355051', 'FreeDiams::CA_HCDPD::DIN', 84032);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nivea Visage Light Moisturizing Day Care', 'cream', 'D02BA30', false, 0, '02355078', 'FreeDiams::CA_HCDPD::DIN', 84033);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anew Sun Sunscreen Face Lotion', 'lotion', 'D02BA30', false, 0, '02355086', 'FreeDiams::CA_HCDPD::DIN', 84034);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anew Sun Sunscreen Body Lotion', 'lotion', 'D02BA30', false, 0, '02355094', 'FreeDiams::CA_HCDPD::DIN', 84035);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Youth Code Day Lotion Spf 30', 'lotion', 'D02BA30', false, 0, '02355108', 'FreeDiams::CA_HCDPD::DIN', 84036);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Revlon Photoready Powder', 'powder', 'D02BA30', false, 0, '02355124', 'FreeDiams::CA_HCDPD::DIN', 84038);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sunscreen Lotion With Skin Rejuvenating Green Tea Lotion Écran Solaire Au Thé Vert Revitalisant Spf Fps 8', 'lotion', 'D02BA30', false, 0, '02355132', 'FreeDiams::CA_HCDPD::DIN', 84039);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra Color Rich Moisture Seduction Lipstick/Rouge Ŕ Lčvres', 'stick', 'D02BA02', false, 0, '02355159', 'FreeDiams::CA_HCDPD::DIN', 84040);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Kids Sunscreen Clear Spray Écran Solaire Incolore En Vaporisateur Pour Enfants 60', 'spray, bag-on-valve', 'D02BA30', false, 0, '02355140', 'FreeDiams::CA_HCDPD::DIN', 84041);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anew Sun Sunscreen Body Mist Lotion', 'aerosol', 'D02BA30', false, 0, '02355167', 'FreeDiams::CA_HCDPD::DIN', 84042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibacterial Foaming Soap Tranquil Meadow', 'liquid', 'D08AE04', false, 0, '02355175', 'FreeDiams::CA_HCDPD::DIN', 84043);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Thalomid', 'capsule', 'L04AX02', false, 0, '02355191', 'FreeDiams::CA_HCDPD::DIN', 84045);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Thalomid', 'capsule', 'L04AX02', false, 0, '02355205', 'FreeDiams::CA_HCDPD::DIN', 84046);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Thalomid', 'capsule', 'L04AX02', false, 0, '02355221', 'FreeDiams::CA_HCDPD::DIN', 84048);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Septa-Citalopram', 'tablet', 'N06AB04', false, 0, '02355272', 'FreeDiams::CA_HCDPD::DIN', 84052);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Septa-Citalopram', 'tablet', 'N06AB04', false, 0, '02355280', 'FreeDiams::CA_HCDPD::DIN', 84053);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prevage Eye Ultra Protection Anti-Aging Moisture Cream Spf 15', 'cream', 'D02BA30', false, 0, '02355302', 'FreeDiams::CA_HCDPD::DIN', 84055);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Damp Mop Quat', 'liquid', 'V07AV', false, 0, '02355310', 'FreeDiams::CA_HCDPD::DIN', 84056);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fresh Essentials Daily Nourishing Moisturizer', 'lotion', 'D02BA30', false, 0, '02355361', 'FreeDiams::CA_HCDPD::DIN', 84061);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Woman''S Laxative', 'tablet', 'A06AB02', false, 0, '02355396', 'FreeDiams::CA_HCDPD::DIN', 84063);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Positively Ageless Sunscreen Lotion Spf 85 Face', 'lotion', 'D02BA30', false, 0, '02355531', 'FreeDiams::CA_HCDPD::DIN', 84076);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02355612', 'FreeDiams::CA_HCDPD::DIN', 84083);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02355620', 'FreeDiams::CA_HCDPD::DIN', 84084);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dom-Atorvastatin', 'tablet', 'C10AA05', false, 0, '02355639', 'FreeDiams::CA_HCDPD::DIN', 84085);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Restasis', 'emulsion', 'S01XA18', false, 0, '02355655', 'FreeDiams::CA_HCDPD::DIN', 84087);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Continuous Spray Spf/Fps 70', 'spray, bag-on-valve', 'D02BA30', false, 0, '02355728', 'FreeDiams::CA_HCDPD::DIN', 84092);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diltiazem Cd', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02355752', 'FreeDiams::CA_HCDPD::DIN', 84095);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diltiazem Cd', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02355760', 'FreeDiams::CA_HCDPD::DIN', 84096);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diltiazem Cd', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02355779', 'FreeDiams::CA_HCDPD::DIN', 84097);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Diltiazem Cd', 'capsule (controlled-delivery)', 'C08DB01', false, 0, '02355787', 'FreeDiams::CA_HCDPD::DIN', 84098);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lift Spf 15', 'cream', 'D02BA30', false, 0, '02355795', 'FreeDiams::CA_HCDPD::DIN', 84099);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Advil Nighttime', 'capsule', 'M01AE51', false, 0, '02355841', 'FreeDiams::CA_HCDPD::DIN', 84104);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benefiance Wrinkleresist24 Day Emulsion', 'emulsion', 'D02BA30', false, 0, '02356007', 'FreeDiams::CA_HCDPD::DIN', 84118);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benefiance Wrinkleresist24 Day Cream', 'cream', 'D02BA30', false, 0, '02356015', 'FreeDiams::CA_HCDPD::DIN', 84119);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydra-C Radiance 24h + Spf 15 Fps Moisturizing Cream Dry Skin Crčme Hydratante Peaux Sčches', 'cream', 'D02BA30', false, 0, '02356023', 'FreeDiams::CA_HCDPD::DIN', 84120);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Finasteride', 'tablet', 'G04CB01', false, 0, '02356058', 'FreeDiams::CA_HCDPD::DIN', 84122);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pcs Oxidizing Disinfectant/Disinfectant Cleaner Concentrate', 'liquid', 'V07AV', false, 0, '02356082', 'FreeDiams::CA_HCDPD::DIN', 84125);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pcs Hypochlorite Disinfectant/Disinfectant Cleaner Concentrate', 'liquid', 'V07AV', false, 0, '02356090', 'FreeDiams::CA_HCDPD::DIN', 84126);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bzk Towelette', 'wipe', 'D08AJ01', false, 0, '02356112', 'FreeDiams::CA_HCDPD::DIN', 84128);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crčme De Soin Solaire Mer Et Tropiques Visage', 'cream', 'D02BA30', false, 0, '02356139', 'FreeDiams::CA_HCDPD::DIN', 84130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lait De Soin Solaire Mer Et Tropiques Corps', 'lotion', 'D02BA30', false, 0, '02356147', 'FreeDiams::CA_HCDPD::DIN', 84131);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lait De Soin Solaire Corps', 'lotion', 'D02BA30', false, 0, '02356155', 'FreeDiams::CA_HCDPD::DIN', 84132);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Crčme De Soin Solaire Visage', 'cream', 'D02BA30', false, 0, '02356163', 'FreeDiams::CA_HCDPD::DIN', 84133);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Patriot 15', 'liquid', 'V07AV', false, 0, '02356287', 'FreeDiams::CA_HCDPD::DIN', 84144);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Selection Disinfectant All Purpose Cleaner', 'liquid', 'V07AV', false, 0, '02356295', 'FreeDiams::CA_HCDPD::DIN', 84145);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Method Antibac Antibacterial Kitchen Cleaner', 'spray', 'V07AV', false, 0, '02356309', 'FreeDiams::CA_HCDPD::DIN', 84146);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Method Antibac Antibacterial Bathroom Cleaner', 'spray', 'V07AV', false, 0, '02356325', 'FreeDiams::CA_HCDPD::DIN', 84148);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fit Me Maybelline New-York', 'lotion', 'D02BA02', false, 0, '02356368', 'FreeDiams::CA_HCDPD::DIN', 84151);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Method Antibac Wipes All Purpose Cleaning And Disinfecting Wipes', 'wipe', 'V07AV', false, 0, '02356392', 'FreeDiams::CA_HCDPD::DIN', 84154);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diamicron Mr', 'tablet (extended-release)', 'A10BB09', false, 0, '02356422', 'FreeDiams::CA_HCDPD::DIN', 84157);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisture Therapy Ultra Skin Care', 'ointment', 'D02AC', false, 0, '02356473', 'FreeDiams::CA_HCDPD::DIN', 84162);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rabeprazole Ec', 'tablet (delayed-release)', 'A02BC04', false, 0, '02356511', 'FreeDiams::CA_HCDPD::DIN', 84166);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Rabeprazole Ec', 'tablet (delayed-release)', 'A02BC04', false, 0, '02356538', 'FreeDiams::CA_HCDPD::DIN', 84167);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravastatin', 'tablet', 'C10AA03', false, 0, '02356546', 'FreeDiams::CA_HCDPD::DIN', 84168);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravastatin', 'tablet', 'C10AA03', false, 0, '02356554', 'FreeDiams::CA_HCDPD::DIN', 84169);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pravastatin', 'tablet', 'C10AA03', false, 0, '02356562', 'FreeDiams::CA_HCDPD::DIN', 84170);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fenofibrate-S', 'tablet', 'C10AB05', false, 0, '02356570', 'FreeDiams::CA_HCDPD::DIN', 84171);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fenofibrate-S', 'tablet', 'C10AB05', false, 0, '02356589', 'FreeDiams::CA_HCDPD::DIN', 84172);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hair Regrowth Formula', 'solution', 'D11AX01', false, 0, '02356597', 'FreeDiams::CA_HCDPD::DIN', 84173);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Valsartan', 'tablet', 'C09CA03', false, 0, '02356643', 'FreeDiams::CA_HCDPD::DIN', 84178);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Valsartan', 'tablet', 'C09CA03', false, 0, '02356651', 'FreeDiams::CA_HCDPD::DIN', 84179);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Valsartan', 'tablet', 'C09CA03', false, 0, '02356678', 'FreeDiams::CA_HCDPD::DIN', 84180);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Valsartan', 'tablet', 'C09CA03', false, 0, '02356686', 'FreeDiams::CA_HCDPD::DIN', 84181);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Valsartan Hct', 'tablet', 'C09DA03', false, 0, '02356694', 'FreeDiams::CA_HCDPD::DIN', 84182);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Valsartan Hct', 'tablet', 'C09DA03', false, 0, '02356708', 'FreeDiams::CA_HCDPD::DIN', 84183);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Valsartan Hct', 'tablet', 'C09DA03', false, 0, '02356716', 'FreeDiams::CA_HCDPD::DIN', 84184);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Valsartan Hct', 'tablet', 'C09DA03', false, 0, '02356724', 'FreeDiams::CA_HCDPD::DIN', 84185);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Valsartan Hct', 'tablet', 'C09DA03', false, 0, '02356732', 'FreeDiams::CA_HCDPD::DIN', 84186);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Valsartan', 'tablet', 'C09CA03', false, 0, '02356740', 'FreeDiams::CA_HCDPD::DIN', 84187);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Valsartan', 'tablet', 'C09CA03', false, 0, '02356759', 'FreeDiams::CA_HCDPD::DIN', 84188);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Valsartan', 'tablet', 'C09CA03', false, 0, '02356767', 'FreeDiams::CA_HCDPD::DIN', 84189);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Valsartan', 'tablet', 'C09CA03', false, 0, '02356775', 'FreeDiams::CA_HCDPD::DIN', 84190);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Metoprolol-L', 'tablet', 'C07AB02', false, 0, '02356813', 'FreeDiams::CA_HCDPD::DIN', 84194);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Metoprolol-L', 'tablet', 'C07AB02', false, 0, '02356821', 'FreeDiams::CA_HCDPD::DIN', 84195);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Metoprolol-L', 'tablet', 'C07AB02', false, 0, '02356848', 'FreeDiams::CA_HCDPD::DIN', 84196);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topiramate', 'tablet', 'N03AX11', false, 0, '02356856', 'FreeDiams::CA_HCDPD::DIN', 84197);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topiramate', 'tablet', 'N03AX11', false, 0, '02356864', 'FreeDiams::CA_HCDPD::DIN', 84198);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Topiramate', 'tablet', 'N03AX11', false, 0, '02356872', 'FreeDiams::CA_HCDPD::DIN', 84199);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperidone', 'tablet', 'N05AX08', false, 0, '02356880', 'FreeDiams::CA_HCDPD::DIN', 84200);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperidone', 'tablet', 'N05AX08', false, 0, '02356899', 'FreeDiams::CA_HCDPD::DIN', 84201);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperidone', 'tablet', 'N05AX08', false, 0, '02356902', 'FreeDiams::CA_HCDPD::DIN', 84202);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperidone', 'tablet', 'N05AX08', false, 0, '02356910', 'FreeDiams::CA_HCDPD::DIN', 84203);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperidone', 'tablet', 'N05AX08', false, 0, '02356929', 'FreeDiams::CA_HCDPD::DIN', 84204);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Risperidone', 'tablet', 'N05AX08', false, 0, '02356937', 'FreeDiams::CA_HCDPD::DIN', 84205);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Antibacterial Foaming Soap Tropical Breeze', 'liquid', 'D08AE04', false, 0, '02356945', 'FreeDiams::CA_HCDPD::DIN', 84206);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Olay Professional Pro-X Clear Uv Moisturizer Spf 15', 'lotion', 'D02BA30', false, 0, '02356953', 'FreeDiams::CA_HCDPD::DIN', 84207);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neostrata Daytime Moisture Infusion Cream', 'cream', 'D02BA30', false, 0, '02356988', 'FreeDiams::CA_HCDPD::DIN', 84209);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Valsartan/Hctz', 'tablet', 'C09DA03', false, 0, '02356996', 'FreeDiams::CA_HCDPD::DIN', 84210);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Valsartan/Hctz', 'tablet', 'C09DA03', false, 0, '02357003', 'FreeDiams::CA_HCDPD::DIN', 84211);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Valsartan/Hctz', 'tablet', 'C09DA03', false, 0, '02357011', 'FreeDiams::CA_HCDPD::DIN', 84212);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Valsartan/Hctz', 'tablet', 'C09DA03', false, 0, '02357038', 'FreeDiams::CA_HCDPD::DIN', 84213);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Valsartan/Hctz', 'tablet', 'C09DA03', false, 0, '02357046', 'FreeDiams::CA_HCDPD::DIN', 84214);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vert-2-Go Nettoyant Désinfectant/Disinfectant', 'liquid', 'V07AV', false, 0, '02357062', 'FreeDiams::CA_HCDPD::DIN', 84216);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Terbinafine', 'tablet', 'D01BA02', false, 0, '02357070', 'FreeDiams::CA_HCDPD::DIN', 84217);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ddm 07', 'liquid', 'V07AV', false, 0, '02357097', 'FreeDiams::CA_HCDPD::DIN', 84220);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vpriv', 'powder for solution', 'A16AB10', false, 0, '02357119', 'FreeDiams::CA_HCDPD::DIN', 84221);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tnt-100', 'liquid', 'V07AV', false, 0, '02357135', 'FreeDiams::CA_HCDPD::DIN', 84223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Amlodipine', 'tablet', 'C08CA01', false, 0, '02357186', 'FreeDiams::CA_HCDPD::DIN', 84231);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Amlodipine', 'tablet', 'C08CA01', false, 0, '02357194', 'FreeDiams::CA_HCDPD::DIN', 84232);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Amlodipine', 'tablet', 'C08CA01', false, 0, '02357208', 'FreeDiams::CA_HCDPD::DIN', 84233);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Bicalutamide', 'tablet', 'L02BB03', false, 0, '02357216', 'FreeDiams::CA_HCDPD::DIN', 84234);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Finasteride', 'tablet', 'G04CB01', false, 0, '02357224', 'FreeDiams::CA_HCDPD::DIN', 84235);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ibuprofen Liquid Capsules', 'capsule', 'M01AE01', false, 0, '02357275', 'FreeDiams::CA_HCDPD::DIN', 84240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Ibuprofen Liquid Capsules', 'capsule', 'M01AE01', false, 0, '02357283', 'FreeDiams::CA_HCDPD::DIN', 84241);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Volulyte', 'solution', 'B05AA07', false, 0, '02357291', 'FreeDiams::CA_HCDPD::DIN', 84242);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stool Softener', 'capsule', 'A06AA02', false, 0, '02357305', 'FreeDiams::CA_HCDPD::DIN', 84243);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Get A Tint Shimmer Tinted Moisturizer Lotion', 'lotion', 'D02BA30', false, 0, '02357313', 'FreeDiams::CA_HCDPD::DIN', 84244);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tropical Solutions Facial Moisturizer Spf 15', 'cream', 'D02BA30', false, 0, '02357348', 'FreeDiams::CA_HCDPD::DIN', 84246);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Strength Tylenol Body Pain Night', 'tablet', 'M03BA53', false, 0, '02357356', 'FreeDiams::CA_HCDPD::DIN', 84247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Uloric', 'tablet', 'M04AA03', false, 0, '02357380', 'FreeDiams::CA_HCDPD::DIN', 84250);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Irbesartan/Hct', 'tablet', 'C09DA04', false, 0, '02357399', 'FreeDiams::CA_HCDPD::DIN', 84252);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Irbesartan/Hct', 'tablet', 'C09DA04', false, 0, '02357402', 'FreeDiams::CA_HCDPD::DIN', 84253);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Co Irbesartan/Hct', 'tablet', 'C09DA04', false, 0, '02357410', 'FreeDiams::CA_HCDPD::DIN', 84254);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imipenem And Cilastatin For Injection', 'powder for solution', 'J01DH51', false, 0, '02357437', 'FreeDiams::CA_HCDPD::DIN', 84256);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ambient Lip Shield Stick Spf 45', 'stick', 'D02BA30', false, 0, '02357445', 'FreeDiams::CA_HCDPD::DIN', 84257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Repaglinide', 'tablet', 'A10BX02', false, 0, '02357453', 'FreeDiams::CA_HCDPD::DIN', 84259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Repaglinide', 'tablet', 'A10BX02', false, 0, '02357461', 'FreeDiams::CA_HCDPD::DIN', 84260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Repaglinide', 'tablet', 'A10BX02', false, 0, '02357488', 'FreeDiams::CA_HCDPD::DIN', 84261);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hawaiian Tropic Shimmer Effect Oil-Free Sunscreen Écran Solaire Sans Huile 15 Spf/Fps', 'lotion', 'D02BA30', false, 0, '02357518', 'FreeDiams::CA_HCDPD::DIN', 84262);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Elizabeth Arden Ceramide Ultra Lift And Firm Makeup Spf 15', 'liquid', 'D02BA30', false, 0, '02357550', 'FreeDiams::CA_HCDPD::DIN', 84266);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Lasting Lipstick/Rouge Ŕ Lčvres', 'stick', 'D02BA02', false, 0, '02357577', 'FreeDiams::CA_HCDPD::DIN', 84268);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Norvir', 'tablet', 'J05AE03', false, 0, '02357593', 'FreeDiams::CA_HCDPD::DIN', 84270);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vimpat', 'tablet', 'N03AX18', false, 0, '02357615', 'FreeDiams::CA_HCDPD::DIN', 84272);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vimpat', 'tablet', 'N03AX18', false, 0, '02357623', 'FreeDiams::CA_HCDPD::DIN', 84273);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vimpat', 'tablet', 'N03AX18', false, 0, '02357631', 'FreeDiams::CA_HCDPD::DIN', 84274);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vimpat', 'tablet', 'N03AX18', false, 0, '02357658', 'FreeDiams::CA_HCDPD::DIN', 84275);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Docusate Sodium Odan', 'capsule', 'A06AA02', false, 0, '02357674', 'FreeDiams::CA_HCDPD::DIN', 84277);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lansoprazole', 'capsule (delayed release)', 'A02BC03', false, 0, '02357682', 'FreeDiams::CA_HCDPD::DIN', 84278);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lansoprazole', 'capsule (delayed release)', 'A02BC03', false, 0, '02357690', 'FreeDiams::CA_HCDPD::DIN', 84279);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Septa-Amlodipine', 'tablet', 'C08CA01', false, 0, '02357704', 'FreeDiams::CA_HCDPD::DIN', 84280);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Septa-Amlodipine', 'tablet', 'C08CA01', false, 0, '02357712', 'FreeDiams::CA_HCDPD::DIN', 84281);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Septa-Amlodipine', 'tablet', 'C08CA01', false, 0, '02357720', 'FreeDiams::CA_HCDPD::DIN', 84282);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dove Men + Care Shampoo Anti-Dandruff', 'shampoo', 'D11AX12', false, 0, '02357739', 'FreeDiams::CA_HCDPD::DIN', 84283);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 60 Sport Sunscreen Continuous Spray', 'spray, bag-on-valve', 'D02BA30', false, 0, '02357828', 'FreeDiams::CA_HCDPD::DIN', 84291);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 60 Baby Sunscreen Continuous Spray Lotion', 'spray, bag-on-valve', 'D02BA30', false, 0, '02357836', 'FreeDiams::CA_HCDPD::DIN', 84292);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kellett Clarifying Acne Treatment', 'gel', 'D10AE01', false, 0, '02357992', 'FreeDiams::CA_HCDPD::DIN', 84307);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Repairing Treatment', 'lotion', 'D10AE01', false, 0, '02358026', 'FreeDiams::CA_HCDPD::DIN', 84309);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Peg 3350', 'powder for solution', 'A06AD15', false, 0, '02358034', 'FreeDiams::CA_HCDPD::DIN', 84310);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lavo Pro 6', 'liquid', 'V07AV', false, 0, '02358107', 'FreeDiams::CA_HCDPD::DIN', 84317);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Picoflo', 'powder for solution', 'A06AB58', false, 0, '02358298', 'FreeDiams::CA_HCDPD::DIN', 84334);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acetazolamide For Injection, Usp', 'powder for solution', 'S01EC01', false, 0, '02358328', 'FreeDiams::CA_HCDPD::DIN', 84336);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imipenem And Cilastatin For Injection Usp', 'powder for solution', 'J01DH51', false, 0, '02358336', 'FreeDiams::CA_HCDPD::DIN', 84339);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Imipenem And Cilastatin For Injection Usp', 'powder for solution', 'J01DH51', false, 0, '02358344', 'FreeDiams::CA_HCDPD::DIN', 84340);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mineral Protective Am Spf 15', 'suspension', 'D02BA30', false, 0, '02358360', 'FreeDiams::CA_HCDPD::DIN', 84342);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Extra Lasting Cream-To-Powder Foundation', 'cream', 'D02BA30', false, 0, '02358387', 'FreeDiams::CA_HCDPD::DIN', 84344);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Suncare Defense Spf 20 Mineral Moisturizer Spray', 'spray', 'D02BA30', false, 0, '02358417', 'FreeDiams::CA_HCDPD::DIN', 84347);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Suncare Defense Spf 30 Mineral Moisturizer', 'suspension', 'D02BA30', false, 0, '02358425', 'FreeDiams::CA_HCDPD::DIN', 84348);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Suncare Defense Spf 25 Mineral Moisturizer Face & Body', 'suspension', 'D02BA30', false, 0, '02358484', 'FreeDiams::CA_HCDPD::DIN', 84353);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Super Neutral L', 'liquid', 'V07AV', false, 0, '02358522', 'FreeDiams::CA_HCDPD::DIN', 84357);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Parvosyl Detergent Disinfectant Pump Spray', 'liquid', 'V07AV', false, 0, '02358530', 'FreeDiams::CA_HCDPD::DIN', 84358);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Meterpak Powder Detergent/Disinfectant', 'powder', 'V07AV', false, 0, '02358638', 'FreeDiams::CA_HCDPD::DIN', 84366);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Stop-It', 'liquid', 'V07AV', false, 0, '02358646', 'FreeDiams::CA_HCDPD::DIN', 84367);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Insomnal', 'tablet', 'R06AA02', false, 0, '02358689', 'FreeDiams::CA_HCDPD::DIN', 84371);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Shine''N Glo Disinfecting Wipes', 'wipe', 'V07AV', false, 0, '02358700', 'FreeDiams::CA_HCDPD::DIN', 84373);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('La Base L''Absolu Rouge', 'stick', 'D02BA02', false, 0, '02358751', 'FreeDiams::CA_HCDPD::DIN', 84378);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Suncare Defense Spf 15, Mineral Moisturizer', 'suspension', 'D02BA30', false, 0, '02358778', 'FreeDiams::CA_HCDPD::DIN', 84379);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pradax', 'capsule', 'B01AE07', false, 0, '02358808', 'FreeDiams::CA_HCDPD::DIN', 84384);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pure Disinfectant', 'liquid', 'V07AV', false, 0, '02358859', 'FreeDiams::CA_HCDPD::DIN', 84389);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valsartan', 'tablet', 'C09CA03', false, 0, '02367734', 'FreeDiams::CA_HCDPD::DIN', 85257);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 4 Sunscreen Lotion With Bronzer', 'lotion', 'D02BA02', false, 0, '02358956', 'FreeDiams::CA_HCDPD::DIN', 84398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avon Care Moisture Replenish Daily Hydrating Cream', 'cream', 'D02BA30', false, 0, '02358964', 'FreeDiams::CA_HCDPD::DIN', 84399);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 45 Body And Scalp Sunscreen Continuous Spray', 'spray, bag-on-valve', 'D02BA30', false, 0, '02359006', 'FreeDiams::CA_HCDPD::DIN', 84403);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lysol Disinfecting Wipes', 'wipe', 'V07AV', false, 0, '02359014', 'FreeDiams::CA_HCDPD::DIN', 84404);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fructis Anti-Dandruff Shampoo Mint Cleanse', 'shampoo', 'D11AX12', false, 0, '02359030', 'FreeDiams::CA_HCDPD::DIN', 84406);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Healthy Skin Radiance', 'cream', 'D02BA30', false, 0, '02359138', 'FreeDiams::CA_HCDPD::DIN', 84414);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Healthy Skin Lift & Firm', 'cream', 'D02BA30', false, 0, '02359146', 'FreeDiams::CA_HCDPD::DIN', 84415);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hertel Disinfectant Cream Cleanser', 'cream', 'V07AV', false, 0, '02359162', 'FreeDiams::CA_HCDPD::DIN', 84419);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bobbi Brown Spf 15 Oil Free Tinted Moisturizer', 'cream', 'D02BA30', false, 0, '02359170', 'FreeDiams::CA_HCDPD::DIN', 84420);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hertel All Purpose Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02359197', 'FreeDiams::CA_HCDPD::DIN', 84422);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Sport Sunscreen Stick', 'stick', 'D02BA30', false, 0, '02359200', 'FreeDiams::CA_HCDPD::DIN', 84423);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 30 Face Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02359219', 'FreeDiams::CA_HCDPD::DIN', 84424);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 60 Baby Sunscreen Stick', 'stick', 'D02BA30', false, 0, '02359227', 'FreeDiams::CA_HCDPD::DIN', 84425);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cold + Sinus Plus', 'tablet', 'M01AE51', false, 0, '02359243', 'FreeDiams::CA_HCDPD::DIN', 84427);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Beriplex P/N', 'powder for solution', 'B02BD01', false, 0, '02359251', 'FreeDiams::CA_HCDPD::DIN', 84428);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lysol Healthy Touch Antibacterial Hand Soap With Refreshing Aloe Vera & Vitamin E', 'liquid', 'D08AJ08', false, 0, '02359278', 'FreeDiams::CA_HCDPD::DIN', 84430);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 60 Sport Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02359286', 'FreeDiams::CA_HCDPD::DIN', 84431);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Acecide-C High-Level Disinfectant And Sterilant', 'liquid', 'V07AV', false, 0, '02359359', 'FreeDiams::CA_HCDPD::DIN', 84438);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pak-It Hard Surface Disinfectant Cleaner', 'stick', 'V07AV', false, 0, '02359367', 'FreeDiams::CA_HCDPD::DIN', 84439);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pristine Quat', 'liquid', 'V07AV', false, 0, '02359375', 'FreeDiams::CA_HCDPD::DIN', 84440);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hertel Toilet Bowl Disinfectant Cleaner', 'gel', 'V07AV', false, 0, '02359383', 'FreeDiams::CA_HCDPD::DIN', 84441);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vitalumičre Aqua', 'lotion', 'D02BA30', false, 0, '02359405', 'FreeDiams::CA_HCDPD::DIN', 84443);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Daxas', 'tablet', 'R03DX07', false, 0, '02359456', 'FreeDiams::CA_HCDPD::DIN', 84447);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moviprep', 'powder for solution', 'A06AD65', false, 0, '02359499', 'FreeDiams::CA_HCDPD::DIN', 84451);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorph Contin', 'capsule (sustained-release)', 'N02AA03', false, 0, '02359502', 'FreeDiams::CA_HCDPD::DIN', 84452);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydromorph Contin', 'capsule (sustained-release)', 'N02AA03', false, 0, '02359510', 'FreeDiams::CA_HCDPD::DIN', 84453);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Risperidone', 'tablet', 'N05AX08', false, 0, '02359529', 'FreeDiams::CA_HCDPD::DIN', 84454);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Risperidone', 'tablet', 'N05AX08', false, 0, '02359537', 'FreeDiams::CA_HCDPD::DIN', 84455);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Risperidone', 'tablet', 'N05AX08', false, 0, '02359545', 'FreeDiams::CA_HCDPD::DIN', 84456);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Risperidone', 'tablet', 'N05AX08', false, 0, '02359553', 'FreeDiams::CA_HCDPD::DIN', 84457);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Risperidone', 'tablet', 'N05AX08', false, 0, '02359561', 'FreeDiams::CA_HCDPD::DIN', 84458);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Risperidone', 'tablet', 'N05AX08', false, 0, '02359588', 'FreeDiams::CA_HCDPD::DIN', 84459);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carmex Moisture Plus', 'stick', 'D02BA30', false, 0, '02359650', 'FreeDiams::CA_HCDPD::DIN', 84465);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Biacna Topical Gel', 'gel', 'D10AF51', false, 0, '02359685', 'FreeDiams::CA_HCDPD::DIN', 84468);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Teva-Olanzapine', 'tablet', 'N05AH03', false, 0, '02359707', 'FreeDiams::CA_HCDPD::DIN', 84470);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 15 Broad Spectrum Sunscreen Lotion', 'lotion', 'D02BA30', false, 0, '02359723', 'FreeDiams::CA_HCDPD::DIN', 84472);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Risperidon', 'tablet', 'N05AX08', false, 0, '02359790', 'FreeDiams::CA_HCDPD::DIN', 84478);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Risperidon', 'tablet', 'N05AX08', false, 0, '02359804', 'FreeDiams::CA_HCDPD::DIN', 84479);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Risperidon', 'tablet', 'N05AX08', false, 0, '02359812', 'FreeDiams::CA_HCDPD::DIN', 84480);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Risperidon', 'tablet', 'N05AX08', false, 0, '02359820', 'FreeDiams::CA_HCDPD::DIN', 84481);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Risperidon', 'tablet', 'N05AX08', false, 0, '02359839', 'FreeDiams::CA_HCDPD::DIN', 84482);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Risperidon', 'tablet', 'N05AX08', false, 0, '02359847', 'FreeDiams::CA_HCDPD::DIN', 84483);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Super Shock Liquid Lip Shine', 'liquid', 'D02BA30', false, 0, '02360055', 'FreeDiams::CA_HCDPD::DIN', 84503);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Theo Er', 'tablet (extended-release)', 'R03DA04', false, 0, '02360101', 'FreeDiams::CA_HCDPD::DIN', 84507);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Theo Er', 'tablet (extended-release)', 'R03DA04', false, 0, '02360128', 'FreeDiams::CA_HCDPD::DIN', 84508);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ambient Light Face Cream Spf 50', 'cream', 'D02BA30', false, 0, '02360233', 'FreeDiams::CA_HCDPD::DIN', 84519);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ambient Light Body Lotion Spf 50', 'lotion', 'D02BA30', false, 0, '02360241', 'FreeDiams::CA_HCDPD::DIN', 84520);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zytram Xl', 'tablet (extended-release)', 'N02AX02', false, 0, '02360322', 'FreeDiams::CA_HCDPD::DIN', 84529);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ambient Ultra Light Mist Spray Spf 30', 'spray', 'D02BA30', false, 0, '02360330', 'FreeDiams::CA_HCDPD::DIN', 84530);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zytram Xl', 'tablet (extended-release)', 'N02AX02', false, 0, '02360349', 'FreeDiams::CA_HCDPD::DIN', 84531);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Furosemide Injection', 'liquid', 'C03CA01', false, 0, '02360365', 'FreeDiams::CA_HCDPD::DIN', 84533);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nucynta Cr', 'tablet (extended-release)', 'N02AX06', false, 0, '02360373', 'FreeDiams::CA_HCDPD::DIN', 84534);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nucynta Cr', 'tablet (extended-release)', 'N02AX06', false, 0, '02360381', 'FreeDiams::CA_HCDPD::DIN', 84535);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nucynta Cr', 'tablet (extended-release)', 'N02AX06', false, 0, '02360403', 'FreeDiams::CA_HCDPD::DIN', 84536);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nucynta Cr', 'tablet (extended-release)', 'N02AX06', false, 0, '02360411', 'FreeDiams::CA_HCDPD::DIN', 84537);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nucynta Cr', 'tablet (extended-release)', 'N02AX06', false, 0, '02360438', 'FreeDiams::CA_HCDPD::DIN', 84538);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Furosemide Special Injection', 'liquid', 'C03CA01', false, 0, '02360446', 'FreeDiams::CA_HCDPD::DIN', 84539);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Capital Lumiere Jour Spf 15', 'cream', 'D02BA30', false, 0, '02360462', 'FreeDiams::CA_HCDPD::DIN', 84541);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ep55 Nettoyant Désinfectant Ŕ Base De Thym / Thyme Based Disinfectant Cleaner', 'solution', 'V07AV', false, 0, '02360497', 'FreeDiams::CA_HCDPD::DIN', 84544);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pcs 5000 Oxidizing Disinfectant/Disinfectant Cleaner', 'liquid', 'V07AV', false, 0, '02360500', 'FreeDiams::CA_HCDPD::DIN', 84545);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pcs 5000 Oxidizing Disinfectant/Disinfectant Cleaner Wipes', 'wipe', 'V07AV', false, 0, '02360519', 'FreeDiams::CA_HCDPD::DIN', 84546);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pcs 1000 Oxidizing Disinfectant/Disinfectant Cleaner Wipes', 'wipe', 'V07AV', false, 0, '02360527', 'FreeDiams::CA_HCDPD::DIN', 84547);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pcs 500 Oxidizing Disinfectant/Disinfectant Cleaner Wipes', 'wipe', 'V07AV', false, 0, '02360535', 'FreeDiams::CA_HCDPD::DIN', 84548);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Protecting Spf 30 Spray', 'spray', 'D02BA30', false, 0, '02360551', 'FreeDiams::CA_HCDPD::DIN', 84553);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Weiman Disinfectant Wipes', 'wipe', 'V07AV', false, 0, '02360578', 'FreeDiams::CA_HCDPD::DIN', 84554);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydrochlorothiazide', 'tablet', 'C03AA03', false, 0, '02360594', 'FreeDiams::CA_HCDPD::DIN', 84556);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydrochlorothiazide', 'tablet', 'C03AA03', false, 0, '02360608', 'FreeDiams::CA_HCDPD::DIN', 84557);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Enteric Coated Daily Low Dose Asa 81mg', 'tablet (delayed-release)', 'N02BA01', false, 0, '02363127', 'FreeDiams::CA_HCDPD::DIN', 84814);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Donosan Disinfectant And No Rinse Sanitizer/Désinfectant Et Assainisseur Sans Rinçage', 'solution', 'V07AV', false, 0, '02360659', 'FreeDiams::CA_HCDPD::DIN', 84566);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cyanokit', 'powder for solution', 'V03AB33', false, 0, '02360721', 'FreeDiams::CA_HCDPD::DIN', 84573);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kara Vita Spf 29', 'lotion', 'D02BA30', false, 0, '02360748', 'FreeDiams::CA_HCDPD::DIN', 84574);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Kara Vita Spf 30', 'lotion', 'D02BA30', false, 0, '02360756', 'FreeDiams::CA_HCDPD::DIN', 84576);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Celazome Spf 29', 'lotion', 'D02BA30', false, 0, '02360799', 'FreeDiams::CA_HCDPD::DIN', 84579);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Celazome Spf 30', 'lotion', 'D02BA30', false, 0, '02360802', 'FreeDiams::CA_HCDPD::DIN', 84580);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clear Eyes Extra Strength Redness Relief', 'solution', 'S01GA51', false, 0, '02360837', 'FreeDiams::CA_HCDPD::DIN', 84583);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Glaxal Base Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02361000', 'FreeDiams::CA_HCDPD::DIN', 84603);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prevention Rtu', 'liquid', 'V07AV', false, 0, '02361094', 'FreeDiams::CA_HCDPD::DIN', 84615);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clonidine', 'tablet', 'C02AC01', false, 0, '02361299', 'FreeDiams::CA_HCDPD::DIN', 84635);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clonidine', 'tablet', 'C02AC01', false, 0, '02361302', 'FreeDiams::CA_HCDPD::DIN', 84636);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Clonidine', 'tablet', 'C02AC01', false, 0, '02361310', 'FreeDiams::CA_HCDPD::DIN', 84637);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Fixx-Icide', 'liquid', 'V07AV', false, 0, '02361329', 'FreeDiams::CA_HCDPD::DIN', 84638);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Quercetin & Oak Hydrating Antiageing Antiwrinkle Day Cream Spf 4', 'cream', 'D02BA30', false, 0, '02361345', 'FreeDiams::CA_HCDPD::DIN', 84640);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oxycodone/Acet', 'tablet', 'N02BE51', false, 0, '02361361', 'FreeDiams::CA_HCDPD::DIN', 84644);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prevention Concentrate', 'liquid', 'V07AV', false, 0, '02361396', 'FreeDiams::CA_HCDPD::DIN', 84646);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Clarithromycin', 'tablet', 'J01FA09', false, 0, '02361426', 'FreeDiams::CA_HCDPD::DIN', 84648);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Clarithromycin', 'tablet', 'J01FA09', false, 0, '02361434', 'FreeDiams::CA_HCDPD::DIN', 84649);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M5000 Désinfectant Concentré', 'liquid', 'V07AV', false, 0, '02361442', 'FreeDiams::CA_HCDPD::DIN', 84650);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Lisinopril', 'tablet', 'C09AA03', false, 0, '02361531', 'FreeDiams::CA_HCDPD::DIN', 84661);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Lisinopril', 'tablet', 'C09AA03', false, 0, '02361558', 'FreeDiams::CA_HCDPD::DIN', 84662);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Lisinopril', 'tablet', 'C09AA03', false, 0, '02361566', 'FreeDiams::CA_HCDPD::DIN', 84663);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Got To Glow Gradual Glow Body Moisturizer Lotion', 'lotion', 'D02BA30', false, 0, '02361574', 'FreeDiams::CA_HCDPD::DIN', 84664);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nature Clean Household Disinfectant Désinfectant Ménager Natural 100% Naturel', 'solution', 'V07AV', false, 0, '02361604', 'FreeDiams::CA_HCDPD::DIN', 84667);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ali-Flex Lf', 'liquid', 'V07AV', false, 0, '02361612', 'FreeDiams::CA_HCDPD::DIN', 84668);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sumatriptan Sun Injection', 'solution', 'N02CC01', false, 0, '02361698', 'FreeDiams::CA_HCDPD::DIN', 84675);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vimovo', 'tablet (delayed and immediate release)', 'M01AE', false, 0, '02361701', 'FreeDiams::CA_HCDPD::DIN', 84676);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vimovo', 'tablet (delayed and immediate release)', 'M01AE', false, 0, '02361728', 'FreeDiams::CA_HCDPD::DIN', 84677);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Nipride', 'solution', 'C02DD01', false, 0, '02361736', 'FreeDiams::CA_HCDPD::DIN', 84678);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zenhale', 'aerosol, metered dose', 'R03AK07', false, 0, '02361744', 'FreeDiams::CA_HCDPD::DIN', 84679);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zenhale', 'aerosol, metered dose', 'R03AK07', false, 0, '02361752', 'FreeDiams::CA_HCDPD::DIN', 84680);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zenhale', 'aerosol, metered dose', 'R03AK07', false, 0, '02361760', 'FreeDiams::CA_HCDPD::DIN', 84681);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avon Naturals Blackberry & Vanilla Anti-Bacterial Hand Soap', 'liquid', 'D08AE04', false, 0, '02361779', 'FreeDiams::CA_HCDPD::DIN', 84682);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Avon Naturals Strawberry & Guava Anti-Bacterial Hand Soap', 'liquid', 'D08AE04', false, 0, '02361787', 'FreeDiams::CA_HCDPD::DIN', 84683);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Byetta', 'solution', 'A10BX04', false, 0, '02361809', 'FreeDiams::CA_HCDPD::DIN', 84685);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Byetta', 'solution', 'A10BX04', false, 0, '02361817', 'FreeDiams::CA_HCDPD::DIN', 84686);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Revolade', 'tablet', 'B02BX05', false, 0, '02361825', 'FreeDiams::CA_HCDPD::DIN', 84687);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Revolade', 'tablet', 'B02BX05', false, 0, '02361833', 'FreeDiams::CA_HCDPD::DIN', 84688);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oleptro', 'tablet (extended-release)', 'N06AX05', false, 0, '02361868', 'FreeDiams::CA_HCDPD::DIN', 84690);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Oleptro', 'tablet (extended-release)', 'N06AX05', false, 0, '02361876', 'FreeDiams::CA_HCDPD::DIN', 84691);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pms-Quetiapine', 'tablet', 'N05AH04', false, 0, '02361892', 'FreeDiams::CA_HCDPD::DIN', 84693);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Docetaxel For Injection', 'solution', 'L01CD02', false, 0, '02361957', 'FreeDiams::CA_HCDPD::DIN', 84699);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Foaming Hand Soap', 'liquid', 'D08AE04', false, 0, '02361981', 'FreeDiams::CA_HCDPD::DIN', 84702);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bienfait Uv Spf 50', 'lotion', 'D02BA30', false, 0, '02362031', 'FreeDiams::CA_HCDPD::DIN', 84706);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hydraphase Uv Intense', 'lotion', 'D02BA30', false, 0, '02362058', 'FreeDiams::CA_HCDPD::DIN', 84707);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Homme Daily Moisturizing Lotion Spf 15', 'lotion', 'D02BA30', false, 0, '02362112', 'FreeDiams::CA_HCDPD::DIN', 84713);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spf 60 Clear', 'spray', 'D02BA30', false, 0, '02362139', 'FreeDiams::CA_HCDPD::DIN', 84715);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pataday', 'solution', 'S01GX09', false, 0, '02362171', 'FreeDiams::CA_HCDPD::DIN', 84721);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Drixoral No Drip', 'spray', 'R01AA05', false, 0, '02362236', 'FreeDiams::CA_HCDPD::DIN', 84725);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Blu-Lite Plus', 'liquid', 'V07AV', false, 0, '02362333', 'FreeDiams::CA_HCDPD::DIN', 84735);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Naproxen', 'tablet', 'M01AE02', false, 0, '02362430', 'FreeDiams::CA_HCDPD::DIN', 84744);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Estee Lauder Resilience Lift Firming/Sculpting Face And Neck Crčme Spf 15 For Dry Skin', 'cream', 'D02BA02', false, 0, '02362600', 'FreeDiams::CA_HCDPD::DIN', 84761);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Amlodipine', 'tablet', 'C08CA01', false, 0, '02362651', 'FreeDiams::CA_HCDPD::DIN', 84766);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Amlodipine', 'tablet', 'C08CA01', false, 0, '02362678', 'FreeDiams::CA_HCDPD::DIN', 84767);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ep66 Av-Mixx Disinfectant/Ep66 Av-Mixx Désinfectant', 'liquid', 'V07AV', false, 0, '02362686', 'FreeDiams::CA_HCDPD::DIN', 84768);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Amlodipine/Atorvastatin', 'tablet', 'C10BX03', false, 0, '02362759', 'FreeDiams::CA_HCDPD::DIN', 84775);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Amlodipine/Atorvastatin', 'tablet', 'C10BX03', false, 0, '02362767', 'FreeDiams::CA_HCDPD::DIN', 84776);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Amlodipine/Atorvastatin', 'tablet', 'C10BX03', false, 0, '02362775', 'FreeDiams::CA_HCDPD::DIN', 84777);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Amlodipine/Atorvastatin', 'tablet', 'C10BX03', false, 0, '02362783', 'FreeDiams::CA_HCDPD::DIN', 84778);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Amlodipine/Atorvastatin', 'tablet', 'C10BX03', false, 0, '02362791', 'FreeDiams::CA_HCDPD::DIN', 84779);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Amlodipine/Atorvastatin', 'tablet', 'C10BX03', false, 0, '02362805', 'FreeDiams::CA_HCDPD::DIN', 84780);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Amlodipine/Atorvastatin', 'tablet', 'C10BX03', false, 0, '02362813', 'FreeDiams::CA_HCDPD::DIN', 84781);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gd-Amlodipine/Atorvastatin', 'tablet', 'C10BX03', false, 0, '02362821', 'FreeDiams::CA_HCDPD::DIN', 84782);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lisinopril/Hctz (Type Z)', 'tablet', 'C09BA03', false, 0, '02362945', 'FreeDiams::CA_HCDPD::DIN', 84793);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lisinopril/Hctz (Type Z)', 'tablet', 'C09BA03', false, 0, '02362953', 'FreeDiams::CA_HCDPD::DIN', 84794);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lisinopril/Hctz (Type Z)', 'tablet', 'C09BA03', false, 0, '02362961', 'FreeDiams::CA_HCDPD::DIN', 84795);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Zolmitriptan', 'tablet', 'N02CC03', false, 0, '02362988', 'FreeDiams::CA_HCDPD::DIN', 84796);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sandoz Zolmitriptan Odt', 'tablet (orally disintegrating)', 'N02CC03', false, 0, '02362996', 'FreeDiams::CA_HCDPD::DIN', 84797);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Valsartan', 'tablet', 'C09CA03', false, 0, '02363062', 'FreeDiams::CA_HCDPD::DIN', 84808);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Valsartan', 'tablet', 'C09CA03', false, 0, '02363100', 'FreeDiams::CA_HCDPD::DIN', 84812);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Valsartan', 'tablet', 'C09CA03', false, 0, '02363119', 'FreeDiams::CA_HCDPD::DIN', 84813);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Suncare Defense Spf 8 Oil Face & Body', 'suspension', 'D02BA30', false, 0, '02363178', 'FreeDiams::CA_HCDPD::DIN', 84818);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('125-280 Solution', 'solution', 'V07AV', false, 0, '02363194', 'FreeDiams::CA_HCDPD::DIN', 84820);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Irbesartan Hctz', 'tablet', 'C09DA04', false, 0, '02363208', 'FreeDiams::CA_HCDPD::DIN', 84821);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Irbesartan Hctz', 'tablet', 'C09DA04', false, 0, '02363216', 'FreeDiams::CA_HCDPD::DIN', 84822);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ran-Irbesartan Hctz', 'tablet', 'C09DA04', false, 0, '02363224', 'FreeDiams::CA_HCDPD::DIN', 84823);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Emend Iv', 'powder for solution', 'A04AD', false, 0, '02363356', 'FreeDiams::CA_HCDPD::DIN', 84835);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Caramel Latte Tinted Moisturizer', 'lotion', 'D02BA30', false, 0, '02363550', 'FreeDiams::CA_HCDPD::DIN', 84853);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cocoa Latte Tinted Moisturizer', 'lotion', 'D02BA30', false, 0, '02363607', 'FreeDiams::CA_HCDPD::DIN', 84858);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun And Snow Sport Spf 15', 'stick', 'D02BA30', false, 0, '02363909', 'FreeDiams::CA_HCDPD::DIN', 84886);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Moisture Therapy Intensive Treatment', 'lotion', 'D02BA30', false, 0, '02364093', 'FreeDiams::CA_HCDPD::DIN', 84903);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abstral', 'tablet', 'N02AB03', false, 0, '02364174', 'FreeDiams::CA_HCDPD::DIN', 84910);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abstral', 'tablet', 'N02AB03', false, 0, '02364182', 'FreeDiams::CA_HCDPD::DIN', 84911);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abstral', 'tablet', 'N02AB03', false, 0, '02364190', 'FreeDiams::CA_HCDPD::DIN', 84912);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abstral', 'tablet', 'N02AB03', false, 0, '02364204', 'FreeDiams::CA_HCDPD::DIN', 84913);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abstral', 'tablet', 'N02AB03', false, 0, '02364212', 'FreeDiams::CA_HCDPD::DIN', 84914);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Abstral', 'tablet', 'N02AB03', false, 0, '02364220', 'FreeDiams::CA_HCDPD::DIN', 84915);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Amiodarone', 'tablet', 'C01BD01', false, 0, '02364336', 'FreeDiams::CA_HCDPD::DIN', 84924);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aller Relief 10mg', 'tablet', 'R06AE07', false, 0, '02364689', 'FreeDiams::CA_HCDPD::DIN', 84957);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Anthelios Ultra-Fluid Lotion', 'lotion', 'D02BA30', false, 0, '02364700', 'FreeDiams::CA_HCDPD::DIN', 84959);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ultra-Light Lotion Spf 50', 'lotion', 'D02BA30', false, 0, '02364735', 'FreeDiams::CA_HCDPD::DIN', 84962);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Colgate Total Advanced Health Gum Defense', 'toothpaste', 'A01AA51', false, 0, '02364786', 'FreeDiams::CA_HCDPD::DIN', 84966);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun Spray Spf 30', 'spray', 'D02BA30', false, 0, '02364867', 'FreeDiams::CA_HCDPD::DIN', 84974);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sun Stick Spf 45', 'stick', 'D02BA30', false, 0, '02364875', 'FreeDiams::CA_HCDPD::DIN', 84975);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Prevention Wipes', 'wipe', 'V07AV', false, 0, '02364891', 'FreeDiams::CA_HCDPD::DIN', 84977);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Next Choice', 'tablet', 'G03AD01', false, 0, '02364905', 'FreeDiams::CA_HCDPD::DIN', 84978);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carvedilol', 'tablet', 'C07AG02', false, 0, '02364913', 'FreeDiams::CA_HCDPD::DIN', 84979);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carvedilol', 'tablet', 'C07AG02', false, 0, '02364921', 'FreeDiams::CA_HCDPD::DIN', 84980);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carvedilol', 'tablet', 'C07AG02', false, 0, '02364948', 'FreeDiams::CA_HCDPD::DIN', 84981);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Carvedilol', 'tablet', 'C07AG02', false, 0, '02364956', 'FreeDiams::CA_HCDPD::DIN', 84982);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Equate Antibacterial Hands & Face Wipes', 'wipe', 'D08AJ01', false, 0, '02365146', 'FreeDiams::CA_HCDPD::DIN', 84999);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tobi Podhaler', 'capsule', 'J01GB01', false, 0, '02365154', 'FreeDiams::CA_HCDPD::DIN', 85000);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Irbesartan-Hctz', 'tablet', 'C09DA04', false, 0, '02365162', 'FreeDiams::CA_HCDPD::DIN', 85001);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Irbesartan-Hctz', 'tablet', 'C09DA04', false, 0, '02365170', 'FreeDiams::CA_HCDPD::DIN', 85002);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Irbesartan-Hctz', 'tablet', 'C09DA04', false, 0, '02365189', 'FreeDiams::CA_HCDPD::DIN', 85003);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Irbesartan', 'tablet', 'C09CA04', false, 0, '02365197', 'FreeDiams::CA_HCDPD::DIN', 85004);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Irbesartan', 'tablet', 'C09CA04', false, 0, '02365200', 'FreeDiams::CA_HCDPD::DIN', 85005);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Irbesartan', 'tablet', 'C09CA04', false, 0, '02365219', 'FreeDiams::CA_HCDPD::DIN', 85006);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Candesartan', 'tablet', 'C09CA06', false, 0, '02365340', 'FreeDiams::CA_HCDPD::DIN', 85025);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Candesartan', 'tablet', 'C09CA06', false, 0, '02365359', 'FreeDiams::CA_HCDPD::DIN', 85026);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Candesartan', 'tablet', 'C09CA06', false, 0, '02365367', 'FreeDiams::CA_HCDPD::DIN', 85027);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Gilenya', 'capsule', 'L04AA27', false, 0, '02365480', 'FreeDiams::CA_HCDPD::DIN', 85038);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02365529', 'FreeDiams::CA_HCDPD::DIN', 85042);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Pioglitazone', 'tablet', 'A10BG03', false, 0, '02365537', 'FreeDiams::CA_HCDPD::DIN', 85043);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Vyloma', 'cream', 'D06BB10', false, 0, '02365561', 'FreeDiams::CA_HCDPD::DIN', 85046);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Sleep Assist', 'capsule', 'R06AA02', false, 0, '02365685', 'FreeDiams::CA_HCDPD::DIN', 85056);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tactuo', 'gel', 'D10AD53', false, 0, '02365871', 'FreeDiams::CA_HCDPD::DIN', 85075);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Spritz Solaire Corps Fps 30', 'spray, bag-on-valve', 'D02BA30', false, 0, '02366037', 'FreeDiams::CA_HCDPD::DIN', 85091);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Folic Acid', 'tablet', 'B03BB01', false, 0, '02366061', 'FreeDiams::CA_HCDPD::DIN', 85094);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Dicyclomine Hcl', 'tablet', 'A03AA07', false, 0, '02366088', 'FreeDiams::CA_HCDPD::DIN', 85095);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alba Botanica Very Emollient/Trčs Émollient Kids Sunscreen Lotion/Lotion Écran Solaire Pour Enfants Spf Fps 45', 'lotion', 'D02BA30', false, 0, '02366096', 'FreeDiams::CA_HCDPD::DIN', 85096);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alba Botanica Very Emollient/Trčs Émollient Fragrance Free Facial Sunscreen Lotion/Lotion Écran Solaire Non Parfumée Pour Le Visage Spf Fps 30', 'lotion', 'D02BA30', false, 0, '02366118', 'FreeDiams::CA_HCDPD::DIN', 85097);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alba Botanica Very Emollient / Trčs Émollient Sport Sunscreen Lotion / Lotion Écran Solaire Sport Spf Fps 45', 'lotion', 'D02BA30', false, 0, '02366126', 'FreeDiams::CA_HCDPD::DIN', 85098);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Alba Botanica Very Emollient / Trčs Émollient Lavender Fragrance Sunscreen Lotion/Lotion Écran Solaire Ŕ Parfum De Lavande Spf Fps 45', 'lotion', 'D02BA30', false, 0, '02366134', 'FreeDiams::CA_HCDPD::DIN', 85099);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lansoprazole', 'capsule (delayed release)', 'A02BC03', false, 0, '02366282', 'FreeDiams::CA_HCDPD::DIN', 85113);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Apo-Memantine', 'tablet', 'N06DX01', false, 0, '02366487', 'FreeDiams::CA_HCDPD::DIN', 85130);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('M.A.C. Matchmaster Spf 15 Foundation', 'emulsion', 'D02BA30', false, 0, '02366517', 'FreeDiams::CA_HCDPD::DIN', 85135);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citrasate C1125', 'solution', 'B05ZA', false, 0, '02366541', 'FreeDiams::CA_HCDPD::DIN', 85140);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citrasate C2125', 'solution', 'B05ZA', false, 0, '02366568', 'FreeDiams::CA_HCDPD::DIN', 85141);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Citrasate C3125', 'solution', 'B05ZA', false, 0, '02366576', 'FreeDiams::CA_HCDPD::DIN', 85142);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Karesse', 'liquid', 'D08AE04', false, 0, '02366878', 'FreeDiams::CA_HCDPD::DIN', 85169);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Diamond Dual-Clean Plus', 'liquid', 'V07AV', false, 0, '02366886', 'FreeDiams::CA_HCDPD::DIN', 85170);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Taro-Mometasone Cream', 'cream', 'D07AC13', false, 0, '02367157', 'FreeDiams::CA_HCDPD::DIN', 85196);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Intervention Wipes', 'wipe', 'V07AV', false, 0, '02367254', 'FreeDiams::CA_HCDPD::DIN', 85205);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Myl-Ranitidine', 'tablet', 'A02BA02', false, 0, '02367378', 'FreeDiams::CA_HCDPD::DIN', 85222);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Myl-Ranitidine', 'tablet', 'A02BA02', false, 0, '02367386', 'FreeDiams::CA_HCDPD::DIN', 85223);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Bobbi Brown Skin Foundation Mineral Makeup Spf 15', 'powder', 'D02BA30', false, 0, '02367432', 'FreeDiams::CA_HCDPD::DIN', 85228);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Atenolol', 'tablet', 'C07AB03', false, 0, '02367556', 'FreeDiams::CA_HCDPD::DIN', 85239);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Atenolol', 'tablet', 'C07AB03', false, 0, '02367564', 'FreeDiams::CA_HCDPD::DIN', 85240);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Atenolol', 'tablet', 'C07AB03', false, 0, '02367572', 'FreeDiams::CA_HCDPD::DIN', 85241);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pramipexole', 'tablet', 'N04BC05', false, 0, '02367602', 'FreeDiams::CA_HCDPD::DIN', 85244);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pramipexole', 'tablet', 'N04BC05', false, 0, '02367610', 'FreeDiams::CA_HCDPD::DIN', 85245);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pramipexole', 'tablet', 'N04BC05', false, 0, '02367629', 'FreeDiams::CA_HCDPD::DIN', 85247);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valsartan', 'tablet', 'C09CA03', false, 0, '02367742', 'FreeDiams::CA_HCDPD::DIN', 85258);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valsartan', 'tablet', 'C09CA03', false, 0, '02367750', 'FreeDiams::CA_HCDPD::DIN', 85259);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valsartan-Hctz', 'tablet', 'C09DA03', false, 0, '02367769', 'FreeDiams::CA_HCDPD::DIN', 85260);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valsartan-Hctz', 'tablet', 'C09DA03', false, 0, '02367777', 'FreeDiams::CA_HCDPD::DIN', 85261);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Valsartan-Hctz', 'tablet', 'C09DA03', false, 0, '02367785', 'FreeDiams::CA_HCDPD::DIN', 85262);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Atenol', 'tablet', 'C07AB03', false, 0, '02368013', 'FreeDiams::CA_HCDPD::DIN', 85283);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Atenol', 'tablet', 'C07AB03', false, 0, '02368021', 'FreeDiams::CA_HCDPD::DIN', 85284);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mint-Atenol', 'tablet', 'C07AB03', false, 0, '02368048', 'FreeDiams::CA_HCDPD::DIN', 85285);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ibuprofen Extra Strength Caplets', 'tablet', 'M01AE01', false, 0, '02368099', 'FreeDiams::CA_HCDPD::DIN', 85291);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Xgeva', 'solution', 'M05BX04', false, 0, '02368153', 'FreeDiams::CA_HCDPD::DIN', 85304);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Tasigna', 'capsule', 'L01XE08', false, 0, '02368250', 'FreeDiams::CA_HCDPD::DIN', 85322);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Germikem', 'liquid', 'V07AV', false, 0, '02368366', 'FreeDiams::CA_HCDPD::DIN', 85333);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Foundation Primer Plus Spf 15', 'gel', 'D02BA30', false, 0, '02368455', 'FreeDiams::CA_HCDPD::DIN', 85341);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Lip Conditioner Spf 15', 'stick', 'D02BA30', false, 0, '02368463', 'FreeDiams::CA_HCDPD::DIN', 85343);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Brilinta', 'tablet', 'B01AC24', false, 0, '02368544', 'FreeDiams::CA_HCDPD::DIN', 85352);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Septa-Atenolol', 'tablet', 'C07AB03', false, 0, '02368633', 'FreeDiams::CA_HCDPD::DIN', 85363);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Septa-Atenolol', 'tablet', 'C07AB03', false, 0, '02368641', 'FreeDiams::CA_HCDPD::DIN', 85364);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Septa-Atenolol', 'tablet', 'C07AB03', false, 0, '02368668', 'FreeDiams::CA_HCDPD::DIN', 85365);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Carvedilol', 'tablet', 'C07AG02', false, 0, '02368897', 'FreeDiams::CA_HCDPD::DIN', 85386);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Carvedilol', 'tablet', 'C07AG02', false, 0, '02368900', 'FreeDiams::CA_HCDPD::DIN', 85387);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Carvedilol', 'tablet', 'C07AG02', false, 0, '02368919', 'FreeDiams::CA_HCDPD::DIN', 85388);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jamp-Carvedilol', 'tablet', 'C07AG02', false, 0, '02368927', 'FreeDiams::CA_HCDPD::DIN', 85389);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Mylan-Zolmitriptan', 'tablet', 'N02CC03', false, 0, '02369036', 'FreeDiams::CA_HCDPD::DIN', 85398);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutra-Quat', 'liquid', 'V07AV', false, 0, '02369109', 'FreeDiams::CA_HCDPD::DIN', 85405);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aloemed Disinfectant 5 Cleaner', 'liquid', 'V07AV', false, 0, '02369303', 'FreeDiams::CA_HCDPD::DIN', 85423);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Echoclean', 'solution', 'V07AV', false, 0, '02369427', 'FreeDiams::CA_HCDPD::DIN', 85436);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('D-3', 'liquid', 'V07AV', false, 0, '02369516', 'FreeDiams::CA_HCDPD::DIN', 85444);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Jevtana', 'solution', 'L01CD04', false, 0, '02369524', 'FreeDiams::CA_HCDPD::DIN', 85445);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benlysta', 'powder for solution', 'L04AA26', false, 0, '02370050', 'FreeDiams::CA_HCDPD::DIN', 85508);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Benlysta', 'powder for solution', 'L04AA26', false, 0, '02370069', 'FreeDiams::CA_HCDPD::DIN', 85509);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Laneige Snow Bb Cream', 'cream', 'D02BA30', false, 0, '02370123', 'FreeDiams::CA_HCDPD::DIN', 85515);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Actonel Dr', 'tablet (delayed-release)', 'M05BA07', false, 0, '02370417', 'FreeDiams::CA_HCDPD::DIN', 85557);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Twynsta', 'tablet', 'C09DB04', false, 0, '02371022', 'FreeDiams::CA_HCDPD::DIN', 85622);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Twynsta', 'tablet', 'C09DB04', false, 0, '02371030', 'FreeDiams::CA_HCDPD::DIN', 85623);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Twynsta', 'tablet', 'C09DB04', false, 0, '02371049', 'FreeDiams::CA_HCDPD::DIN', 85624);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Twynsta', 'tablet', 'C09DB04', false, 0, '02371057', 'FreeDiams::CA_HCDPD::DIN', 85625);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Zytiga', 'tablet', 'L02BX03', false, 0, '02371065', 'FreeDiams::CA_HCDPD::DIN', 85626);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Victrelis Triple', 'kit', 'L03AB60', false, 0, '02371448', 'FreeDiams::CA_HCDPD::DIN', 85660);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Victrelis Triple', 'kit', 'L03AB60', false, 0, '02371456', 'FreeDiams::CA_HCDPD::DIN', 85661);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Victrelis Triple', 'kit', 'L03AB60', false, 0, '02371464', 'FreeDiams::CA_HCDPD::DIN', 85662);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Victrelis Triple', 'kit', 'L03AB60', false, 0, '02371472', 'FreeDiams::CA_HCDPD::DIN', 85663);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Pharma-D 50000 Iu', 'capsule', 'A11CC05', false, 0, '02371502', 'FreeDiams::CA_HCDPD::DIN', 85666);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Largal Ultra', 'liquid', NULL, false, 0, '00229636', 'FreeDiams::CA_HCDPD::DIN', 1248);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Dso Dressing', 'liquid', NULL, false, 0, '00232661', 'FreeDiams::CA_HCDPD::DIN', 1291);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Neutralite Liq', 'liquid', NULL, false, 0, '00313467', 'FreeDiams::CA_HCDPD::DIN', 1958);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Hepartichaut Tab', 'tablet', NULL, false, 0, '00394874', 'FreeDiams::CA_HCDPD::DIN', 2981);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Regubil', 'tablet', NULL, false, 0, '00557110', 'FreeDiams::CA_HCDPD::DIN', 5276);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Air X 15 Disinfectant Cleaner', 'liquid', NULL, false, 0, '00638854', 'FreeDiams::CA_HCDPD::DIN', 8428);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Air X 78 Disinfectant Cleaner', 'liquid', NULL, false, 0, '00638870', 'FreeDiams::CA_HCDPD::DIN', 8429);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Delflex A Periton.Dial.Soln. W.2.5% Dextrose', 'solution', NULL, false, 0, '02025485', 'FreeDiams::CA_HCDPD::DIN', 15763);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Delflex A Periton.Dial.Soln.W.4.25% Dextrose', 'solution', NULL, false, 0, '02025507', 'FreeDiams::CA_HCDPD::DIN', 15764);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Delflex Perit.Dial.Sol.1.5%Dex.Low Ca Low Mg', 'solution', NULL, false, 0, '02025531', 'FreeDiams::CA_HCDPD::DIN', 15768);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Delflex Perit.Dial.Sol.2.5%Dex.Low Ca Low Mg', 'solution', NULL, false, 0, '02025523', 'FreeDiams::CA_HCDPD::DIN', 15769);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Delflex Perit.Dial.Sol.4.25%Dex.Low Calow Mg', 'solution', NULL, false, 0, '02025930', 'FreeDiams::CA_HCDPD::DIN', 15772);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Delflex A Periton.Dial.Soln.W.1.5% Dextrose', 'solution', NULL, false, 0, '02025477', 'FreeDiams::CA_HCDPD::DIN', 15778);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Cuivre-Or-Argent Oligosol', 'liquid', NULL, false, 0, '00657867', 'FreeDiams::CA_HCDPD::DIN', 15975);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Aliquat Liq 10%', 'liquid', NULL, false, 0, '02094835', 'FreeDiams::CA_HCDPD::DIN', 16053);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Super Zone', 'liquid', NULL, false, 0, '02160617', 'FreeDiams::CA_HCDPD::DIN', 19111);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Ix-91', 'liquid', NULL, false, 0, '02224046', 'FreeDiams::CA_HCDPD::DIN', 37925);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Friar''S Balsam Benzoin Tincture', 'tincture', NULL, false, 0, '00545279', 'FreeDiams::CA_HCDPD::DIN', 41578);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Allergenic Extract - Standardized Mite Mix', 'liquid', NULL, false, 0, '02231325', 'FreeDiams::CA_HCDPD::DIN', 50632);
INSERT INTO staging.branded_drug (description, preparation, atc_code, is_fake, fk_data_source, external_code, external_code_type, drug_code) VALUES ('Traditional Laxative', 'capsule', NULL, false, 0, '02236890', 'FreeDiams::CA_HCDPD::DIN', 60180);


--
-- PostgreSQL database dump complete
--

--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = staging, pg_catalog;

--
-- Data for Name: ingred; Type: TABLE DATA; Schema: staging; Owner: gm-dbo
--

INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9518, 3182, 'OXYQUINOLINE', 'I', 0.5, '%', '', '', 'N', '', '8-HYDROXYQUINOLINE 0.4% CHG TO 0.5% AS PER VDD 2006.04.05');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10804, 3182, 'OXYQUINOLINE', 'I', 0.14, '%', '', '', 'N', '%', 'Historic Freeform Text: 8-HYDROXYQUINOLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1338, 3047, 'ALDIOXA', 'I', 0.2, '%', '', '', 'N', '', 'Historic Freeform Text: ALDIOXA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 3049, 'MANGANESE OXIDE', 'I', 15, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: MANGANESE OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37569, 9697, 'MEGLUMINE IODIPAMIDE', 'I', 52, '%', '', '', 'N', '', 'Historic Freeform Text: MEGLUMINE IODIPAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37573, 9697, 'MEGLUMINE IODIPAMIDE', 'I', 26.9, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: MEGLUMINE IODIPAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 9699, 'EUGENOL', 'I', 0.034, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS FRAGRANCE MIX 0.35MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4875, 9699, 'EUGENOL', 'I', 13.7, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: EUGENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11456, 9627, 'ISOSORBIDE DINITRATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: ISOSORBIDE DINITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11457, 9627, 'ISOSORBIDE DINITRATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: ISOSORBIDE DINITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6550, 9627, 'ISOSORBIDE DINITRATE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ISOSORBIDE DINITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4730, 9627, 'ISOSORBIDE DINITRATE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ISOSORBIDE DINITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4731, 9627, 'ISOSORBIDE DINITRATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: ISOSORBIDE DINITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5180, 9627, 'ISOSORBIDE DINITRATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: ISOSORBIDE DINITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5179, 9627, 'ISOSORBIDE DINITRATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: ISOSORBIDE DINITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2748, 9629, 'GUANETHIDINE SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: GUANETHIDINE ((MONOSULPHATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2749, 9629, 'GUANETHIDINE SULFATE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: GUANETHIDINE ((MONOSULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26536, 9590, 'ACETANILIDE', 'I', 15, 'G', '', '95', 'N', 'G', 'Historic Freeform Text: ACETANILIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11889, 9590, 'ACETANILIDE', 'I', 15, 'G', '', '95', 'N', 'G', 'Historic Freeform Text: ACETANILIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1765, 9590, 'ACETANILIDE', 'I', 160.0, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: ACETANILIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2148, 9613, 'DIPHENYLPYRALINE HYDROCHLORIDE', 'I', 1.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENYLPYRALINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2149, 9613, 'DIPHENYLPYRALINE HYDROCHLORIDE', 'I', 0.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENYLPYRALINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2150, 9613, 'DIPHENYLPYRALINE HYDROCHLORIDE', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENYLPYRALINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37150, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19103, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4468, 9615, 'GUAIFENESIN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65822, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70399, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71091, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71201, 9615, 'GUAIFENESIN', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76681, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76178, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76236, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78062, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77185, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81657, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82152, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79088, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83056, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83303, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83304, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83878, 9615, 'GUAIFENESIN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83879, 9615, 'GUAIFENESIN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83880, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65633, 9615, 'GUAIFENESIN', 'I', 400, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41646, 9615, 'GUAIFENESIN', 'I', 50, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41988, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41989, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42606, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36293, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36232, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34650, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30826, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30557, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28683, 9615, 'GUAIFENESIN', 'I', 33.33, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27461, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27463, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19772, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19690, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19625, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19060, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19044, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19026, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18910, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '15', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16698, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16662, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15618, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13565, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13494, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13479, 9615, 'GUAIFENESIN', 'I', 221, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13453, 9615, 'GUAIFENESIN', 'I', 500, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13454, 9615, 'GUAIFENESIN', 'I', 500, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13440, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14486, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14485, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13296, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12449, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11001, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12717, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12192, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70443, 5446, 'CLOROPHENE', 'I', 5.45, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12620, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11918, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73982, 2813, 'TRICLOSAN', 'I', 0.55, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4252, 9615, 'GUAIFENESIN', 'I', 50, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4258, 9615, 'GUAIFENESIN', 'I', 50, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1980, 9615, 'GUAIFENESIN', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GUAIACOL GLYCERYL ETHER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (956, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIACOL GLYCERYL ETHER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1498, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIACOL GLYCERYL ETHER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52513, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52514, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60207, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66724, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66840, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66851, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65015, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66947, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66983, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65128, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65129, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65130, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65131, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67954, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68034, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68035, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69813, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69814, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76388, 9615, 'GUAIFENESIN', 'I', 50, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75087, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75088, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75089, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72923, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75515, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75516, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74333, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74432, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74797, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74852, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74853, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73724, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77454, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77475, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80636, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80637, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79002, 9615, 'GUAIFENESIN', 'I', 400, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80682, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80928, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80935, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80938, 9615, 'GUAIFENESIN', 'I', 200, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83190, 9615, 'GUAIFENESIN', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2480, 9615, 'GUAIFENESIN', 'I', 31.75, 'G', '', '454', 'N', 'G', 'Historic Freeform Text: GUAIFENESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2195, 9615, 'GUAIFENESIN', 'I', 31.75, 'G', '', '454', 'N', 'G', 'Historic Freeform Text: GUAIACOL GLYCERYL ETHER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16653, 9542, 'NAPHAZOLINE HYDROCHLORIDE', 'I', 0.025, '%', '', '', 'N', '', 'Historic Freeform Text: NAPHAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8155, 9542, 'NAPHAZOLINE HYDROCHLORIDE', 'I', 0.02675, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NAPHAZOLINE HYDROCHLORIDE. 970822: CHANGED CONCENTRATION FROM 0.025% TO 0.02');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3743, 9542, 'NAPHAZOLINE HYDROCHLORIDE', 'I', 0.025, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NAPHAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3028, 9542, 'NAPHAZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: NAPHAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66582, 9542, 'NAPHAZOLINE HYDROCHLORIDE', 'I', 0.025, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72379, 9542, 'NAPHAZOLINE HYDROCHLORIDE', 'I', 0.012, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72380, 9542, 'NAPHAZOLINE HYDROCHLORIDE', 'I', 0.012, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78028, 9542, 'NAPHAZOLINE HYDROCHLORIDE', 'I', 0.012, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80140, 9542, 'NAPHAZOLINE HYDROCHLORIDE', 'I', 0.051, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80143, 9542, 'NAPHAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84583, 9542, 'NAPHAZOLINE HYDROCHLORIDE', 'I', 0.03, '%', '', '', 'N', 'W/W', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8526, 9542, 'NAPHAZOLINE HYDROCHLORIDE', 'I', 0.012, '%', '', '', 'N', 'W/V', 'Historic Freeform Text: NAPHAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17734, 9542, 'NAPHAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '%', 'Historic Freeform Text: NAPHAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6772, 9542, 'NAPHAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '%', 'Historic Freeform Text: NAPHAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (934, 9542, 'NAPHAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '%', 'Historic Freeform Text: NAPHAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2634, 9542, 'NAPHAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '%', 'Historic Freeform Text: NAPHAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33329, 9542, 'NAPHAZOLINE HYDROCHLORIDE', 'I', 0.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NAPHAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63128, 9543, 'METHACHOLINE CHLORIDE', 'I', 100, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67775, 9543, 'METHACHOLINE CHLORIDE', 'I', 1280, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70667, 9543, 'METHACHOLINE CHLORIDE', 'I', 160, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70668, 9543, 'METHACHOLINE CHLORIDE', 'I', 320, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74930, 9543, 'METHACHOLINE CHLORIDE', 'I', 100, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74931, 9543, 'METHACHOLINE CHLORIDE', 'I', 480, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74932, 9543, 'METHACHOLINE CHLORIDE', 'I', 1600, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77421, 9543, 'METHACHOLINE CHLORIDE', 'I', 1600, 'MG', '', '', 'N', 'VIAL', 'VIAL WITH WHITE FLIP OFF SEAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15491, 9547, 'MANNITOL', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: MANNITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10516, 9547, 'MANNITOL', 'I', 20, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MANNITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10517, 9547, 'MANNITOL', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: MANNITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9829, 9547, 'MANNITOL', 'I', 500, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MANNITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3823, 9547, 'MANNITOL', 'I', 5.4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MANNITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1740, 9547, 'MANNITOL', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MANNITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1181, 9547, 'MANNITOL', 'I', 250, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MANNITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67055, 9547, 'MANNITOL', 'I', 250, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MANNITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (959, 9556, 'BUSULFAN', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BUSULFAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64173, 9556, 'BUSULFAN', 'I', 6, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2092, 9563, 'TOLBUTAMIDE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: TOLBUTAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70553, 5446, 'CLOROPHENE', 'I', 3.75, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (697, 9580, 'TRICHLORMETHIAZIDE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRICHLORMETHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4774, 9580, 'TRICHLORMETHIAZIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRICHLORMETHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13952, 7636, 'DOLICHOVESPULA ARENARIA VENOM PROTEIN EXTRACT', 'I', 120, 'µG', '', '', 'N', 'VIAL', 'Historic Freeform Text: DOLICHOVESPULA ARENARIA VENOM PROTEIN EXTRACT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46470, 7636, 'DOLICHOVESPULA ARENARIA VENOM PROTEIN EXTRACT', 'I', 1.1, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: DOLICHOVESPULA ARENARIA VENOM PROTEIN EXTRACT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13951, 7637, 'VESPULA SPP VENOM PROTEIN EXTRACT', 'I', 120, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: VESPULA SPP VENOM PROTEIN EXTRACT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50137, 7637, 'VESPULA SPP VENOM PROTEIN EXTRACT', 'I', 1300, 'µG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14598, 7637, 'VESPULA SPP VENOM PROTEIN EXTRACT', 'I', 1.1, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: VESPULA SPP VENOM PROTEIN EXTRACT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15874, 7638, 'DOLICHOVESPULA MACULATA VENOM PROTEIN EXTRACT', 'I', 120, 'µG', '', '', 'N', 'VIAL', 'Historic Freeform Text: DOLICHOVESPULA MACULATA VENOM PROTEIN EXTRACT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46471, 7638, 'DOLICHOVESPULA MACULATA VENOM PROTEIN EXTRACT', 'I', 1.1, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: DOLICHOVESPULA MACULATA VENOM PROTEIN EXTRACT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13950, 7639, 'POLISTES SPP VENOM PROTEIN EXTRACT', 'I', 120, 'µG', '', '', 'N', 'VIAL', 'Historic Freeform Text: POLISTES SPP VENOM PROTEIN EXTRACT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50138, 7639, 'POLISTES SPP VENOM PROTEIN EXTRACT', 'I', 1300, 'µG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14597, 7639, 'POLISTES SPP VENOM PROTEIN EXTRACT', 'I', 1.1, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: POLISTES SPP VENOM PROTEIN EXTRACT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14601, 7640, 'APIS MELLIFERA VENOM PROTEIN EXTRACT', 'I', 120, 'µG', '', '', 'N', 'VIAL', 'Historic Freeform Text: APIS MELLIFERA VENOM PROTEIN EXTRACT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50133, 7640, 'APIS MELLIFERA VENOM PROTEIN EXTRACT', 'I', 1300, 'µG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14602, 7640, 'APIS MELLIFERA VENOM PROTEIN EXTRACT', 'I', 1.1, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: APIS MELLIFERA VENOM PROTEIN EXTRACT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19685, 7644, 'PORFIMER SODIUM', 'I', 75, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: PORFIMER SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19686, 7644, 'PORFIMER SODIUM', 'I', 15, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: PORFIMER SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (55838, 7645, 'LYMPHOCYTE IMMUNE GLOBULIN ANTI-THYMOCYTE GLOBULIN (EQUINE)', 'I', 50, 'MG', '', '', 'N', 'ML', 'NO PRESERVATIVE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76152, 7650, 'INSULIN ISOPHANE INJECTION PORK', 'I', 100, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13140, 7652, 'TETANUS PROTEIN', 'I', 20, 'µG', '', '0.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: TETANUS PROTEIN 20 MCG PER SINGLE-DOSE VIAL, 5 VIALS PER KIT  STRENGTH VALUE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50651, 7652, 'TETANUS PROTEIN', 'I', 20, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67042, 7652, 'TETANUS PROTEIN', 'I', 20, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44019, 7654, 'INACTIVATED POLIOMYELITIS VACCINE (V.C.O.) TYPE 2 MEF1', 'I', 8, 'UNIT', '', '0.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: INACTIV.POLIOM.VAC.(V.C.O.) TYPE 2 (MEF1) UNIT IS  D ANTIGEN UNITS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12474, 7657, 'FILGRASTIM (R-METHUG-CSF)', 'I', 300, 'µG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: FILGRASTIM (R-METHUG-CSF)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76153, 7659, 'INSULIN INJECTION PORK', 'I', 100, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43205, 7660, 'DERMATOPHAGOIDES FARINAE', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '10000 AU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37351, 7660, 'DERMATOPHAGOIDES FARINAE', 'I', 10000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MITE (DERMATOPHAGOI.FARINAE, 10000 AU/ML)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37352, 7660, 'DERMATOPHAGOIDES FARINAE', 'I', 30000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MITE (DERMATOPHAGOI.FARINAE, 30000 AU/ML)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37353, 7660, 'DERMATOPHAGOIDES FARINAE', 'I', 15000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MITE (DERMATOPHAGOI.FARINAE, 15000 AU/ML)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37354, 7660, 'DERMATOPHAGOIDES FARINAE', 'I', 5000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MITE (DERMATOPHAGOID.FARINAE, 5000 AU/ML)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50628, 7660, 'DERMATOPHAGOIDES FARINAE', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '10000 BAU/ML.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50632, 7660, 'DERMATOPHAGOIDES FARINAE', 'I', 5000, 'UNIT', '', '', 'N', 'ML', '5000 BAU/ML.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75630, 7660, 'DERMATOPHAGOIDES FARINAE', 'I', 5000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DERMATOPHAGOIDES FARINAE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1581, 7606, 'BETAMETHASONE ACETATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: BETAMETHASONE 21-ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (354, 7606, 'BETAMETHASONE ACETATE', 'I', 3, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BETAMETHASONE 21-ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61194, 7606, 'BETAMETHASONE ACETATE', 'I', 3, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19225, 7610, 'BETAMETHASONE (BETAMETHASONE VALERATE)', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BETAMETHASONE 17-VALERATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13888, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: BETAMETHASONE DIPROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13889, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BETAMETHASONE DIPROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10941, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: BETAMETHASONE DIPROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10748, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BETAMETHASONE DIPROPIONATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8972, 7610, 'BETAMETHASONE (BETAMETHASONE VALERATE)', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BETAMETHASONE 17-VALERATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6620, 7610, 'BETAMETHASONE (BETAMETHASONE VALERATE)', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BETAMETHASONE 17-VALERATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6822, 7610, 'BETAMETHASONE (BETAMETHASONE VALERATE)', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BETAMETHASONE 17-VALERATE ((BASE 0.5MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3718, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BETAMETHASONE DIPROPIONATE  2011.04.29.  BETAMETHASONE 0.05%, SUPPLIED AS BE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3719, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BETAMETHASONE DIPROPIONATE  2011.04.29.  BETAMETHASONE 0.05%, SUPPLIED AS BE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1147, 7610, 'BETAMETHASONE (BETAMETHASONE VALERATE)', 'I', 0.1, '%', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: BETAMETHASONE 17-VALERATE ((BETAMETHASONE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (816, 7610, 'BETAMETHASONE (BETAMETHASONE VALERATE)', 'I', 0.1, '%', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: BETAMETHASONE 17-VALERATE ((BETAMETHASONE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14132, 7610, 'BETAMETHASONE (BETAMETHASONE VALERATE)', 'I', 0.1, '%', '', '', 'Y', '%', 'Historic Freeform Text: BETAMETHASONE 17-VALERATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13005, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.05, '%', '', '', 'Y', '%', 'Historic Freeform Text: BETAMETHASONE DIPROPIONATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27517, 7610, 'BETAMETHASONE (BETAMETHASONE SODIUM PHOSPHATE)', 'I', 5, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BETAMETHASONE ((AS SODIUM PHOSPHATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6528, 7610, 'BETAMETHASONE (BETAMETHASONE VALERATE)', 'I', 0.284, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: BETAMETHASONE VALERATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7418, 7610, 'BETAMETHASONE (BETAMETHASONE SODIUM PHOSPHATE)', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: BETAMETHASONE DISOD PHOS ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (354, 7610, 'BETAMETHASONE (BETAMETHASONE SODIUM PHOSPHATE)', 'I', 3, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BETAMETHASONE DISODIUM PHOSPHATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61194, 7610, 'BETAMETHASONE (BETAMETHASONE 21-DISODIUM PHOSPHATE)', 'I', 3, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68998, 7610, 'BETAMETHASONE (BETAMETHASONE SODIUM PHOSPHATE)', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13690, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: BETAMETHASONE DIPROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14445, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.5, 'MG', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10940, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.5, 'MG', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10777, 7610, 'BETAMETHASONE (BETAMETHASONE VALERATE)', 'I', 1.0, 'MG', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9270, 7610, 'BETAMETHASONE (BETAMETHASONE VALERATE)', 'I', 0.5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: BETAMETHASONE 17-VALERATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10211, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: BETAMETHASONE ((AS DIPROPIONATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8190, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: BETAMETHASONE DIPROPIONATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6529, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.5, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: BETAMETHASONE DIPROPIONATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5561, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.5, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: BETAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5315, 7610, 'BETAMETHASONE (BETAMETHASONE SODIUM PHOSPHATE)', 'I', 1, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: BETAMETHASONE SOD PHOSPH ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5287, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: BETAMETHASONE ((DIPROPIONATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1285, 7610, 'BETAMETHASONE (BETAMETHASONE VALERATE)', 'I', 1, 'MG', '', '', 'Y', 'G', 'HISTORIC FREEFORM TEXT: BETAMETHASONE VALERATE ((BETAMETHASONE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68084, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.5, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69789, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: BETAMETHASONE ((DIPROPIONATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76041, 7610, 'BETAMETHASONE (BETAMETHASONE VALERATE)', 'I', 1, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80450, 7610, 'BETAMETHASONE (BETAMETHASONE DIPROPIONATE)', 'I', 0.5, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16234, 7617, 'PREDNISOLONE ACETATE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PREDNISOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16625, 7617, 'PREDNISOLONE ACETATE', 'I', 0.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PREDNISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14126, 7617, 'PREDNISOLONE ACETATE', 'I', 0.12, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PREDNISOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13946, 7617, 'PREDNISOLONE ACETATE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PREDNISOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10169, 7617, 'PREDNISOLONE ACETATE', 'I', 0.2, '%', '', '', 'N', '', 'Historic Freeform Text: PREDNISOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7042, 7617, 'PREDNISOLONE ACETATE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: PREDNISOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1971, 7617, 'PREDNISOLONE ACETATE', 'I', 0.2, '%', '', '', 'N', '', 'Historic Freeform Text: PREDNISOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1936, 7617, 'PREDNISOLONE ACETATE', 'I', 0.12, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PREDNISOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1937, 7617, 'PREDNISOLONE ACETATE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: PREDNISOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15495, 7617, 'PREDNISOLONE ACETATE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PREDNISOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10300, 7617, 'PREDNISOLONE ACETATE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PREDNISOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6365, 7617, 'PREDNISOLONE ACETATE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PREDNISOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5744, 7617, 'PREDNISOLONE ACETATE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PREDNISOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1999, 7617, 'PREDNISOLONE ACETATE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PREDNISOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1504, 7617, 'PREDNISOLONE ACETATE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PREDNISOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16649, 7617, 'PREDNISOLONE ACETATE', 'I', 5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PREDNISOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1396, 7626, 'METHYLPREDNISOLONE', 'I', 16, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: 6-@-METHYLPREDNISOLONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1397, 7626, 'METHYLPREDNISOLONE', 'I', 4, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: 6-@-METHYLPREDNISOLONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16743, 7626, 'METHYLPREDNISOLONE (METHYLPREDNISOLONE SODIUM SUCCINATE)', 'I', 1, 'G', '', '', 'Y', 'VIAL', 'Historic Freeform Text: METHYLPREDNISOLONE ((AS SODIUM SUCCINATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1130, 7626, 'METHYLPREDNISOLONE (METHYLPREDNISOLONE SODIUM SUCCINATE)', 'I', 1, 'G', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: 6-A-METHYLPREDNISOLONE 21-SOD SUCC ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52242, 7626, 'METHYLPREDNISOLONE', 'I', 1, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19021, 7626, 'METHYLPREDNISOLONE (METHYLPREDNISOLONE SODIUM SUCCINATE)', 'I', 500, 'MG', '', '', 'Y', 'VIAL', 'Historic Freeform Text: METHYLPREDNISOLONE ((AS SODIUM SUCCINATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16742, 7626, 'METHYLPREDNISOLONE (METHYLPREDNISOLONE SODIUM SUCCINATE)', 'I', 40, 'MG', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: METHYLPREDNISOLONE ((AS SODIUM SUCCINATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16710, 7626, 'METHYLPREDNISOLONE (METHYLPREDNISOLONE SODIUM SUCCINATE)', 'I', 125, 'MG', '', '', 'Y', 'VIAL', 'Historic Freeform Text: METHYLPREDNISOLONE ((AS SODIUM SUCCINATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1132, 7626, 'METHYLPREDNISOLONE (METHYLPREDNISOLONE SODIUM SUCCINATE)', 'I', 500, 'MG', '', '', 'Y', 'VIAL', 'Historic Freeform Text: 6-A-METHYLPREDNISOLONE 21-SOD SUCC ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51346, 7626, 'METHYLPREDNISOLONE (METHYLPREDNISOLONE SODIUM SUCCINATE)', 'I', 40, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51347, 7626, 'METHYLPREDNISOLONE (METHYLPREDNISOLONE SODIUM SUCCINATE)', 'I', 125, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51348, 7626, 'METHYLPREDNISOLONE (METHYLPREDNISOLONE SODIUM SUCCINATE)', 'I', 500, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52240, 7626, 'METHYLPREDNISOLONE', 'I', 500, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64837, 7626, 'METHYLPREDNISOLONE (METHYLPREDNISOLONE SODIUM SUCCINATE)', 'I', 1000, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18750, 7627, 'PREDNISOLONE SODIUM PHOSPHATE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: PREDNISOLONE PHOSPHATE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13075, 7627, 'PREDNISOLONE SODIUM PHOSPHATE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: PREDNISOLONE PHOSPHATE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7626, 7576, 'FLUOROMETHOLONE', 'I', 0.25, '%', '', '', 'N', '', 'Historic Freeform Text: FLUOROMETHOLONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1470, 7576, 'FLUOROMETHOLONE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: FLUOROMETHOLONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61995, 7576, 'FLUOROMETHOLONE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8229, 7577, 'FLUOROMETHOLONE ACETATE', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUOROMETHOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43534, 7581, 'BUDESONIDE', 'I', 3, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUDESONIDE Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16264, 7581, 'BUDESONIDE', 'I', 2.3, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BUDESONIDE  (TABLET)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14570, 7581, 'BUDESONIDE', 'I', 100, 'µG', '', '', 'N', 'ACT', 'Historic Freeform Text: BUDESONIDE Qty Unit: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12182, 7581, 'BUDESONIDE', 'I', 400, 'µG', '', '', 'N', 'ACT', 'Historic Freeform Text: BUDESONIDE Qty Unit: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10666, 7581, 'BUDESONIDE', 'I', 200, 'µG', '', '', 'N', 'ACT', 'Historic Freeform Text: BUDESONIDE Qty Unit: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10667, 7581, 'BUDESONIDE', 'I', 100, 'µG', '', '', 'N', 'ACT', 'HISTORIC FREEFORM TEXT: BUDESONIDE QTY UNIT: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51375, 7581, 'BUDESONIDE', 'I', 64, 'µG', '', '', 'N', 'ACT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49895, 7581, 'BUDESONIDE', 'I', 100, 'µG', '', '', 'N', 'ACT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64595, 7581, 'BUDESONIDE', 'I', 64, 'µG', '', '', 'N', 'ACT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69428, 7581, 'BUDESONIDE', 'I', 100, 'µG', '', '', 'N', 'DOSE', 'Historic Freeform Text: BUDESONIDE Qty Unit: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69429, 7581, 'BUDESONIDE', 'I', 200, 'µG', '', '', 'N', 'DOSE', 'Historic Freeform Text: BUDESONIDE Qty Unit: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43511, 7581, 'BUDESONIDE', 'I', 0.125, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BUDESONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13191, 7581, 'BUDESONIDE', 'I', 0.25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: BUDESONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13190, 7581, 'BUDESONIDE', 'I', 0.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: BUDESONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35794, 7582, 'TRIAMCINOLONE HEXACETONIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIAMCINOLONE HEXACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70589, 5446, 'CLOROPHENE', 'I', 5.32, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13276, 7587, 'TRIAMCINOLONE DIACETATE', 'I', 40, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: TRIAMCINOLONE 16 @-21 DIACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35783, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35784, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35785, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 0.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9278, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 0.025, '%', '', '', 'N', '', 'Historic Freeform Text: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8573, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19807, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 55, 'µG', '', '', 'N', 'DOSE', 'HISTORIC FREEFORM TEXT: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13157, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 100, 'µG', '', '', 'N', 'DOSE', 'HISTORIC FREEFORM TEXT: TRIAMCINOLONE ACETONIDE QTY UNIT: AEM DOSAGE UNIT CHANGED FROM ACT TO DOSE A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75280, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13360, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 0.1, '%', '', '', 'N', '%', 'Historic Freeform Text: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16174, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 0.86, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15481, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15482, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13998, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12174, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47450, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47461, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15598, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 1, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11867, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 1, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12862, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 1, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9280, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 1, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9448, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 1, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9449, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 1, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TRIAMCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84909, 7588, 'TRIAMCINOLONE ACETONIDE', 'I', 1, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43314, 7592, 'DESOXIMETASONE', 'I', 0.25, '%', '', '', 'N', '', 'Historic Freeform Text: DESOXIMETASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43315, 7592, 'DESOXIMETASONE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DESOXIMETASONE OF 0.5 MG/G  IN ORDER TO BE CONSISTEN BETWEEN PM, LABEL, AND ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43317, 7592, 'DESOXIMETASONE', 'I', 0.25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DESOXIMETASONE 0.25MG/G  IN ORDER TO BE CONSISTEN BETWEEN PM, LABEL, AND OTH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62520, 7592, 'DESOXIMETASONE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62523, 7592, 'DESOXIMETASONE', 'I', 0.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65557, 7592, 'DESOXIMETASONE', 'I', 0.05, '%', '', '', 'N', '', '0.05% W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43316, 7592, 'DESOXIMETASONE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DESOXIMETASONE ------------------------------------------------------WHEN DI');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16262, 7598, 'DEXAMETHASONE SODIUM PHOSPHATE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: DEXAMETHASONE 21-PHOSPHATE DISODIUM SALT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6364, 7598, 'DEXAMETHASONE SODIUM PHOSPHATE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: DEXAMETHASONE 21-PHOSPHATE DISODIUM SALT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12640, 7598, 'DEXAMETHASONE SODIUM PHOSPHATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXAMETHASONE 21-PHOSPHATE DISODIUM SALT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7795, 7598, 'DEXAMETHASONE SODIUM PHOSPHATE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXAMETHASONE 21-PHOSPHATE DISODIUM SALT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6368, 7598, 'DEXAMETHASONE SODIUM PHOSPHATE', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXAMETHASONE 21-PHOSPHATE DISODIUM SALT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5502, 7598, 'DEXAMETHASONE SODIUM PHOSPHATE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXAMETHASONE 21-PHOSPHATE DISODIUM SALT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79961, 7598, 'DEXAMETHASONE SODIUM PHOSPHATE', 'I', 5.0, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23260, 7600, 'DEXAMETHASONE', 'I', 0.75, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23261, 7600, 'DEXAMETHASONE', 'I', 0.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23194, 7600, 'DEXAMETHASONE', 'I', 4, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10576, 7600, 'DEXAMETHASONE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3661, 7600, 'DEXAMETHASONE', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (697, 7600, 'DEXAMETHASONE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1899, 7600, 'DEXAMETHASONE', 'I', 0.75, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1887, 7600, 'DEXAMETHASONE', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60349, 7600, 'DEXAMETHASONE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60347, 7600, 'DEXAMETHASONE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60348, 7600, 'DEXAMETHASONE', 'I', 0.75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64268, 7600, 'DEXAMETHASONE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64271, 7600, 'DEXAMETHASONE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63010, 7600, 'DEXAMETHASONE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76497, 7600, 'DEXAMETHASONE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74650, 7600, 'DEXAMETHASONE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73487, 7600, 'DEXAMETHASONE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79685, 7600, 'DEXAMETHASONE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84844, 7600, 'DEXAMETHASONE', 'I', 0.7, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11068, 7600, 'DEXAMETHASONE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10971, 7600, 'DEXAMETHASONE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4591, 7600, 'DEXAMETHASONE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2620, 7600, 'DEXAMETHASONE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73758, 7600, 'DEXAMETHASONE', 'I', 0.1, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2790, 7600, 'DEXAMETHASONE', 'I', 10, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37363, 7600, 'DEXAMETHASONE (DEXAMETHASONE SODIUM METASULPHOBENZOATE)', 'I', 0.5, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: DEXAMETHASONE ((AS NA METASULPHOBENZO. AN))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16624, 7600, 'DEXAMETHASONE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12967, 7600, 'DEXAMETHASONE', 'I', 0.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13146, 7600, 'DEXAMETHASONE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12208, 7600, 'DEXAMETHASONE (DEXAMETHASONE SODIUM PHOSPHATE)', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXMETH SOD PHOSPH ((DEXMETH PHOSPH EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5700, 7600, 'DEXAMETHASONE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2008, 7600, 'DEXAMETHASONE (DEXAMETHASONE SODIUM PHOSPHATE)', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXAMETHASONE SODIUM PHOSPHATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (259, 7600, 'DEXAMETHASONE', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72229, 7600, 'DEXAMETHASONE (DEXAMETHASONE SODIUM METASULPHOBENZOATE)', 'I', 0.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63299, 9437, 'PAMABROM', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69692, 7600, 'DEXAMETHASONE (DEXAMETHASONE SODIUM PHOSPHATE)', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74552, 7600, 'DEXAMETHASONE', 'I', 0.5, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83919, 7600, 'DEXAMETHASONE (DEXAMETHASONE ACETATE)', 'I', 0.9, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16648, 7600, 'DEXAMETHASONE', 'I', 1, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9566, 7600, 'DEXAMETHASONE', 'I', 10, 'MG', '', '15', 'N', 'G', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1251, 7600, 'DEXAMETHASONE', 'I', 10, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2423, 7600, 'DEXAMETHASONE', 'I', 1, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2977, 7600, 'DEXAMETHASONE', 'I', 1, 'MG', '', '1', 'N', 'G', 'Historic Freeform Text: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83457, 7600, 'DEXAMETHASONE', 'I', 10, 'MG', '', '15', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4774, 7602, 'DEXAMETHASONE ACETATE', 'I', 0.55, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXAMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2272, 7603, 'BETAMETHASONE DIPROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: BETAMETHASONE DIPROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2870, 7603, 'BETAMETHASONE DIPROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: BETAMETHASONE DIPROPIONATE ((EQ 0.05% BASE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36947, 5325, 'LEVOTHYROXINE SODIUM', 'I', 150, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2071, 7603, 'BETAMETHASONE DIPROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BETAMETHASONE DIPROPIONATE ((BASE 0.5MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18006, 7603, 'BETAMETHASONE DIPROPIONATE', 'I', 0.05, '%', '', '', 'N', '%', 'Historic Freeform Text: BETAMETHASONE DIPROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18007, 7603, 'BETAMETHASONE DIPROPIONATE', 'I', 0.05, '%', '', '', 'N', '%', 'Historic Freeform Text: BETAMETHASONE DIPROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18008, 7603, 'BETAMETHASONE DIPROPIONATE', 'I', 0.05, '%', '', '', 'N', '%', 'Historic Freeform Text: BETAMETHASONE DIPROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18009, 7603, 'BETAMETHASONE DIPROPIONATE', 'I', 0.05, '%', '', '', 'N', '%', 'Historic Freeform Text: BETAMETHASONE DIPROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17992, 7603, 'BETAMETHASONE DIPROPIONATE', 'I', 0.05, '%', '', '', 'N', '%', 'Historic Freeform Text: BETAMETHASONE DIPROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17968, 7603, 'BETAMETHASONE DIPROPIONATE', 'I', 0.05, '%', '', '', 'N', '%', 'Historic Freeform Text: BETAMETHASONE DIPROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12272, 7603, 'BETAMETHASONE DIPROPIONATE', 'I', 0.5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: BETAMETHASONE DIPROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43483, 7573, 'FLUMETHASONE', 'I', 0.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: FLUMETHASONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43299, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 2.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MEDROXYPROGESTERONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43300, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MEDROXYPROGESTERONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43301, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MEDROXYPROGESTERONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13037, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13592, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14529, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7480, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (675, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (430, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66710, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 2.5, 'MG', '', '', 'N', '', 'BLISTER CARD CONTAINING WHITE 2.5MG ''MPA'' TABLETS. (TABLET #2)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66711, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 5.0, 'MG', '', '', 'N', '', 'BLISTER CARD CONTAINING PURPLE 5.0MG ''MPA'' TABLETS. (TABLET #2)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68715, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68716, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70819, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 2.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MEDROXYPROGESTERONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70820, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MEDROXYPROGESTERONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70821, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MEDROXYPROGESTERONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71837, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 2.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MEDROXYPROGESTERONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71839, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MEDROXYPROGESTERONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71840, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MEDROXYPROGESTERONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75305, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76294, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73852, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73853, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19667, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 150, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEDROXYPROGESTERONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (441, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MEDROXYPROGESTERONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80771, 7538, 'MEDROXYPROGESTERONE ACETATE', 'I', 150, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6664, 7542, 'ALTRENOGEST', 'I', 2.2, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ALTRENOGEST');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8268, 7543, 'MELENGESTROL ACETATE', 'I', 17.6, 'MG', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: MELENGESTROL ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10001, 7543, 'MELENGESTROL ACETATE', 'I', 220, 'MG', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: MELENGESTROL ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (621, 5503, 'MENTHYL SALICYLATE', 'I', 0.6, '%', '', '', 'N', '', 'Historic Freeform Text: MENTHYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36549, 5446, 'CLOROPHENE', 'I', 10.6, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19364, 5446, 'CLOROPHENE', 'I', 3.15, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20271, 5446, 'CLOROPHENE', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19302, 5446, 'CLOROPHENE', 'I', 3.6, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19768, 5446, 'CLOROPHENE', 'I', 8.5, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18412, 5446, 'CLOROPHENE', 'I', 2.75, '%', '', '', 'N', '', 'ISOPROPYL ALCOHOL 4.2%, SODIUM DODECYLBENZENESULFONATE 2.8%. AMD SODIUM EDETATE 1.84%  TAKEN OUT AS ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17426, 5446, 'CLOROPHENE', 'I', 0.7, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16133, 5446, 'CLOROPHENE', 'I', 3.56, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14368, 5446, 'CLOROPHENE', 'I', 3.75, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12396, 5446, 'CLOROPHENE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12247, 5446, 'CLOROPHENE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11343, 5446, 'CLOROPHENE', 'I', 8.5, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6212, 5446, 'CLOROPHENE', 'I', 8.5, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3829, 5446, 'CLOROPHENE', 'I', 1.72, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4201, 5446, 'CLOROPHENE', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3629, 5446, 'CLOROPHENE', 'I', 3.225, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3879, 5446, 'CLOROPHENE', 'I', 1.72, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3093, 5446, 'CLOROPHENE', 'I', 3.37, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50814, 5446, 'CLOROPHENE', 'I', 0.03, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60158, 5446, 'CLOROPHENE', 'I', 1.7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62881, 5446, 'CLOROPHENE', 'I', 10.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66340, 5446, 'CLOROPHENE', 'I', 5.32, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44068, 5416, 'L-CYSTEINE (L-CYSTEINE HYDROCHLORIDE)', 'I', 13.9, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CYSTEINE ((AS CYSTEINE HCL.H2O 0.019GM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15493, 5416, 'L-CYSTEINE (L-CYSTEINE HYDROCHLORIDE)', 'I', 13, 'MG', '', '100', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CYSTEINE ((AS CYS.HCL.H20 USPLESSTH..014G))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 5416, 'L-CYSTEINE', 'I', 189, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8986, 5401, 'POVIDONE-IODINE', 'I', 2, '%', '', '', 'N', '', 'W/W. HISTORIC FREEFORM TEXT: POLYVINYLPYRROLIDONE-IODINE COMPLEX.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5347, 5401, 'POVIDONE-IODINE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: POVIDONE IODINE ((IODINE 1% EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3668, 5401, 'POVIDONE-IODINE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: POVIDONE IODINE ((IODINE 1% EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69660, 5401, 'POVIDONE-IODINE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79127, 5401, 'POVIDONE-IODINE', 'I', 10, '%', '', '', 'N', '', '1% AVAILABLE IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12798, 5401, 'POVIDONE-IODINE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: POUIDONE IODINE ((IODINE FREE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9355, 5401, 'POVIDONE-IODINE', 'I', 10, '%', '', '', 'N', '%', 'Historic Freeform Text: POVIDONE IODINE ((IODINE 1% EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6398, 5401, 'POVIDONE-IODINE', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: POLYVINYLPYRROLIDONE-IODINE COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36945, 5325, 'LEVOTHYROXINE SODIUM', 'I', 50, 'µG', '', '', 'N', '', 'Historic Freeform Text: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36946, 5325, 'LEVOTHYROXINE SODIUM', 'I', 100, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36948, 5325, 'LEVOTHYROXINE SODIUM', 'I', 200, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36949, 5325, 'LEVOTHYROXINE SODIUM', 'I', 300, 'µG', '', '', 'N', '', 'Historic Freeform Text: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19587, 5325, 'LEVOTHYROXINE SODIUM', 'I', 50, 'µG', '', '', 'N', '', 'Historic Freeform Text: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19588, 5325, 'LEVOTHYROXINE SODIUM', 'I', 25, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19589, 5325, 'LEVOTHYROXINE SODIUM', 'I', 112, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19594, 5325, 'LEVOTHYROXINE SODIUM', 'I', 125, 'µG', '', '', 'N', '', 'Historic Freeform Text: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19595, 5325, 'LEVOTHYROXINE SODIUM', 'I', 75, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19596, 5325, 'LEVOTHYROXINE SODIUM', 'I', 300, 'µG', '', '', 'N', '', 'Historic Freeform Text: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19597, 5325, 'LEVOTHYROXINE SODIUM', 'I', 200, 'µG', '', '', 'N', '', 'Historic Freeform Text: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19598, 5325, 'LEVOTHYROXINE SODIUM', 'I', 150, 'µG', '', '', 'N', '', 'Historic Freeform Text: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19599, 5325, 'LEVOTHYROXINE SODIUM', 'I', 88, 'µG', '', '', 'N', '', 'Historic Freeform Text: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19600, 5325, 'LEVOTHYROXINE SODIUM', 'I', 175, 'µG', '', '', 'N', '', 'Historic Freeform Text: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19601, 5325, 'LEVOTHYROXINE SODIUM', 'I', 100, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53868, 5325, 'LEVOTHYROXINE SODIUM', 'I', 137, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74978, 5325, 'LEVOTHYROXINE SODIUM', 'I', 25, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74979, 5325, 'LEVOTHYROXINE SODIUM', 'I', 50, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74980, 5325, 'LEVOTHYROXINE SODIUM', 'I', 75, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74981, 5325, 'LEVOTHYROXINE SODIUM', 'I', 88, 'µG', '', '', 'N', '', 'Historic Freeform Text: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74982, 5325, 'LEVOTHYROXINE SODIUM', 'I', 100, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74984, 5325, 'LEVOTHYROXINE SODIUM', 'I', 112, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74985, 5325, 'LEVOTHYROXINE SODIUM', 'I', 125, 'µG', '', '', 'N', '', 'Historic Freeform Text: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74986, 5325, 'LEVOTHYROXINE SODIUM', 'I', 137, 'µG', '', '', 'N', '', 'Historic Freeform Text: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74987, 5325, 'LEVOTHYROXINE SODIUM', 'I', 150, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74988, 5325, 'LEVOTHYROXINE SODIUM', 'I', 175, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74989, 5325, 'LEVOTHYROXINE SODIUM', 'I', 200, 'µG', '', '', 'N', '', 'Historic Freeform Text: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74991, 5325, 'LEVOTHYROXINE SODIUM', 'I', 300, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18544, 5325, 'LEVOTHYROXINE SODIUM', 'I', 0.8, 'MG', '', '', 'N', '', 'Historic Freeform Text: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18545, 5325, 'LEVOTHYROXINE SODIUM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18546, 5325, 'LEVOTHYROXINE SODIUM', 'I', 0.3, 'MG', '', '', 'N', '', 'Historic Freeform Text: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18547, 5325, 'LEVOTHYROXINE SODIUM', 'I', 0.1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18535, 5325, 'LEVOTHYROXINE SODIUM', 'I', 0.2, 'MG', '', '', 'N', '', 'Historic Freeform Text: SODIUM LEVOTHYROXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61848, 5325, 'LEVOTHYROXINE SODIUM', 'I', 0.1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61849, 5325, 'LEVOTHYROXINE SODIUM', 'I', 0.2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61850, 5325, 'LEVOTHYROXINE SODIUM', 'I', 0.3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61851, 5325, 'LEVOTHYROXINE SODIUM', 'I', 0.4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61852, 5325, 'LEVOTHYROXINE SODIUM', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61853, 5325, 'LEVOTHYROXINE SODIUM', 'I', 0.6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61854, 5325, 'LEVOTHYROXINE SODIUM', 'I', 0.7, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61855, 5325, 'LEVOTHYROXINE SODIUM', 'I', 0.8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70072, 5325, 'LEVOTHYROXINE SODIUM', 'I', 500, 'µG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18290, 3033, 'SODIUM LAURYL SULFOACETATE', 'I', 9, 'MG', '', '', 'N', 'ML', '70%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12931, 2949, 'OIL OF SWEET ALMOND', 'I', 98, '%', '', '', 'N', 'W/V', 'Historic Freeform Text: OIL OF SWEET ALMOND');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19582, 2953, 'CYTARABINE', 'I', 1, 'G', '', '', 'N', 'VIAL', 'Historic Freeform Text: CYTARABINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19583, 2953, 'CYTARABINE', 'I', 2, 'G', '', '', 'N', 'VIAL', 'Historic Freeform Text: CYTARABINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19581, 2953, 'CYTARABINE', 'I', 100, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: CYTARABINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19578, 2953, 'CYTARABINE', 'I', 500, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: CYTARABINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43843, 2953, 'CYTARABINE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CYTARABINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2792, 2953, 'CYTARABINE', 'I', 100, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CYTARABINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64756, 2953, 'CYTARABINE', 'I', 10, 'MG', '', '', 'N', 'ML', 'CYTARABINE (LIPOSOME)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49664, 2958, 'TETRACAINE (TETRACAINE HYDROCHLORIDE)', 'I', 40, 'MG', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20278, 2959, 'L-ALANINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19306, 2959, 'L-ALANINE', 'I', 1.49, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19610, 2959, 'L-ALANINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20302, 2959, 'L-ALANINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 2959, 'L-ALANINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 2959, 'L-ALANINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 2959, 'L-ALANINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 2959, 'L-ALANINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20279, 2959, 'L-ALANINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18550, 2959, 'L-ALANINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 2959, 'L-ALANINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14077, 2959, 'L-ALANINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 2959, 'L-ALANINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 2959, 'L-ALANINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 2959, 'L-ALANINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14067, 2959, 'L-ALANINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11329, 2959, 'L-ALANINE', 'I', 2.07, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 2959, 'L-ALANINE', 'I', 1.1, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5890, 2959, 'L-ALANINE', 'I', 1.1, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4661, 2959, 'L-ALANINE', 'I', 2.08, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3468, 2959, 'L-ALANINE', 'I', 1.28, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 2959, 'L-ALANINE', 'I', 422, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 2959, 'L-ALANINE', 'I', 880, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20303, 2959, 'L-ALANINE', 'I', 880, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 2959, 'L-ALANINE', 'I', 880, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20289, 2959, 'L-ALANINE', 'I', 880, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 2959, 'L-ALANINE', 'I', 520, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 2959, 'L-ALANINE', 'I', 422, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 2959, 'L-ALANINE', 'I', 422, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 2959, 'L-ALANINE', 'I', 348, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 2959, 'L-ALANINE', 'I', 422, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19143, 2959, 'L-ALANINE', 'I', 1040, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 2959, 'L-ALANINE', 'I', 422, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 2959, 'L-ALANINE', 'I', 348, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 2959, 'L-ALANINE', 'I', 496, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 2959, 'L-ALANINE', 'I', 348, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 2959, 'L-ALANINE', 'I', 422, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 2959, 'L-ALANINE', 'I', 490, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18644, 2959, 'L-ALANINE', 'I', 993, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 2959, 'L-ALANINE', 'I', 348, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 2959, 'L-ALANINE', 'I', 993, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18608, 2959, 'L-ALANINE', 'I', 695, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 2959, 'L-ALANINE', 'I', 698, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18607, 2959, 'L-ALANINE', 'I', 844, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14073, 2959, 'L-ALANINE', 'I', 880, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 2959, 'L-ALANINE', 'I', 880, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14071, 2959, 'L-ALANINE', 'I', 880, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 2959, 'L-ALANINE', 'I', 520, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 2959, 'L-ALANINE', 'I', 880, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4560, 2959, 'L-ALANINE', 'I', 900, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2776, 2959, 'L-ALANINE', 'I', 640, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 2959, 'L-ALANINE', 'I', 800, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 2963, 'ALANINE', 'I', 440, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43947, 2963, 'ALANINE', 'I', 2.76, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 2963, 'ALANINE', 'I', 2.08, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44068, 2963, 'ALANINE', 'I', 600, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 2963, 'ALANINE', 'I', 2, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 2963, 'ALANINE', 'I', 0.8, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 2963, 'ALANINE', 'I', 95.1, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 2963, 'ALANINE', 'I', 3.66, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 2963, 'ALANINE', 'I', 6.41, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 2963, 'ALANINE', 'I', 8.24, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 2963, 'ALANINE', 'I', 8.24, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84428, 2931, 'COAGULATION FACTOR II (HUMAN)', 'I', 800, 'UNIT', '', '', 'N', '', '380 IU - 800IU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78001, 2931, 'COAGULATION FACTOR II (HUMAN)', 'I', 760, 'UNIT', '', '', 'N', 'VIAL', '220-760 INT. UNIT; AFTER DILUTION:11-38 IU/ML.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1195, 9872, 'MELPHALAN', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MELPHALAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18786, 9872, 'MELPHALAN (MELPHALAN HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: MELPHALAN ((AS MELPHALAN HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4202, 9797, 'PRILOCAINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4203, 9797, 'PRILOCAINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2828, 9797, 'PRILOCAINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PRILOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83307, 9797, 'PRILOCAINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 9806, 'LYSINE', 'I', 700, 'MG', '', '', 'N', '', 'Historic Freeform Text: LYSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43947, 9806, 'LYSINE (LYSINE ACETATE)', 'I', 1.35, 'G', '', '100', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: LYSINE ((AS LYSINE ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 9806, 'LYSINE (LYSINE ACETATE)', 'I', 446, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-LYSINE ACETATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44068, 9806, 'LYSINE (LYSINE ACETATE)', 'I', 620, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LYSINE ((AS ACETATE 0.87GM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20279, 9806, 'LYSINE (L-LYSINE HYDROCHLORIDE)', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ((AS THE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20278, 9806, 'LYSINE (L-LYSINE HYDROCHLORIDE)', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ((AS THE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 9806, 'LYSINE (L-LYSINE HYDROCHLORIDE)', 'I', 246.5, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-LYSINE ((AS THE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20303, 9806, 'LYSINE (L-LYSINE HYDROCHLORIDE)', 'I', 246.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ((AS THE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20302, 9806, 'LYSINE (L-LYSINE HYDROCHLORIDE)', 'I', 290, 'MG', '', '100', 'Y', 'ML', 'Historic Freeform Text: L-LYSINE ((AS THE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 9806, 'LYSINE (L-LYSINE HYDROCHLORIDE)', 'I', 246.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ((AS THE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 9806, 'LYSINE (L-LYSINE HYDROCHLORIDE)', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ((AS THE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20289, 9806, 'LYSINE (L-LYSINE HYDROCHLORIDE)', 'I', 246.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ((AS THE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 9806, 'LYSINE (L-LYSINE HYDROCHLORIDE)', 'I', 290, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-LYSINE ((AS THE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 9806, 'LYSINE (L-LYSINE HYDROCHLORIDE)', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ((AS THE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 9806, 'LYSINE (L-LYSINE HYDROCHLORIDE)', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ((AS THE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15493, 9806, 'LYSINE (LYSINE ACETATE)', 'I', 640, 'MG', '', '100', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: LYSINE ((AS ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 9806, 'LYSINE', 'I', 4.9, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LYSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7163, 9806, 'LYSINE (LYSINE ACETATE)', 'I', 535, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-LYSINE ((AS ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 9806, 'LYSINE (LYSINE ACETATE)', 'I', 624, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 9806, 'LYSINE', 'I', 2.5, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LYSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 9806, 'LYSINE', 'I', 4, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LYSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 9806, 'LYSINE', 'I', 4, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LYSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 9806, 'LYSINE (LYSINE MONOHYDROCHLORIDE)', 'I', 95.5, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 9806, 'LYSINE (L-LYSINE ACETATE)', 'I', 1.99, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 9806, 'LYSINE (L-LYSINE ACETATE)', 'I', 3.48, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 9806, 'LYSINE (L-LYSINE ACETATE)', 'I', 4.48, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 9806, 'LYSINE (L-LYSINE ACETATE)', 'I', 4.48, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3189, 9758, 'CELLULASE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CELLULASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47182, 9766, 'SALICYLIC ACID', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41889, 9766, 'SALICYLIC ACID', 'I', 2.0, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15950, 9766, 'SALICYLIC ACID', 'I', 2.0, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13031, 9766, 'SALICYLIC ACID', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13013, 9766, 'SALICYLIC ACID', 'I', 1.8, '%', '', '', 'N', '', 'W/W HISTORIC FREEFORM TEXT: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13014, 9766, 'SALICYLIC ACID', 'I', 1.8, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13542, 9766, 'SALICYLIC ACID', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13858, 9766, 'SALICYLIC ACID', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10673, 9766, 'SALICYLIC ACID', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SALICYLIC ACID. W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10142, 9766, 'SALICYLIC ACID', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SALICYLIC ACID W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9361, 9766, 'SALICYLIC ACID', 'I', 30, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6848, 9766, 'SALICYLIC ACID', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5634, 9766, 'SALICYLIC ACID', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5635, 9766, 'SALICYLIC ACID', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5314, 9766, 'SALICYLIC ACID', 'I', 30, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4037, 9766, 'SALICYLIC ACID', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3347, 9766, 'SALICYLIC ACID', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3320, 9766, 'SALICYLIC ACID', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1938, 9766, 'SALICYLIC ACID', 'I', 0.2, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1686, 9766, 'SALICYLIC ACID', 'I', 0.2, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1687, 9766, 'SALICYLIC ACID', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1667, 9766, 'SALICYLIC ACID', 'I', 2.0, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2072, 9766, 'SALICYLIC ACID', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47375, 9766, 'SALICYLIC ACID', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48713, 9766, 'SALICYLIC ACID', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64695, 9766, 'SALICYLIC ACID', 'I', 2, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70547, 9766, 'SALICYLIC ACID', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75154, 9766, 'SALICYLIC ACID', 'I', 0.22, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18807, 9766, 'SALICYLIC ACID', 'I', 3.0, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10674, 9766, 'SALICYLIC ACID', 'I', 3, '%', '', '', 'N', 'W/V', 'HISTORIC FREEFORM TEXT: SALICYLIC ACID.W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10141, 9766, 'SALICYLIC ACID', 'I', 4, '%', '', '', 'N', 'W/V', 'HISTORIC FREEFORM TEXT: SALICYLIC ACID.W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80278, 9766, 'SALICYLIC ACID', 'I', 2, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79691, 9766, 'SALICYLIC ACID', 'I', 0.10, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81731, 9766, 'SALICYLIC ACID', 'I', 2, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13246, 9766, 'SALICYLIC ACID', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8599, 9766, 'SALICYLIC ACID', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66816, 9766, 'SALICYLIC ACID', 'I', 0.10, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53273, 9766, 'SALICYLIC ACID', 'I', 1.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66168, 9766, 'SALICYLIC ACID', 'I', 5.80, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5561, 9766, 'SALICYLIC ACID', 'I', 20, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5287, 9766, 'SALICYLIC ACID', 'I', 30, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1218, 9766, 'SALICYLIC ACID', 'I', 20, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48860, 9766, 'SALICYLIC ACID', 'I', 3.4, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69789, 9766, 'SALICYLIC ACID', 'I', 20, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25821, 9782, 'DIMENHYDRINATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16428, 9782, 'DIMENHYDRINATE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9585, 9782, 'DIMENHYDRINATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5885, 9782, 'DIMENHYDRINATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5572, 9782, 'DIMENHYDRINATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3491, 9782, 'DIMENHYDRINATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3943, 9782, 'DIMENHYDRINATE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3944, 9782, 'DIMENHYDRINATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (577, 9782, 'DIMENHYDRINATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2890, 9782, 'DIMENHYDRINATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2891, 9782, 'DIMENHYDRINATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2701, 9782, 'DIMENHYDRINATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (193, 9782, 'DIMENHYDRINATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63745, 9782, 'DIMENHYDRINATE', 'I', 50.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65184, 9782, 'DIMENHYDRINATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69289, 9782, 'DIMENHYDRINATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69468, 9782, 'DIMENHYDRINATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69984, 9782, 'DIMENHYDRINATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73930, 9782, 'DIMENHYDRINATE', 'I', 100, 'MG', '', '', 'N', '', 'PROVIDES IMMEDIATE AND SUSTAINED RELEASE OF ITS ACTIVE INGREDIENT COMBINED RELEASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74882, 9782, 'DIMENHYDRINATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (40419, 9782, 'DIMENHYDRINATE', 'I', 3, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20059, 9782, 'DIMENHYDRINATE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16994, 9782, 'DIMENHYDRINATE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3595, 9782, 'DIMENHYDRINATE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3397, 9782, 'DIMENHYDRINATE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1256, 9782, 'DIMENHYDRINATE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (197, 9782, 'DIMENHYDRINATE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78595, 9782, 'DIMENHYDRINATE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13585, 9783, 'SODIUM SALICYLATE', 'I', 2.0, '%', '', '', 'N', '', 'W/V. HISTORIC FREEFORM TEXT: SODIUM SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6261, 9783, 'SODIUM SALICYLATE', 'I', 570, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3546, 9783, 'SODIUM SALICYLATE', 'I', 56, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 9749, 'CYSTINE', 'I', 120, 'MG', '', '', 'N', '', 'Historic Freeform Text: CYSTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19347, 9785, 'CLOMIPHENE CITRATE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOMIPHENE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11805, 9785, 'CLOMIPHENE CITRATE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOMIPHENE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6391, 9785, 'CLOMIPHENE CITRATE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOMIPHENE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61438, 9724, 'GLYCOL SALICYLATE', 'I', 1.25, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33922, 9733, 'DEXBROMPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DEXBROMPHENIRAMINE MALEATE ((WH.NIGHT TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3717, 9733, 'DEXBROMPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXBROMPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2048, 9733, 'DEXBROMPHENIRAMINE MALEATE', 'I', 6, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DEXBROMPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20066, 9733, 'DEXBROMPHENIRAMINE MALEATE', 'I', 1.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXBROMPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5700, 9707, 'THIABENDAZOLE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIABENDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2226, 9670, 'HALOTHANE', 'I', 99.99, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HALOTHANE THE STRENGTH SAID NIL BEFORE AS PER ADMIN DIN/ SAME LABEL IT WAS C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (129, 9677, 'POTASSIUM PERMANGANATE', 'I', 908, 'G', '', '81.6', 'N', 'L', 'Historic Freeform Text: POTASSIUM PERMANGANATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78285, 7554, 'PROGESTERONE', 'I', 1.55, 'G', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79353, 7554, 'PROGESTERONE', 'I', 1.38, 'G', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83910, 7554, 'PROGESTERONE', 'I', 0.35, 'G', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46520, 7554, 'PROGESTERONE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: TESTOSTERONE PROPIONATE Qty Unit: IMP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18500, 7554, 'PROGESTERONE', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PROGESTERONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13291, 7554, 'PROGESTERONE', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PROGESTERONE QTY UNIT: IMP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82061, 7554, 'PROGESTERONE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64606, 7554, 'PROGESTERONE', 'I', 8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6075, 7554, 'PROGESTERONE', 'I', 100, 'MG', '', '', 'N', 'IMP', 'HISTORIC FREEFORM TEXT: PROGESTERONE QTY UNIT: IMP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1639, 7554, 'PROGESTERONE', 'I', 200, 'MG', '', '', 'N', 'IMP', 'Historic Freeform Text: PROGESTERONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69850, 7554, 'PROGESTERONE', 'I', 200, 'MG', '', '', 'N', 'DOSE', 'Historic Freeform Text: PROGESTERONE Qty Unit: IMP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13300, 7554, 'PROGESTERONE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PROGESTERONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6785, 7554, 'PROGESTERONE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PROGESTERONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37001, 7557, 'CLOBETASONE BUTYRATE', 'I', 0.05, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23184, 5253, 'MAGNESIUM ACETATE', 'I', 860, 'MG', '', '25', 'N', 'ML', 'MAGNESIUM ACETATE.4H2O');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43175, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: CLOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36954, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: CLOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36953, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36952, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: CLOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20127, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20117, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: CLOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13437, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13438, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13439, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: CLOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14381, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: CLOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14382, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: CLOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51612, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69609, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: CLOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69610, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69611, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74161, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: CLOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74162, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: CLOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78510, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79513, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51610, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51611, 7558, 'CLOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43464, 7559, 'PREDNICARBATE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: PREDNICARBATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49818, 7559, 'PREDNICARBATE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10222, 7563, 'ISOFLUPREDONE ACETATE', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28440, 7567, 'BECLOMETHASONE DIPROPIONATE', 'I', 0.025, '%', '', '', 'N', '', 'Historic Freeform Text: BECLOMETHASONE DIPROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62003, 7567, 'BECLOMETHASONE DIPROPIONATE', 'I', 50, 'µG', '', '', 'N', 'SPRAY', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62232, 7567, 'BECLOMETHASONE DIPROPIONATE', 'I', 50, 'µG', '', '', 'N', 'SPRAY', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43481, 7567, 'BECLOMETHASONE DIPROPIONATE', 'I', 50, 'µG', '', '', 'N', 'ACT', 'Historic Freeform Text: BECLOMETHASONE DIPROPIONATE Qty Unit: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18874, 7567, 'BECLOMETHASONE DIPROPIONATE', 'I', 50, 'µG', '', '', 'N', 'ACT', 'HISTORIC FREEFORM TEXT: BECLOMETHASONE DIPROPIONATE QTY UNIT: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65700, 7567, 'BECLOMETHASONE DIPROPIONATE', 'I', 50, 'µG', '', '', 'N', 'ACT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65701, 7567, 'BECLOMETHASONE DIPROPIONATE', 'I', 100, 'µG', '', '', 'N', 'ACT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7394, 7572, 'CYPROTERONE ACETATE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: CYPROTERONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52361, 7572, 'CYPROTERONE ACETATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53444, 7572, 'CYPROTERONE ACETATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70015, 7572, 'CYPROTERONE ACETATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77558, 7572, 'CYPROTERONE ACETATE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79517, 7572, 'CYPROTERONE ACETATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11880, 7572, 'CYPROTERONE ACETATE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CYPROTERONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5442, 7507, 'DIFLUCORTOLONE VALERATE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: DIFLUCORTOLONE VALERATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5443, 7507, 'DIFLUCORTOLONE VALERATE', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIFLUCORTOLONE VALERATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5444, 7507, 'DIFLUCORTOLONE VALERATE', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIFLUCORTOLONE VALERATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18807, 7507, 'DIFLUCORTOLONE VALERATE', 'I', 0.1, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: DIFLUCORTOLONE VALERATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66824, 7509, 'HYDROCORTISONE VALERATE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66825, 7509, 'HYDROCORTISONE VALERATE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19654, 7513, 'DESOXYCORTICOSTERONE PIVALATE', 'I', 25, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DESOXYCORTICOSTERONE PIVALATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1954, 7517, 'COSYNTROPIN', 'I', 0.25, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: COSYNTROPIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3725, 7517, 'COSYNTROPIN (COSYNTROPIN ZINC HYDROXIDE COMPLEX)', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: COSYNTROPIN ZINC HYDROXIDE COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10817, 7529, 'HYDROCORTISONE SODIUM SUCCINATE', 'I', 12.5, 'MG', '', '10', 'N', 'ML', 'Historic Freeform Text: HYDROCORTISONE-21-SODIUM SUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1802, 7530, 'CORTISONE ACETATE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36799, 7531, 'HYDROCORTISONE ACETATE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6418, 7531, 'HYDROCORTISONE ACETATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4629, 7531, 'HYDROCORTISONE ACETATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4630, 7531, 'HYDROCORTISONE ACETATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59873, 7531, 'HYDROCORTISONE ACETATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64442, 7531, 'HYDROCORTISONE ACETATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66620, 7531, 'HYDROCORTISONE ACETATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66621, 7531, 'HYDROCORTISONE ACETATE', 'I', 10, 'MG', '', '', 'N', '', 'HYDROCORTISONE ACETATE, MICRONISED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18240, 7531, 'HYDROCORTISONE ACETATE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8338, 7531, 'HYDROCORTISONE ACETATE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10393, 7531, 'HYDROCORTISONE ACETATE', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6417, 7531, 'HYDROCORTISONE ACETATE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4390, 7531, 'HYDROCORTISONE ACETATE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4389, 7531, 'HYDROCORTISONE ACETATE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5280, 7531, 'HYDROCORTISONE ACETATE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE ACETATE CHANGE FROM 1G/100ML TO 1%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3492, 7531, 'HYDROCORTISONE ACETATE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4583, 7531, 'HYDROCORTISONE ACETATE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE ACETATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49970, 7531, 'HYDROCORTISONE ACETATE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (55837, 7531, 'HYDROCORTISONE ACETATE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62005, 7531, 'HYDROCORTISONE ACETATE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61410, 7531, 'HYDROCORTISONE ACETATE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5575, 7531, 'HYDROCORTISONE ACETATE', 'I', 10, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63617, 7531, 'HYDROCORTISONE ACETATE', 'I', 10, 'MG', '', '', 'N', 'SUP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34945, 7531, 'HYDROCORTISONE ACETATE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9275, 7531, 'HYDROCORTISONE ACETATE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13383, 7531, 'HYDROCORTISONE ACETATE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10817, 7531, 'HYDROCORTISONE ACETATE', 'I', 20, 'MG', '', '10', 'N', 'ML', 'Historic Freeform Text: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1251, 7531, 'HYDROCORTISONE ACETATE', 'I', 1, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13115, 7531, 'HYDROCORTISONE ACETATE', 'I', 25, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13682, 7531, 'HYDROCORTISONE ACETATE', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4060, 7531, 'HYDROCORTISONE ACETATE', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: HYDROCORTISONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71955, 7531, 'HYDROCORTISONE ACETATE', 'I', 5, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71956, 7531, 'HYDROCORTISONE ACETATE', 'I', 5, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19730, 7534, 'MEGESTROL ACETATE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: MEGESTROL ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19731, 7534, 'MEGESTROL ACETATE', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: MEGESTROL ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20029, 7534, 'MEGESTROL ACETATE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: MEGESTROL ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20026, 7534, 'MEGESTROL ACETATE', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: MEGESTROL ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19230, 7534, 'MEGESTROL ACETATE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEGESTROL ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13410, 7487, 'TESTOSTERONE CYPIONATE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TESTOSTERONE CYPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1398, 7487, 'TESTOSTERONE CYPIONATE', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70198, 7487, 'TESTOSTERONE CYPIONATE', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12840, 7488, 'TESTOSTERONE PROPIONATE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: TESTOSTERONE PROPIONATE Qty Unit: IMP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4594, 7488, 'TESTOSTERONE PROPIONATE', 'I', 200, 'MG', '', '', 'N', 'IMP', '25MG/PELLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69853, 7488, 'TESTOSTERONE PROPIONATE', 'I', 200, 'MG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13414, 7488, 'TESTOSTERONE PROPIONATE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TESTOSTERONE PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4717, 7488, 'TESTOSTERONE PROPIONATE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TESTOSTERONE PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2756, 7488, 'TESTOSTERONE PROPIONATE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TESTOSTERONE PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12988, 7492, 'NORGESTIMATE', 'I', 0.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORGESTIMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12998, 7492, 'NORGESTIMATE', 'I', 0.25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NORGESTIMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14199, 7492, 'NORGESTIMATE', 'I', 0.215, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NORGESTIMATE ((LIGHT BLUE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14199, 7492, 'NORGESTIMATE', 'I', 0.25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NORGESTIMATE ((BLUE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14197, 7492, 'NORGESTIMATE', 'I', 0.18, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NORGESTIMATE ((WHITE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14197, 7492, 'NORGESTIMATE', 'I', 0.215, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NORGESTIMATE ((LIGHT BLUE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14197, 7492, 'NORGESTIMATE', 'I', 0.25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NORGESTIMATE ((BLUE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14199, 7492, 'NORGESTIMATE', 'I', 0.18, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NORGESTIMATE ((WHITE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74376, 7492, 'NORGESTIMATE', 'I', 0.180, 'MG', '', '', 'N', '', 'NORGESTIMATE (WHITE TAB)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74376, 7492, 'NORGESTIMATE', 'I', 0.215, 'MG', '', '', 'N', '', 'NORGESTIMATE (LIGHT BLUE TAB)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74376, 7492, 'NORGESTIMATE', 'I', 0.250, 'MG', '', '', 'N', '', 'NORGESTIMATE (DARK BLUE TAB)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74378, 7492, 'NORGESTIMATE', 'I', 0.180, 'MG', '', '', 'N', '', 'NORGESTIMATE (WHITE TAB)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74378, 7492, 'NORGESTIMATE', 'I', 0.215, 'MG', '', '', 'N', '', 'NORGESTIMATE (LIGHT BLUE TAB)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74378, 7492, 'NORGESTIMATE', 'I', 0.250, 'MG', '', '', 'N', '', 'NORGESTIMATE (DARK BLUE TAB)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43160, 7494, 'NORGESTREL', 'I', 300, 'µG', '', '', 'N', '', 'Historic Freeform Text: NORGESTREL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1401, 7498, 'NORETHINDRONE ACETATE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NORETHINDRONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1922, 7498, 'NORETHINDRONE ACETATE', 'I', 1.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORETHINDRONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2386, 7498, 'NORETHINDRONE ACETATE', 'I', 1.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORETHINDRONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2254, 7498, 'NORETHINDRONE ACETATE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORETHINDRONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2255, 7498, 'NORETHINDRONE ACETATE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORETHINDRONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65502, 7498, 'NORETHINDRONE ACETATE', 'I', 2.7, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65503, 7498, 'NORETHINDRONE ACETATE', 'I', 4.8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66279, 7498, 'NORETHINDRONE ACETATE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73420, 7498, 'NORETHINDRONE ACETATE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79461, 7498, 'NORETHINDRONE ACETATE', 'I', 0.1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42921, 7500, 'NORETHINDRONE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORETHINDRONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42922, 7500, 'NORETHINDRONE', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NORETHINDRONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42952, 7500, 'NORETHINDRONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42960, 7500, 'NORETHINDRONE', 'I', 1.0, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORETHINDRONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42888, 7500, 'NORETHINDRONE', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORETHINDRONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42889, 7500, 'NORETHINDRONE', 'I', 0.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NORETHINDRONE (BLUE TABLET)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63901, 9437, 'PAMABROM', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42889, 7500, 'NORETHINDRONE', 'I', 1.0, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NORETHINDRONE (WHITE TABLET)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42890, 7500, 'NORETHINDRONE', 'I', 0.5, 'MG', '', '', 'N', '', 'HISTORICAL FREEFORM TEXT: NORETHINDRONE (BLUE TABLET)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42890, 7500, 'NORETHINDRONE', 'I', 1.0, 'MG', '', '', 'N', '', 'HISTORICAL FREEFORM TEXT: NORETHINDRONE (WHITE TABLET)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20162, 7500, 'NORETHINDRONE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5482, 7500, 'NORETHINDRONE', 'I', 0.75, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORETHINDRONE ((AS LT PEACH TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5482, 7500, 'NORETHINDRONE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORETHINDRONE ((AS DK PEACH TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5483, 7500, 'NORETHINDRONE', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORETHINDRONE ((AS WHITE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5483, 7500, 'NORETHINDRONE', 'I', 0.75, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORETHINDRONE ((AS LT PEACH TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5483, 7500, 'NORETHINDRONE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORETHINDRONE ((AS DK PEACH TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5482, 7500, 'NORETHINDRONE', 'I', 0.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NORETHINDRONE ((AS WHITE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5103, 7500, 'NORETHINDRONE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORETHINDRONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5104, 7500, 'NORETHINDRONE', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORETHINDRONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5105, 7500, 'NORETHINDRONE', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NORETHINDRONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5106, 7500, 'NORETHINDRONE', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORETHINDRONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1290, 7500, 'NORETHINDRONE', 'I', 0.35, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NORETHINDRONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3756, 7436, 'ESTERIFIED ESTROGENS', 'I', 0.3, 'MG', '', '', 'N', '', 'Historic Freeform Text: ESTERIFIED ESTROGENS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1978, 7436, 'ESTERIFIED ESTROGENS', 'I', 0.625, 'MG', '', '', 'N', '', 'Historic Freeform Text: ESTERIFIED ESTROGENS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7645, 7445, 'ESTRONE', 'I', 1, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: ESTRONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11641, 7393, 'NOREPINEPHRINE (NOREPINEPHRINE BITARTRATE)', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-ARTERENOL BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65651, 7393, 'NOREPINEPHRINE (NOREPINEPHRINE BITARTRATE)', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NOREPINEPHRINE ((AS BITARTRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13539, 5353, 'BISMUTH TRIBROMOPHENATE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: BISMUTH TRIBROMOPHENATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13573, 5303, 'METHOXSALEN', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHOXSALEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11972, 5303, 'METHOXSALEN', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METHOXSALEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13403, 5303, 'METHOXSALEN', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METHOXSALEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14008, 5304, 'MONOBENZONE', 'I', 20, '%', '', '', 'N', '', 'Historic Freeform Text: MONOBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71282, 2813, 'TRICLOSAN', 'I', 0.55, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11038, 5253, 'MAGNESIUM ACETATE', 'I', 32, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1739, 5253, 'MAGNESIUM ACETATE', 'I', 0.21, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MAGNESIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5322, 5253, 'MAGNESIUM ACETATE', 'I', 0.5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: MAGNESIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19632, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE DIACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19630, 5280, 'CHLORHEXIDINE ACETATE', 'I', 1.2, '%', '', '', 'N', '', 'W/W. HISTORIC FREEFORM TEXT: CHLORHEXIDINE DIACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19631, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15801, 5280, 'CHLORHEXIDINE ACETATE', 'I', 10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE ACETATE THE PM SAYS CHLORHEXIDINE ACETATE 10% & IT IS  CONSIST');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7796, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: CHLORHEXIDINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7269, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.55, '%', '', '', 'N', '', 'Historic Freeform Text: CHLORHEXIDINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1016, 5280, 'CHLORHEXIDINE ACETATE', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (89, 5280, 'CHLORHEXIDINE ACETATE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (90, 5280, 'CHLORHEXIDINE ACETATE', 'I', 1.6, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72929, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75436, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.002, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74897, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74900, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74901, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74902, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74903, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73633, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.01, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76967, 5280, 'CHLORHEXIDINE ACETATE', 'I', 1.6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78509, 5280, 'CHLORHEXIDINE ACETATE', 'I', 1.6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14106, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.52, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9165, 5280, 'CHLORHEXIDINE ACETATE', 'I', 1.50, '%', '', '', 'N', 'W/W', 'Historic Freeform Text: CHLORHEXIDINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74899, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81834, 5280, 'CHLORHEXIDINE ACETATE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80845, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.52, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81375, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.002, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84027, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.002, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84079, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.002, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65359, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.1, 'MG', '', '', 'N', 'SRD', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65380, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.33, 'MG', '', '', 'N', 'SRD', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13349, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9157, 5280, 'CHLORHEXIDINE ACETATE', 'I', 1.6, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9161, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6015, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6114, 5280, 'CHLORHEXIDINE ACETATE', 'I', 1.6, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7270, 5280, 'CHLORHEXIDINE ACETATE', 'I', 1.6, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3111, 5280, 'CHLORHEXIDINE ACETATE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37235, 5280, 'CHLORHEXIDINE ACETATE', 'I', 1.025, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHLORHEXIDINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2494, 2843, 'CLOROPHENE SODIUM', 'I', 6.1, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2495, 2843, 'CLOROPHENE SODIUM', 'I', 6.1, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2493, 2843, 'CLOROPHENE SODIUM', 'I', 6.1, '%', '', '', 'N', '', 'Historic Freeform Text: CLOROPHENE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4468, 2852, 'BISMUTH CAMPHOCARBONATE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: BISMUTH CAMPHOCARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41931, 2813, 'TRICLOSAN', 'I', 0.02, '%', '', '', 'N', '', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37672, 2813, 'TRICLOSAN', 'I', 0.58, '%', '', '', 'N', '', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37673, 2813, 'TRICLOSAN', 'I', 0.30, '%', '', '', 'N', '', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37625, 2813, 'TRICLOSAN', 'I', 0.6, '%', '', '', 'N', '', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37501, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37869, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19611, 2813, 'TRICLOSAN', 'I', 0.25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18442, 2813, 'TRICLOSAN', 'I', 0.15, '%', '', '', 'N', '', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13617, 2813, 'TRICLOSAN', 'I', 0.15, '%', '', '', 'N', '', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14444, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13357, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12792, 2813, 'TRICLOSAN', 'I', 0.15, '%', '', '', 'N', '', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11919, 2813, 'TRICLOSAN', 'I', 0.55, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5480, 2813, 'TRICLOSAN', 'I', 0.6, '%', '', '', 'N', '', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6621, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', 'W/W. HISTORIC FREEFORM TEXT: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7121, 2813, 'TRICLOSAN', 'I', 0.15, '%', '', '', 'N', '', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7341, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1667, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2072, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50083, 2813, 'TRICLOSAN', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50946, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59735, 2813, 'TRICLOSAN', 'I', 0.375, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60734, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60738, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61685, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62780, 2813, 'TRICLOSAN', 'I', 0.30, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63657, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65853, 2813, 'TRICLOSAN', 'I', 1, '%', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65934, 2813, 'TRICLOSAN', 'I', 0.19, '%', '', '', 'N', '', '0.19% W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65951, 2813, 'TRICLOSAN', 'I', 0.10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65956, 2813, 'TRICLOSAN', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66674, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66676, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66138, 2813, 'TRICLOSAN', 'I', 0.19, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65029, 2813, 'TRICLOSAN', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65095, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67303, 2813, 'TRICLOSAN', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67304, 2813, 'TRICLOSAN', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67305, 2813, 'TRICLOSAN', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67306, 2813, 'TRICLOSAN', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67307, 2813, 'TRICLOSAN', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67995, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68120, 2813, 'TRICLOSAN', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68204, 2813, 'TRICLOSAN', 'I', 0.375, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71337, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70825, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69527, 2813, 'TRICLOSAN', 'I', 0.50, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70288, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70352, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76373, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76374, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76689, 2813, 'TRICLOSAN', 'I', 0.1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76690, 2813, 'TRICLOSAN', 'I', 0.1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75407, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73055, 2813, 'TRICLOSAN', 'I', 0.10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74262, 2813, 'TRICLOSAN', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75504, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75505, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73383, 2813, 'TRICLOSAN', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73418, 2813, 'TRICLOSAN', 'I', 0.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73440, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72682, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72683, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73591, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73652, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74924, 2813, 'TRICLOSAN', 'I', 0.46, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73688, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75039, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72751, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77277, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77106, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76939, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77860, 2813, 'TRICLOSAN', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77866, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77213, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77216, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78342, 2813, 'TRICLOSAN', 'I', 0.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80104, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80105, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82465, 2813, 'TRICLOSAN', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85169, 2813, 'TRICLOSAN', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37844, 2813, 'TRICLOSAN', 'I', 0.1, '%', '', '', 'N', 'W/W', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18812, 2813, 'TRICLOSAN', 'I', 0.1, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67289, 2813, 'TRICLOSAN', 'I', 0.25, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68330, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68254, 2813, 'TRICLOSAN', 'I', 1, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79709, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79710, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79711, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80794, 2813, 'TRICLOSAN', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80421, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80459, 2813, 'TRICLOSAN', 'I', 0.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80461, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80877, 2813, 'TRICLOSAN', 'I', 0.46, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79431, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81365, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82524, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83155, 2813, 'TRICLOSAN', 'I', 0.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83339, 2813, 'TRICLOSAN', 'I', 0.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83340, 2813, 'TRICLOSAN', 'I', 0.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83341, 2813, 'TRICLOSAN', 'I', 0.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84682, 2813, 'TRICLOSAN', 'I', 0.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84683, 2813, 'TRICLOSAN', 'I', 0.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84702, 2813, 'TRICLOSAN', 'I', 0.46, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84966, 2813, 'TRICLOSAN', 'I', 0.300, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84043, 2813, 'TRICLOSAN', 'I', 0.10, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84206, 2813, 'TRICLOSAN', 'I', 0.1, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20166, 2813, 'TRICLOSAN', 'I', 0.32, '%', '', '', 'N', '%', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20042, 2813, 'TRICLOSAN', 'I', 0.55, '%', '', '', 'N', '%', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17953, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15566, 2813, 'TRICLOSAN', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15971, 2813, 'TRICLOSAN', 'I', 0.2, '%', '', '', 'N', '%', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10499, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10500, 2813, 'TRICLOSAN', 'I', 0.745, '%', '', '', 'N', '%', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11537, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: TRICLOSAN 0.3% V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8599, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66725, 9437, 'PAMABROM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7122, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '%', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6538, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1668, 2813, 'TRICLOSAN', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: TRICLOSAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50085, 2813, 'TRICLOSAN', 'I', 0.2, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50961, 2813, 'TRICLOSAN', 'I', 0.32, '%', '', '', 'N', '%', 'ALSO CALLED 244''-TRICHLORO-2''-HYDROXY-DIPHENYL-ETHER ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61329, 2813, 'TRICLOSAN', 'I', 0.25, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61379, 2813, 'TRICLOSAN', 'I', 0.2, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62107, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61762, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63527, 2813, 'TRICLOSAN', 'I', 1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62713, 2813, 'TRICLOSAN', 'I', 1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63917, 2813, 'TRICLOSAN', 'I', 1.0, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66041, 2813, 'TRICLOSAN', 'I', 0.32, '%', '', '', 'N', '%', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64830, 2813, 'TRICLOSAN', 'I', 0.3, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1687, 2774, 'COCONUT OIL ETHANOLAMIDE', 'I', 8, '%', '', '', 'N', '', 'Historic Freeform Text: COCONUT OIL ETHANOLAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13907, 9523, 'CLOFEDANOL HYDROCHLORIDE', 'I', 25, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CLOFEDANOL HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1997, 9536, 'PHENYLBUTAZONE', 'I', 1, 'G', '', '', 'N', '', 'Historic Freeform Text: PHENYLBUTAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1503, 9536, 'PHENYLBUTAZONE', 'I', 1, 'G', '', '', 'N', '', 'Historic Freeform Text: PHENYLBUTAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62353, 9536, 'PHENYLBUTAZONE', 'I', 1000, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13123, 9536, 'PHENYLBUTAZONE', 'I', 1, 'G', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: PHENYLBUTAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4871, 9536, 'PHENYLBUTAZONE', 'I', 1, 'G', '', '3', 'N', 'ML', 'Historic Freeform Text: PHENYLBUTAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13460, 9536, 'PHENYLBUTAZONE', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PHENYLBUTAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5501, 9536, 'PHENYLBUTAZONE', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PHENYLBUTAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1998, 9536, 'PHENYLBUTAZONE (PHENYLBUTAZONE SODIUM)', 'I', 200, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: PHENYLBUTAZONE SODIUM ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1234, 9536, 'PHENYLBUTAZONE (PHENYLBUTAZONE SODIUM)', 'I', 200, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: PHENYLBUTAZONE SODIUM ((PHENYLBUTAZONE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48214, 9536, 'PHENYLBUTAZONE', 'I', 200, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81933, 9536, 'PHENYLBUTAZONE', 'I', 200, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14410, 9536, 'PHENYLBUTAZONE', 'I', 1, 'G', '', '15', 'N', 'G', 'Historic Freeform Text: PHENYLBUTAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9765, 9536, 'PHENYLBUTAZONE', 'I', 8, 'G', '', '30', 'N', 'G', 'Historic Freeform Text: PHENYLBUTAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (29531, 9536, 'PHENYLBUTAZONE', 'I', 266.66, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PHENYLBUTAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26615, 9536, 'PHENYLBUTAZONE', 'I', 100, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PHENYLBUTAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26618, 9536, 'PHENYLBUTAZONE', 'I', 266.66, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PHENYLBUTAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9764, 9536, 'PHENYLBUTAZONE', 'I', 100, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PHENYLBUTAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17236, 9471, 'LIDOCAINE', 'I', 5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LIDOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16733, 9471, 'LIDOCAINE', 'I', 2.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LIDOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12266, 9471, 'LIDOCAINE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: LIDOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (211, 9471, 'LIDOCAINE', 'I', 5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LIDOCAINE 50 MG/G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50081, 9471, 'LIDOCAINE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50944, 9471, 'LIDOCAINE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53831, 9471, 'LIDOCAINE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68513, 9471, 'LIDOCAINE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70023, 9471, 'LIDOCAINE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70063, 9471, 'LIDOCAINE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69914, 9471, 'LIDOCAINE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76670, 9471, 'LIDOCAINE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74263, 9471, 'LIDOCAINE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81134, 9471, 'LIDOCAINE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79170, 9471, 'LIDOCAINE', 'I', 9.6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80801, 9471, 'LIDOCAINE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84010, 9471, 'LIDOCAINE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46020, 9471, 'LIDOCAINE', 'I', 9.6, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: LIDOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74102, 9471, 'LIDOCAINE', 'I', 0.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82012, 9471, 'LIDOCAINE', 'I', 0.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50454, 9471, 'LIDOCAINE (LIDOCAINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', 'ACT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15237, 9471, 'LIDOCAINE (LIDOCAINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HCL ((LIDOCAINE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16174, 9471, 'LIDOCAINE', 'I', 8.6, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14240, 9471, 'LIDOCAINE (LIDOCAINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: LIDOCAINE  ((AS LIDOCAINE HCL MONOHYD.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37164, 9471, 'LIDOCAINE', 'I', 15, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: LIDOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4410, 9471, 'LIDOCAINE', 'I', 5, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: LIDOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11440, 9471, 'LIDOCAINE', 'I', 25, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: LIDOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64139, 9471, 'LIDOCAINE', 'I', 50, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78975, 9471, 'LIDOCAINE', 'I', 50, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67819, 9483, 'BETAHISTINE HYDROCHLORIDE', 'I', 16, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76586, 9483, 'BETAHISTINE HYDROCHLORIDE', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76588, 9483, 'BETAHISTINE HYDROCHLORIDE', 'I', 24, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76587, 9483, 'BETAHISTINE HYDROCHLORIDE', 'I', 16, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72312, 9483, 'BETAHISTINE HYDROCHLORIDE', 'I', 24, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3290, 9418, 'DIAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3291, 9418, 'DIAZEPAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3178, 9418, 'DIAZEPAM', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3084, 9418, 'DIAZEPAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3085, 9418, 'DIAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1718, 9418, 'DIAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1719, 9418, 'DIAZEPAM', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1720, 9418, 'DIAZEPAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2037, 9418, 'DIAZEPAM', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2657, 9418, 'DIAZEPAM', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71416, 9418, 'DIAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71417, 9418, 'DIAZEPAM', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71418, 9418, 'DIAZEPAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71740, 9418, 'DIAZEPAM', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71741, 9418, 'DIAZEPAM', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71742, 9418, 'DIAZEPAM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18641, 9418, 'DIAZEPAM', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13092, 9418, 'DIAZEPAM', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3721, 9418, 'DIAZEPAM', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61553, 9418, 'DIAZEPAM', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67132, 9418, 'DIAZEPAM', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7288, 9437, 'PAMABROM', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: PAMABROM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50547, 9437, 'PAMABROM', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: PAMABROM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62514, 9437, 'PAMABROM', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70470, 9437, 'PAMABROM', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76087, 9437, 'PAMABROM', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: PAMABROM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73655, 9437, 'PAMABROM', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77787, 9437, 'PAMABROM', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (158, 9439, 'PROPYLTHIOURACIL', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PROPYL THIOURACIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (159, 9439, 'PROPYLTHIOURACIL', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPYL THIOURACIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1812, 9449, 'THIOGUANINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: THIOGUANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19183, 9388, 'ALLOPURINOL', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALLOPURINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3843, 9388, 'ALLOPURINOL', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALLOPURINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3194, 9388, 'ALLOPURINOL', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALLOPURINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4835, 9388, 'ALLOPURINOL', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALLOPURINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4302, 9388, 'ALLOPURINOL', 'I', 300, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALLOPURINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4303, 9388, 'ALLOPURINOL', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALLOPURINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4304, 9388, 'ALLOPURINOL', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALLOPURINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4305, 9388, 'ALLOPURINOL', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALLOPURINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4276, 9388, 'ALLOPURINOL', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALLOPURINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4724, 9388, 'ALLOPURINOL', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALLOPURINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4725, 9388, 'ALLOPURINOL', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALLOPURINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4547, 9388, 'ALLOPURINOL', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALLOPURINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1892, 9388, 'ALLOPURINOL', 'I', 300, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALLOPURINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 9396, 'PROLINE', 'I', 550, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43947, 9396, 'PROLINE', 'I', 1.34, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44068, 9396, 'PROLINE', 'I', 950, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11329, 9396, 'PROLINE', 'I', 680, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 9396, 'PROLINE', 'I', 6.4, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 9396, 'PROLINE', 'I', 750, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4661, 9396, 'PROLINE', 'I', 420, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 9396, 'PROLINE', 'I', 3.3, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 9396, 'PROLINE', 'I', 420, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 9396, 'PROLINE', 'I', 59.5, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18230, 9401, 'PENTAZOCINE (PENTAZOCINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: PENTAZOCINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65646, 9401, 'PENTAZOCINE (PENTAZOCINE LACTATE)', 'I', 30, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: PENTAZOCINE ((AS LACTATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44270, 9407, 'VINBLASTINE SULFATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VINBLASTINE SULPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5858, 7408, 'SPIRONOLACTONE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: SPIRONOLACTONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6892, 7408, 'SPIRONOLACTONE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: SPIRONOLACTONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5646, 7408, 'SPIRONOLACTONE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: SPIRONOLACTONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5647, 7408, 'SPIRONOLACTONE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: SPIRONOLACTONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84425, 7289, 'ZINC OXIDE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5316, 7408, 'SPIRONOLACTONE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: SPIRONOLACTONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1403, 7408, 'SPIRONOLACTONE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: SPIRONOLACTONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1404, 7408, 'SPIRONOLACTONE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: SPIRONOLACTONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2145, 7408, 'SPIRONOLACTONE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: SPIRONOLACTONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3633, 7410, 'ETHYNODIOL DIACETATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3374, 7410, 'ETHYNODIOL DIACETATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11012, 7417, 'ESTRADIOL ENANTHATE', 'I', 7.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ESTRADIOL ENANTHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31359, 7387, 'VASOPRESSIN', 'I', 20, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VASOPRESSIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8604, 7387, 'VASOPRESSIN', 'I', 20, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VASOPRESSIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72248, 7387, 'VASOPRESSIN', 'I', 20, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70276, 7387, 'VASOPRESSIN (ARGININE VASOPRESSIN)', 'I', 20, 'UNIT', '', '1', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64959, 7419, 'ESTRADIOL', 'I', 25, 'µG', '', '', 'Y', '', 'AS ESTRADIOL HEMIHYDRATE  JH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81084, 7419, 'ESTRADIOL (ESTRADIOL HEMIHYDRATE)', 'I', 10, 'µG', '', '', 'N', '', 'AS ESTRADIOL HEMIHYDRATE 10.3 MCG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43420, 7419, 'ESTRADIOL', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: ESTRADIOL-17B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19405, 7419, 'ESTRADIOL', 'I', 2.0, 'MG', '', '', 'N', '', 'Historic Freeform Text: ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19406, 7419, 'ESTRADIOL', 'I', 1.0, 'MG', '', '', 'N', '', 'Historic Freeform Text: ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18640, 7419, 'ESTRADIOL', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: ESTRADIOL Qty Unit: SDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8386, 7419, 'ESTRADIOL', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8175, 7419, 'ESTRADIOL', 'I', 8, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50587, 7419, 'ESTRADIOL', 'I', 14, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50849, 7419, 'ESTRADIOL (ESTRADIOL HEMIHYDRATE)', 'I', 3.8, 'MG', '', '', 'N', '', 'PROVIDES CONTROL DELIVERY OF 0.05 MG/DAY FOR 7 DAYS. ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50850, 7419, 'ESTRADIOL (ESTRADIOL HEMIHYDRATE)', 'I', 7.6, 'MG', '', '', 'N', '', 'PROVIDES CONTROL DELIVERY OF 0.10 MG/DAY FOR 7 DAYS (ESTRADIOL 17-BETA).  ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61191, 7419, 'ESTRADIOL', 'I', 24, 'MG', '', '', 'N', '', 'EACH IMPLANT (6 PELLETS) CONTAINS: 120MG TRENBOLONE ACETATE AND  24MG ESTRADIOL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65502, 7419, 'ESTRADIOL', 'I', 0.62, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65503, 7419, 'ESTRADIOL', 'I', 0.51, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67942, 7419, 'ESTRADIOL', 'I', 0.585, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67943, 7419, 'ESTRADIOL', 'I', 0.780, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67944, 7419, 'ESTRADIOL', 'I', 1.17, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67945, 7419, 'ESTRADIOL', 'I', 1.56, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67654, 7419, 'ESTRADIOL', 'I', 5, 'MG', '', '', 'N', '', 'ESTRADIOL-17B (HEMIHYDRATE).  DELIVERY OF ESTRADIOL 100MCG/DAY.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67656, 7419, 'ESTRADIOL', 'I', 10, 'MG', '', '', 'N', '', 'ESTRADIOL-17B (HEMIHYDRATE).  DELIVERY OF ESTRADIOL 75MCG/DAY PER 33CM2 PATCH.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71749, 7419, 'ESTRADIOL (ESTRADIOL HEMIHYDRATE)', 'I', 2, 'MG', '', '', 'N', '', 'PROVIDES CONTROL DELIVERY OF 0.025 MG/DAY FOR 7 DAYS.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71750, 7419, 'ESTRADIOL (ESTRADIOL HEMIHYDRATE)', 'I', 5.7, 'MG', '', '', 'N', '', 'PROVIDES CONTROL DELIVERY OF 0.075 MG/DAY FOR 7 DAYS.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70362, 7419, 'ESTRADIOL', 'I', 8, 'MG', '', '', 'N', '', '4 MG PER PELLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69776, 7419, 'ESTRADIOL', 'I', 0.39, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71196, 7419, 'ESTRADIOL (ESTRADIOL HEMIHYDRATE)', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71197, 7419, 'ESTRADIOL (ESTRADIOL HEMIHYDRATE)', 'I', 6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71198, 7419, 'ESTRADIOL (ESTRADIOL HEMIHYDRATE)', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73894, 7419, 'ESTRADIOL', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75422, 7419, 'ESTRADIOL', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73420, 7419, 'ESTRADIOL', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73542, 7419, 'ESTRADIOL', 'I', 4.40, 'MG', '', '', 'N', '', '4.55MG OF ESTRADIOL HEMIHYDRATE PROVIDES CONTROLLED DELIVERY OF ESTRADIOL 0.045MG/DAY');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79461, 7419, 'ESTRADIOL', 'I', 0.5, 'MG', '', '', 'N', '', '0.5MG ESTRADIOL (AS HEMIHYDRATE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80251, 7419, 'ESTRADIOL', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62136, 7419, 'ESTRADIOL', 'I', 0.06, '%', '', '', 'N', '', '17B-ESTRADIOL (AS ESTRADIOL HEMIHYDRATE E.P.)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16884, 7419, 'ESTRADIOL', 'I', 24, 'MG', '', '', 'N', 'IMP', 'Historic Freeform Text: ESTRADIOL Qty Unit: IMP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5543, 7419, 'ESTRADIOL', 'I', 24, 'MG', '', '', 'N', 'IMP', 'HISTORIC FREEFORM TEXT: ESTRADIOL QTY UNIT: IMP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68718, 7419, 'ESTRADIOL', 'I', 14, 'MG', '', '', 'N', 'DOSE', 'EACH IMPLANT (6 PELLETS) CONTAINS: 120MG TRENBOLONE ACETATE AND  24MG ESTRADIOL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69765, 7419, 'ESTRADIOL', 'I', 14, 'MG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69852, 7419, 'ESTRADIOL', 'I', 24, 'MG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44257, 7358, 'CHORIONIC GONADOTROPIN', 'I', 10000, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: GONADOTROPHIN HUMAN CHORIONIC (HCG)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19706, 7358, 'CHORIONIC GONADOTROPIN', 'I', 200, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: GONADOTROPHIN HUMAN CHORIONIC (HCG)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71705, 7358, 'CHORIONIC GONADOTROPIN', 'I', 10000, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10687, 7358, 'CHORIONIC GONADOTROPIN', 'I', 1000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: GONADOTROPHIN HUMAN CHORIONIC (HCG)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44183, 7361, 'GONADORELIN DIACETATE TETRAHYDRATE', 'I', 50, 'µG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GONADORELIN DIACETATE TETRAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66943, 7364, 'SOMATROPIN', 'I', 6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66944, 7364, 'SOMATROPIN', 'I', 12, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66945, 7364, 'SOMATROPIN', 'I', 24, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43174, 7364, 'SOMATROPIN', 'I', 10, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: SOMATROPIN ((10MG/VIAL, APPROX. 30IU))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75761, 7364, 'SOMATROPIN', 'I', 8.8, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8187, 7364, 'SOMATROPIN', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SOMATROPIN R-DNA ORIGIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47897, 7364, 'SOMATROPIN', 'I', 5, 'MG', '', '', 'N', 'ML', '5MG/ML APPROX. = 30IU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73387, 7364, 'SOMATROPIN', 'I', 10, 'MG', '', '2', 'N', 'ML', 'PER CARTRIDGE. 10 MG EQUIVALENT TO APPROX. 30IU/2ML.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81048, 7364, 'SOMATROPIN', 'I', 5.0, 'MG', '', '1.5', 'N', 'ML', 'SOMATROPIN R-DNA ORIGIN. 15 IU/1.5ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81049, 7364, 'SOMATROPIN', 'I', 10.0, 'MG', '', '1.5', 'N', 'ML', 'SOMATROPIN R-DNA ORIGIN. 30 IU/1.5ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82055, 7364, 'SOMATROPIN', 'I', 15, 'MG', '', '1.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82056, 7364, 'SOMATROPIN', 'I', 10, 'MG', '', '1.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82057, 7364, 'SOMATROPIN', 'I', 5, 'MG', '', '1.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83536, 7364, 'SOMATROPIN', 'I', 5.83, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83537, 7364, 'SOMATROPIN', 'I', 8, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83538, 7364, 'SOMATROPIN', 'I', 8, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43151, 7364, 'SOMATROPIN', 'I', 3.3, 'MG', '', '', 'N', 'KIT', 'HISTORIC FREEFORM TEXT: SOMATROPIN ((10 IU/VIAL, APPROX. 3.33MG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62499, 7364, 'SOMATROPIN', 'I', 5, 'MG', '', '', 'N', 'KIT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62500, 7364, 'SOMATROPIN', 'I', 6, 'MG', '', '', 'N', 'KIT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61332, 7364, 'SOMATROPIN', 'I', 5, 'MG', '', '', 'N', 'KIT', '5MG/VIAL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36762, 7375, 'OXYTOCIN', 'I', 20, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: OXYTOCIN ((USP, SYNTHETIC))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31361, 7375, 'OXYTOCIN', 'I', 10, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: OXYTOCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7464, 7375, 'OXYTOCIN', 'I', 20, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: OXYTOCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4293, 7375, 'OXYTOCIN', 'I', 10, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: OXYTOCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4204, 7375, 'OXYTOCIN', 'I', 20, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: OXYTOCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1995, 7375, 'OXYTOCIN', 'I', 20, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: OXYTOCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (595, 7375, 'OXYTOCIN', 'I', 20, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: OXYTOCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1141, 7375, 'OXYTOCIN', 'I', 20, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: OXYTOCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75524, 7375, 'OXYTOCIN', 'I', 20, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: OXYTOCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77433, 7375, 'OXYTOCIN', 'I', 20, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6818, 7384, 'DIETHYLSTILBESTROL', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIETHYLSTILBESTROL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16466, 7320, 'INSULIN ZINC PORK', 'I', 40, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: INSULIN ZINC PORK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9788, 7323, 'INSULIN ISOPHANE (NPH)', 'I', 70, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: INSULIN ISOPHANE (NPH) -----------------------------------------------------');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9788, 7326, 'INSULIN', 'I', 30, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: INSULIN ------------------------------------------------------ CONCENTRATION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16274, 7330, 'GONADORELIN ACETATE', 'I', 0.8, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: GONADORELIN ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14403, 7330, 'GONADORELIN ACETATE', 'I', 50, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: GONADORELIN ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80744, 7334, 'TRILOSTANE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80745, 7334, 'TRILOSTANE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80741, 7334, 'TRILOSTANE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9301, 7341, 'MELATONIN', 'I', 2.7, 'MG', '', '', 'N', 'IMP', 'Historic Freeform Text: MELATONIN Qty Unit: IMP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34260, 7287, 'DEHYDROCHOLIC ACID', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEHYDROCHOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5276, 7287, 'DEHYDROCHOLIC ACID', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEHYDROCHOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2981, 7287, 'DEHYDROCHOLIC ACID', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEHYDROCHOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 7289, 'ZINC OXIDE', 'I', 125, 'MG', '', '', 'N', '', 'Historic Freeform Text: ZINC OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13247, 7289, 'ZINC OXIDE', 'I', 7, '%', '', '', 'N', '', 'Historic Freeform Text: ZINC OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3139, 7289, 'ZINC OXIDE', 'I', 15.63, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (233, 7289, 'ZINC OXIDE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: ZINC OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62057, 7289, 'ZINC OXIDE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68594, 7289, 'ZINC OXIDE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72102, 7289, 'ZINC OXIDE', 'I', 9.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72290, 7289, 'ZINC OXIDE', 'I', 2.85, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70373, 7289, 'ZINC OXIDE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71277, 7289, 'ZINC OXIDE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75151, 7289, 'ZINC OXIDE', 'I', 2.85, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75235, 7289, 'ZINC OXIDE', 'I', 4.88, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76600, 7289, 'ZINC OXIDE', 'I', 8.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74039, 7289, 'ZINC OXIDE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76743, 7289, 'ZINC OXIDE', 'I', 6.7, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75425, 7289, 'ZINC OXIDE', 'I', 3.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74229, 7289, 'ZINC OXIDE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75513, 7289, 'ZINC OXIDE', 'I', 8.8, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75531, 7289, 'ZINC OXIDE', 'I', 3.88, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72406, 7289, 'ZINC OXIDE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74363, 7289, 'ZINC OXIDE', 'I', 6.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75641, 7289, 'ZINC OXIDE', 'I', 6.65, '%', '', '', 'N', '', 'ORIGINAL AMT 6.86% WAS INCORRECTLY SUBMITTED BY CO. CORRECT AMT IS 6.65% WHICH HAS BEEN APPROVED BY ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73157, 7289, 'ZINC OXIDE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73158, 7289, 'ZINC OXIDE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73159, 7289, 'ZINC OXIDE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73161, 7289, 'ZINC OXIDE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74455, 7289, 'ZINC OXIDE', 'I', 2.9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74458, 7289, 'ZINC OXIDE', 'I', 6.79, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75752, 7289, 'ZINC OXIDE', 'I', 3, '%', '', '', 'N', '', 'ZINC OXIDE (Z-COTE) W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75755, 7289, 'ZINC OXIDE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75756, 7289, 'ZINC OXIDE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75920, 7289, 'ZINC OXIDE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73304, 7289, 'ZINC OXIDE', 'I', 6.7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76132, 7289, 'ZINC OXIDE', 'I', 16.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74880, 7289, 'ZINC OXIDE', 'I', 7.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73606, 7289, 'ZINC OXIDE', 'I', 1.7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73607, 7289, 'ZINC OXIDE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73654, 7289, 'ZINC OXIDE', 'I', 8.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73674, 7289, 'ZINC OXIDE', 'I', 6.7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74955, 7289, 'ZINC OXIDE', 'I', 1.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72724, 7289, 'ZINC OXIDE', 'I', 13.9, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72726, 7289, 'ZINC OXIDE', 'I', 13.9, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72727, 7289, 'ZINC OXIDE', 'I', 9.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76349, 7289, 'ZINC OXIDE', 'I', 2.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76379, 7289, 'ZINC OXIDE', 'I', 1.75, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78091, 7289, 'ZINC OXIDE', 'I', 4.8, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77512, 7289, 'ZINC OXIDE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77223, 7289, 'ZINC OXIDE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77186, 7289, 'ZINC OXIDE', 'I', 9.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77375, 7289, 'ZINC OXIDE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77083, 7289, 'ZINC OXIDE', 'I', 3.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77632, 7289, 'ZINC OXIDE', 'I', 9.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78240, 7289, 'ZINC OXIDE', 'I', 13.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77076, 7289, 'ZINC OXIDE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76910, 7289, 'ZINC OXIDE', 'I', 0.45, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77411, 7289, 'ZINC OXIDE', 'I', 1.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78047, 7289, 'ZINC OXIDE', 'I', 5.50, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79021, 7289, 'ZINC OXIDE', 'I', 2.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79533, 7289, 'ZINC OXIDE', 'I', 7.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79240, 7289, 'ZINC OXIDE', 'I', 19.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79276, 7289, 'ZINC OXIDE', 'I', 2.9, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82792, 7289, 'ZINC OXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80045, 7289, 'ZINC OXIDE', 'I', 9.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78901, 7289, 'ZINC OXIDE', 'I', 1.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79090, 7289, 'ZINC OXIDE', 'I', 2.2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80673, 7289, 'ZINC OXIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81642, 7289, 'ZINC OXIDE', 'I', 5.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81643, 7289, 'ZINC OXIDE', 'I', 5.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80281, 7289, 'ZINC OXIDE', 'I', 4.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80457, 7289, 'ZINC OXIDE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82313, 7289, 'ZINC OXIDE', 'I', 8.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82530, 7289, 'ZINC OXIDE', 'I', 15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83796, 7289, 'ZINC OXIDE', 'I', 40, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84130, 7289, 'ZINC OXIDE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84246, 7289, 'ZINC OXIDE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71503, 7289, 'ZINC OXIDE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72398, 7289, 'ZINC OXIDE', 'I', 40, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72764, 7289, 'ZINC OXIDE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78398, 7289, 'ZINC OXIDE', 'I', 3.43, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78399, 7289, 'ZINC OXIDE', 'I', 3.92, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77463, 7289, 'ZINC OXIDE', 'I', 2.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81251, 7289, 'ZINC OXIDE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79770, 7289, 'ZINC OXIDE', 'I', 6.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79458, 7289, 'ZINC OXIDE', 'I', 3.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79773, 7289, 'ZINC OXIDE', 'I', 1.9, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80773, 7289, 'ZINC OXIDE', 'I', 7.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81714, 7289, 'ZINC OXIDE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81715, 7289, 'ZINC OXIDE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80631, 7289, 'ZINC OXIDE', 'I', 8.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80226, 7289, 'ZINC OXIDE', 'I', 2.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82304, 7289, 'ZINC OXIDE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82315, 7289, 'ZINC OXIDE', 'I', 10.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80775, 7289, 'ZINC OXIDE', 'I', 9.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80776, 7289, 'ZINC OXIDE', 'I', 9.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81293, 7289, 'ZINC OXIDE', 'I', 7.35, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82283, 7289, 'ZINC OXIDE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82160, 7289, 'ZINC OXIDE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80131, 7289, 'ZINC OXIDE', 'I', 12, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79540, 7289, 'ZINC OXIDE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82525, 7289, 'ZINC OXIDE', 'I', 2.45, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83168, 7289, 'ZINC OXIDE', 'I', 7.35, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83278, 7289, 'ZINC OXIDE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84853, 7289, 'ZINC OXIDE', 'I', 6.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84858, 7289, 'ZINC OXIDE', 'I', 6.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85515, 7289, 'ZINC OXIDE', 'I', 1.96, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3724, 7289, 'ZINC OXIDE', 'I', 16.5, 'G', '', '', 'N', 'PAD', 'Historic Freeform Text: ZINC OXIDE Qty Unit: PAD');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62743, 7289, 'ZINC OXIDE', 'I', 3, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63661, 7289, 'ZINC OXIDE', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63662, 7289, 'ZINC OXIDE', 'I', 30, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66124, 7289, 'ZINC OXIDE', 'I', 5.04, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72236, 7289, 'ZINC OXIDE', 'I', 5, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41558, 7296, 'CALAMINE', 'I', 8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CALAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63619, 7296, 'CALAMINE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63620, 7296, 'CALAMINE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65100, 7296, 'CALAMINE', 'I', 8, '%', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3724, 7296, 'CALAMINE', 'I', 13.2, 'G', '', '', 'N', 'PAD', 'Historic Freeform Text: CALAMINE Qty Unit: PAD');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70891, 7296, 'CALAMINE', 'I', 8, 'G', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69976, 7297, 'ALTEPLASE', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43443, 7297, 'ALTEPLASE', 'I', 50, 'MG', '', '', 'N', 'KIT', 'Historic Freeform Text: ALTEPLASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20105, 7297, 'ALTEPLASE', 'I', 100, 'MG', '', '', 'N', 'KIT', 'HISTORIC FREEFORM TEXT: ALTEPLASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5326, 7311, 'INSULIN NPH HUMAN DNA ORIGIN', 'I', 100, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: INSULIN NPH HUMAN DNA ORIGIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5325, 7312, 'INSULIN SEMI SYNTHETIC HUMAN', 'I', 100, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: INSULIN DNA ORIGIN HUMAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1914, 5183, 'POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', 'POTENCY EXPRESSED IN PNU/ML UP TO AND INCLUDING 100,000PNU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37484, 5183, 'POLLEN', 'I', 40000, 'UNIT', '', '', 'N', 'ML', 'POTENCY EXPRESSED IN PNU/ML UP TO AND INCLUDING 40000 PNU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (129, 5186, 'ALUMINUM SULFATE', 'I', 908, 'G', '', '81.6', 'N', 'L', 'Historic Freeform Text: ALUMINUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71374, 5190, 'SENNOSIDES', 'I', 8.6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71635, 5190, 'SENNOSIDES', 'I', 8.6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71178, 5190, 'SENNOSIDES', 'I', 8.6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77658, 5190, 'SENNOSIDES', 'I', 8.6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12682, 5196, 'DICHLORVOS (D.D.V.P.)', 'I', 9.6, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DICHLORVOS (D.D.V.P.)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18186, 5201, 'OXETACAINE', 'I', 10, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: OXETACAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61900, 5159, 'KENTUCKY BLUEGRASS', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '100,000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61901, 5159, 'KENTUCKY BLUEGRASS', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '10,000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5708, 5097, 'CUPRIC CHLORIDE', 'I', 0.42, 'MG', '', '', 'N', 'ML', 'CUPRIC CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4518, 5051, 'COD LIVER OIL', 'I', 20, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: COD LIVER OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18080, 5054, 'TRETINOIN', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRETINOIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42932, 5054, 'TRETINOIN', 'I', 0.025, '%', '', '', 'N', '', 'Historic Freeform Text: TRETINOIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19617, 5054, 'TRETINOIN', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13524, 5054, 'TRETINOIN', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13954, 5054, 'TRETINOIN', 'I', 0.01, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13958, 5054, 'TRETINOIN', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64097, 2609, 'IBUPROFEN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13929, 5054, 'TRETINOIN', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13930, 5054, 'TRETINOIN', 'I', 0.025, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14397, 5054, 'TRETINOIN', 'I', 0.01, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11843, 5054, 'TRETINOIN', 'I', 0.01, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11844, 5054, 'TRETINOIN', 'I', 0.025, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11151, 5054, 'TRETINOIN', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11152, 5054, 'TRETINOIN', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11153, 5054, 'TRETINOIN', 'I', 0.025, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11154, 5054, 'TRETINOIN', 'I', 0.01, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12753, 5054, 'TRETINOIN', 'I', 0.01, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12754, 5054, 'TRETINOIN', 'I', 0.025, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12544, 5054, 'TRETINOIN', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11432, 5054, 'TRETINOIN', 'I', 0.025, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8989, 5054, 'TRETINOIN', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5471, 5054, 'TRETINOIN', 'I', 0.025, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6619, 5054, 'TRETINOIN', 'I', 0.01, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6204, 5054, 'TRETINOIN', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4220, 5054, 'TRETINOIN', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5278, 5054, 'TRETINOIN', 'I', 0.025, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5168, 5054, 'TRETINOIN', 'I', 0.025, '%', '', '', 'N', '', 'Historic Freeform Text: RETINOIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67856, 5054, 'TRETINOIN', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75010, 5054, 'TRETINOIN', 'I', 0.04, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84468, 5054, 'TRETINOIN', 'I', 0.025, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67151, 5054, 'TRETINOIN', 'I', 0.01, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17121, 5059, 'VITAMIN A ACETATE', 'I', 1280000, 'UNIT', '', '400', 'N', 'G', 'Historic Freeform Text: VIT. A ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 5059, 'VITAMIN A ACETATE', 'I', 2566000, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: VIT. A ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15001, 5059, 'VITAMIN A ACETATE', 'I', 6600, 'UNIT', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: VIT. A ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2493, 2747, 'SODIUM ALKYL POLYETHER SULFATE', 'I', 6, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM ALKYL POLYETHER SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74867, 2752, 'ALKYL PHENOL POLYGLYCOL ETHER IODINE COMPLEX', 'I', 2.584, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74869, 2752, 'ALKYL PHENOL POLYGLYCOL ETHER IODINE COMPLEX', 'I', 2.584, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74870, 2752, 'ALKYL PHENOL POLYGLYCOL ETHER IODINE COMPLEX', 'I', 2.584, '%', '', '', 'N', '', 'W/W (1% W/W TITRABLE IODINE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74871, 2752, 'ALKYL PHENOL POLYGLYCOL ETHER IODINE COMPLEX', 'I', 2.584, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74898, 2752, 'ALKYL PHENOL POLYGLYCOL ETHER IODINE COMPLEX', 'I', 8.75, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4067, 2752, 'ALKYL PHENOL POLYGLYCOL ETHER IODINE COMPLEX', 'I', 8.17, '%', '', '', 'N', 'W/V', 'Historic Freeform Text: ALKYL PHENOL POLYGLYCOL ETHER IODINE COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1957, 2752, 'ALKYL PHENOL POLYGLYCOL ETHER IODINE COMPLEX', 'I', 2.584, '%', '', '', 'N', 'W/V', 'Historic Freeform Text: ALKYL PHENOL POLYGLYCOL ETHER IODINE COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74867, 2753, 'POLYOXYETHYLENE GLYCOL IODINE COMPLEX', 'I', 5.34, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74869, 2753, 'POLYOXYETHYLENE GLYCOL IODINE COMPLEX', 'I', 5.34, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74870, 2753, 'POLYOXYETHYLENE GLYCOL IODINE COMPLEX', 'I', 5.34, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74871, 2753, 'POLYOXYETHYLENE GLYCOL IODINE COMPLEX', 'I', 5.34, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1957, 2753, 'POLYOXYETHYLENE GLYCOL IODINE COMPLEX', 'I', 5.31, '%', '', '', 'N', 'W/V', 'Historic Freeform Text: POLYOXYETHYLENE GLYCOL IODINE COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10873, 2762, 'BUTOXY POLYOXYPROPYLENE POLYOXYETHYLENE GLY.IODINE', 'I', 10.4, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BUTOXPOLYPROXPOLYETH ETHAIOD COMP ((IOD 1.2%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2954, 2762, 'BUTOXY POLYOXYPROPYLENE POLYOXYETHYLENE GLY.IODINE', 'I', 15.5, '%', '', '', 'N', '', 'Historic Freeform Text: BUTOXY POLYOXYPROPYLENE POLYOXYETHYLENE GLY.IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66815, 2767, 'ROBENIDINE HYDROCHLORIDE', 'I', 66, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37840, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 15.36, '%', '', '', 'N', '', 'W/W. HISTORIC FREEFORM TEXT: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37819, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.684, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36709, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.68, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34234, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 4.35, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33839, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 9.22, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28516, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.906, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27723, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 9.22, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27724, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.95, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27725, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.9, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26014, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.05, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21969, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.953, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20265, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.54, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20266, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 9.22, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20267, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.88, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20268, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.44, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20223, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.99, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20091, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.953, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20068, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.324, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18016, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.1475, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18733, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.35, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18713, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.35, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18714, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.953, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17768, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.54, '%', '', '', 'N', '', 'INCREASED FROM 2.31% TO 2.54% DURING CONTROL NO. 138561 APPROVED BY DU/BGIVD');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65845, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17771, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 15.36, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17772, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.85, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18934, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.906, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16774, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 4.61, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16721, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 15.36, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16722, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.85, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15586, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 15.36, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16875, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.906, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15973, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.24, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15972, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.27, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15954, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.3, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15947, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.31, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13683, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 4.61, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13687, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.31, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14412, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 9.22, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13249, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 10.14, '%', '', '', 'N', '', 'STRENGTH OF ACTIVE CHANGED FROM 9.22 TO 10.14% AS PER DISINFECTANT REVIEW AREA - SHANNON C. WRIGHT. ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13233, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 5.07, '%', '', '', 'N', '', 'STRENGTH OF ACTIVE CHANGED FROM 4.61 TO 5.07% AS PER DISINFECTANT REVIEW AREA - SHANNON C. WRIGHT. P');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13211, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14255, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.953, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12403, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 4.61, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12404, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 9.22, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12405, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.31, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12406, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.31, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12407, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.31, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12210, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 4.61, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11922, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.684, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9822, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.125, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8461, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.875, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8435, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.875, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9621, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.05, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9323, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.125, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7079, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.26, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5849, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50032, 7160, 'METHYLENE BLUE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6799, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6784, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.0, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4830, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.5, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49585, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 15.36, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49586, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 15.36, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49587, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 15.36, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50583, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.85, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49650, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.75, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50870, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.684, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49954, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 15.36, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61859, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.35, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60432, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.906, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61177, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 15.36, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61178, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61429, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.31, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60956, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.35, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61784, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.68, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62416, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.99, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62417, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.684, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62418, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 15.36, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62419, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.68, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63207, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64646, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 11.525, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64299, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63042, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.68, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67119, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.31, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67134, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.31, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65191, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.953, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65192, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.953, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65240, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 15.36, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65839, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.68, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66379, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66562, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 9.22, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66174, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66931, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 11.53, '%', '', '', 'N', '', 'QUATS IN THE  FORMULATION ARE SUPPLIED IN AN 80% STRENGTH.  THEREFORE 9.22%  REFLECTS THE ACTUAL CON');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66940, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65643, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 15.36, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66995, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.015, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65142, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 8.704, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67048, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68309, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67512, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69105, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68144, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67651, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67652, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67608, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67773, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.76, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68288, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72148, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.01995, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72152, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72153, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72154, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69931, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69957, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.015, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72200, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 15.36, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70000, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.35, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70001, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70767, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.015, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71522, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.58, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71523, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.58, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72301, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 8.704, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70268, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.0945, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70274, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71698, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.99, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71713, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.815, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70365, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69735, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70471, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.35, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70506, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.015, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71209, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70549, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71318, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 4.61, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76443, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.407, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76444, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.048, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76446, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.048, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73896, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.35, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76498, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.72, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72793, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.31, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75205, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 15.36, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75206, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.815, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75223, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.47, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75225, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.44, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75242, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.45, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75251, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.31, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76631, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76639, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78810, 9117, 'MORPHINE SULFATE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76640, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.018, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76650, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72933, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72991, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.72, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75402, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 10.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76765, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76777, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.015, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73025, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 10.14, '%', '', '', 'N', '', 'INCREASED FROM 9.22% TO 10.14% AS APPROVED BY DU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73035, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73036, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73037, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72340, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74326, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.88, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75586, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.026, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75632, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75633, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.015, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72427, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 9.22, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74491, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 15.36, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72498, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.31, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72499, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 9.22, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75959, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 9.22, '%', '', '', 'N', '', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73296, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.906, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73298, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73357, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 30, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76012, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 4.1472, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76050, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.52, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76078, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73405, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.825, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65897, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75783, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 9.22, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76119, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.85, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73470, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.015, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73633, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.03, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74943, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.09, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76264, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 9.22, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72770, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.906, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72771, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.906, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73858, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.47, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78114, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77180, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 5.28, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78400, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.44, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78415, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78487, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 9.22, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76873, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.35, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77548, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.68, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78044, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.01995, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78127, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78230, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.013, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78233, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78236, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.45, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78238, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77005, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.534, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77006, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.016, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77235, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.85, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77874, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77412, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76820, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.54, '%', '', '', 'N', '', 'DURING CONTROL NO. 140615 ACTIVES WERE CHANGED FROM DIDECYL DIMETHYL AMMONIUM CHLORIDE 2.31% TO 2.54');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78017, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.125, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79845, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79846, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78933, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.953, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79260, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.35, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78783, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.990, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81857, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80095, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.5375, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80737, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80738, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.29, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83038, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83039, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.407, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83042, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79106, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.407, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79881, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.953, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79882, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.013, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82554, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.875, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80406, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 5.28, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80754, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.29, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79968, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 5.28, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81651, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80642, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80646, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79561, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79562, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80976, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80388, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79858, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.875, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81996, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81997, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.875, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80887, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81165, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83041, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80216, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.06, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80532, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82114, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.018, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83214, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.54, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83379, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83525, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.63, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83950, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.013, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84056, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84216, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84357, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84367, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.125, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84439, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.62, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84638, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.75, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84650, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84735, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.048, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85405, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13294, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.54, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: DIDECYL DIMETHYL AMMONIUM CHLORIDE  2009.06.04. ACTIVE INGREDIENT STRENGTH R');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82604, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 10.14, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77007, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.990, '%', '', '', 'N', 'W/W', 'Historic Freeform Text: DIDECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77008, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.015, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79847, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.68, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80521, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 9.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80866, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.01125, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79995, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.01995, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66413, 2609, 'IBUPROFEN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79977, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80645, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81994, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.01995, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80036, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 10.14, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80037, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.53, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82532, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.84, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82533, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.84, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84144, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.84, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84389, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.84, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85333, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85423, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61680, 2730, 'DIDECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.104, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36843, 2694, 'SODIUM DIACETATE', 'I', 7.14, 'G', '', '400', 'N', 'G', 'TOTAL SODIUM EQ. 120.58 G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17818, 2694, 'SODIUM DIACETATE', 'I', 7.14, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: SODIUM DIACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17121, 2694, 'SODIUM DIACETATE', 'I', 7.14, 'G', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: SODIUM DIACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 2694, 'SODIUM DIACETATE', 'I', 2.083, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: SODIUM DIACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33790, 2694, 'SODIUM DIACETATE', 'I', 19.23, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SODIUM DIACETATE ((NA EQ.303MG FR.ALL S.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15001, 2694, 'SODIUM DIACETATE', 'I', 19.23, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SOD.DIACETATE ((NA EQ. TO 3.11MG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5322, 2694, 'SODIUM DIACETATE', 'I', 0.66, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SODIUM DIACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 2646, 'BENZYL PARABEN', 'I', 0.16, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS PARABEN MIX 0.80MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4875, 2660, 'PENGHAWAR', 'I', 3.5, 'G', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: PENGHAWAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1235, 2662, 'PITCHER PLANT', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: PITCHER PLANT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37358, 2664, 'NORMETHADONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NORMETHADONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1253, 9412, 'NITROGLYCERIN', 'I', 0.6, 'MG', '', '', 'N', '', 'Historic Freeform Text: NITROGLYCERIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1254, 9412, 'NITROGLYCERIN', 'I', 0.3, 'MG', '', '', 'N', '', 'Historic Freeform Text: NITROGLYCERIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49993, 9412, 'NITROGLYCERIN', 'I', 22.4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49995, 9412, 'NITROGLYCERIN', 'I', 44.8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49996, 9412, 'NITROGLYCERIN', 'I', 67.2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12220, 9412, 'NITROGLYCERIN', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NITROGLYCERIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15572, 9412, 'NITROGLYCERIN', 'I', 75, 'MG', '', '', 'N', 'SRD', 'HISTORIC FREEFORM TEXT: NITROGLYCERIN QTY UNIT: SRD');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50758, 9412, 'NITROGLYCERIN', 'I', 0.4, 'MG', '', '', 'N', 'ACT', 'HISTORIC FREEFORM TEXT: NITROGLYCERIN QTY UNIT: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62447, 9412, 'NITROGLYCERIN', 'I', 0.4, 'MG', '', '', 'N', 'ACT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67506, 9412, 'NITROGLYCERIN', 'I', 0.4, 'MG', '', '', 'N', 'ACT', 'HISTORIC FREEFORM TEXT: NITROGLYCERIN QTY UNIT: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19028, 9412, 'NITROGLYCERIN', 'I', 54, 'MG', '', '20', 'N', 'SQ CM', 'Historic Freeform Text: NITROGLYCERIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19029, 9412, 'NITROGLYCERIN', 'I', 36, 'MG', '', '13.3', 'N', 'SQ CM', 'HISTORIC FREEFORM TEXT: NITROGLYCERIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14742, 9412, 'NITROGLYCERIN', 'I', 160, 'MG', '', '40', 'N', 'SQ CM', 'HISTORIC FREEFORM TEXT: NITROGLYCERIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11225, 9412, 'NITROGLYCERIN', 'I', 80, 'MG', '', '20', 'N', 'SQ CM', 'NITRO-DUR 0.4MG/H DISC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11226, 9412, 'NITROGLYCERIN', 'I', 120, 'MG', '', '30', 'N', 'SQ CM', 'NITRO-DUR 0.6MG/H DISC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11227, 9412, 'NITROGLYCERIN', 'I', 40, 'MG', '', '10', 'N', 'SQ CM', 'NITRO-DUR 0.2MG/H DISC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10116, 9412, 'NITROGLYCERIN', 'I', 50, 'MG', '', '20', 'N', 'SQ CM', 'HISTORIC FREEFORM TEXT: NITROGLYCERIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9858, 9412, 'NITROGLYCERIN', 'I', 25, 'MG', '', '10', 'N', 'SQ CM', 'HISTORIC FREEFORM TEXT: NITROGLYCERIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (891, 9412, 'NITROGLYCERIN', 'I', 18, 'MG', '', '6.7', 'N', 'SQ CM', 'HISTORIC FREEFORM TEXT: NITROGLYCERIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18085, 9412, 'NITROGLYCERIN', 'I', 40, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: NITROGLYCERIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18086, 9412, 'NITROGLYCERIN', 'I', 20, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NITROGLYCERIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18087, 9412, 'NITROGLYCERIN', 'I', 10, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NITROGLYCERIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16848, 9412, 'NITROGLYCERIN', 'I', 5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NITROGLYCERIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10705, 9412, 'NITROGLYCERIN', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NITROGLYCERIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10706, 9412, 'NITROGLYCERIN', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NITROGLYCERIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13312, 9357, 'CAFFEINE CITRATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13765, 9357, 'CAFFEINE CITRATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13761, 9357, 'CAFFEINE CITRATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11753, 9357, 'CAFFEINE CITRATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (696, 9357, 'CAFFEINE CITRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2178, 9357, 'CAFFEINE CITRATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2179, 9357, 'CAFFEINE CITRATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2180, 9357, 'CAFFEINE CITRATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (876, 9357, 'CAFFEINE CITRATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51867, 9357, 'CAFFEINE CITRATE', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CAFFEINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51868, 9357, 'CAFFEINE CITRATE', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CAFFEINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51869, 9357, 'CAFFEINE CITRATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (55849, 9357, 'CAFFEINE CITRATE', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CAFFEINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62074, 9357, 'CAFFEINE CITRATE', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CAFFEINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8125, 9362, 'DITHRANOL', 'I', 0.4, '%', '', '', 'N', '%', 'Historic Freeform Text: DITHRANOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5667, 9362, 'DITHRANOL', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: DITHRANOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5668, 9362, 'DITHRANOL', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: DITHRANOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4677, 9362, 'DITHRANOL', 'I', 0.1, '%', '', '', 'N', '%', 'Historic Freeform Text: DITHRANOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4678, 9362, 'DITHRANOL', 'I', 0.2, '%', '', '', 'N', '%', 'Historic Freeform Text: DITHRANOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17401, 9366, 'ERGONOVINE MALEATE', 'I', 0.25, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ERGONOVINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4292, 9366, 'ERGONOVINE MALEATE', 'I', 0.25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ERGONOVINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78148, 9366, 'ERGONOVINE MALEATE', 'I', 0.25, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ERGONOVINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42699, 9329, 'TROLAMINE SALICYLATE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: TRIETHANOLAMINE SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33537, 9329, 'TROLAMINE SALICYLATE', 'I', 13.3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRIETHANOLAMINE SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49001, 9329, 'TROLAMINE SALICYLATE', 'I', 15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64100, 9329, 'TROLAMINE SALICYLATE', 'I', 15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68558, 9329, 'TROLAMINE SALICYLATE', 'I', 20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70239, 9329, 'TROLAMINE SALICYLATE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76410, 9329, 'TROLAMINE SALICYLATE', 'I', 12.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63472, 9329, 'TROLAMINE SALICYLATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80107, 9329, 'TROLAMINE SALICYLATE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80615, 9329, 'TROLAMINE SALICYLATE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83559, 9329, 'TROLAMINE SALICYLATE', 'I', 20, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42373, 9329, 'TROLAMINE SALICYLATE', 'I', 15, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: TRIETHANOLAMINE SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42374, 9329, 'TROLAMINE SALICYLATE', 'I', 10, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: TRIETHANOLAMINE SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33476, 9329, 'TROLAMINE SALICYLATE', 'I', 15, '%', '', '', 'N', '%', 'Historic Freeform Text: TRIETHANOLAMINE SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19111, 9332, 'ALKYLC9-C15 TOLYL METHYL TRIMETHYL AMMONIUM CHLORI', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYLC9-C15 TOLYL METHYL TRIMETHYL AMMONIUM CHLORI');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7152, 9260, 'CROTAMITON', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: CROTAMITON');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9411, 9267, 'IMIPRAMINE HYDROCHLORIDE', 'I', 75, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10008, 9267, 'IMIPRAMINE HYDROCHLORIDE', 'I', 75, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8560, 9267, 'IMIPRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: IMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8561, 9267, 'IMIPRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: IMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8562, 9267, 'IMIPRAMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: IMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1877, 9267, 'IMIPRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1884, 9267, 'IMIPRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: IMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1885, 9267, 'IMIPRAMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: IMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2444, 9267, 'IMIPRAMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: IMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1030, 9267, 'IMIPRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: IMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1031, 9267, 'IMIPRAMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: IMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1032, 9267, 'IMIPRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: IMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2211, 9267, 'IMIPRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: IMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2212, 9267, 'IMIPRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: IMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7153, 9206, 'DIBUCAINE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: DIBUCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7287, 9206, 'DIBUCAINE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: DIBUCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (38054, 7234, 'QUININE SULFATE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (38055, 7234, 'QUININE SULFATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (38056, 7234, 'QUININE SULFATE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (651, 7234, 'QUININE SULFATE', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: QUININE SULPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (290, 7234, 'QUININE SULFATE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: QUININE SULPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79680, 7234, 'QUININE SULFATE', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: QUININE SULPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79681, 7234, 'QUININE SULFATE', 'I', 300, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: QUININE SULPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64083, 7247, 'SODIUM SULFATE', 'I', 25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33649, 7247, 'SODIUM SULFATE', 'I', 5.68, 'G', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: SODIUM SULFATE ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9351, 7247, 'SODIUM SULFATE', 'I', 22.96, 'G', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: SODIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81164, 7247, 'SODIUM SULFATE', 'I', 5.74, 'G', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9631, 7247, 'SODIUM SULFATE', 'I', 5.74, 'G', '', '', 'N', 'L', 'HISTORIC FREEFORM TEXT: SODIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6370, 7247, 'SODIUM SULFATE', 'I', 22.74, 'G', '', '4', 'N', 'L', 'Historic Freeform Text: SODIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6616, 7247, 'SODIUM SULFATE', 'I', 81.2, 'MG', '', '', 'N', 'G', 'LABEL HAS SODIUM SULFATE ANHYDROUS 22.72G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64083, 7270, 'GENTIANA LUTEA', 'I', 0.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (134, 7270, 'GENTIANA LUTEA', 'I', 60, 'G', '', '11.35', 'N', 'KG', 'Historic Freeform Text: GENTIAN ((TINCTURE CO EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3567, 7206, 'ANISE', 'I', 0.84, '%', '', '', 'N', '%', 'Historic Freeform Text: ANISE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18636, 7211, 'GINGER', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: GINGER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64083, 7211, 'GINGER', 'I', 1.25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3567, 7211, 'GINGER', 'I', 1.26, '%', '', '', 'N', '%', 'Historic Freeform Text: GINGER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18637, 7211, 'GINGER', 'I', 75, 'MG', '', '28.35', 'N', 'G', 'Historic Freeform Text: GINGER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 7216, 'DL-METHIONINE', 'I', 140, 'MG', '', '', 'N', '', 'Historic Freeform Text: DL-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 7216, 'DL-METHIONINE', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44068, 7216, 'DL-METHIONINE', 'I', 450, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: DL-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43947, 7216, 'DL-METHIONINE', 'I', 760, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: DL-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15493, 7216, 'DL-METHIONINE', 'I', 880, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: DL-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10470, 7216, 'DL-METHIONINE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DL-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12562, 7216, 'DL-METHIONINE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DL-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 7216, 'DL-METHIONINE', 'I', 1.7, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: DL-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6071, 7216, 'DL-METHIONINE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DL-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 7216, 'DL-METHIONINE', 'I', 0.3, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DL-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 7216, 'DL-METHIONINE', 'I', 1, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: DL-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 7216, 'DL-METHIONINE', 'I', 1, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 7216, 'DL-METHIONINE', 'I', 85, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78915, 7216, 'DL-METHIONINE', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 7216, 'DL-METHIONINE', 'I', 13, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: DL-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1144, 7216, 'DL-METHIONINE', 'I', 80, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 7218, 'IODINE (POTASSIUM IODIDE)', 'I', 0.025, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70202, 7218, 'IODINE (POTASSIUM IODIDE)', 'I', 0.15, 'MG', '', '', 'N', '', 'PINK TABLET A.M.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76186, 7218, 'IODINE (POTASSIUM IODIDE)', 'I', 0.15, 'MG', '', '', 'N', '', 'PINK TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81317, 7218, 'IODINE (CALCIUM IODATE)', 'I', 505, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15803, 7218, 'IODINE (NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX)', 'I', 1.75, '%', '', '', 'Y', '', 'Historic Freeform Text: NONOXYNOL IODOPHOR ((IODINE 1.75% EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13434, 7218, 'IODINE (HYDRIODIC ACID - IODINE COMPLEX)', 'I', 0.25, '%', '', '', 'Y', '', 'Historic Freeform Text: HYDRIODIC ACID ((IODINE COMPLEX))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8159, 7218, 'IODINE (NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE)', 'I', 1.75, '%', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: NONOXYNOL IODOPHOR ((IODINE 1.75% EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6445, 7218, 'IODINE (NONYLPHENOXYPOLY(ETHYLENEOXY)ETHANOL-IODINE COMPLEX)', 'I', 0.5, '%', '', '', 'Y', '', 'TITRATABLE IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5679, 7218, 'IODINE (NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE)', 'I', 1.75, '%', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: NONOXYNOL IODOPHOR ((IODINE 1.75% EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4110, 7218, 'IODINE (NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX)', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: NONOXYNOL IODOPHOR ((IODINE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4000, 7218, 'IODINE (NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX)', 'I', 1.75, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NONOXYNOL IODOPHOR ((IODINE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (230, 7218, 'IODINE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66438, 2609, 'IBUPROFEN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50507, 7218, 'IODINE (NONYLPHENYL-OMEGA-HYDROXYPOLY OXYETHYLENE - IODINE COMPLEX)', 'I', 1.75, '%', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63587, 7218, 'IODINE (POLYALKYLENE GLYCOL ETHER IODOPHOR)', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72121, 7218, 'IODINE (NONYLPHENOXYPOLY(ETHYLENEOXY)ETHANOL-IODINE COMPLEX)', 'I', 0.5, '%', '', '', 'Y', '', 'TITRATABLE IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70184, 7218, 'IODINE (NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX)', 'I', 1.75, '%', '', '', 'Y', '', 'Historic Freeform Text: NONOXYNOL IODOPHOR ((IODINE 1.75% EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74872, 7218, 'IODINE (NONYLPHENOXYPOLY(ETHYLENEOXY)ETHANOL-IODINE COMPLEX)', 'I', 0.4, '%', '', '', 'N', '', 'TITRATABLE IODINE 0.4%W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74873, 7218, 'IODINE (NONYLPHENOXYPOLY(ETHYLENEOXY)ETHANOL-IODINE COMPLEX)', 'I', 0.5, '%', '', '', 'N', '', 'TITRATABLE IODINE 0.5%W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76973, 7218, 'IODINE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66170, 7218, 'IODINE', 'I', 2.55, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79816, 7218, 'IODINE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12931, 7218, 'IODINE', 'I', 2, '%', '', '', 'N', 'W/V', 'Historic Freeform Text: IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12540, 7218, 'IODINE (POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL - IODINE COMPLEX)', 'I', 0.25, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60155, 7218, 'IODINE (POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL - IODINE COMPLEX)', 'I', 1, '%', '', '', 'N', 'W/V', 'W/V AS PER NATALIE BELANGER, VDD.2010.12.06./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84552, 7218, 'IODINE (POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL - IODINE COMPLEX)', 'I', 1, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13515, 7218, 'IODINE', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9551, 7218, 'IODINE', 'I', 0.3, '%', '', '', 'N', '%', 'Historic Freeform Text: IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3665, 7218, 'IODINE', 'I', 0.02, '%', '', '', 'N', '%', 'Historic Freeform Text: IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4073, 7218, 'IODINE (NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE)', 'I', 1.75, '%', '', '', 'N', '%', 'Historic Freeform Text: NONOXYNOL IODOPHOR ((IODINE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1895, 7218, 'IODINE', 'I', 2.53, '%', '', '', 'N', '%', 'Historic Freeform Text: IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2253, 7218, 'IODINE', 'I', 7, '%', '', '', 'N', '%', 'Historic Freeform Text: IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62056, 7218, 'IODINE', 'I', 3.10, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62060, 7218, 'IODINE', 'I', 1.82, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6564, 7218, 'IODINE', 'I', 6.5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3297, 7218, 'IODINE', 'I', 60, 'G', '', '237', 'N', 'ML', 'Historic Freeform Text: IODINE ((TCT EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4771, 7218, 'IODINE', 'I', 4, 'G', '', '221.8', 'N', 'ML', 'Historic Freeform Text: IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4553, 7218, 'IODINE', 'I', 3.7, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70822, 7218, 'IODINE', 'I', 11.0, 'G', '', '100', 'N', 'ML', 'CRUDE IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20314, 7218, 'IODINE (SODIUM IODIDE)', 'I', 25, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: IODIDE ((AS SODIUM IODIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16226, 7218, 'IODINE (SODIUM IODIDE)', 'I', 60, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: IODIDE ((AS SODIUM IODIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16227, 7218, 'IODINE (SODIUM IODIDE)', 'I', 75, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: IODIDE ((AS SODIUM IODIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14491, 7218, 'IODINE', 'I', 60, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6694, 7218, 'IODINE', 'I', 120, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (818, 7218, 'IODINE', 'I', 47.44, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5879, 7218, 'IODINE', 'I', 1.9, '%', '', '', 'N', 'ML', 'Historic Freeform Text: IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 7218, 'IODINE (ETHYLENEDIAMINE DIHYDROIODIDE)', 'I', 25.4, 'MG', '', '', 'Y', 'KG', 'HISTORIC FREEFORM TEXT: EDDI ((IODINE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2570, 7218, 'IODINE (ETHIODIZED OIL)', 'I', 380, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: ETHIODIZED OIL ((IODINE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3567, 7227, 'GAMBOGE', 'I', 0.42, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: GAMBOGE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3166, 7149, 'BISMUTH SUBGALLATE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: BISMUTH SUBGALLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7288, 7155, 'PYRILAMINE MALEATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: PYRILAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50547, 7155, 'PYRILAMINE MALEATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: PYRILAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62514, 7155, 'PYRILAMINE MALEATE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63299, 7155, 'PYRILAMINE MALEATE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63901, 7155, 'PYRILAMINE MALEATE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75894, 7155, 'PYRILAMINE MALEATE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76086, 7155, 'PYRILAMINE MALEATE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76087, 7155, 'PYRILAMINE MALEATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: PYRILAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73655, 7155, 'PYRILAMINE MALEATE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77787, 7155, 'PYRILAMINE MALEATE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2963, 7155, 'PYRILAMINE MALEATE', 'I', 0.1, '%', '', '', 'N', '%', 'Historic Freeform Text: PYRILAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41646, 7155, 'PYRILAMINE MALEATE', 'I', 10, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13758, 7155, 'PYRILAMINE MALEATE', 'I', 25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRILAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1980, 7155, 'PYRILAMINE MALEATE', 'I', 1.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRILAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2548, 7155, 'PYRILAMINE MALEATE', 'I', 25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRILAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2044, 7155, 'PYRILAMINE MALEATE', 'I', 25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRILAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75771, 7155, 'PYRILAMINE MALEATE', 'I', 25, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13861, 7155, 'PYRILAMINE MALEATE', 'I', 50, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PYRILAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41559, 7160, 'METHYLENE BLUE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: METHYLENE BLUE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8048, 7160, 'METHYLENE BLUE', 'I', 0.75, '%', '', '', 'N', '', 'Historic Freeform Text: METHYLENE BLUE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68, 7160, 'METHYLENE BLUE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METHYLENE BLUE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69, 7160, 'METHYLENE BLUE', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METHYLENE BLUE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33329, 7160, 'METHYLENE BLUE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METHYLENE BLUE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16999, 7160, 'METHYLENE BLUE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: METHYLENE BLUE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10064, 7160, 'METHYLENE BLUE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: METHYLENE BLUE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78806, 7160, 'METHYLENE BLUE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: METHYLENE BLUE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5504, 7182, 'SENEGA', 'I', 0.566, 'MG', '', '1', 'N', 'ML', 'Historic Freeform Text: SENEGA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41919, 7128, 'HYDROGEN PEROXIDE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROGEN PEROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41925, 7128, 'HYDROGEN PEROXIDE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROGEN PEROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20058, 7128, 'HYDROGEN PEROXIDE', 'I', 58, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROGEN PEROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18687, 7128, 'HYDROGEN PEROXIDE', 'I', 20, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROGEN PEROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16065, 7128, 'HYDROGEN PEROXIDE', 'I', 35, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROGEN PEROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16939, 7128, 'HYDROGEN PEROXIDE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROGEN PEROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13689, 7128, 'HYDROGEN PEROXIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROGEN PEROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13535, 7128, 'HYDROGEN PEROXIDE', 'I', 58, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROGEN PEROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11758, 7128, 'HYDROGEN PEROXIDE', 'I', 3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROGEN PEROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48981, 7128, 'HYDROGEN PEROXIDE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62185, 7128, 'HYDROGEN PEROXIDE', 'I', 35, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63257, 7128, 'HYDROGEN PEROXIDE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63315, 7128, 'HYDROGEN PEROXIDE', 'I', 7, '%', '', '', 'N', '', 'HYDROGEN PEROXIDE(50%): 14.0%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63904, 7128, 'HYDROGEN PEROXIDE', 'I', 25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78600, 7128, 'HYDROGEN PEROXIDE', 'I', 27.11, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78598, 7128, 'HYDROGEN PEROXIDE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64864, 7128, 'HYDROGEN PEROXIDE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64865, 7128, 'HYDROGEN PEROXIDE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66791, 7128, 'HYDROGEN PEROXIDE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66941, 7128, 'HYDROGEN PEROXIDE', 'I', 7.50, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68494, 7128, 'HYDROGEN PEROXIDE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69065, 7128, 'HYDROGEN PEROXIDE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68698, 7128, 'HYDROGEN PEROXIDE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70105, 7128, 'HYDROGEN PEROXIDE', 'I', 21.7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71130, 7128, 'HYDROGEN PEROXIDE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69761, 7128, 'HYDROGEN PEROXIDE', 'I', 3, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73893, 7128, 'HYDROGEN PEROXIDE', 'I', 3.95, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76483, 7128, 'HYDROGEN PEROXIDE', 'I', 2, '%', '', '', 'N', '', 'W/W.LABEL HAS 2%, 3011 HAD HYDROGEN PEROXIDE (50%) 4%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76716, 7128, 'HYDROGEN PEROXIDE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75418, 7128, 'HYDROGEN PEROXIDE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73517, 7128, 'HYDROGEN PEROXIDE', 'I', 58, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76311, 7128, 'HYDROGEN PEROXIDE', 'I', 22.00, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73816, 7128, 'HYDROGEN PEROXIDE', 'I', 58, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROGEN PEROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77192, 7128, 'HYDROGEN PEROXIDE', 'I', 2, '%', '', '', 'N', '', 'W/W.LABEL HAS 2%, 3011 HAD HYDROGEN PEROXIDE (50%) 4%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77657, 7128, 'HYDROGEN PEROXIDE', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77279, 7128, 'HYDROGEN PEROXIDE', 'I', 7, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77085, 7128, 'HYDROGEN PEROXIDE', 'I', 0.5, '%', '', '', 'N', '', 'W/W HYDROGEN PEROXIDE (50%): 1% ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77125, 7128, 'HYDROGEN PEROXIDE', 'I', 0.5, '%', '', '', 'N', '', 'W/W HYDROGEN PEROXIDE (50% ACTIVE): 1%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77127, 7128, 'HYDROGEN PEROXIDE', 'I', 0.5, '%', '', '', 'N', '', 'HYDROGEN PEROXIDE(50%): 1%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76896, 7128, 'HYDROGEN PEROXIDE', 'I', 0.5, '%', '', '', 'N', '', 'HYDROGEN PEROXIDE(50%): 1%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77844, 7128, 'HYDROGEN PEROXIDE', 'I', 7.99, '%', '', '', 'N', '', 'CONCENTRATE PART B. W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78203, 7128, 'HYDROGEN PEROXIDE', 'I', 58, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78271, 7128, 'HYDROGEN PEROXIDE', 'I', 4.5, '%', '', '', 'N', '', 'HYDROGEN PEROXIDE 50% W/W QTY 9.0%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76812, 7128, 'HYDROGEN PEROXIDE', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78892, 7128, 'HYDROGEN PEROXIDE', 'I', 59, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79843, 7128, 'HYDROGEN PEROXIDE', 'I', 7.99, '%', '', '', 'N', '', 'CONCENTRATE PART B. W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80386, 7128, 'HYDROGEN PEROXIDE', 'I', 22, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82791, 7128, 'HYDROGEN PEROXIDE', 'I', 50, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81862, 7128, 'HYDROGEN PEROXIDE', 'I', 4.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82224, 7128, 'HYDROGEN PEROXIDE', 'I', 4.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82590, 7128, 'HYDROGEN PEROXIDE', 'I', 3.95, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82588, 7128, 'HYDROGEN PEROXIDE', 'I', 3.95, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80714, 7128, 'HYDROGEN PEROXIDE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROGEN PEROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83358, 7128, 'HYDROGEN PEROXIDE', 'I', 3.95, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83359, 7128, 'HYDROGEN PEROXIDE', 'I', 3.95, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83744, 7128, 'HYDROGEN PEROXIDE', 'I', 0.80, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROGEN PEROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84615, 7128, 'HYDROGEN PEROXIDE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84646, 7128, 'HYDROGEN PEROXIDE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84977, 7128, 'HYDROGEN PEROXIDE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64866, 7128, 'HYDROGEN PEROXIDE', 'I', 0.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76533, 7128, 'HYDROGEN PEROXIDE', 'I', 0.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77278, 7128, 'HYDROGEN PEROXIDE', 'I', 7, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76912, 7128, 'HYDROGEN PEROXIDE', 'I', 0.5, '%', '', '', 'N', 'W/W', 'W/W HYDROGEN PEROXIDE (50% ACTIVE): 1%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76913, 7128, 'HYDROGEN PEROXIDE', 'I', 0.5, '%', '', '', 'N', 'W/W', 'HYDROGEN PEROXIDE(50%): 1%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81863, 7128, 'HYDROGEN PEROXIDE', 'I', 22.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80441, 7128, 'HYDROGEN PEROXIDE', 'I', 3.130, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79564, 7128, 'HYDROGEN PEROXIDE', 'I', 4.5, '%', '', '', 'N', 'W/W', 'HYDROGEN PEROXIDE 50% W/W QTY 9.0%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79857, 7128, 'HYDROGEN PEROXIDE', 'I', 4.5, '%', '', '', 'N', 'W/W', 'HYDROGEN PEROXIDE 50% W/W QTY 9.0%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80463, 7128, 'HYDROGEN PEROXIDE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83975, 7128, 'HYDROGEN PEROXIDE', 'I', 23.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84438, 7128, 'HYDROGEN PEROXIDE', 'I', 8.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84820, 7128, 'HYDROGEN PEROXIDE', 'I', 50, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85205, 7128, 'HYDROGEN PEROXIDE', 'I', 0.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7144, 5015, 'NICOTINAMIDE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 5015, 'NICOTINAMIDE', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70202, 5015, 'NICOTINAMIDE', 'I', 20, 'MG', '', '', 'N', '', 'PINK TABLET A.M.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76186, 5015, 'NICOTINAMIDE', 'I', 20, 'MG', '', '', 'N', '', 'PINK TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65359, 5015, 'NICOTINAMIDE', 'I', 8.25, 'MG', '', '', 'N', 'SRD', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65380, 5015, 'NICOTINAMIDE', 'I', 27.50, 'MG', '', '', 'N', 'SRD', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66277, 5015, 'NICOTINAMIDE', 'I', 17, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6071, 5015, 'NICOTINAMIDE', 'I', 100, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 5015, 'NICOTINAMIDE', 'I', 1.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19369, 5015, 'NICOTINAMIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18602, 5015, 'NICOTINAMIDE', 'I', 1.111, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16486, 5015, 'NICOTINAMIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16462, 5015, 'NICOTINAMIDE', 'I', 8, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE ((VIAL 1))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10470, 5015, 'NICOTINAMIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9254, 5015, 'NICOTINAMIDE', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9527, 5015, 'NICOTINAMIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7179, 5015, 'NICOTINAMIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6072, 5015, 'NICOTINAMIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 5015, 'NICOTINAMIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5902, 5015, 'NICOTINAMIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6339, 5015, 'NICOTINAMIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6341, 5015, 'NICOTINAMIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7329, 5015, 'NICOTINAMIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5613, 5015, 'NICOTINAMIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3497, 5015, 'NICOTINAMIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3921, 5015, 'NICOTINAMIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 5015, 'NICOTINAMIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 5015, 'NICOTINAMIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2871, 5015, 'NICOTINAMIDE', 'I', 750, 'MG', '', '10', 'N', 'ML', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31, 5015, 'NICOTINAMIDE', 'I', 75, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NICOTINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68684, 5015, 'NICOTINAMIDE', 'I', 8, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 5015, 'NICOTINAMIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12562, 5015, 'NICOTINAMIDE', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78915, 5015, 'NICOTINAMIDE', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17121, 5015, 'NICOTINAMIDE', 'I', 6.72, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14165, 5015, 'NICOTINAMIDE', 'I', 3, 'G', '', '450', 'N', 'G', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14119, 5015, 'NICOTINAMIDE', 'I', 6.72, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14115, 5015, 'NICOTINAMIDE', 'I', 2500, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14113, 5015, 'NICOTINAMIDE', 'I', 4.488, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3926, 5015, 'NICOTINAMIDE', 'I', 3, 'G', '', '450', 'N', 'G', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36843, 5015, 'NICOTINAMIDE', 'I', 6720, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24400, 5015, 'NICOTINAMIDE', 'I', 3905, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17818, 5015, 'NICOTINAMIDE', 'I', 6720, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18635, 5015, 'NICOTINAMIDE', 'I', 10, 'MG', '', '19', 'N', 'G', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 5015, 'NICOTINAMIDE', 'I', 4488, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12923, 5015, 'NICOTINAMIDE', 'I', 8.4, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5144, 5015, 'NICOTINAMIDE', 'I', 2500, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5125, 5015, 'NICOTINAMIDE', 'I', 2500, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1617, 5015, 'NICOTINAMIDE', 'I', 3400, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1613, 5015, 'NICOTINAMIDE', 'I', 400, 'MG', '', '454', 'N', 'G', 'Historic Freeform Text: NIACINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50391, 5015, 'NICOTINAMIDE', 'I', 3.5, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64903, 5015, 'NICOTINAMIDE', 'I', 100, 'MG', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66631, 5015, 'NICOTINAMIDE', 'I', 11000, 'MG', '', '300', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66864, 5015, 'NICOTINAMIDE', 'I', 125, 'MG', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12562, 5021, 'RIBOFLAVIN 5''-PHOSPHATE SODIUM', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: RIBOFLAVIN SODIUM PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9254, 5021, 'RIBOFLAVIN 5''-PHOSPHATE SODIUM', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6071, 5021, 'RIBOFLAVIN 5''-PHOSPHATE SODIUM', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: RIBOFLAVIN SODIUM PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5902, 5021, 'RIBOFLAVIN 5''-PHOSPHATE SODIUM', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: RIBOFLAVIN SODIUM PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 5021, 'RIBOFLAVIN 5''-PHOSPHATE SODIUM', 'I', 4, 'MG', '', '100', 'N', 'ML', 'AS RIBOFLAVIN 5-PHOSPHATE SODIUM DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78915, 5021, 'RIBOFLAVIN 5''-PHOSPHATE SODIUM', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12923, 5021, 'RIBOFLAVIN 5''-PHOSPHATE SODIUM', 'I', 1.2, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: RIBOFLAVIN SODIUM PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23039, 5028, 'ADENINE', 'I', 17.3, 'MG', '', '63', 'N', 'ML', 'Historic Freeform Text: ADENINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 5038, 'THIAMINE MONONITRATE', 'I', 330, 'MG', '', '', 'N', 'KG', 'Historic Freeform Text: THIAMINE MONONITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24471, 5038, 'THIAMINE MONONITRATE', 'I', 224.4, 'MG', '', '170', 'N', 'G', 'Historic Freeform Text: THIAMINE MONONITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7144, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35700, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 0.1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19369, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 75, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18602, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 0.222, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17000, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16486, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9254, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 75, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9524, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10063, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7179, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 75, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6072, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7209, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6395, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6339, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 75, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6341, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6277, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7329, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 75, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3503, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3497, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2871, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 200, 'MG', '', '10', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65653, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67443, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 116, 'MG', '', '', 'N', 'KG', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24400, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 185, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18635, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '19', 'N', 'G', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 462.5, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14113, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 462.5, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12923, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 0.57, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: THIAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64903, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 100, 'MG', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66864, 5040, 'THIAMINE HYDROCHLORIDE', 'I', 125, 'MG', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5128, 5044, 'ISOTRETINOIN', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: ISOTRETIONIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5129, 5044, 'ISOTRETINOIN', 'I', 40, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ISOTRETIONIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74319, 5044, 'ISOTRETINOIN', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ISOTRETIONIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74320, 5044, 'ISOTRETINOIN', 'I', 40, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ISOTRETIONIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19369, 4983, 'SOLUBLE LIVER EXTRACT', 'I', 27, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIVER FRACTION 1');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9254, 4983, 'SOLUBLE LIVER EXTRACT', 'I', 27, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7179, 4983, 'SOLUBLE LIVER EXTRACT', 'I', 27, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIVER FRACTION 1');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6339, 4983, 'SOLUBLE LIVER EXTRACT', 'I', 27, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIVER FRACTION 1');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7329, 4983, 'SOLUBLE LIVER EXTRACT', 'I', 27, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LIVER FRACTION 1');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7144, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 18, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31465, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 0.012, 'G', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22007, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 0.88, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9372, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 0.88, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 2.035, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 3.92, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 928, 'MG', '', '', 'N', 'KG', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17121, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 3.2, 'G', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14119, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 3.2, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14113, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 3.252, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65789, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 0.012, 'G', '', '76', 'N', 'G', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65790, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 0.012, 'G', '', '185', 'N', 'G', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36843, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 3200, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: CALCIUM D-PANTOTHENATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24400, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 1100, 'MG', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17818, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 3200, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18635, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 18, 'MG', '', '19', 'N', 'G', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 3252, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14115, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 750, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8101, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 615, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5144, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 750, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5125, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 750, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1617, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 2650, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: PANTOTHENATE CALCIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50391, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 3, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64903, 4999, 'CALCIUM D-PANTOTHENATE', 'I', 10, 'MG', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 5000, 'D-PANTOTHENIC ACID (CALCIUM D-PANTOTHENATE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70202, 5000, 'D-PANTOTHENIC ACID (CALCIUM D-PANTOTHENATE)', 'I', 5, 'MG', '', '', 'N', '', 'PINK TABLET A.M.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76186, 5000, 'D-PANTOTHENIC ACID (CALCIUM D-PANTOTHENATE)', 'I', 5, 'MG', '', '', 'N', '', 'PINK TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5613, 5000, 'D-PANTOTHENIC ACID (CALCIUM D-PANTOTHENATE, RIBOFLAVIN-5-PHOSPHATE)', 'I', 2.6, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: PANTOTH. ACID ((CA D PANTOTH.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24471, 5000, 'D-PANTOTHENIC ACID', 'I', 1.496, 'G', '', '170', 'N', 'G', 'Historic Freeform Text: D-PANTOTHENIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12922, 5000, 'D-PANTOTHENIC ACID (CALCIUM D-PANTOTHENATE)', 'I', 4.52, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: PANTOTHEMIC ACID ((CALC D PANTO))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14165, 5000, 'D-PANTOTHENIC ACID', 'I', 700, 'MG', '', '450', 'N', 'G', 'Historic Freeform Text: D-PANTOTHENIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12923, 5000, 'D-PANTOTHENIC ACID (CALCIUM D-PANTOTHENATE)', 'I', 7.1, 'MG', '', '', 'Y', 'G', 'HISTORIC FREEFORM TEXT: PANTOTHENIC ACID ((CALC. D PANTO))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3926, 5000, 'D-PANTOTHENIC ACID', 'I', 700, 'MG', '', '450', 'N', 'G', 'Historic Freeform Text: D-PANTOTHENIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66631, 5000, 'D-PANTOTHENIC ACID', 'I', 200, 'MG', '', '300', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66864, 5000, 'D-PANTOTHENIC ACID', 'I', 12, 'MG', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7144, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5509, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2396, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66277, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 0.1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22007, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 0.075, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19369, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18602, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 0.042, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16462, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 0.8, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL ((VIAL 1))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10470, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12562, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9254, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9372, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 0.075, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7179, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6072, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6071, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6339, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6341, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7329, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 10, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4267, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3501, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3497, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2871, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 50, 'MG', '', '10', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68684, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 0.8, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69230, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 10, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78915, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 330, 'MG', '', '', 'N', 'KG', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 116, 'MG', '', '', 'N', 'KG', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12922, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 1.888, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6161, 2609, 'IBUPROFEN', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24471, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 224.4, 'MG', '', '170', 'N', 'G', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24400, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 195, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18635, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 2, 'MG', '', '19', 'N', 'G', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 448.8, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14115, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 326, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14113, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 448.8, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12923, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 1.38, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5144, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 326, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5125, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 326, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1617, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 325, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66631, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 25, 'MG', '', '300', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66864, 5008, 'PYRIDOXINE HYDROCHLORIDE', 'I', 10, 'MG', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18602, 4955, 'CHOLINE', 'I', 2.222, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHOLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 4956, 'CHOLINE BITARTRATE', 'I', 70, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17121, 4956, 'CHOLINE BITARTRATE', 'I', 5.76, 'G', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: CHOLINE BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14119, 4956, 'CHOLINE BITARTRATE', 'I', 5.76, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: CHOLINE BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36843, 4956, 'CHOLINE BITARTRATE', 'I', 5760, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: CHOLINE BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17818, 4956, 'CHOLINE BITARTRATE', 'I', 5760, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: CHOLINE BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66631, 4956, 'CHOLINE BITARTRATE', 'I', 400, 'MG', '', '300', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31096, 4957, 'ACETYLCHOLINE CHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ACETYLCHOLINE CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (236, 4959, 'INOSITOL', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: INOSITOL (MONOHYDRATE & DIHYDRATE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 4959, 'INOSITOL', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18602, 4959, 'INOSITOL', 'I', 2.222, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: INOSITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10470, 4959, 'INOSITOL', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: INOSITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12562, 4959, 'INOSITOL', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: INOSITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6071, 4959, 'INOSITOL', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: INOSITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6716, 4959, 'INOSITOL', 'I', 2.5, 'MG', '', '7.5', 'N', 'ML', 'Historic Freeform Text: INOSITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78915, 4959, 'INOSITOL', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82159, 4959, 'INOSITOL', 'I', 3, 'MG', '', '8', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 4962, 'BIOTIN', 'I', 10, 'µG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66277, 4962, 'BIOTIN', 'I', 20, 'µG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16462, 4962, 'BIOTIN', 'I', 12, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: BIOTIN ((VIAL 2))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10470, 4962, 'BIOTIN', 'I', 10, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: BIOTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12562, 4962, 'BIOTIN', 'I', 10, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: BIOTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6071, 4962, 'BIOTIN', 'I', 10, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: BIOTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6716, 4962, 'BIOTIN', 'I', 14, 'µG', '', '7.5', 'N', 'ML', 'Historic Freeform Text: BIOTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68684, 4962, 'BIOTIN', 'I', 12, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78915, 4962, 'BIOTIN', 'I', 10, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82159, 4962, 'BIOTIN', 'I', 16, 'µG', '', '8', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 4962, 'BIOTIN', 'I', 440, 'µG', '', '', 'N', 'KG', 'Historic Freeform Text: BIOTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 4962, 'BIOTIN', 'I', 2.901, 'MG', '', '', 'N', 'KG', 'Historic Freeform Text: BIOTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33790, 4962, 'BIOTIN', 'I', 60, 'µG', '', '', 'N', 'G', 'Historic Freeform Text: BIOTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24400, 4962, 'BIOTIN', 'I', 15600, 'µG', '', '100', 'N', 'G', 'Historic Freeform Text: BIOTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 4962, 'BIOTIN', 'I', 18700, 'µG', '', '100', 'N', 'G', 'Historic Freeform Text: BIOTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12923, 4962, 'BIOTIN', 'I', 60.6, 'µG', '', '', 'N', 'G', 'Historic Freeform Text: BIOTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15001, 4962, 'BIOTIN', 'I', 60, 'µG', '', '', 'N', 'G', 'Historic Freeform Text: BIOTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24471, 4962, 'BIOTIN', 'I', 18.7, 'MG', '', '170', 'N', 'G', 'Historic Freeform Text: BIOTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14113, 4962, 'BIOTIN', 'I', 18.7, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: BIOTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4809, 4962, 'BIOTIN (D-BIOTIN)', 'I', 25, 'MG', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: BIOTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84573, 4971, 'HYDROXOCOBALAMIN', 'I', 2.5, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5852, 4971, 'HYDROXOCOBALAMIN', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HYDROXOCOBALAMIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3502, 4971, 'HYDROXOCOBALAMIN', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HYDROXOCOBALAMIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66277, 4918, 'VITAMIN K1', 'I', 0.2, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12892, 4918, 'VITAMIN K1', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VIT. K1');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9993, 4918, 'VITAMIN K1', 'I', 2, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VIT. K1');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9994, 4918, 'VITAMIN K1', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. K1');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4270, 4918, 'VITAMIN K1', 'I', 2, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VIT. K1');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4271, 4918, 'VITAMIN K1', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VIT. K1');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3978, 4918, 'VITAMIN K1', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. K1');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 4918, 'VITAMIN K1', 'I', 440, 'MG', '', '', 'N', 'KG', 'Historic Freeform Text: VIT. K1');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46758, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47123, 2609, 'IBUPROFEN', 'I', 600, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47112, 2609, 'IBUPROFEN', 'I', 400, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35329, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19585, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18539, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13625, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14089, 2609, 'IBUPROFEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14090, 2609, 'IBUPROFEN', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14091, 2609, 'IBUPROFEN', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13452, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14492, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10294, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5432, 2609, 'IBUPROFEN', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5433, 2609, 'IBUPROFEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5917, 2609, 'IBUPROFEN', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6320, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6321, 2609, 'IBUPROFEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6322, 2609, 'IBUPROFEN', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6323, 2609, 'IBUPROFEN', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6749, 2609, 'IBUPROFEN', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49613, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65432, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68562, 2609, 'IBUPROFEN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71388, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71586, 2609, 'IBUPROFEN', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71587, 2609, 'IBUPROFEN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70575, 2609, 'IBUPROFEN', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75302, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75304, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75315, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76544, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76703, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73002, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74314, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72567, 2609, 'IBUPROFEN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75835, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75836, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73565, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77730, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77840, 2609, 'IBUPROFEN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78292, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81864, 2609, 'IBUPROFEN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80337, 2609, 'IBUPROFEN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80988, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80349, 2609, 'IBUPROFEN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80029, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80030, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80031, 2609, 'IBUPROFEN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79650, 2609, 'IBUPROFEN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82770, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82772, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81395, 2609, 'IBUPROFEN', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80286, 2609, 'IBUPROFEN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82306, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83757, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84104, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IBUPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84240, 2609, 'IBUPROFEN', 'I', 200, 'MG', '', '', 'N', '', 'IBUPROFEN CAPSULES AS FREE ACID AND POTASSIUM SALT- AS PER PM.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84241, 2609, 'IBUPROFEN', 'I', 400, 'MG', '', '', 'N', '', 'IBUPROFEN CAPSULES AS FREE ACID AND POTASSIUM SALT- AS PER PM.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84427, 2609, 'IBUPROFEN', 'I', 200.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85291, 2609, 'IBUPROFEN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51742, 2609, 'IBUPROFEN', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62054, 2609, 'IBUPROFEN', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66076, 2609, 'IBUPROFEN', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66270, 2609, 'IBUPROFEN', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72786, 2609, 'IBUPROFEN', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76585, 2609, 'IBUPROFEN', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75412, 2609, 'IBUPROFEN', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81396, 2609, 'IBUPROFEN', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81397, 2609, 'IBUPROFEN', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83995, 2609, 'IBUPROFEN', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3758, 2619, 'GILSONITE', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GILSONITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2842, 2634, 'OIL OF HEMLOCK CANADIAN', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18851, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 2, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: SALBUTAMOL ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18852, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 4, 'MG', '', '', 'Y', '', 'Historic Freeform Text: SALBUTAMOL ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18067, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 4, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SALBUTAMOL ((AS SALBUTAMOL SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18068, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SALBUTAMOL ((AS SALBUTAMOL SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66984, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 200, 'µG', '', '', 'Y', 'BLISTER', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9941, 2585, 'SALBUTAMOL', 'I', 100, 'µG', '', '', 'N', 'ACT', 'Historic Freeform Text: SALBUTAMOL Qty Unit: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69769, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 100, 'µG', '', '', 'N', 'ACT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81180, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 100, 'µG', '', '', 'N', 'ACT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52048, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 100, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65137, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 100, 'µG', '', '', 'Y', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43194, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SALBUTAMOL ((AS SALBUTAMOL SULPHATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43769, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 0.4, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: SALBUTAMOL ((AS SULPHATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43104, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SALBUTAMOL ((AS SALBUTAMOL SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43108, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 5, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: SALBUTAMOL ((AS SALBUTAMOL SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43100, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 2.5, 'MG', '', '2.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SALBUTAMOL ((AS SALBUTAMOL SULPHATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43101, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 5, 'MG', '', '2.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SALBUTAMOL ((AS SALBUTAMOL SULPHATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19761, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 0.5, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: SALBUTAMOL ((SALBUTAMOL SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19762, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 2, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: SALBUTAMOL ((SALBUTAMOL SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19763, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: SALBUTAMOL ((SALBUTAMOL SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19237, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 5, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: SALBUTAMOL ((AS SALBUTAMOL SULPHATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19058, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 2, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: SALBUTAMOL ((AS SALBUTAMOL SULPHATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16521, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SALBUTAMOL ((AS SULPHATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16452, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 5, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: SALBUTAMOL ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13668, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SALBUTAMOL ((AS SULPHATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13550, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SALBUTAMOL SULFATE ((BASE EQ))-2.5MG/2.5ML.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10391, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SALBUTAMOL SULPHATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51215, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51216, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50819, 2585, 'SALBUTAMOL', 'I', 2.5, 'MG', '', '2.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51050, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 1.0, 'MG', '', '', 'N', 'ML', '2.5MG/2.5ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78811, 9117, 'MORPHINE SULFATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51054, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52472, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 5, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60224, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 0.5, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60225, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 1, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60226, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 2, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62834, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 0.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62835, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 2, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67727, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 2.5, 'MG', '', '2.5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67769, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 0.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75181, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 2.5, 'MG', '', '2.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75820, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 2.5, 'MG', '', '2.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74671, 2585, 'SALBUTAMOL (SALBUTAMOL SULFATE)', 'I', 0.4, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: SALBUTAMOL ((AS SULPHATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14713, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONIDINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14715, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.1, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONIDINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10909, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.1, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONIDINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10910, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONIDINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12692, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONIDINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12693, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.1, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONIDINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11482, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONIDINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11483, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.1, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONIDINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4045, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.025, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONIDINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1943, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLONIDINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1601, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.1, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONIDINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71867, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.1, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONIDINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71868, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONIDINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73100, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.025, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78947, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.025, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84635, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.025, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84636, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84637, 2564, 'CLONIDINE HYDROCHLORIDE', 'I', 0.2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16163, 2493, 'BUPIVACAINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BUPIVACAINE HCL -AS THE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16164, 2493, 'BUPIVACAINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BUPIVACAINE HCL -AS THE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16161, 2493, 'BUPIVACAINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BUPIVACAINE HCL (AS THE MONOHYDRATE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16162, 2493, 'BUPIVACAINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BUPIVACAINE HCL -AS THE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65584, 2493, 'BUPIVACAINE HYDROCHLORIDE', 'I', 7.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: BUPIVACAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65585, 2493, 'BUPIVACAINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: BUPIVACAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65586, 2493, 'BUPIVACAINE HYDROCHLORIDE', 'I', 5.0, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: BUPIVACAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65587, 2493, 'BUPIVACAINE HYDROCHLORIDE', 'I', 7.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: BUPIVACAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65588, 2493, 'BUPIVACAINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: BUPIVACAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65589, 2493, 'BUPIVACAINE HYDROCHLORIDE', 'I', 5.0, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: BUPIVACAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79145, 2493, 'BUPIVACAINE HYDROCHLORIDE', 'I', 5.0, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: BUPIVACAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79742, 2493, 'BUPIVACAINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79144, 2493, 'BUPIVACAINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BUPIVACAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79063, 2493, 'BUPIVACAINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10899, 2495, 'CLORAZEPATE DIPOTASSIUM', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLORAZEPATE DIPOTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10902, 2495, 'CLORAZEPATE DIPOTASSIUM', 'I', 3.75, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLORAZEPATE DIPOTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10903, 2495, 'CLORAZEPATE DIPOTASSIUM', 'I', 7.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLORAZEPATE DIPOTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6096, 2495, 'CLORAZEPATE DIPOTASSIUM', 'I', 3.75, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLORAZEPATE DIPOTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6097, 2495, 'CLORAZEPATE DIPOTASSIUM', 'I', 7.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLORAZEPATE DIPOTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6098, 2495, 'CLORAZEPATE DIPOTASSIUM', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLORAZEPATE DIPOTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43714, 2497, 'PANCURONIUM BROMIDE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PANCURONIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19555, 2497, 'PANCURONIUM BROMIDE', 'I', 2, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PANCURONIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19556, 2497, 'PANCURONIUM BROMIDE', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PANCURONIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18549, 2497, 'PANCURONIUM BROMIDE', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PANCURONIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5708, 9229, 'MANGANESE CHLORIDE', 'I', 0.37, 'MG', '', '', 'N', 'ML', 'MANGANESE CHLORIDE TETRAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 9234, 'THIMEROSAL', 'I', 0.0065, 'MG', '', '', 'N', 'PATCH', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2758, 9240, 'SODIUM IODIDE', 'I', 20, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2012, 9240, 'SODIUM IODIDE', 'I', 20, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14491, 9240, 'SODIUM IODIDE', 'I', 90, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6526, 9240, 'SODIUM IODIDE', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5621, 9240, 'SODIUM IODIDE', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5555, 9240, 'SODIUM IODIDE', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12930, 9192, 'SORBITOL', 'I', 5.5, '%', '', '', 'N', '', 'Historic Freeform Text: SORBITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8427, 9192, 'SORBITOL', 'I', 9, '%', '', '', 'N', '', 'Historic Freeform Text: SORBITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9829, 9192, 'SORBITOL', 'I', 2.5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SORBITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18290, 9192, 'SORBITOL', 'I', 625, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5373, 9192, 'SORBITOL', 'I', 25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SORBITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3823, 9192, 'SORBITOL', 'I', 27, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SORBITOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81095, 9197, 'SODIUM BICARBONATE', 'I', 650, 'G', '', '', 'N', '', 'PER BAG.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7144, 9197, 'SODIUM BICARBONATE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2479, 9197, 'SODIUM BICARBONATE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2191, 9197, 'SODIUM BICARBONATE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69406, 9197, 'SODIUM BICARBONATE', 'I', 1700, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4913, 9197, 'SODIUM BICARBONATE', 'I', 0.21, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13018, 9197, 'SODIUM BICARBONATE', 'I', 650, 'G', '', '', 'N', 'CARTRIDGE', 'HISTORIC FREEFORM TEXT: SODIUM BICARBONATE QTY UNIT: CTG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81113, 9197, 'SODIUM BICARBONATE', 'I', 650, 'G', '', '', 'N', 'CARTRIDGE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78812, 9117, 'MORPHINE SULFATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42652, 9197, 'SODIUM BICARBONATE', 'I', 1.916, 'G', '', '', 'N', 'EVT', 'Historic Freeform Text: SODIUM BICARBONATE Qty Unit: EVT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3567, 9197, 'SODIUM BICARBONATE', 'I', 1.69, '%', '', '', 'N', '%', 'Historic Freeform Text: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37283, 9197, 'SODIUM BICARBONATE', 'I', 650, 'G', '', '', 'N', 'PCK', 'Historic Freeform Text: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37559, 9197, 'SODIUM BICARBONATE', 'I', 650, 'G', '', '', 'N', 'PCK', 'Historic Freeform Text: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33649, 9197, 'SODIUM BICARBONATE', 'I', 1.68, 'G', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9351, 9197, 'SODIUM BICARBONATE', 'I', 6.76, 'G', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81164, 9197, 'SODIUM BICARBONATE', 'I', 1.69, 'G', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76654, 9197, 'SODIUM BICARBONATE', 'I', 6, 'KG', '', '', 'N', 'PCK', 'PCK STANDS FOR PAIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2190, 9197, 'SODIUM BICARBONATE', 'I', 7.5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76040, 9197, 'SODIUM BICARBONATE', 'I', 58.8, 'G', '', '1000', 'N', 'ML', 'COMPARTMENT A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76308, 9197, 'SODIUM BICARBONATE', 'I', 3.090, 'G', '', '1000', 'N', 'ML', 'SOLUTION B (BUFFER).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76310, 9197, 'SODIUM BICARBONATE', 'I', 3.090, 'G', '', '1000', 'N', 'ML', 'SOLUTION B (BUFFER).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66962, 9197, 'SODIUM BICARBONATE', 'I', 3.09, 'G', '', '1000', 'N', 'ML', 'COMPARTEMENT B ACTIVE CHANGED 2.69G TO 3.09G APPROVED BPS CONTROL NO. 117439. EW');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11905, 9197, 'SODIUM BICARBONATE', 'I', 4.20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8350, 9197, 'SODIUM BICARBONATE', 'I', 42, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3837, 9197, 'SODIUM BICARBONATE', 'I', 75, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1905, 9197, 'SODIUM BICARBONATE', 'I', 84, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9631, 9197, 'SODIUM BICARBONATE', 'I', 1.69, 'G', '', '', 'N', 'L', 'HISTORIC FREEFORM TEXT: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8587, 9197, 'SODIUM BICARBONATE', 'I', 650, 'G', '', '8', 'N', 'L', 'HISTORIC FREEFORM TEXT: SODIUM BICARBONATE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6370, 9197, 'SODIUM BICARBONATE', 'I', 6.74, 'G', '', '4', 'N', 'L', 'Historic Freeform Text: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6775, 9197, 'SODIUM BICARBONATE', 'I', 81.3, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48615, 9197, 'SODIUM BICARBONATE', 'I', 81.25, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67542, 9197, 'SODIUM BICARBONATE', 'I', 39.7, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71993, 9197, 'SODIUM BICARBONATE', 'I', 3.29, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71997, 9197, 'SODIUM BICARBONATE', 'I', 3.29, 'G', '', '', 'N', 'L', 'BAG B.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71998, 9197, 'SODIUM BICARBONATE', 'I', 3.29, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73309, 9197, 'SODIUM BICARBONATE', 'I', 80.7, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76226, 9197, 'SODIUM BICARBONATE', 'I', 28.35, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78010, 9197, 'SODIUM BICARBONATE', 'I', 12.9, 'G', '', '', 'N', 'L', 'SMALL COMPARTMENT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78012, 9197, 'SODIUM BICARBONATE', 'I', 12.9, 'G', '', '', 'N', 'L', 'SMALL COMPARTMENT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 9197, 'SODIUM BICARBONATE', 'I', 4.166, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10527, 9197, 'SODIUM BICARBONATE', 'I', 10, 'G', '', '75', 'N', 'G', 'Historic Freeform Text: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33790, 9197, 'SODIUM BICARBONATE', 'I', 57.69, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18635, 9197, 'SODIUM BICARBONATE', 'I', 500, 'MG', '', '19', 'N', 'G', 'Historic Freeform Text: SODIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15001, 9197, 'SODIUM BICARBONATE', 'I', 57.69, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SOD.BICARB. ((NA EQ. TO 15.79MG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6616, 9197, 'SODIUM BICARBONATE', 'I', 24.02, 'MG', '', '', 'N', 'G', 'LABEL HAS 6.72 G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42846, 9117, 'MORPHINE SULFATE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42847, 9117, 'MORPHINE SULFATE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42848, 9117, 'MORPHINE SULFATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18878, 9117, 'MORPHINE SULFATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18877, 9117, 'MORPHINE SULFATE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16102, 9117, 'MORPHINE SULFATE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16480, 9117, 'MORPHINE SULFATE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16481, 9117, 'MORPHINE SULFATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14176, 9117, 'MORPHINE SULFATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14178, 9117, 'MORPHINE SULFATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14142, 9117, 'MORPHINE SULFATE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14144, 9117, 'MORPHINE SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14107, 9117, 'MORPHINE SULFATE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14108, 9117, 'MORPHINE SULFATE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14110, 9117, 'MORPHINE SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14111, 9117, 'MORPHINE SULFATE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14541, 9117, 'MORPHINE SULFATE', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14542, 9117, 'MORPHINE SULFATE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14543, 9117, 'MORPHINE SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14502, 9117, 'MORPHINE SULFATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14394, 9117, 'MORPHINE SULFATE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14395, 9117, 'MORPHINE SULFATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6753, 9117, 'MORPHINE SULFATE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6754, 9117, 'MORPHINE SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6755, 9117, 'MORPHINE SULFATE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6757, 9117, 'MORPHINE SULFATE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MORPHINE SULFATE ((BASE EQ))  2009.04.03. AI SHOULD READ MORPHINE SULFATE AS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6129, 9117, 'MORPHINE SULFATE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6132, 9117, 'MORPHINE SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51392, 9117, 'MORPHINE SULFATE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51391, 9117, 'MORPHINE SULFATE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65841, 9117, 'MORPHINE SULFATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69308, 9117, 'MORPHINE SULFATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69309, 9117, 'MORPHINE SULFATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69310, 9117, 'MORPHINE SULFATE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69311, 9117, 'MORPHINE SULFATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69312, 9117, 'MORPHINE SULFATE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68780, 9117, 'MORPHINE SULFATE', 'I', 15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68781, 9117, 'MORPHINE SULFATE', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68782, 9117, 'MORPHINE SULFATE', 'I', 60, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78808, 9117, 'MORPHINE SULFATE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78809, 9117, 'MORPHINE SULFATE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83602, 9117, 'MORPHINE SULFATE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83608, 9117, 'MORPHINE SULFATE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83610, 9117, 'MORPHINE SULFATE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83611, 9117, 'MORPHINE SULFATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83613, 9117, 'MORPHINE SULFATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31285, 9117, 'MORPHINE SULFATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31286, 9117, 'MORPHINE SULFATE', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31288, 9117, 'MORPHINE SULFATE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13077, 9117, 'MORPHINE SULFATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13078, 9117, 'MORPHINE SULFATE', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13079, 9117, 'MORPHINE SULFATE', 'I', 5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12990, 9117, 'MORPHINE SULFATE', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12991, 9117, 'MORPHINE SULFATE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12992, 9117, 'MORPHINE SULFATE', 'I', 15, 'MG', '', '1', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12968, 9117, 'MORPHINE SULFATE', 'I', 0.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14020, 9117, 'MORPHINE SULFATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13966, 9117, 'MORPHINE SULFATE', 'I', 0.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10485, 9117, 'MORPHINE SULFATE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12728, 9117, 'MORPHINE SULFATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12701, 9117, 'MORPHINE SULFATE', 'I', 25, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12702, 9117, 'MORPHINE SULFATE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8917, 9117, 'MORPHINE SULFATE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7136, 9117, 'MORPHINE SULFATE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7421, 9117, 'MORPHINE SULFATE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6871, 9117, 'MORPHINE SULFATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6131, 9117, 'MORPHINE SULFATE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6133, 9117, 'MORPHINE SULFATE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6134, 9117, 'MORPHINE SULFATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6690, 9117, 'MORPHINE SULFATE', 'I', 25, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3043, 9117, 'MORPHINE SULFATE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3042, 9117, 'MORPHINE SULFATE', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66221, 9117, 'MORPHINE SULFATE', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18316, 9118, 'MEPERIDINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: MEPERIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36719, 9118, 'MEPERIDINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MEPERIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6872, 9118, 'MEPERIDINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEPERIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4294, 9118, 'MEPERIDINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEPERIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4234, 9118, 'MEPERIDINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEPERIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4235, 9118, 'MEPERIDINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEPERIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4236, 9118, 'MEPERIDINE HYDROCHLORIDE', 'I', 75, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEPERIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4237, 9118, 'MEPERIDINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEPERIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65672, 9118, 'MEPERIDINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEPERIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65673, 9118, 'MEPERIDINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MEPERIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65674, 9118, 'MEPERIDINE HYDROCHLORIDE', 'I', 75, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEPERIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65675, 9118, 'MEPERIDINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEPERIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65676, 9118, 'MEPERIDINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEPERIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2148, 9125, 'CAMPHOR', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2149, 9125, 'CAMPHOR', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2150, 9125, 'CAMPHOR', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42607, 9125, 'CAMPHOR', 'I', 0.38, '%', '', '', 'N', '', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9518, 9125, 'CAMPHOR', 'I', 0.65, '%', '', '', 'N', '', 'CAMPHOR 0.52% CHG TO 0.65% AS PER VDD 2006.04.05');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10065, 9125, 'CAMPHOR', 'I', 65, '%', '', '', 'N', '', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2819, 9125, 'CAMPHOR', 'I', 5.4, '%', '', '', 'N', '', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76643, 9125, 'CAMPHOR', 'I', 1.7, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76644, 9125, 'CAMPHOR', 'I', 1.7, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42334, 9125, 'CAMPHOR', 'I', 0.38, '%', '', '', 'N', '%', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22937, 9125, 'CAMPHOR', 'I', 5, '%', '', '', 'N', '%', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9551, 9125, 'CAMPHOR', 'I', 3, '%', '', '', 'N', '%', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3669, 9125, 'CAMPHOR', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6249, 9125, 'CAMPHOR', 'I', 5.124, 'G', '', '470', 'N', 'ML', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4553, 9125, 'CAMPHOR', 'I', 4.8, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3312, 9125, 'CAMPHOR', 'I', 6, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3314, 9125, 'CAMPHOR', 'I', 5.1, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5880, 9125, 'CAMPHOR', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6694, 9125, 'CAMPHOR', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (818, 9125, 'CAMPHOR', 'I', 31.17, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4657, 9125, 'CAMPHOR', 'I', 0.44, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2842, 9125, 'CAMPHOR', 'I', 25, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13570, 9125, 'CAMPHOR', 'I', 0.5, '%', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2443, 9125, 'CAMPHOR', 'I', 90, 'G', '', '4.8', 'N', 'KG', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61438, 9125, 'CAMPHOR', 'I', 0.3, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2977, 9125, 'CAMPHOR', 'I', 649, 'MG', '', '1', 'N', 'G', 'Historic Freeform Text: CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35047, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31568, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33917, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23669, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23354, 9131, 'CODEINE PHOSPHATE', 'I', 16.2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23355, 9131, 'CODEINE PHOSPHATE', 'I', 32.4, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22274, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19935, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19248, 9131, 'CODEINE PHOSPHATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19249, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74871, 7104, 'GLYCERINE', 'I', 10.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19250, 9131, 'CODEINE PHOSPHATE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15805, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15579, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15580, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15581, 9131, 'CODEINE PHOSPHATE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15578, 9131, 'CODEINE PHOSPHATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16474, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16475, 9131, 'CODEINE PHOSPHATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13699, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12944, 9131, 'CODEINE PHOSPHATE', 'I', 16.2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12946, 9131, 'CODEINE PHOSPHATE', 'I', 32.4, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12942, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12943, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14596, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14595, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13312, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13259, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13765, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13761, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11753, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11741, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11065, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11921, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11339, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9626, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9439, 9131, 'CODEINE PHOSPHATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5371, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5372, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6516, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6479, 9131, 'CODEINE PHOSPHATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5876, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6415, 9131, 'CODEINE PHOSPHATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6416, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6419, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5780, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6893, 9131, 'CODEINE PHOSPHATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6894, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6346, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7434, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6824, 9131, 'CODEINE PHOSPHATE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6763, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6764, 9131, 'CODEINE PHOSPHATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2918, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1025, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (955, 9131, 'CODEINE PHOSPHATE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2178, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2179, 9131, 'CODEINE PHOSPHATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2180, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (873, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (876, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (872, 9131, 'CODEINE PHOSPHATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47954, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47955, 9131, 'CODEINE PHOSPHATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52221, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51867, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51868, 9131, 'CODEINE PHOSPHATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51869, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (55849, 9131, 'CODEINE PHOSPHATE', 'I', 15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62074, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62075, 9131, 'CODEINE PHOSPHATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62101, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60750, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60162, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60917, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60919, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65859, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66118, 9131, 'CODEINE PHOSPHATE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66910, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67922, 9131, 'CODEINE PHOSPHATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67923, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70220, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70240, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73918, 9131, 'CODEINE PHOSPHATE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73920, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73187, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73359, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73537, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73681, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78862, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74897, 7104, 'GLYCERINE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2982, 9131, 'CODEINE PHOSPHATE', 'I', 0.2, '%', '', '', 'N', '%', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34650, 9131, 'CODEINE PHOSPHATE', 'I', 3.3, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19690, 9131, 'CODEINE PHOSPHATE', 'I', 10, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19625, 9131, 'CODEINE PHOSPHATE', 'I', 3.3, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20329, 9131, 'CODEINE PHOSPHATE', 'I', 10, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19244, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15618, 9131, 'CODEINE PHOSPHATE', 'I', 10, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13494, 9131, 'CODEINE PHOSPHATE', 'I', 10, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11384, 9131, 'CODEINE PHOSPHATE', 'I', 8, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8616, 9131, 'CODEINE PHOSPHATE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5504, 9131, 'CODEINE PHOSPHATE', 'I', 0.667, 'MG', '', '1', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6844, 9131, 'CODEINE PHOSPHATE', 'I', 3.33, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4806, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4232, 9131, 'CODEINE PHOSPHATE', 'I', 30, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4233, 9131, 'CODEINE PHOSPHATE', 'I', 60, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4469, 9131, 'CODEINE PHOSPHATE', 'I', 3.33, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (956, 9131, 'CODEINE PHOSPHATE', 'I', 10, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (957, 9131, 'CODEINE PHOSPHATE', 'I', 10, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (943, 9131, 'CODEINE PHOSPHATE', 'I', 143, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66929, 9131, 'CODEINE PHOSPHATE', 'I', 10, 'MG', '', '5', 'N', 'ML', 'AS HEMIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67953, 9131, 'CODEINE PHOSPHATE', 'I', 3.33, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67954, 9131, 'CODEINE PHOSPHATE', 'I', 3.3, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68031, 9131, 'CODEINE PHOSPHATE', 'I', 10, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68034, 9131, 'CODEINE PHOSPHATE', 'I', 10, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69689, 9131, 'CODEINE PHOSPHATE', 'I', 3.3, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69813, 9131, 'CODEINE PHOSPHATE', 'I', 3.3, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74333, 9131, 'CODEINE PHOSPHATE', 'I', 3.3, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CODEINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10569, 9150, 'DOCUSATE CALCIUM', 'I', 240, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL CALCIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10505, 9150, 'DOCUSATE CALCIUM', 'I', 240, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL CALCIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12344, 9150, 'DOCUSATE CALCIUM', 'I', 240, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL CALCIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10316, 9150, 'DOCUSATE CALCIUM', 'I', 240, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL CALCIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6756, 9150, 'DOCUSATE CALCIUM', 'I', 240, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIOCTYL CALCIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47964, 9150, 'DOCUSATE CALCIUM', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69084, 9150, 'DOCUSATE CALCIUM', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70938, 9150, 'DOCUSATE CALCIUM', 'I', 240, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIOCTYL CALCIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76888, 9150, 'DOCUSATE CALCIUM', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11296, 9114, 'CYCLOPENTAMINE HYDROCHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: CYCLOPENTAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (631, 9081, 'CLIOQUINOL', 'I', 3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IODOCHLORHYDROXYQUIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (868, 9081, 'CLIOQUINOL', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IODOCHLORHYDROXYQUIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (810, 9081, 'CLIOQUINOL', 'I', 3, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: IODOCHLORHYDROXYQUIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 9081, 'CLIOQUINOL', 'I', 0.08, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS QUINOLINE MIX 0.154MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11970, 9099, 'NYLIDRIN HYDROCHLORIDE', 'I', 6, 'MG', '', '', 'N', '', 'Historic Freeform Text: NYLIDRIN HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5367, 9099, 'NYLIDRIN HYDROCHLORIDE', 'I', 6, 'MG', '', '', 'N', '', 'Historic Freeform Text: NYLIDRIN HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14568, 7145, 'CETRIMONIUM BROMIDE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: CETRIMONIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10565, 7145, 'CETRIMONIUM BROMIDE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: CETRIMONIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12864, 7145, 'CETRIMONIUM BROMIDE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: CETRIMONIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4410, 7145, 'CETRIMONIUM BROMIDE', 'I', 150, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: CETRIMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1248, 7145, 'CETRIMONIUM BROMIDE', 'I', 750, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: CETRIMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2043, 7145, 'CETRIMONIUM BROMIDE', 'I', 40, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: CETRIMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (740, 7070, 'COTTON SEED OIL EXT.', 'I', 34.7, '%', '', '', 'N', '', 'Historic Freeform Text: COTTON SEED OIL EXT.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1385, 7091, 'BUTYL ALCOHOL', 'I', 7.0, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: N-             BUTYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78504, 7091, 'BUTYL ALCOHOL', 'I', 70, 'MG', '', '', 'N', 'ML', '(NF)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43377, 7093, 'POTASSIUM GLUCONATE', 'I', 468, 'MG', '', '', 'N', '', 'Historic Freeform Text: POTASSIUM GLUCONATE ((EQUIVAL. TO 2 MEQ K))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43378, 7093, 'POTASSIUM GLUCONATE', 'I', 720, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: POTASSIUM GLUCONATE ((EQUIVAL. TO 2 MEQ K))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13344, 7094, 'HEXETIDINE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: HEXETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61969, 7095, 'AMYLMETACRESOL', 'I', 0.6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59951, 7095, 'AMYLMETACRESOL', 'I', 0.6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81250, 7095, 'AMYLMETACRESOL', 'I', 0.6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80640, 7095, 'AMYLMETACRESOL', 'I', 0.6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43651, 7104, 'GLYCERINE', 'I', 2.6, '%', '', '', 'N', '', 'Historic Freeform Text: GLYCERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19632, 7104, 'GLYCERINE', 'I', 4.85, '%', '', '', 'N', '', 'Historic Freeform Text: GLYCERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19634, 7104, 'GLYCERINE', 'I', 8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19631, 7104, 'GLYCERINE', 'I', 4.85, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16106, 7104, 'GLYCERINE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15101, 7104, 'GLYCERINE', 'I', 10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GLYCERIN ((ACTIVATOR))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8427, 7104, 'GLYCERINE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: GLYCERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9555, 7104, 'GLYCERINE', 'I', 6.0, '%', '', '', 'N', '', 'Historic Freeform Text: GLYCERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1912, 7104, 'GLYCERINE', 'I', 50, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GLYCERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (620, 7104, 'GLYCERINE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: GLYCERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1593, 7104, 'GLYCERINE', 'I', 10.52, '%', '', '', 'N', '', 'Historic Freeform Text: GLYCERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47379, 7104, 'GLYCERINE', 'I', 0.2, '%', '', '', 'N', '', 'V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63587, 7104, 'GLYCERINE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66850, 7104, 'GLYCERINE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67103, 7104, 'GLYCERINE', 'I', 5.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71847, 7104, 'GLYCERINE', 'I', 5, '%', '', '', 'N', '', 'W/W   GLYCERINE 99.5%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71848, 7104, 'GLYCERINE', 'I', 5, '%', '', '', 'N', '', 'W/W   GLYCERINE 99.5%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70567, 7104, 'GLYCERINE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75216, 7104, 'GLYCERINE', 'I', 8, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72929, 7104, 'GLYCERINE', 'I', 7, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72379, 7104, 'GLYCERINE', 'I', 0.26, '%', '', '', 'N', '', 'V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74675, 7104, 'GLYCERINE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74867, 7104, 'GLYCERINE', 'I', 10.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74869, 7104, 'GLYCERINE', 'I', 10.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74870, 7104, 'GLYCERINE', 'I', 10.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74898, 7104, 'GLYCERINE', 'I', 3.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74900, 7104, 'GLYCERINE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74901, 7104, 'GLYCERINE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74902, 7104, 'GLYCERINE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74903, 7104, 'GLYCERINE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76973, 7104, 'GLYCERINE', 'I', 10, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78464, 7104, 'GLYCERINE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78465, 7104, 'GLYCERINE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3890, 7104, 'GLYCERINE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7269, 7104, 'GLYCERINE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77230, 7104, 'GLYCERINE', 'I', 0.25, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78028, 7104, 'GLYCERINE', 'I', 0.25, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79438, 7104, 'GLYCERINE', 'I', 8.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79247, 7104, 'GLYCERINE', 'I', 8.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8342, 7104, 'GLYCERINE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60155, 7104, 'GLYCERINE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62999, 7104, 'GLYCERINE', 'I', 7.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74899, 7104, 'GLYCERINE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1957, 7104, 'GLYCERINE', 'I', 10.00, '%', '', '', 'N', 'W/W', 'GLYCERINE ADDED AS AN ACTIVE DURING CONTROL NO. 137265.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84552, 7104, 'GLYCERINE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84583, 7104, 'GLYCERINE', 'I', 0.50, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12540, 7104, 'GLYCERINE', 'I', 2.000, '%', '', '', 'N', 'W/V', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80709, 7104, 'GLYCERINE', 'I', 0.3, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83970, 7104, 'GLYCERINE', 'I', 0.2, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3724, 7104, 'GLYCERINE', 'I', 36, 'G', '', '', 'N', 'PAD', 'Historic Freeform Text: GLYCERINE Qty Unit: PAD');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24726, 7104, 'GLYCERINE', 'I', 10, '%', '', '', 'N', '%', 'Historic Freeform Text: GLYCERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9161, 7104, 'GLYCERINE', 'I', 5, '%', '', '', 'N', '%', 'Historic Freeform Text: GLYCERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6015, 7104, 'GLYCERINE', 'I', 5, '%', '', '', 'N', '%', 'Historic Freeform Text: GLYCERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1894, 7104, 'GLYCERINE', 'I', 13, '%', '', '', 'N', '%', 'Historic Freeform Text: GLYCERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43172, 7104, 'GLYCERINE', 'I', 1.67, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GLYCERINE ((ANHYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18484, 7104, 'GLYCERINE', 'I', 2.2, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18647, 7104, 'GLYCERINE', 'I', 2.2, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11330, 7104, 'GLYCERINE', 'I', 57, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60965, 7104, 'GLYCERINE', 'I', 800, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66081, 7104, 'GLYCERINE', 'I', 3, 'MG', '', '', 'N', 'ML', 'APPROVED LABEL HAS 0.3% W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37335, 7053, 'DIBUCAINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIBUCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37455, 7053, 'DIBUCAINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIBUCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66276, 7053, 'DIBUCAINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72190, 7053, 'DIBUCAINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 7053, 'DIBUCAINE HYDROCHLORIDE', 'I', 0.073, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS CAINE MIX 0.51MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37334, 7053, 'DIBUCAINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: DIBUCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37454, 7053, 'DIBUCAINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: DIBUCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66275, 7053, 'DIBUCAINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71565, 7053, 'DIBUCAINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4538, 7068, 'METHENAMINE MANDELATE', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METHENAMINE MANDELATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1291, 6995, 'CHLOROBUTANOL', 'I', 38.3, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: CHLOROBUTANOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1103, 6995, 'CHLOROBUTANOL', 'I', 0.55, 'G', '', '11', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1958, 6995, 'CHLOROBUTANOL', 'I', 1.41875, 'KG', '', '576', 'N', 'L', 'Historic Freeform Text: CHLOROBUTANOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (622, 6999, 'TANNIC ACID', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: TANNIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2181, 6999, 'TANNIC ACID', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: TANNIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71907, 6999, 'TANNIC ACID', 'I', 6, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1895, 6999, 'TANNIC ACID', 'I', 1.82, '%', '', '', 'N', '%', 'Historic Freeform Text: TANNIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1320, 6999, 'TANNIC ACID', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: TANNIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8567, 6999, 'TANNIC ACID', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TANNIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8529, 6999, 'TANNIC ACID', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TANNIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4657, 6964, 'AMMONIUM CARBONATE', 'I', 30.2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79691, 6966, 'BENZOIC ACID', 'I', 0.15, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66816, 6966, 'BENZOIC ACID', 'I', 0.15, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70202, 4922, 'VITAMIN D3 (CHOLECALCIFEROL)', 'I', 250, 'UNIT', '', '', 'N', '', 'BLUE TABLET P.M.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76186, 4922, 'VITAMIN D3 (CHOLECALCIFEROL)', 'I', 250, 'UNIT', '', '', 'N', '', 'BLUE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76210, 4922, 'VITAMIN D3 (CHOLECALCIFEROL)', 'I', 2800, 'UNIT', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73813, 4922, 'VITAMIN D3 (CHOLECALCIFEROL)', 'I', 10000, 'UNIT', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80047, 4922, 'VITAMIN D3 (CHOLECALCIFEROL)', 'I', 5600, 'UNIT', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85666, 4922, 'VITAMIN D3', 'I', 50000, 'UNIT', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22007, 4922, 'VITAMIN D3', 'I', 176.7, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VIT. D');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9372, 4922, 'VITAMIN D3', 'I', 176.7, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7146, 4922, 'VITAMIN D3', 'I', 75000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. D');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5607, 4922, 'VITAMIN D3', 'I', 75000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (921, 4922, 'VITAMIN D3 (CHOLECALCIFEROL)', 'I', 4000, 'UNIT', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62354, 4922, 'VITAMIN D3 (CHOLECALCIFEROL)', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63763, 4922, 'VITAMIN D3', 'I', 5000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63765, 4922, 'VITAMIN D3', 'I', 25000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72902, 4922, 'VITAMIN D3', 'I', 75000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74400, 4922, 'VITAMIN D3 (CHOLECALCIFEROL)', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 4922, 'VITAMIN D3', 'I', 440000, 'UNIT', '', '', 'N', 'KG', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19635, 4922, 'VITAMIN D3', 'I', 55000, 'UNIT', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11033, 4922, 'VITAMIN D3', 'I', 27500, 'UNIT', '', '', 'N', 'KG', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 4922, 'VITAMIN D3', 'I', 58024, 'UNIT', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8267, 4922, 'VITAMIN D3', 'I', 66000, 'UNIT', '', '', 'N', 'KG', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5784, 4922, 'VITAMIN D3', 'I', 55000, 'UNIT', '', '', 'N', 'KG', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 4922, 'VITAMIN D3', 'I', 440000, 'UNIT', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82282, 4922, 'VITAMIN D3', 'I', 66000, 'UNIT', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36843, 4922, 'VITAMIN D3 (CHOLECALCIFEROL)', 'I', 1000000, 'UNIT', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: VITAMIN D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35469, 4922, 'VITAMIN D3', 'I', 353, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: VITAMIN D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33790, 4922, 'VITAMIN D3 (CHOLECALCIFEROL)', 'I', 1320, 'UNIT', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24471, 4922, 'VITAMIN D3', 'I', 280500, 'UNIT', '', '170', 'N', 'G', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24400, 4922, 'VITAMIN D3', 'I', 253125, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17818, 4922, 'VITAMIN D3', 'I', 1000000, 'UNIT', '', '400', 'N', 'G', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17121, 4922, 'VITAMIN D3', 'I', 1000000, 'UNIT', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 4922, 'VITAMIN D3', 'I', 561000, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14165, 4922, 'VITAMIN D3', 'I', 80000, 'UNIT', '', '450', 'N', 'G', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14119, 4922, 'VITAMIN D3', 'I', 1000000, 'UNIT', '', '400', 'N', 'G', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14115, 4922, 'VITAMIN D3', 'I', 250000, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14113, 4922, 'VITAMIN D3', 'I', 561000, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12922, 4922, 'VITAMIN D3', 'I', 1485000, 'UNIT', '', '400', 'N', 'G', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15001, 4922, 'VITAMIN D3 (CHOLECALCIFEROL)', 'I', 1320, 'UNIT', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8101, 4922, 'VITAMIN D3', 'I', 70000, 'UNIT', '', '400', 'N', 'G', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5322, 4922, 'VITAMIN D3', 'I', 1322.8, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5144, 4922, 'VITAMIN D3', 'I', 250000, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5125, 4922, 'VITAMIN D3', 'I', 250000, 'UNIT', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3926, 4922, 'VITAMIN D3', 'I', 80000, 'UNIT', '', '450', 'N', 'G', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1617, 4922, 'VITAMIN D3', 'I', 383333, 'UNIT', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1613, 4922, 'VITAMIN D3', 'I', 140000, 'UNIT', '', '454', 'N', 'G', 'Historic Freeform Text: VIT. D3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50391, 4922, 'VITAMIN D3', 'I', 240, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66631, 4922, 'VITAMIN D3 (CHOLECALCIFEROL)', 'I', 33000, 'UNIT', '', '300', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (236, 4924, 'VITAMIN D2', 'I', 125, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: VIT. D2');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60784, 4924, 'VITAMIN D2', 'I', 50000, 'UNIT', '', '', 'N', '', 'MEDICINAL INGREDIENT CHANGED FROM VITAMIN D TO D2 TO MORE ACCURATELY REFLECT THIS PRODUCT ESPECIALLY');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78724, 4924, 'VITAMIN D2', 'I', 50000, 'UNIT', '', '', 'N', '', 'MEDICINAL INGREDIENT CHANGED FROM VITAMIN D TO D2 TO MORE ACCURATELY REFLECT THIS PRODUCT ESPECIALLY');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (45769, 4931, 'DL-ALPHA TOCOPHERYL ACETATE', 'I', 10000, 'UNIT', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: VIT E ((DL @ TOCOPH ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17121, 4931, 'DL-ALPHA TOCOPHERYL ACETATE', 'I', 1500, 'UNIT', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: TOCOPHERYL DL-ALPHA ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66864, 4931, 'DL-ALPHA TOCOPHERYL ACETATE', 'I', 75, 'UNIT', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12874, 4861, 'FERRIC HYPOPHOSPHITE', 'I', 68, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: FERRIC HYPOPHOSPHITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64083, 4863, 'IRON OXIDE', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49958, 4876, 'IRON SUBSULFATE', 'I', 61, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76196, 4876, 'IRON SUBSULFATE', 'I', 61, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36697, 4884, 'FERRIC CHLORIDE', 'I', 1.131, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FERRIC CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5655, 4884, 'FERRIC CHLORIDE', 'I', 1.13, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FERRIC CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3190, 4884, 'FERRIC CHLORIDE', 'I', 5.655, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: FERRIC CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4718, 4884, 'FERRIC CHLORIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: FERRIC CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3104, 4884, 'FERRIC CHLORIDE', 'I', 5.655, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: FERRIC CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19369, 4889, 'FERRIC AMMONIUM CITRATE', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FERRIC AMMONIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16486, 4889, 'FERRIC AMMONIUM CITRATE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FERRIC AMMONIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10470, 4889, 'FERRIC AMMONIUM CITRATE', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FERRIC AMMONIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12562, 4889, 'FERRIC AMMONIUM CITRATE', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FERRIC AMMONIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9254, 4889, 'FERRIC AMMONIUM CITRATE', 'I', 15, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9527, 4889, 'FERRIC AMMONIUM CITRATE', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FERRIC AMMONIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7179, 4889, 'FERRIC AMMONIUM CITRATE', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FERRIC AMMONIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6071, 4889, 'FERRIC AMMONIUM CITRATE', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FERRIC AMMONIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5902, 4889, 'FERRIC AMMONIUM CITRATE', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FERRIC AMMONIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6339, 4889, 'FERRIC AMMONIUM CITRATE', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FERRIC AMMONIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7329, 4889, 'FERRIC AMMONIUM CITRATE', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FERRIC AMMONIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78915, 4889, 'FERRIC AMMONIUM CITRATE', 'I', 15, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7292, 4892, 'ALFACALCIDOL', 'I', 0.25, 'µG', '', '', 'N', '', 'Historic Freeform Text: ALFACALCIDOL ((CAP))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7293, 4892, 'ALFACALCIDOL', 'I', 1, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALFACALCIDOL ((CAP))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63869, 4892, 'ALFACALCIDOL', 'I', 2, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66245, 4892, 'ALFACALCIDOL', 'I', 2, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3429, 4893, 'CALCITRIOL', 'I', 0.5, 'µG', '', '', 'N', '', 'Historic Freeform Text: CALCITRIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3430, 4893, 'CALCITRIOL', 'I', 0.25, 'µG', '', '', 'N', '', 'Historic Freeform Text: CALCITRIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11291, 4893, 'CALCITRIOL', 'I', 2, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: CALCITRIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11150, 4893, 'CALCITRIOL', 'I', 1, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: CALCITRIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12885, 4893, 'CALCITRIOL', 'I', 1, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: CALCITRIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69787, 4893, 'CALCITRIOL', 'I', 1, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: CALCITRIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82422, 4893, 'CALCITRIOL', 'I', 3, 'µG', '', '', 'N', 'G', 'Historic Freeform Text: CALCITRIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37581, 4825, 'IRON PEPTONIZED', 'I', 0.06, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: IRON PEPTONIZED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80280, 4825, 'IRON PEPTONIZED', 'I', 0.50, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13009, 4800, 'CALCIUM BOROGLUCONATE', 'I', 23, '%', '', '', 'N', '', 'Historic Freeform Text: CALCIUM BOROGLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12924, 4800, 'CALCIUM BOROGLUCONATE', 'I', 23, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12930, 4800, 'CALCIUM BOROGLUCONATE', 'I', 18.7, '%', '', '', 'N', '', 'Historic Freeform Text: CALCIUM BOROGLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4770, 4800, 'CALCIUM BOROGLUCONATE', 'I', 23, '%', '', '', 'N', '', 'Historic Freeform Text: CALCIUM BOROGLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3326, 4800, 'CALCIUM BOROGLUCONATE', 'I', 23, '%', '', '', 'N', '', 'Historic Freeform Text: CALCIUM BOROGLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73240, 4800, 'CALCIUM BOROGLUCONATE', 'I', 23, '%', '', '', 'N', 'W/V', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12932, 4800, 'CALCIUM BOROGLUCONATE', 'I', 23, '%', '', '', 'N', '%', 'Historic Freeform Text: CALCIUM BOROGLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12933, 4800, 'CALCIUM BOROGLUCONATE', 'I', 23, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM BOROGLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2003, 4808, 'CALCIUM GLUCONATE', 'I', 100, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: CALCIUM GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1614, 4808, 'CALCIUM GLUCONATE', 'I', 100, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: CALCIUM GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18936, 4808, 'CALCIUM GLUCONATE', 'I', 94, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CALCIUM GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14119, 4808, 'CALCIUM GLUCONATE', 'I', 15.5, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: CALCIUM GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8523, 4808, 'CALCIUM GLUCONATE', 'I', 40, 'G', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2043, 4808, 'CALCIUM GLUCONATE', 'I', 200, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: CALCIUM GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4761, 4809, 'CALCIUM LEVULINATE', 'I', 15, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CALCIUM LEVULINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2193, 4810, 'CALCIUM ACETATE', 'I', 1.755, 'G', '', '', 'N', '', 'Historic Freeform Text: CALCIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2182, 4810, 'CALCIUM ACETATE', 'I', 1.755, 'G', '', '', 'N', '', 'Historic Freeform Text: CALCIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47284, 4810, 'CALCIUM ACETATE', 'I', 667, 'MG', '', '', 'N', '', 'EACH TABLET CONTAIN 667 MG OF CALCIUM ACETATE EQUIVALENT TO 169MG OF CALCIUM /JJ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23184, 4810, 'CALCIUM ACETATE', 'I', 440, 'MG', '', '25', 'N', 'ML', 'CALCIUM ACETATE.H2O');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36843, 4810, 'CALCIUM ACETATE', 'I', 7.14, 'G', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: CALCIUM ACETATE ((CALCIUM EQ.1.81GM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17818, 4810, 'CALCIUM ACETATE', 'I', 7.14, 'G', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: CA ((AS ACETATE 7.14GM)),');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33790, 4810, 'CALCIUM ACETATE', 'I', 9, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: CALCIUM ACETATE ((CALCIUM EQ. 2 MG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5322, 4810, 'CALCIUM ACETATE', 'I', 0.33, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: CALCIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2488, 6850, 'BENZOYL PEROXIDE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (622, 4811, 'CALCIUM HYDROXIDE', 'I', 71, '%', '', '', 'N', '', 'Historic Freeform Text: CALCIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1894, 4811, 'CALCIUM HYDROXIDE', 'I', 33.33, '%', '', '', 'N', '%', 'Historic Freeform Text: CALCIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9342, 4811, 'CALCIUM HYDROXIDE', 'I', 18.4, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: CALCIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 4817, 'COBALT CARBONATE (BASIC)', 'I', 0.25, 'G', '', '', 'N', 'KG', 'ADDED 2010.04.14 AS PER VDD REQUEST./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19369, 4818, 'COBALT GLUCONATE', 'I', 0.7, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: COBALT GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16486, 4818, 'COBALT GLUCONATE', 'I', 0.05, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: COBALT GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10470, 4818, 'COBALT GLUCONATE', 'I', 0.7, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: COBALT GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12562, 4818, 'COBALT GLUCONATE', 'I', 0.7, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: COBALT GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9254, 4818, 'COBALT GLUCONATE', 'I', 0.7, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7179, 4818, 'COBALT GLUCONATE', 'I', 0.7, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: COBALT GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6071, 4818, 'COBALT GLUCONATE', 'I', 0.7, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: COBALT GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6339, 4818, 'COBALT GLUCONATE', 'I', 0.7, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: COBALT GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7329, 4818, 'COBALT GLUCONATE', 'I', 0.7, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: COBALT GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78915, 4818, 'COBALT GLUCONATE', 'I', 0.7, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 4820, 'COBALT SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: COBALT SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12874, 4820, 'COBALT SULFATE', 'I', 32, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: COBALT SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5925, 4820, 'COBALT SULFATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: COBALT SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5147, 4820, 'COBALT SULFATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: COBALT SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6566, 4820, 'COBALT SULFATE', 'I', 35, 'µG', '', '', 'N', 'G', 'Historic Freeform Text: COBALT SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2119, 4820, 'COBALT SULFATE', 'I', 1, 'MG', '', '30', 'N', 'G', 'Historic Freeform Text: COBALT SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47888, 4820, 'COBALT SULFATE', 'I', 0.0701, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66864, 4820, 'COBALT SULFATE', 'I', 14.7, 'MG', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66865, 4820, 'COBALT SULFATE', 'I', 14.7, 'MG', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7144, 4821, 'COBALT (COBALTOUS CHLORIDE)', 'I', 22, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: COBALT CHLORIDE ((COBALT EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81317, 4821, 'COBALT (COBALT CARBONATE (BASIC))', 'I', 235, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9527, 4821, 'COBALT (COBALT GLUCONATE)', 'I', 0.7, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: COBALT GLUCONATE ((COBALT EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 4821, 'COBALT (COBALT CARBONATE (BASIC))', 'I', 3.09, 'MG', '', '', 'Y', 'KG', 'HISTORIC FREEFORM TEXT: COBALT CARBONATE ((COBALT EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18635, 4821, 'COBALT (COBALTOUS CHLORIDE)', 'I', 22, 'MG', '', '19', 'Y', 'G', 'HISTORIC FREEFORM TEXT: CO ((AS CHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64359, 11907, 'TELMISARTAN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64358, 11907, 'TELMISARTAN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68312, 11907, 'TELMISARTAN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80418, 11907, 'TELMISARTAN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85622, 11907, 'TELMISARTAN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85623, 11907, 'TELMISARTAN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85624, 11907, 'TELMISARTAN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85625, 11907, 'TELMISARTAN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64397, 11909, 'ICODEXTRIN', 'I', 75, 'G', '', '', 'N', 'L', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64454, 11911, 'ZANAMIVIR', 'I', 5, 'MG', '', '', 'N', 'BLISTER', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64588, 11916, 'LEPIRUDIN', 'I', 50, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64296, 11879, 'INOSINE PRANOBEX', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63758, 11881, 'ANCESTIM', 'I', 1875, 'µG', '', '', 'N', 'VIAL', '1875MCG/VIAL/KIT.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63865, 11884, 'ORLISTAT', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82321, 11885, 'ALITRETINOIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82322, 11885, 'ALITRETINOIN', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63892, 11891, 'EPTIFIBATIDE', 'I', 0.75, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63894, 11891, 'EPTIFIBATIDE', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63899, 11893, 'ABACAVIR (ABACAVIR SULFATE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68746, 11893, 'ABACAVIR (ABACAVIR SULFATE)', 'I', 300, 'MG', '', '', 'Y', '', 'ABACAVIR SULFATE 351.0 MG IS EQUIVALENT TO 300 MG ABACAVIR PER TABLET BASED ON A SULFATE SALT CONVER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75473, 11893, 'ABACAVIR (ABACAVIR SULFATE)', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63900, 11893, 'ABACAVIR (ABACAVIR SULFATE)', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63981, 11894, 'EPROSARTAN (EPROSARTAN MESYLATE)', 'I', 400, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67885, 11894, 'EPROSARTAN (EPROSARTAN MESYLATE)', 'I', 600, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73859, 11894, 'EPROSARTAN (EPROSARTAN MESYLATE)', 'I', 600, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64089, 11899, 'RIZATRIPTAN (RIZATRIPTAN BENZOATE)', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64090, 11899, 'RIZATRIPTAN (RIZATRIPTAN BENZOATE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64091, 11899, 'RIZATRIPTAN (RIZATRIPTAN BENZOATE)', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64092, 11899, 'RIZATRIPTAN (RIZATRIPTAN BENZOATE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63507, 11874, 'TRIPTORELIN (TRIPTORELIN PAMOATE)', 'I', 3.75, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67797, 11874, 'TRIPTORELIN (TRIPTORELIN PAMOATE)', 'I', 11.25, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64277, 11905, 'TRASTUZUMAB', 'I', 440, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63376, 11857, 'EFAVIRENZ', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63374, 11857, 'EFAVIRENZ', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78602, 11857, 'EFAVIRENZ', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70176, 11857, 'EFAVIRENZ', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70739, 11859, 'CARPROFEN', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70740, 11859, 'CARPROFEN', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70741, 11859, 'CARPROFEN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80606, 11859, 'CARPROFEN', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80605, 11859, 'CARPROFEN', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80607, 11859, 'CARPROFEN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74088, 11859, 'CARPROFEN', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63424, 11860, 'REPAGLINIDE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63425, 11860, 'REPAGLINIDE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63426, 11860, 'REPAGLINIDE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80688, 11860, 'REPAGLINIDE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80689, 11860, 'REPAGLINIDE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80690, 11860, 'REPAGLINIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84011, 11860, 'REPAGLINIDE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84012, 11860, 'REPAGLINIDE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84013, 11860, 'REPAGLINIDE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84259, 11860, 'REPAGLINIDE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84260, 11860, 'REPAGLINIDE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84261, 11860, 'REPAGLINIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63442, 11865, 'CELECOXIB', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63443, 11865, 'CELECOXIB', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62602, 11819, 'RISEDRONATE SODIUM (RISEDRONATE SODIUM HEMI-PENTAHYDRATE)', 'I', 30, 'MG', '', '', 'N', '', 'AS RISEDRONATE SODIUM HEMI-PENTAHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66266, 11819, 'RISEDRONATE SODIUM (RISEDRONATE SODIUM HEMI-PENTAHYDRATE)', 'I', 5, 'MG', '', '', 'N', '', 'RISEDRONATE SODIUM (AS HEMI-PENTAHYDRATE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71123, 11819, 'RISEDRONATE SODIUM (RISEDRONATE SODIUM HEMI-PENTAHYDRATE)', 'I', 35, 'MG', '', '', 'N', '', 'RISEDRONATE SODIUM (AS HEMI-PENTAHYDRATE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76526, 11819, 'RISEDRONATE SODIUM', 'I', 35, 'MG', '', '', 'N', '', 'LIGHT ORANGE TABLET WITH RSN : RISEDRONATE SODIUM SUPPLIED AS RISEDRONATE SODIUM HEMI-PENTAHYDRATE (');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78367, 11819, 'RISEDRONATE SODIUM (RISEDRONATE SODIUM MONOHYDRATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78368, 11819, 'RISEDRONATE SODIUM (RISEDRONATE SODIUM MONOHYDRATE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78369, 11819, 'RISEDRONATE SODIUM (RISEDRONATE SODIUM MONOHYDRATE)', 'I', 35, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78312, 11819, 'RISEDRONATE SODIUM (RISEDRONATE SODIUM HEMI-PENTAHYDRATE)', 'I', 75, 'MG', '', '', 'N', '', 'ANHYDROUS RISEDRONATE SODIUM IN THE FORM OF THE HEMIPENTAHYDRATE WITH SMALL AMTS OF MONOHYDRATE. EW ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80233, 11819, 'RISEDRONATE SODIUM (RISEDRONATE SODIUM HEMI-PENTAHYDRATE)', 'I', 150, 'MG', '', '', 'N', '', 'ANHYDROUS RISEDRONATE SODIUM IN THE FORM OF THE HEMIPENTAHYDRATE WITH SMALL AMTS OF MONOHYDRATE. EW ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82662, 11819, 'RISEDRONATE SODIUM (RISEDRONATE SODIUM HEMI-PENTAHYDRATE)', 'I', 35, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79553, 11819, 'RISEDRONATE SODIUM (RISEDRONATE SODIUM HEMI-PENTAHYDRATE)', 'I', 35, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78754, 11819, 'RISEDRONATE SODIUM (RISEDRONATE SODIUM HEMI-PENTAHYDRATE)', 'I', 35, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81259, 11819, 'RISEDRONATE SODIUM (RISEDRONATE SODIUM HEMI-PENTAHYDRATE)', 'I', 35, 'MG', '', '', 'N', '', 'RISEDRONATE SODIUM (AS HEMI-PENTAHYDRATE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80533, 11819, 'RISEDRONATE SODIUM (RISEDRONATE SODIUM HEMI-PENTAHYDRATE)', 'I', 35, 'MG', '', '', 'Y', '', 'RISEDRONATE SODIUM  35 MG AS THE HEMI-PENTAHYDRATE WITH SMALL AMOUNTS OF MONOHYDRATE AS PER PM - DOS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83286, 11819, 'RISEDRONATE SODIUM (RISEDRONATE SODIUM HEMI-PENTAHYDRATE)', 'I', 35, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83739, 11819, 'RISEDRONATE SODIUM (RISEDRONATE SODIUM HEMI-PENTAHYDRATE)', 'I', 35, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83888, 11819, 'RISEDRONATE SODIUM (RISEDRONATE SODIUM HEMI-PENTAHYDRATE)', 'I', 35, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85557, 11819, 'RISEDRONATE SODIUM (RISEDRONATE SODIUM HEMI-PENTAHYDRATE)', 'I', 35, 'MG', '', '', 'N', '', 'AS RISEDRONATE SODIUM HEMI-PENTAHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62626, 11821, 'TIZANIDINE (TIZANIDINE HYDROCHLORIDE)', 'I', 4, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74515, 11821, 'TIZANIDINE (TIZANIDINE HYDROCHLORIDE)', 'I', 4, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75758, 11821, 'TIZANIDINE (TIZANIDINE HYDROCHLORIDE)', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62662, 11827, 'VEDAPROFEN', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71154, 11827, 'VEDAPROFEN', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62882, 11833, 'CAT (FELIS DOMESTICUS) PELT AND CAT DANDER', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13536, 9054, 'WARFARIN SODIUM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: WARFARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13418, 9054, 'WARFARIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: WARFARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13419, 9054, 'WARFARIN SODIUM', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: WARFARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13375, 9054, 'WARFARIN SODIUM', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: WARFARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12818, 9054, 'WARFARIN SODIUM', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: WARFARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12819, 9054, 'WARFARIN SODIUM', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: WARFARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63731, 9054, 'WARFARIN SODIUM', 'I', 3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63732, 9054, 'WARFARIN SODIUM', 'I', 6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66470, 9054, 'WARFARIN SODIUM', 'I', 1, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66471, 9054, 'WARFARIN SODIUM', 'I', 2, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66472, 9054, 'WARFARIN SODIUM', 'I', 2.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66473, 9054, 'WARFARIN SODIUM', 'I', 3, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66474, 9054, 'WARFARIN SODIUM', 'I', 4, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66475, 9054, 'WARFARIN SODIUM', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66476, 9054, 'WARFARIN SODIUM', 'I', 6, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66477, 9054, 'WARFARIN SODIUM', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66492, 9054, 'WARFARIN SODIUM', 'I', 7.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66762, 9054, 'WARFARIN SODIUM', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66763, 9054, 'WARFARIN SODIUM', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66764, 9054, 'WARFARIN SODIUM', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66765, 9054, 'WARFARIN SODIUM', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66766, 9054, 'WARFARIN SODIUM', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66767, 9054, 'WARFARIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68431, 9054, 'WARFARIN SODIUM', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68432, 9054, 'WARFARIN SODIUM', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68433, 9054, 'WARFARIN SODIUM', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68435, 9054, 'WARFARIN SODIUM', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68436, 9054, 'WARFARIN SODIUM', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68437, 9054, 'WARFARIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69718, 9054, 'WARFARIN SODIUM', 'I', 3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75076, 9054, 'WARFARIN SODIUM', 'I', 1, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75077, 9054, 'WARFARIN SODIUM', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75078, 9054, 'WARFARIN SODIUM', 'I', 2.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75079, 9054, 'WARFARIN SODIUM', 'I', 3, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75080, 9054, 'WARFARIN SODIUM', 'I', 4, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75081, 9054, 'WARFARIN SODIUM', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77289, 9054, 'WARFARIN SODIUM', 'I', 3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77290, 9054, 'WARFARIN SODIUM', 'I', 6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77291, 9054, 'WARFARIN SODIUM', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82943, 9054, 'WARFARIN SODIUM', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82944, 9054, 'WARFARIN SODIUM', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82945, 9054, 'WARFARIN SODIUM', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82946, 9054, 'WARFARIN SODIUM', 'I', 3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82947, 9054, 'WARFARIN SODIUM', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82948, 9054, 'WARFARIN SODIUM', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82949, 9054, 'WARFARIN SODIUM', 'I', 6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82950, 9054, 'WARFARIN SODIUM', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82951, 9054, 'WARFARIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1118, 9062, 'ACENOCOUMAROL', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACENOCOUMAROL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1084, 9062, 'ACENOCOUMAROL', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACENOCOUMAROL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37335, 9068, 'ESCULIN', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: ESCULIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37455, 9068, 'ESCULIN', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ESCULIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66276, 9068, 'ESCULIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72190, 9068, 'ESCULIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37334, 9068, 'ESCULIN', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: ESCULIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37454, 9068, 'ESCULIN', 'I', 10, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: ESCULIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66275, 9068, 'ESCULIN', 'I', 10, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71565, 9068, 'ESCULIN', 'I', 10, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4882, 8989, 'METHSCOPOLAMINE BROMIDE', 'I', 0.25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METHSCOPOLAMINE BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2782, 8989, 'METHSCOPOLAMINE BROMIDE', 'I', 0.25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METHSCOPOLAMINE BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4989, 9011, 'SCOPOLAMINE HYDROBROMIDE', 'I', 2.4, 'µG', '', '', 'N', '', 'Historic Freeform Text: HYOSCINE HYDROBROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4787, 9011, 'SCOPOLAMINE HYDROBROMIDE', 'I', 0.4, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HYOSCINE HYDROBROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4788, 9011, 'SCOPOLAMINE HYDROBROMIDE', 'I', 0.6, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HYOSCINE HYDROBROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66635, 9011, 'SCOPOLAMINE HYDROBROMIDE', 'I', 0.4, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66636, 9011, 'SCOPOLAMINE HYDROBROMIDE', 'I', 0.6, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4989, 8966, 'HYOSCYAMINE HYDROBROMIDE', 'I', 0.09, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYOSCYAMINE HYDROBROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4088, 8967, 'ATROPINE METHYLNITRATE', 'I', 1.35, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATROPINE METHYLNITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2587, 8967, 'ATROPINE METHYLNITRATE', 'I', 0.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATROPINE METHYLNITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (753, 8967, 'ATROPINE METHYLNITRATE', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATROPINE METHYLNITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1612, 8975, 'HYOSCYAMINE SULFATE', 'I', 0.1, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYOSCYAMINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2005, 8975, 'HYOSCYAMINE SULFATE', 'I', 0.1, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYOSCYAMINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1993, 8975, 'HYOSCYAMINE SULFATE', 'I', 2.5, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: HYOSCYAMINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1766, 8975, 'HYOSCYAMINE SULFATE', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HYOSCYAMINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2013, 8944, 'L-EPHEDRINE HYDROCHLORIDE', 'I', 0.01, '%', '', '', 'N', '%', 'Historic Freeform Text: L-EPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13479, 8944, 'L-EPHEDRINE HYDROCHLORIDE', 'I', 7.5, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: L-EPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2548, 8944, 'L-EPHEDRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: L-EPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2044, 8944, 'L-EPHEDRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: L-EPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16163, 8926, 'EPINEPHRINE (EPINEPHRINE BITARTRATE)', 'I', 5, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: EPINEPHRINE BITARTRATE (BASE EQ)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16162, 8926, 'EPINEPHRINE (EPINEPHRINE BITARTRATE)', 'I', 5, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: EPINEPHRINE BITARTRATE (BASE EQ)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16508, 8926, 'EPINEPHRINE', 'I', 5, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12648, 8926, 'EPINEPHRINE', 'I', 10, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12649, 8926, 'EPINEPHRINE', 'I', 10, 'µG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9802, 8926, 'EPINEPHRINE (EPINEPHRINE BITARTRATE)', 'I', 5, 'µG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4202, 8926, 'EPINEPHRINE (EPINEPHRINE BITARTRATE)', 'I', 5, 'µG', '', '', 'N', 'ML', '(AS BITARTRATE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2541, 8926, 'EPINEPHRINE', 'I', 18, 'µG', '', '1.8', 'N', 'ML', 'HISTORIC FREEFORM TEXT: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2506, 8926, 'EPINEPHRINE (EPINEPHRINE BITARTRATE)', 'I', 36, 'µG', '', '1.8', 'N', 'ML', 'HISTORIC FREEFORM TEXT: EPINEPHRINE 2010.02.22. ADDITION OF EPINEPRINE BITARTRATE IN THE SUPPLIED AS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1830, 8926, 'EPINEPHRINE', 'I', 5, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (590, 8926, 'EPINEPHRINE', 'I', 5, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (591, 8926, 'EPINEPHRINE', 'I', 5, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2828, 8926, 'EPINEPHRINE', 'I', 5, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83307, 8926, 'EPINEPHRINE', 'I', 5, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17901, 8926, 'EPINEPHRINE', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16998, 8926, 'EPINEPHRINE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16511, 8926, 'EPINEPHRINE', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16850, 8926, 'EPINEPHRINE (EPINEPHRINE BITARTRATE)', 'I', 0.01, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: EPINEPHRINE ((AS BITARTRATE 0.018MG/ML))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16851, 8926, 'EPINEPHRINE (EPINEPHRINE BITARTRATE)', 'I', 0.005, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: EPINEPHRINE ((AS BITARTRATE 0.009MG/ML))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8352, 8926, 'EPINEPHRINE', 'I', 0.1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9164, 8926, 'EPINEPHRINE', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5970, 8926, 'EPINEPHRINE', 'I', 0.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: EPINEPHRINE (0.15MG/0.3ML).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7403, 8926, 'EPINEPHRINE', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3805, 8926, 'EPINEPHRINE', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3155, 8926, 'EPINEPHRINE', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3735, 8926, 'EPINEPHRINE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3883, 8926, 'EPINEPHRINE', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: EPINEPHRINE (0.3MG/0.3ML).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (635, 8926, 'EPINEPHRINE (EPINEPHRINE BITARTRATE)', 'I', 0.02, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (636, 8926, 'EPINEPHRINE (EPINEPHRINE BITARTRATE)', 'I', 0.01, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (589, 8926, 'EPINEPHRINE', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (592, 8926, 'EPINEPHRINE (EPINEPHRINE BITARTRATE)', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (593, 8926, 'EPINEPHRINE (EPINEPHRINE BITARTRATE)', 'I', 0.02, 'MG', '', '', 'N', 'ML', '2010.02.22. EPINEPHRINE BITARTRATE ADDED TO THE SUPPLIED AS FIELD. APPROVED BY CATHERINE YEN, MANAGE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2881, 8926, 'EPINEPHRINE', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (940, 8926, 'EPINEPHRINE (EPINEPHRINE HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: EPINEPHRINE HCL ((EPINEPHRINE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1508, 8926, 'EPINEPHRINE (EPINEPHRINE HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: EPINEPHRINE HCL ((EPINEPHRINE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (781, 8926, 'EPINEPHRINE', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68622, 8926, 'EPINEPHRINE (EPINEPHRINE BITARTRATE)', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71553, 8926, 'EPINEPHRINE', 'I', 0.3, 'MG', '', '0.3', 'N', 'ML', 'STRENGTH EXPRESSED AS 0.3MG/0.3ML INSTEAD OF 1MG/ML FOR CONSISTENCY WITH DIN 02268205, AND ALSO TO B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72840, 8926, 'EPINEPHRINE (EPINEPHRINE BITARTRATE)', 'I', 0.01, 'MG', '', '', 'N', 'ML', '1:100000');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72841, 8926, 'EPINEPHRINE (EPINEPHRINE BITARTRATE)', 'I', 0.005, 'MG', '', '', 'N', 'ML', '1:200000');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75360, 8926, 'EPINEPHRINE', 'I', 0.15, 'MG', '', '0.15', 'N', 'ML', '1:1000 (0.15MG/0.15ML DOSE). ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74608, 8926, 'EPINEPHRINE (EPINEPHRINE BITARTRATE)', 'I', 0.01, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: EPINEPHRINE ((AS BITARTRATE 0.018MG/ML))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78332, 8926, 'EPINEPHRINE', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81063, 8926, 'EPINEPHRINE', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81732, 8926, 'EPINEPHRINE', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'AS BASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79244, 8926, 'EPINEPHRINE', 'I', 0.15, 'MG', '', '0.3', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79245, 8926, 'EPINEPHRINE', 'I', 0.3, 'MG', '', '0.3', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83052, 8926, 'EPINEPHRINE (EPINEPHRINE BITARTRATE)', 'I', 0.02, 'MG', '', '', 'N', 'ML', 'STRENGTH EXPRESSED IN A DIFFERENT WAY FROM THE ORIGINAL DIN (0.02 MG/ML EPINEPHRINE INSTEAD OF 36 MC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37358, 8934, 'P-HYDROXYEPHEDRINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: P-HYDROXYEPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5475, 8936, 'ETAFEDRIN HYDROCHLORIDE', 'I', 3.33, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ETAFEDRIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4615, 8936, 'ETAFEDRIN HYDROCHLORIDE', 'I', 3.33, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ETAFEDRIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50030, 8936, 'ETAFEDRIN HYDROCHLORIDE', 'I', 3.33, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ETAFEDRIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11096, 8937, 'EPHEDRINE SULFATE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: L-EPHEDRINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (790, 8937, 'EPHEDRINE SULFATE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-             EPHEDRINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66800, 8937, 'EPHEDRINE SULFATE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4665, 8903, 'BENZOCAINE', 'I', 7.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: BENZOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (186, 8903, 'BENZOCAINE', 'I', 7.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: BENZOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78568, 8903, 'BENZOCAINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41931, 8903, 'BENZOCAINE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: BENZOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26564, 8903, 'BENZOCAINE', 'I', 14, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16688, 8903, 'BENZOCAINE', 'I', 14, '%', '', '', 'N', '', 'Historic Freeform Text: BENZOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15550, 8903, 'BENZOCAINE', 'I', 20, '%', '', '', 'N', '', 'Historic Freeform Text: BENZOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13347, 8903, 'BENZOCAINE', 'I', 18, '%', '', '', 'N', '', 'Historic Freeform Text: BENZOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3269, 8903, 'BENZOCAINE', 'I', 1.952, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48713, 8903, 'BENZOCAINE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50238, 8903, 'BENZOCAINE', 'I', 18, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61410, 8903, 'BENZOCAINE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80364, 8903, 'BENZOCAINE', 'I', 18, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71907, 8903, 'BENZOCAINE', 'I', 10, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73832, 8903, 'BENZOCAINE', 'I', 20, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 8903, 'BENZOCAINE', 'I', 0.364, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS CAINE MIX 0.51MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13349, 8903, 'BENZOCAINE', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: BENZOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1062, 8903, 'BENZOCAINE', 'I', 23, '%', '', '', 'N', '%', 'Historic Freeform Text: BENZOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63187, 8903, 'BENZOCAINE', 'I', 18, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64576, 8903, 'BENZOCAINE', 'I', 18, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3313, 8903, 'BENZOCAINE', 'I', 5.7, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: BENZOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81814, 8903, 'BENZOCAINE', 'I', 14, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BENZOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13766, 8903, 'BENZOCAINE', 'I', 180, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: BENZOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3276, 8903, 'BENZOCAINE', 'I', 180, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: BENZOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18092, 6970, 'FORMALDEHYDE', 'I', 37, '%', '', '', 'N', '', 'Historic Freeform Text: FORMALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14494, 6970, 'FORMALDEHYDE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: FORMALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13786, 6970, 'FORMALDEHYDE', 'I', 0.2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FORMALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1926, 6970, 'FORMALDEHYDE', 'I', 37, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FORMALDEHYDE (W/W)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52647, 6970, 'FORMALDEHYDE', 'I', 0.23, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66752, 6970, 'FORMALDEHYDE', 'I', 2.02, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69733, 6970, 'FORMALDEHYDE', 'I', 2.28, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61292, 6970, 'FORMALDEHYDE', 'I', 0.23, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28169, 6974, 'LANOLIN', 'I', 3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LIQUID LANOLIN ((ANYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17759, 6974, 'LANOLIN', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: LANOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18099, 6974, 'LANOLIN', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: LANOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7049, 6974, 'LANOLIN', 'I', 13, '%', '', '', 'N', '', 'Historic Freeform Text: LANOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5348, 6974, 'LANOLIN', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: LANOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2256, 6974, 'LANOLIN', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: LANOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51033, 6974, 'LANOLIN', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75436, 6974, 'LANOLIN', 'I', 2, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76990, 6974, 'LANOLIN', 'I', 9.88, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76818, 6974, 'LANOLIN', 'I', 2.0, '%', '', '', 'N', '', 'LANOLIN ETHOXYLATE 50% PROVIDING 2% LANOLIN STRENGTH: 4% W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59943, 6974, 'LANOLIN', 'I', 15.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81375, 6974, 'LANOLIN', 'I', 2, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84027, 6974, 'LANOLIN', 'I', 2, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84079, 6974, 'LANOLIN', 'I', 2.00, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12947, 6974, 'LANOLIN', 'I', 3, '%', '', '', 'N', '%', 'Historic Freeform Text: LANOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5577, 6974, 'LANOLIN', 'I', 13.35, '%', '', '', 'N', '%', 'Historic Freeform Text: LANOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3621, 6974, 'LANOLIN', 'I', 5, '%', '', '', 'N', '%', 'Historic Freeform Text: LANOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5167, 6974, 'LANOLIN', 'I', 90, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LANOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12801, 6974, 'LANOLIN', 'I', 78.5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: LANOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5076, 6974, 'LANOLIN', 'I', 78.5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: LANOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3889, 6974, 'LANOLIN', 'I', 50, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: LANOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37581, 6910, 'OLEIC ACID', 'I', 2, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: OLEIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80280, 6910, 'OLEIC ACID', 'I', 12.33, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7049, 6934, 'TURPENTINE', 'I', 7.5, '%', '', '', 'N', '', 'Historic Freeform Text: TURPENTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2819, 6934, 'TURPENTINE', 'I', 4.3, '%', '', '', 'N', '', 'Historic Freeform Text: TURPENTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (740, 6934, 'TURPENTINE', 'I', 18.4, '%', '', '', 'N', '', 'Historic Freeform Text: TURPENTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5577, 6934, 'TURPENTINE', 'I', 7.5, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: TURPENTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4553, 6934, 'TURPENTINE', 'I', 3.2, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: TURPENTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3314, 6934, 'TURPENTINE', 'I', 5.1, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: TURPENTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12801, 6934, 'TURPENTINE', 'I', 69, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TURPENTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5076, 6934, 'TURPENTINE', 'I', 69, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TURPENTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42607, 6935, 'PHENOL', 'I', 0.48, '%', '', '', 'N', '', 'Historic Freeform Text: PHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36396, 6935, 'PHENOL', 'I', 1.56, '%', '', '', 'N', '', 'Historic Freeform Text: PHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17211, 6935, 'PHENOL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: PHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13999, 6935, 'PHENOL', 'I', 6, '%', '', '', 'N', '', 'Historic Freeform Text: PHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9518, 6935, 'PHENOL', 'I', 3.25, '%', '', '', 'N', '', 'PHENOL 2.9% CHG TO 3.25% AS PER VDD 2006.04.05');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5348, 6935, 'PHENOL', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: PHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1911, 6935, 'PHENOL', 'I', 0.4, '%', '', '', 'N', '', 'Historic Freeform Text: PHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1912, 6935, 'PHENOL', 'I', 0.4, '%', '', '', 'N', '', 'Historic Freeform Text: PHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76643, 6935, 'PHENOL', 'I', 0.44, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76644, 6935, 'PHENOL', 'I', 0.44, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36398, 6935, 'PHENOL', 'I', 1.56, '%', '', '', 'N', 'W/W', 'Historic Freeform Text: PHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42334, 6935, 'PHENOL', 'I', 0.45, '%', '', '', 'N', '%', 'Historic Freeform Text: PHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3666, 6935, 'PHENOL', 'I', 0.75, '%', '', '', 'N', '%', 'Historic Freeform Text: PHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3669, 6935, 'PHENOL', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: PHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81202, 8618, 'ERYTHROMYCIN', 'I', 5, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3621, 6935, 'PHENOL', 'I', 0.3, '%', '', '', 'N', '%', 'Historic Freeform Text: PHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1502, 6935, 'PHENOL', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: PHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4161, 6935, 'PHENOL', 'I', 7.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5167, 6935, 'PHENOL', 'I', 2.7, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4792, 6935, 'PHENOL', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12801, 6935, 'PHENOL', 'I', 25, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5076, 6935, 'PHENOL', 'I', 25, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (231, 6938, 'ASPIDOSPERMA', 'I', 1.014, 'G', '', '2.9', 'N', 'G', 'HISTORIC FREEFORM TEXT: ASPIDOSPERMA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5504, 6940, 'EUPHORBIA', 'I', 3.73, 'MG', '', '1', 'N', 'ML', 'Historic Freeform Text: EUPHORBIA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (160, 6941, 'PAPAVERINE HYDROCHLORIDE', 'I', 65, 'MG', '', '2', 'N', 'ML', 'Historic Freeform Text: PAPAVERINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (740, 6946, 'ROSIN', 'I', 40.7, '%', '', '', 'N', '', 'Historic Freeform Text: ROSIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 6946, 'ROSIN', 'I', 0.69, 'MG', '', '', 'N', 'PATCH', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3567, 6877, 'NUX VOMICA', 'I', 1.26, '%', '', '', 'N', '%', 'Historic Freeform Text: NUX VOMICA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62999, 6883, 'MALT', 'I', 46.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37581, 6883, 'MALT', 'I', 40.07, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: MALT  MALT AS MALT EXTRACT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12874, 6883, 'MALT', 'I', 15.75, 'G', '', '30', 'N', 'ML', 'Historic Freeform Text: MALT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 6893, 'MANGANESE SULFATE', 'I', 475, 'MG', '', '', 'N', '', 'Historic Freeform Text: MANGANESE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 6893, 'MANGANESE SULFATE', 'I', 0.05, 'G', '', '', 'N', 'KG', 'ADDED 2010.04.14 AS PER VDD REQUEST./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47888, 6893, 'MANGANESE SULFATE', 'I', 4.6, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (236, 6895, 'PHENIRAMINE MALEATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17733, 6895, 'PHENIRAMINE MALEATE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16653, 6895, 'PHENIRAMINE MALEATE', 'I', 0.3, '%', '', '', 'N', '', 'Historic Freeform Text: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6773, 6895, 'PHENIRAMINE MALEATE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3743, 6895, 'PHENIRAMINE MALEATE', 'I', 0.3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8155, 6895, 'PHENIRAMINE MALEATE', 'I', 0.315, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PHENIRAMINE MALEATE. 970822: CHANGED CONCENTRATION FROM 0.3% TO 0.315% AS   ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66582, 6895, 'PHENIRAMINE MALEATE', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41952, 6895, 'PHENIRAMINE MALEATE', 'I', 0.20, '%', '', '', 'N', 'W/V', 'Historic Freeform Text: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37051, 6895, 'PHENIRAMINE MALEATE', 'I', 20, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26396, 6895, 'PHENIRAMINE MALEATE', 'I', 20, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26397, 6895, 'PHENIRAMINE MALEATE', 'I', 20, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21167, 6895, 'PHENIRAMINE MALEATE', 'I', 20, 'MG', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2490, 6850, 'BENZOYL PEROXIDE', 'I', 20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21168, 6895, 'PHENIRAMINE MALEATE', 'I', 20, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11901, 6895, 'PHENIRAMINE MALEATE', 'I', 20, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70790, 6895, 'PHENIRAMINE MALEATE', 'I', 20, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76387, 6895, 'PHENIRAMINE MALEATE', 'I', 20, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76511, 6895, 'PHENIRAMINE MALEATE', 'I', 20, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19690, 6895, 'PHENIRAMINE MALEATE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13494, 6895, 'PHENIRAMINE MALEATE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5431, 6895, 'PHENIRAMINE MALEATE', 'I', 5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4252, 6895, 'PHENIRAMINE MALEATE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62576, 6895, 'PHENIRAMINE MALEATE', 'I', 20, 'MG', '', '22', 'N', 'MG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31530, 6895, 'PHENIRAMINE MALEATE', 'I', 20, 'MG', '', '22', 'N', 'G', 'Historic Freeform Text: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (32780, 6895, 'PHENIRAMINE MALEATE', 'I', 20, 'MG', '', '23', 'N', 'G', 'HISTORIC FREEFORM TEXT: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19088, 6895, 'PHENIRAMINE MALEATE', 'I', 20, 'MG', '', '23', 'N', 'G', 'Historic Freeform Text: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62330, 6895, 'PHENIRAMINE MALEATE', 'I', 20, 'MG', '', '23', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65060, 6895, 'PHENIRAMINE MALEATE', 'I', 20, 'MG', '', '22', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73067, 6895, 'PHENIRAMINE MALEATE', 'I', 20, 'MG', '', '22', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13104, 6848, 'DIIODOHYDROXYQUIN', 'I', 210, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIIODOHYDROXYQUIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13112, 6848, 'DIIODOHYDROXYQUIN', 'I', 650, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIIODOHYDROXYQUIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41695, 6849, 'COAL TAR', 'I', 0.166, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR ((TOPICAL-SOL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42099, 6849, 'COAL TAR', 'I', 7.5, '%', '', '', 'N', '', 'Historic Freeform Text: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42042, 6849, 'COAL TAR', 'I', 7.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42043, 6849, 'COAL TAR', 'I', 7.5, '%', '', '', 'N', '', 'Historic Freeform Text: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41889, 6849, 'COAL TAR', 'I', 4.25, '%', '', '', 'N', '', 'Historic Freeform Text: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42609, 6849, 'COAL TAR', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42610, 6849, 'COAL TAR', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17265, 6849, 'COAL TAR', 'I', 4, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15950, 6849, 'COAL TAR', 'I', 0.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13012, 6849, 'COAL TAR', 'I', 0.5, '%', '', '', 'N', '', 'W/W HISTORIC FREEFORM TEXT: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13013, 6849, 'COAL TAR', 'I', 0.55, '%', '', '', 'N', '', 'W/W HISTORIC FREEFORM TEXT: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13014, 6849, 'COAL TAR', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13858, 6849, 'COAL TAR', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR SOLN ((COAL TAR EQ.2%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12890, 6849, 'COAL TAR', 'I', 5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10142, 6849, 'COAL TAR', 'I', 8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9334, 6849, 'COAL TAR', 'I', 4.3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6435, 6849, 'COAL TAR', 'I', 10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR ((DISTILLATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6436, 6849, 'COAL TAR', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR ((DISTILLATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6437, 6849, 'COAL TAR', 'I', 3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR ((DISTILLATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6848, 6849, 'COAL TAR', 'I', 10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5634, 6849, 'COAL TAR', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5635, 6849, 'COAL TAR', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6207, 6849, 'COAL TAR', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR ((DISTILLATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5557, 6849, 'COAL TAR', 'I', 0.33, '%', '', '', 'N', '', 'Historic Freeform Text: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4037, 6849, 'COAL TAR', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3998, 6849, 'COAL TAR', 'I', 1.0, '%', '', '', 'N', '', 'Historic Freeform Text: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3347, 6849, 'COAL TAR', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3320, 6849, 'COAL TAR', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1938, 6849, 'COAL TAR', 'I', 0.4, '%', '', '', 'N', '', 'Historic Freeform Text: COAL TAR ((LIQUOR CARBONIS DETERGENS EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2984, 6849, 'COAL TAR', 'I', 0.04, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2317, 6849, 'COAL TAR', 'I', 20, '%', '', '', 'N', '', 'Historic Freeform Text: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1686, 6849, 'COAL TAR', 'I', 0.4, '%', '', '', 'N', '', 'Historic Freeform Text: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1687, 6849, 'COAL TAR', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR ((LIQUOR CARBONIS DETERGENS EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1667, 6849, 'COAL TAR', 'I', 5.0, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR ((SOLN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2197, 6849, 'COAL TAR', 'I', 10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LIQUOR CARBONIS DETERGENS ((COAL TAR SOLN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1495, 6849, 'COAL TAR', 'I', 0.09, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR ((SOLUTION EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2022, 6849, 'COAL TAR', 'I', 1.0, '%', '', '', 'N', '', 'Historic Freeform Text: COAL TAR ((AS SOLN))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48713, 6849, 'COAL TAR', 'I', 40.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64224, 6849, 'COAL TAR', 'I', 0.50, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63668, 6849, 'COAL TAR', 'I', 1.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63766, 6849, 'COAL TAR', 'I', 0.711, '%', '', '', 'N', '', 'COAL TAR EQUIVALENT 0.711% AS COAL TAR TOPICAL SOLUTION, 3%.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64533, 6849, 'COAL TAR', 'I', 0.33, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COAL TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71204, 6849, 'COAL TAR', 'I', 0.66, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77120, 6849, 'COAL TAR', 'I', 10.0, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77934, 6849, 'COAL TAR', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79280, 6849, 'COAL TAR', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10674, 6849, 'COAL TAR', 'I', 10, '%', '', '', 'N', 'W/V', 'HISTORIC FREEFORM TEXT: COAL TAR.W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10141, 6849, 'COAL TAR', 'I', 10, '%', '', '', 'N', 'W/V', 'HISTORIC FREEFORM TEXT: COAL TAR.W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77121, 6849, 'COAL TAR', 'I', 10.0, '%', '', '', 'N', 'W/V', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13859, 6849, 'COAL TAR', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: COAL TAR SOLN ((COAL TAR EQ. 1%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1218, 6849, 'COAL TAR', 'I', 40, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: COAL TAR ((LIQUOR CARBONIS DETERGENS EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37729, 6850, 'BENZOYL PEROXIDE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37836, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37837, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37835, 6850, 'BENZOYL PEROXIDE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34258, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20298, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20299, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14500, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14396, 6850, 'BENZOYL PEROXIDE', 'I', 8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13311, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13244, 6850, 'BENZOYL PEROXIDE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11862, 6850, 'BENZOYL PEROXIDE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10498, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11657, 6850, 'BENZOYL PEROXIDE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11658, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3292, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3293, 6850, 'BENZOYL PEROXIDE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4408, 6850, 'BENZOYL PEROXIDE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3198, 6850, 'BENZOYL PEROXIDE', 'I', 20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4131, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1339, 6850, 'BENZOYL PEROXIDE', 'I', 20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1317, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1647, 6850, 'BENZOYL PEROXIDE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1648, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51275, 6850, 'BENZOYL PEROXIDE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59870, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62868, 6850, 'BENZOYL PEROXIDE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62870, 6850, 'BENZOYL PEROXIDE', 'I', 2.50, '%', '', '', 'N', '', 'BENZOYL PEROXIDE 75% - 3.35%.  EQUIVALENT TO LABEL CLAIM OF 2.5% BENZOYL PEROXIDE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65812, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72252, 6850, 'BENZOYL PEROXIDE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72253, 6850, 'BENZOYL PEROXIDE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70091, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71270, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72824, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', 'WHEN RECONSTITUTED.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75208, 6850, 'BENZOYL PEROXIDE', 'I', 3.7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74146, 6850, 'BENZOYL PEROXIDE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74147, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75421, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74359, 6850, 'BENZOYL PEROXIDE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75687, 6850, 'BENZOYL PEROXIDE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72553, 6850, 'BENZOYL PEROXIDE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76851, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77539, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77590, 6850, 'BENZOYL PEROXIDE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77752, 6850, 'BENZOYL PEROXIDE', 'I', 5.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77622, 6850, 'BENZOYL PEROXIDE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79019, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79193, 6850, 'BENZOYL PEROXIDE', 'I', 3.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79194, 6850, 'BENZOYL PEROXIDE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16458, 6850, 'BENZOYL PEROXIDE', 'I', 2.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4861, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60085, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60086, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80076, 6850, 'BENZOYL PEROXIDE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79848, 6850, 'BENZOYL PEROXIDE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80729, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80728, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80530, 6850, 'BENZOYL PEROXIDE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80610, 6850, 'BENZOYL PEROXIDE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81233, 6850, 'BENZOYL PEROXIDE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81234, 6850, 'BENZOYL PEROXIDE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80893, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82243, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80822, 6850, 'BENZOYL PEROXIDE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84307, 6850, 'BENZOYL PEROXIDE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84309, 6850, 'BENZOYL PEROXIDE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85075, 6850, 'BENZOYL PEROXIDE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43428, 6850, 'BENZOYL PEROXIDE', 'I', 50, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67033, 6850, 'BENZOYL PEROXIDE', 'I', 50, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4834, 6801, 'PHENYLBUTAZONE SODIUM', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PHENYLBUTAZONE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (905, 6803, 'SODIUM ARSANILATE', 'I', 2.275, 'G', '', '30', 'N', 'ML', 'Historic Freeform Text: SODIUM AMINARSONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35772, 6803, 'SODIUM ARSANILATE', 'I', 75.6, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM ARSANILATE ((YIELD.23.7MG ARSENIC))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9885, 6805, 'NITROFURAZONE', 'I', 0.2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NITROFURAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81896, 6805, 'NITROFURAZONE', 'I', 0.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5511, 6805, 'NITROFURAZONE', 'I', 0.2, '%', '', '', 'N', '%', 'Historic Freeform Text: NITROFURAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5166, 6805, 'NITROFURAZONE', 'I', 0.2, '%', '', '', 'N', '%', 'Historic Freeform Text: NITROFURAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5237, 6805, 'NITROFURAZONE', 'I', 0.2, '%', '', '', 'N', '%', 'Historic Freeform Text: NITROFURAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2169, 6805, 'NITROFURAZONE', 'I', 0.2, '%', '', '', 'N', '%', 'Historic Freeform Text: NITROFURAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2120, 6805, 'NITROFURAZONE', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: NITROFURAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79744, 6805, 'NITROFURAZONE', 'I', 0.2, 'G', '', '100', 'N', 'ML', '0.2%W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79745, 6805, 'NITROFURAZONE', 'I', 0.2, 'G', '', '100', 'N', 'G', '0.2%W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 4771, 'SODIUM GLYCEROPHOSPHATE', 'I', 1.91, 'G', '', '', 'N', 'L', 'SODIUM GLYCEROPHOSPHATE HYDRATED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 4771, 'SODIUM GLYCEROPHOSPHATE', 'I', 3.67, 'G', '', '', 'N', 'L', 'SODIUM GLYCEROPHOSPHATE HYDRATED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 4771, 'SODIUM GLYCEROPHOSPHATE', 'I', 3.67, 'G', '', '', 'N', 'L', 'SODIUM GLYCEROPHOSPHATE HYDRATED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4761, 4775, 'CALCIUM GLYCEROPHOSPHATE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CALCIUM GLYCEROPHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12874, 4784, 'CALCIUM HYPOPHOSPHITE', 'I', 270, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: CALCIUM HYPOPHOSPHITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43936, 4732, 'ADENOSINE', 'I', 3, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ADENOSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19437, 4732, 'ADENOSINE', 'I', 3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ADENOSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67346, 4732, 'ADENOSINE', 'I', 3, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ADENOSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75307, 4732, 'ADENOSINE', 'I', 3, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ADENOSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75535, 4748, 'SODIUM PHOSPHATE (TRIBASIC)', 'I', 1.19, '%', '', '', 'N', '', 'HISTORICAL FREE FORM: TRISODIUM PHOSPHATE (ANHYDROUS). W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77858, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63077, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', 'ACCORDING TO DPIF, INGREDIENT LISTED AS CITALOPRAM HYDROBROMIDE. CALCULATED AS A BASE. MAR.10,2005. ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63078, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', 'ACCORDING TO DPIF, INGREDIENT LISTED AS CITALOPRAM HYDROBROMIDE. CALCULATED AS A BASE. MAR.10,2005. ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70781, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70782, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70187, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70188, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72326, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72327, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74277, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74278, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75597, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72370, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72371, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75855, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72503, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72504, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73317, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73318, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73319, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73320, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73411, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73412, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75903, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73647, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80150, 11776, 'IRBESARTAN', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73649, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73700, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73701, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77113, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77114, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77859, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78149, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77039, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77040, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79893, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79894, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78858, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78859, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78860, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79179, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79180, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79783, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78996, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78997, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81046, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83886, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83887, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84052, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84053, 11847, 'CITALOPRAM (CITALOPRAM HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63139, 11852, 'MODAFINIL', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63248, 11854, 'SILDENAFIL (SILDENAFIL CITRATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63249, 11854, 'SILDENAFIL (SILDENAFIL CITRATE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63250, 11854, 'SILDENAFIL (SILDENAFIL CITRATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76500, 11854, 'SILDENAFIL (SILDENAFIL CITRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80498, 11854, 'SILDENAFIL (SILDENAFIL CITRATE)', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82711, 11854, 'SILDENAFIL (SILDENAFIL CITRATE)', 'I', 0.8, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63319, 11856, 'INTERFERON ALFACON-1', 'I', 0.03, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61873, 11787, 'CAPECITABINE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61874, 11787, 'CAPECITABINE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62045, 11789, 'NELFINAVIR (NELFINAVIR MESYLATE)', 'I', 250, 'MG', '', '', 'Y', '', 'NELFINAVIR (FREE BASE): 250MG/TAB. SUPPLIED AS NELFINAVIR MESYLATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73129, 11789, 'NELFINAVIR (NELFINAVIR MESYLATE)', 'I', 625, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62046, 11789, 'NELFINAVIR (NELFINAVIR MESYLATE)', 'I', 50, 'MG', '', '', 'Y', 'G', 'NELFINAVIR (FREE BASE): 50MG/GM. SUPPLIED AS NELFINAVIR MESYLATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62057, 11792, 'SODIUM BENTONITE', 'I', 27.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62089, 11793, 'ZOLMITRIPTAN', 'I', 2.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66907, 11793, 'ZOLMITRIPTAN', 'I', 2.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81019, 11793, 'ZOLMITRIPTAN', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82803, 11793, 'ZOLMITRIPTAN', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80970, 11793, 'ZOLMITRIPTAN', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79948, 11793, 'ZOLMITRIPTAN', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84796, 11793, 'ZOLMITRIPTAN', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84797, 11793, 'ZOLMITRIPTAN', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85398, 11793, 'ZOLMITRIPTAN', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73377, 11793, 'ZOLMITRIPTAN', 'I', 2.5, 'MG', '', '', 'N', 'SPRAY', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73378, 11793, 'ZOLMITRIPTAN', 'I', 5.0, 'MG', '', '', 'N', 'SPRAY', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62114, 11795, 'CLOPIDOGREL (CLOPIDOGREL BISULFATE)', 'I', 75, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81628, 11795, 'CLOPIDOGREL (CLOPIDOGREL BISULFATE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62181, 11796, 'NEVIRAPINE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80408, 11796, 'NEVIRAPINE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62288, 11798, 'PENCICLOVIR', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62313, 11799, 'BRINZOLAMIDE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81730, 11799, 'BRINZOLAMIDE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4657, 11802, 'BUCKTHORN', 'I', 0.70, 'MG', '', '', 'N', 'ML', 'SOLID EXTRACT OF BUCKTHORN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (960, 11804, 'MERCAPTOPURINE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: 6-             MERCAPTOPURINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7146, 11805, 'VITAMIN A PROPIONATE', 'I', 500000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62354, 11805, 'VITAMIN A PROPIONATE', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63763, 11805, 'VITAMIN A PROPIONATE', 'I', 50000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63765, 11805, 'VITAMIN A PROPIONATE', 'I', 50000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72902, 11805, 'VITAMIN A PROPIONATE', 'I', 500000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74400, 11805, 'VITAMIN A PROPIONATE', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62480, 11811, 'RALOXIFENE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', 'DPD HAD RALOXIFENE 55.71MG SUPPLIED AS RALOXIFENE HYDROCHLORIDE 60 MG BUT WAS CHANGED TO RALOXIFENE ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76475, 11811, 'RALOXIFENE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79780, 11811, 'RALOXIFENE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61760, 11786, 'DELAVIRDINE MESYLATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62546, 11814, 'CANDESARTAN CILEXETIL', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62547, 11814, 'CANDESARTAN CILEXETIL', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62548, 11814, 'CANDESARTAN CILEXETIL', 'I', 16, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67964, 11814, 'CANDESARTAN CILEXETIL', 'I', 16, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81228, 11814, 'CANDESARTAN CILEXETIL', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81229, 11814, 'CANDESARTAN CILEXETIL', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81230, 11814, 'CANDESARTAN CILEXETIL', 'I', 16, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79720, 11814, 'CANDESARTAN CILEXETIL', 'I', 32, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81858, 11814, 'CANDESARTAN CILEXETIL', 'I', 32, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81859, 11814, 'CANDESARTAN CILEXETIL', 'I', 32, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85025, 11814, 'CANDESARTAN CILEXETIL', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85026, 11814, 'CANDESARTAN CILEXETIL', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85027, 11814, 'CANDESARTAN CILEXETIL', 'I', 16, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61288, 11776, 'IRBESARTAN', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61289, 11776, 'IRBESARTAN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61290, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65483, 11776, 'IRBESARTAN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65484, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76589, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81399, 11776, 'IRBESARTAN', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81400, 11776, 'IRBESARTAN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81401, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81403, 11776, 'IRBESARTAN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81404, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81405, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80257, 11776, 'IRBESARTAN', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80258, 11776, 'IRBESARTAN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80259, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80190, 11776, 'IRBESARTAN', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80191, 11776, 'IRBESARTAN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80192, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81624, 11776, 'IRBESARTAN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81625, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81626, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81358, 11776, 'IRBESARTAN', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81359, 11776, 'IRBESARTAN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81361, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80151, 11776, 'IRBESARTAN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80152, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82301, 11776, 'IRBESARTAN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82302, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82303, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80153, 11776, 'IRBESARTAN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80154, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80155, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84252, 11776, 'IRBESARTAN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84253, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84254, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84821, 11776, 'IRBESARTAN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84822, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84823, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85001, 11776, 'IRBESARTAN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85002, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85003, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85004, 11776, 'IRBESARTAN', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85005, 11776, 'IRBESARTAN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85006, 11776, 'IRBESARTAN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68278, 11777, 'SEVELAMER HYDROCHLORIDE', 'I', 800, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78022, 11780, 'TAMSULOSIN HYDROCHLORIDE', 'I', 0.4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76705, 11780, 'TAMSULOSIN HYDROCHLORIDE', 'I', 0.4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75550, 11780, 'TAMSULOSIN HYDROCHLORIDE', 'I', 0.4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78387, 11780, 'TAMSULOSIN HYDROCHLORIDE', 'I', 0.4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77961, 11780, 'TAMSULOSIN HYDROCHLORIDE', 'I', 0.4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78045, 11780, 'TAMSULOSIN HYDROCHLORIDE', 'I', 0.4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82577, 11780, 'TAMSULOSIN HYDROCHLORIDE', 'I', 0.4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83768, 11780, 'TAMSULOSIN HYDROCHLORIDE', 'I', 0.4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61542, 11782, 'PROGUANIL HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'AMT OF PROGUANIL 85.6MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75044, 11782, 'PROGUANIL HYDROCHLORIDE', 'I', 25.0, 'MG', '', '', 'N', '', 'AMT OF PROGUANIL 21.4MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61609, 11784, 'MONTELUKAST (MONTELUKAST SODIUM)', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61610, 11784, 'MONTELUKAST (MONTELUKAST SODIUM)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67521, 11784, 'MONTELUKAST (MONTELUKAST SODIUM)', 'I', 4, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72310, 11784, 'MONTELUKAST (MONTELUKAST SODIUM)', 'I', 4, 'MG', '', '', 'Y', 'PCK', '1PACKET = 500MG./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60678, 11749, 'EMEDASTINE (EMEDASTINE DIFUMARATE)', 'I', 0.05, '%', '', '', 'Y', '', 'AS EMEDASTINE DIFUMARATE  0.884MG/ML.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64293, 11752, 'TIROFIBAN (TIROFIBAN HYDROCHLORIDE)', 'I', 5, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78389, 11753, 'ZIPRASIDONE (ZIPRASIDONE HYDROCHLORIDE MONOHYDRATE)', 'I', 20, 'MG', '', '', 'Y', '', 'ZIPRASIDONE HYDROCHLORIDE MONOHYDRATE 22.65MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78392, 11753, 'ZIPRASIDONE (ZIPRASIDONE HYDROCHLORIDE MONOHYDRATE)', 'I', 40, 'MG', '', '', 'Y', '', 'ZIPRASIDONE HYDROCHLORIDE MONOHYDRATE 45.30MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78393, 11753, 'ZIPRASIDONE (ZIPRASIDONE HYDROCHLORIDE MONOHYDRATE)', 'I', 60, 'MG', '', '', 'Y', '', 'ZIPRASIDONE HYDROCHLORIDE MONOHYDRATE 67.95MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78394, 11753, 'ZIPRASIDONE (ZIPRASIDONE HYDROCHLORIDE MONOHYDRATE)', 'I', 80, 'MG', '', '', 'Y', '', 'ZIPRASIDONE HYDROCHLORIDE MONOHYDRATE 90.60MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61060, 11763, 'ORBIFLOXACIN', 'I', 5.7, 'MG', '', '', 'N', '', 'YELLOW TABLET.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84181, 11702, 'VALSARTAN', 'I', 320, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61061, 11763, 'ORBIFLOXACIN', 'I', 22.7, 'MG', '', '', 'N', '', 'GREEN SCORED TABLET.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61062, 11763, 'ORBIFLOXACIN', 'I', 68, 'MG', '', '', 'N', '', 'BLUE SCORED TABLET.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66608, 11764, 'MELOXICAM', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66609, 11764, 'MELOXICAM', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72198, 11764, 'MELOXICAM', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72961, 11764, 'MELOXICAM', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72962, 11764, 'MELOXICAM', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72963, 11764, 'MELOXICAM', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72964, 11764, 'MELOXICAM', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74120, 11764, 'MELOXICAM', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74121, 11764, 'MELOXICAM', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72351, 11764, 'MELOXICAM', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74353, 11764, 'MELOXICAM', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74354, 11764, 'MELOXICAM', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72606, 11764, 'MELOXICAM', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72607, 11764, 'MELOXICAM', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73355, 11764, 'MELOXICAM', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73356, 11764, 'MELOXICAM', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73483, 11764, 'MELOXICAM', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73484, 11764, 'MELOXICAM', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80979, 11764, 'MELOXICAM', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80978, 11764, 'MELOXICAM', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80448, 11764, 'MELOXICAM', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80449, 11764, 'MELOXICAM', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83836, 11764, 'MELOXICAM', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83837, 11764, 'MELOXICAM', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61069, 11764, 'MELOXICAM', 'I', 1.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64022, 11764, 'MELOXICAM', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81581, 11764, 'MELOXICAM', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84543, 11764, 'MELOXICAM', 'I', 0.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61098, 11767, 'ATIPAMEZOLE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82281, 11767, 'ATIPAMEZOLE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61179, 11770, 'NARATRIPTAN (NARATRIPTAN HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61180, 11770, 'NARATRIPTAN (NARATRIPTAN HYDROCHLORIDE)', 'I', 2.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79985, 11770, 'NARATRIPTAN (NARATRIPTAN HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79986, 11770, 'NARATRIPTAN (NARATRIPTAN HYDROCHLORIDE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80778, 11770, 'NARATRIPTAN (NARATRIPTAN HYDROCHLORIDE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61860, 11772, 'BUPROPION HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61184, 11772, 'BUPROPION HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74546, 11772, 'BUPROPION HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76058, 11772, 'BUPROPION HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76059, 11772, 'BUPROPION HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76060, 11772, 'BUPROPION HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76061, 11772, 'BUPROPION HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77116, 11772, 'BUPROPION HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77117, 11772, 'BUPROPION HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81077, 11772, 'BUPROPION HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81075, 11772, 'BUPROPION HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79896, 11772, 'BUPROPION HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81729, 11772, 'BUPROPION HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60463, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60464, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60465, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65251, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75469, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75470, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75471, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75472, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77541, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77542, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77543, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77544, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78262, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78267, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78268, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78269, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78270, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77772, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77773, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77774, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77776, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80080, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80081, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80082, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80083, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79472, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79473, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79474, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79475, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81116, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81117, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81118, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81119, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85244, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85245, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 0.50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85247, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85248, 11733, 'PRAMIPEXOLE DIHYDROCHLORIDE MONOHYDRATE', 'I', 1.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 8872, 'GLUTAMIC ACID', 'I', 2.25, 'G', '', '', 'N', '', 'Historic Freeform Text: GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43947, 8872, 'GLUTAMIC ACID', 'I', 1.02, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19306, 8872, 'GLUTAMIC ACID', 'I', 1.107, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 8872, 'GLUTAMIC ACID', 'I', 1, 'G', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 8872, 'GLUTAMIC ACID', 'I', 314, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 8872, 'GLUTAMIC ACID', 'I', 314, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 8872, 'GLUTAMIC ACID', 'I', 314, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 8872, 'GLUTAMIC ACID', 'I', 258, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 8872, 'GLUTAMIC ACID', 'I', 314, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 8872, 'GLUTAMIC ACID', 'I', 314, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 8872, 'GLUTAMIC ACID', 'I', 258, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 8872, 'GLUTAMIC ACID', 'I', 369, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 8872, 'GLUTAMIC ACID', 'I', 258, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 8872, 'GLUTAMIC ACID', 'I', 314, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 8872, 'GLUTAMIC ACID', 'I', 258, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 8872, 'GLUTAMIC ACID', 'I', 576, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18644, 8872, 'GLUTAMIC ACID', 'I', 738, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 8872, 'GLUTAMIC ACID', 'I', 738, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18607, 8872, 'GLUTAMIC ACID', 'I', 627, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18608, 8872, 'GLUTAMIC ACID', 'I', 517, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 8872, 'GLUTAMIC ACID', 'I', 820, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 8872, 'GLUTAMIC ACID', 'I', 12.8, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 8872, 'GLUTAMIC ACID', 'I', 6.7, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GLUTAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 8872, 'GLUTAMIC ACID', 'I', 1.26, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 8872, 'GLUTAMIC ACID', 'I', 2.21, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 8872, 'GLUTAMIC ACID', 'I', 2.84, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 8872, 'GLUTAMIC ACID', 'I', 2.84, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13988, 8887, 'PROPYL ALCOHOL', 'I', 32, '%', '', '', 'N', '', 'Historic Freeform Text: PROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13850, 8887, 'PROPYL ALCOHOL', 'I', 15, '%', '', '', 'N', '', 'Historic Freeform Text: PROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72560, 8887, 'PROPYL ALCOHOL', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36829, 8890, 'ALCOHOL ANHYDROUS', 'I', 70.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36797, 8890, 'ALCOHOL ANHYDROUS', 'I', 70.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36791, 8890, 'ALCOHOL ANHYDROUS', 'I', 18.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26739, 8890, 'ALCOHOL ANHYDROUS', 'I', 53, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25672, 8890, 'ALCOHOL ANHYDROUS', 'I', 50.16, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21687, 8890, 'ALCOHOL ANHYDROUS', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15893, 8890, 'ALCOHOL ANHYDROUS', 'I', 75, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15829, 8890, 'ALCOHOL ANHYDROUS', 'I', 40, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15507, 8890, 'ALCOHOL ANHYDROUS', 'I', 2.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15498, 8890, 'ALCOHOL ANHYDROUS', 'I', 70, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15499, 8890, 'ALCOHOL ANHYDROUS', 'I', 70, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15500, 8890, 'ALCOHOL ANHYDROUS', 'I', 70, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13706, 8890, 'ALCOHOL ANHYDROUS', 'I', 49.95, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13988, 8890, 'ALCOHOL ANHYDROUS', 'I', 26, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13830, 8890, 'ALCOHOL ANHYDROUS', 'I', 49.95, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13786, 8890, 'ALCOHOL ANHYDROUS', 'I', 82.2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12408, 8890, 'ALCOHOL ANHYDROUS', 'I', 70, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3011, 8890, 'ALCOHOL ANHYDROUS', 'I', 100, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2406, 8890, 'ALCOHOL ANHYDROUS', 'I', 2.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1593, 8890, 'ALCOHOL ANHYDROUS', 'I', 50.00, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PROPYLENE GLYCOL 32.29%. MOVED TO NMI FEB. 26 2010. REPLACED WITH ETHYL ALCO');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52647, 8890, 'ALCOHOL ANHYDROUS', 'I', 57.02, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60446, 8890, 'ALCOHOL ANHYDROUS', 'I', 70.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60445, 8890, 'ALCOHOL ANHYDROUS', 'I', 18.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61475, 8890, 'ALCOHOL ANHYDROUS', 'I', 70, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62709, 8890, 'ALCOHOL ANHYDROUS', 'I', 79, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63709, 8890, 'ALCOHOL ANHYDROUS', 'I', 79, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64391, 8890, 'ALCOHOL ANHYDROUS', 'I', 70, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63862, 8890, 'ALCOHOL ANHYDROUS', 'I', 12.0, '%', '', '', 'N', '', 'V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67988, 8890, 'ALCOHOL ANHYDROUS', 'I', 70.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70836, 8890, 'ALCOHOL ANHYDROUS', 'I', 79, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70166, 8890, 'ALCOHOL ANHYDROUS', 'I', 49.95, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70268, 8890, 'ALCOHOL ANHYDROUS', 'I', 65, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71113, 8890, 'ALCOHOL ANHYDROUS', 'I', 61, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72815, 8890, 'ALCOHOL ANHYDROUS', 'I', 65.87, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75267, 8890, 'ALCOHOL ANHYDROUS', 'I', 79.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75436, 8890, 'ALCOHOL ANHYDROUS', 'I', 50, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75587, 8890, 'ALCOHOL ANHYDROUS', 'I', 79.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72560, 8890, 'ALCOHOL ANHYDROUS', 'I', 54.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74949, 8890, 'ALCOHOL ANHYDROUS', 'I', 50.16, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76854, 8890, 'ALCOHOL ANHYDROUS', 'I', 50.16, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76811, 8890, 'ALCOHOL ANHYDROUS', 'I', 79, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78729, 8890, 'ALCOHOL ANHYDROUS', 'I', 2.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80171, 8890, 'ALCOHOL ANHYDROUS', 'I', 2.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81653, 8890, 'ALCOHOL ANHYDROUS', 'I', 2.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80691, 8890, 'ALCOHOL ANHYDROUS', 'I', 50.16, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82117, 8890, 'ALCOHOL ANHYDROUS', 'I', 50.16, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12254, 8890, 'ALCOHOL ANHYDROUS', 'I', 53.72, '%', '', '', 'N', '', '2010.06.25. ADDITION OF A THIRD ACTIVE INGREDIENT: ALCOHOL ANHYDROUS 53.72% REQUESTED BY BGIV''S DU A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83945, 8890, 'ALCOHOL ANHYDROUS', 'I', 53.72, '%', '', '', 'N', '', '2010.06.25. ADDITION OF A THIRD ACTIVE INGREDIENT: ALCOHOL ANHYDROUS 53.72% REQUESTED BY BGIV''S DU A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44478, 8890, 'ALCOHOL ANHYDROUS', 'I', 62.74, '%', '', '', 'N', '', 'ETHANOL ADDED AS A MI DURING PDC 141016 APPROVED BY EU/BGIVD/IAN CHISHOLM EW 2011.02.04');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76471, 8890, 'ALCOHOL ANHYDROUS', 'I', 58.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77576, 8890, 'ALCOHOL ANHYDROUS', 'I', 70, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50653, 8890, 'ALCOHOL ANHYDROUS', 'I', 70, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80681, 8890, 'ALCOHOL ANHYDROUS', 'I', 70, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79988, 8890, 'ALCOHOL ANHYDROUS', 'I', 70, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79811, 8890, 'ALCOHOL ANHYDROUS', 'I', 20, '%', '', '', 'N', 'W/W', 'ETHANOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82418, 8890, 'ALCOHOL ANHYDROUS', 'I', 70, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81375, 8890, 'ALCOHOL ANHYDROUS', 'I', 50, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84027, 8890, 'ALCOHOL ANHYDROUS', 'I', 50, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84079, 8890, 'ALCOHOL ANHYDROUS', 'I', 50.00, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84182, 11702, 'VALSARTAN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77225, 8890, 'ALCOHOL ANHYDROUS', 'I', 70, '%', '', '', 'N', 'V/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66816, 8890, 'ALCOHOL ANHYDROUS', 'I', 9.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66168, 8890, 'ALCOHOL ANHYDROUS', 'I', 629.30, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12803, 8890, 'ALCOHOL ANHYDROUS', 'I', 0.2, 'ML', '', '', 'N', 'ML', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10924, 8890, 'ALCOHOL ANHYDROUS', 'I', 5, 'ML', '', '100', 'N', 'ML', 'Historic Freeform Text: DEHYDRATED ALCOHOL ((USP 99.5%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5475, 8890, 'ALCOHOL ANHYDROUS', 'I', 0.05, 'ML', '', '', 'N', 'ML', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4442, 8890, 'ALCOHOL ANHYDROUS', 'I', 0.995, 'ML', '', '', 'N', 'ML', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50030, 8890, 'ALCOHOL ANHYDROUS', 'I', 0.05, 'ML', '', '', 'N', 'ML', 'Historic Freeform Text: ALCOHOL ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80735, 8890, 'ALCOHOL ANHYDROUS', 'I', 70, '%', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80764, 8890, 'ALCOHOL ANHYDROUS', 'I', 70, '%', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66399, 8890, 'ALCOHOL ANHYDROUS', 'I', 520, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42486, 8825, 'GELATIN', 'I', 13.3, '%', '', '', 'N', '', 'Historic Freeform Text: GELATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65746, 8828, 'STERILE WATER (DILUENT)', 'I', 2, 'ML', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27606, 8833, 'SUCCINYLCHOLINE CHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SUCCINYLCHOLINE CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2526, 8833, 'SUCCINYLCHOLINE CHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SUCCINYLCHOLINE CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (227, 8833, 'SUCCINYLCHOLINE CHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SUCCINYLCHOLINE CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65649, 8836, 'PROCAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PROCAINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2013, 8836, 'PROCAINE HYDROCHLORIDE', 'I', 2.5, '%', '', '', 'N', '%', 'Historic Freeform Text: PROCAINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71266, 8843, 'PHENYLPROPANOLAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2819, 8782, 'OX BILE EXTRACT', 'I', 48.6, '%', '', '', 'N', '', 'Historic Freeform Text: OXBILE EXT.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2133, 8798, 'SENNA', 'I', 187, 'MG', '', '', 'N', '', 'Historic Freeform Text: SENNA ((CONCETRATE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5504, 8723, 'SQUILL', 'I', 0.566, 'MG', '', '1', 'N', 'ML', 'Historic Freeform Text: SQUILL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4657, 8723, 'SQUILL', 'I', 0.50, 'MG', '', '', 'N', 'ML', 'LIQUID EXTRACT OF SQUILL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (623, 8742, 'SODIUM PROPIONATE', 'I', 1.4, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (620, 8742, 'SODIUM PROPIONATE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1593, 8742, 'SODIUM PROPIONATE', 'I', 2.33, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26536, 8742, 'SODIUM PROPIONATE', 'I', 40, 'G', '', '95', 'N', 'G', 'HISTORIC FREEFORM TEXT: SODIUM PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11889, 8742, 'SODIUM PROPIONATE', 'I', 40, 'G', '', '95', 'N', 'G', 'Historic Freeform Text: SODIUM PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1765, 8742, 'SODIUM PROPIONATE', 'I', 425.6, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SODIUM PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7089, 6809, 'MERBROMIN', 'I', 2, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (134, 6809, 'MERBROMIN', 'I', 7, 'G', '', '11.35', 'N', 'KG', 'Historic Freeform Text: MERBROMIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26307, 6817, 'ERYTHROSINE', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ERYTHROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (620, 6820, 'GENTIAN VIOLET', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: GENTIAN VIOLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44, 6820, 'GENTIAN VIOLET', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: GENTIAN VIOLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1500, 6820, 'GENTIAN VIOLET', 'I', 0.675, '%', '', '', 'N', '%', 'Historic Freeform Text: GENTIAN VIOLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12799, 6820, 'GENTIAN VIOLET', 'I', 2.4, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GENTIAN VIOLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11003, 6820, 'GENTIAN VIOLET', 'I', 2.4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GENTIAN VIOLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5346, 6820, 'GENTIAN VIOLET', 'I', 2.4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GENTIAN VIOLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3888, 6820, 'GENTIAN VIOLET', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GENTIAN VIOLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6196, 6760, 'COLCHICINE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: COLCHICINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5069, 6760, 'COLCHICINE', 'I', 0.6, 'MG', '', '', 'N', '', 'Historic Freeform Text: COLCHICINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1931, 6760, 'COLCHICINE', 'I', 0.6, 'MG', '', '', 'N', '', 'Historic Freeform Text: COLCHICINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1934, 6760, 'COLCHICINE', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COLCHICINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80280, 6770, 'PEPTONE', 'I', 9.59, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23184, 6787, 'SODIUM GLUCONATE', 'I', 1.09, 'G', '', '25', 'N', 'ML', 'Historic Freeform Text: SODIUM GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21757, 6787, 'SODIUM GLUCONATE', 'I', 500, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21998, 6787, 'SODIUM GLUCONATE', 'I', 500, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12741, 6787, 'SODIUM GLUCONATE', 'I', 500, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1737, 6787, 'SODIUM GLUCONATE', 'I', 5.02, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1738, 6787, 'SODIUM GLUCONATE', 'I', 5.02, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1623, 6787, 'SODIUM GLUCONATE', 'I', 502, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1622, 6787, 'SODIUM GLUCONATE', 'I', 502, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82495, 6787, 'SODIUM GLUCONATE', 'I', 502, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26564, 6788, 'TETRACAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TETRACAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16688, 6788, 'TETRACAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: TETRACAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13347, 6788, 'TETRACAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: TETRACAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50238, 6788, 'TETRACAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60078, 6788, 'TETRACAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65647, 6788, 'TETRACAINE HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: TETRACAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80364, 6788, 'TETRACAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18749, 6788, 'TETRACAINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', 'W/V', 'Historic Freeform Text: TETRACAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18751, 6788, 'TETRACAINE HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', 'W/V', 'Historic Freeform Text: TETRACAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 6788, 'TETRACAINE HYDROCHLORIDE', 'I', 0.073, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS CAINE MIX 0.51MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63187, 6788, 'TETRACAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64576, 6788, 'TETRACAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7439, 6788, 'TETRACAINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: TETRACAINE HYDROCHLORIDE ---------------------------------------------------');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65648, 6788, 'TETRACAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '2', 'N', 'ML', 'THE MI STRENGTH IS 20MG/2ML AS PER THE LATEST LABEL. STRENGTH VALUE PER DOSAGE UNIT ADDED TO MAKE TH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3276, 6788, 'TETRACAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TETRACAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3297, 6749, 'ETHYL ETHER', 'I', 37.5, 'G', '', '237', 'N', 'ML', 'Historic Freeform Text: ETHYL ETHER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3314, 6749, 'ETHYL ETHER', 'I', 10.5, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: ETHYL ETHER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5879, 6749, 'ETHYL ETHER', 'I', 6, '%', '', '', 'N', 'ML', 'Historic Freeform Text: ETHYL ETHER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36697, 6744, 'SODIUM CACODYLATE', 'I', 6.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NA CACODYLATE ((TETRAHYDRATE,ARSENIC DER.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5655, 6744, 'SODIUM CACODYLATE', 'I', 6.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CACODYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3190, 6744, 'SODIUM CACODYLATE', 'I', 32.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: SODIUM CACODYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4718, 6744, 'SODIUM CACODYLATE', 'I', 32, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: SODIUM CACODYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3104, 6744, 'SODIUM CACODYLATE', 'I', 32.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: SODIUM CACODYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9361, 6689, 'PODOPHYLLIN', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: RESIN PODOPHYLLUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5314, 6689, 'PODOPHYLLIN', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: RESIN PODOPHYLLUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5764, 6689, 'PODOPHYLLIN', 'I', 250, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: RESIN PODOPHYLLUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25672, 4544, 'TRIETHYLENE GLYCOL', 'I', 4.66, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRIETHYLENE GLYCOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74949, 4544, 'TRIETHYLENE GLYCOL', 'I', 4.66, '%', '', '', 'N', '', 'Historic Freeform Text: TRIETHYLENE GLYCOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76854, 4544, 'TRIETHYLENE GLYCOL', 'I', 4.66, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRIETHYLENE GLYCOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80691, 4544, 'TRIETHYLENE GLYCOL', 'I', 4.66, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRIETHYLENE GLYCOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82117, 4544, 'TRIETHYLENE GLYCOL', 'I', 4.66, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRIETHYLENE GLYCOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44117, 4571, 'TRICAINE', 'I', 1, 'G', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: TRICAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (57341, 11607, 'STANDARDIZED CAT PELT', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '10000BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53282, 11564, 'THROMBIN (HUMAN)', 'I', 4, 'UNIT', '', '1', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53282, 11564, 'THROMBIN (HUMAN)', 'I', 500, 'UNIT', '', '1', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53284, 11564, 'THROMBIN (HUMAN)', 'I', 20, 'UNIT', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53284, 11564, 'THROMBIN (HUMAN)', 'I', 2500, 'UNIT', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81151, 11564, 'THROMBIN (HUMAN)', 'I', 500, 'UNIT', '', '', 'N', 'ML', 'FREEZE DRIED THROMBIN (HUMAN) AND CALCIUM CHLORIDE ARE THE COMPONENTS OF THE THROMBIN SOLUTION 1ML.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83385, 11564, 'THROMBIN (HUMAN)', 'I', 1200, 'UNIT', '', '', 'N', 'ML', 'COMPONENT 2 THROMBIN (HUMAN): 800-1200 IU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53282, 11565, 'TOTAL PROTEIN', 'I', 130, 'MG', '', '1', 'N', 'ML', 'TOTAL PROTEIN 100 - 130 MG PER KIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53284, 11565, 'TOTAL PROTEIN', 'I', 650, 'MG', '', '5', 'N', 'ML', 'TOTAL PROTEIN 500- 650 MG PER KIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53282, 11566, 'PLASMAFIBRONECTIN (CIG)', 'I', 9, 'MG', '', '1', 'N', 'ML', 'PLASMAFIBRONECTIN (CIG) 2 - 9 MG PER KIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53284, 11566, 'PLASMAFIBRONECTIN (CIG)', 'I', 45, 'MG', '', '5', 'N', 'ML', 'PLASMAFIBRONECTIN (CIG)10 - 45 MG PER KIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42886, 11567, 'APROTININ (BOVINE)', 'I', 10000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: APROTININ APROTINI BOVINE AS PER PM AND JANICE CAMPBELL FROM BGTD. /2009.05.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53282, 11567, 'APROTININ (BOVINE)', 'I', 3000, 'KIU', '', '1', 'N', 'ML', 'DILUENT  KIU IS KALLIDINOGENASE INACTIVATOR UNIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53284, 11567, 'APROTININ (BOVINE)', 'I', 15000, 'KIU', '', '5', 'N', 'ML', 'DILUENT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69719, 11533, 'GLATIRAMER ACETATE', 'I', 20, 'MG', '', '1', 'N', 'ML', '20MG/1ML PRE-FILLED SYRINGE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52499, 11534, 'RETEPLASE', 'I', 10.4, 'UNIT', '', '', 'N', 'VIAL', 'RETEPLASE: 18.8MG (10.8UNIT) / VIAL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53275, 11561, 'OLOPATADINE (OLOPATADINE HYDROCHLORIDE)', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84721, 11561, 'OLOPATADINE (OLOPATADINE HYDROCHLORIDE)', 'I', 0.2, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1343, 8755, 'UREA', 'I', 13.44, 'G', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: UREA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2046, 8755, 'UREA', 'I', 13.44, 'G', '', '', 'N', '', 'Historic Freeform Text: UREA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5569, 8755, 'UREA', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: UREA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5280, 8755, 'UREA', 'I', 10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: UREA CHANGE FROM 10G/100ML TO 10%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4583, 8755, 'UREA', 'I', 10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: UREA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (623, 8755, 'UREA', 'I', 1.8, '%', '', '', 'N', '', 'Historic Freeform Text: UREA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (620, 8755, 'UREA', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: UREA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1593, 8755, 'UREA', 'I', 3.00, '%', '', '', 'N', '', 'Historic Freeform Text: UREA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69914, 8755, 'UREA', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76990, 8755, 'UREA', 'I', 25.0, '%', '', '', 'N', '', 'STRENGTH OF UREA: 25% AS PER ANA NESIC''S 2006.08.11 E-MAIL (IN THE FILE).3011 FORM WAS SHOWING 24.83');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49970, 8755, 'UREA', 'I', 10, '%', '', '', 'N', '', 'UREA 10% ADDED DURING PDC 145004 APPROVED BY BMORS/ SYLVIE LEFEBVRE/MANAGER/MMDD');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8338, 8755, 'UREA', 'I', 10, '%', '', '', 'N', '', 'UREA 10% ADDED TO MI FIELD AS PER CONSULTATION BETWEEN MYRIAM WALLET AND MAI PHAM/BMORS. EW 2011.06.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3830, 8755, 'UREA', 'I', 98.8, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: UREA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3773, 8755, 'UREA', 'I', 98.8, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: UREA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18789, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 4, 'G', '', '', 'N', '', 'Historic Freeform Text: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14282, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11956, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5293, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (735, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9767, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 1, 'G', '', '', 'N', 'G', 'Historic Freeform Text: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5657, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 25, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4810, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 25, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5143, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 100, 'G', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1990, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 25, 'G', '', '454', 'N', 'G', 'Historic Freeform Text: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1827, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 25, 'G', '', '454', 'N', 'G', 'Historic Freeform Text: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24755, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 62.5, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14166, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14167, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14102, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 1000, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14333, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13751, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10602, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11899, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 55, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8104, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 1000, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4877, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 1000, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5211, 8683, 'TETRACYCLINE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: TETRACYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18421, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DOXYCYCLINE ((AS DOXYCYCLINE HYCLATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14939, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DOXYCYCLINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14940, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DOXYCYCLINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9814, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DOXYCYCLINE HYCLATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10383, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DOXYCYCLINE HYCLATE ((DOXYCYCLINE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10117, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DOXYCYLINE HYCLATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10024, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DOXYCYCLINE HYCLATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7627, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DOXYCYCLINE HYCLATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6795, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DOXYCYCLINE HYDROCHLORIDE  2010.04.27. ACTIVE INGREDIENT REVISED FROM DOXYCY');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (722, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DOXYCYCLINE HYCLATE ((DOXYCYCLINE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71343, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77482, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77490, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77494, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77480, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77481, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77489, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83642, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DOXYCYLINE HYCLATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83643, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DOXYCYCLINE ((AS DOXYCYCLINE HYCLATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68783, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 8.8, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66197, 8642, 'DOXYCYCLINE (DOXYCYCLINE HYCLATE)', 'I', 44, 'MG', '', '', 'Y', 'UNIT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10897, 8644, 'DOXYCYCLINE HYCLATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DOXYCYCLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43030, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: OXYTETRACYCLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42862, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42858, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13028, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9225, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9120, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7296, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73256, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37346, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 220, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: OXYTETRACYCLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11033, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 2.2, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10022, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 440, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6498, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 220, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6120, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 110, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: OXYTETRACYCLINE COMP ((OXYTET HCL EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6681, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 440, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1565, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 110, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64826, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 600, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71006, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE (OXYTETRACYCLINE DIHYDRATE)', 'I', 110, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71007, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE (OXYTETRACYCLINE DIHYDRATE)', 'I', 220, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71008, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE (OXYTETRACYCLINE DIHYDRATE)', 'I', 440, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9766, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 1, 'G', '', '', 'N', 'G', 'Historic Freeform Text: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5967, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 20, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5321, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 20, 'G', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13027, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14103, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14112, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10033, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 1000, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4811, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5319, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 55, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5320, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 220, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5193, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 62.5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: OXYTETRACYCLINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50417, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 11, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50418, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 55, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74221, 8651, 'OXYTETRACYCLINE HYDROCHLORIDE', 'I', 1000, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46971, 8652, 'OXYTETRACYCLINE', 'I', 200, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: OXYTETRACYCLINE ((DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44256, 8652, 'OXYTETRACYCLINE (OXYTETRACYCLINE DIHYDRATE)', 'I', 200, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: OXYTETRACYCLINE ACTIVE INGREDIENT FIELD UPDATED TO ADD SUPPLIED AS OXYTETRAC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42856, 8652, 'OXYTETRACYCLINE (OXYTETRACYCLINE DIHYDRATE)', 'I', 200, 'MG', '', '', 'N', 'ML', 'OXYTETRACYCLINE AS DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42860, 8652, 'OXYTETRACYCLINE (OXYTETRACYCLINE DIHYDRATE)', 'I', 300, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: OXYTETRACYLINE ((AS DIHYDRATE))  AS PER STAN TWARDOWSKI''S REQUEST THE AI HAS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20101, 8652, 'OXYTETRACYCLINE', 'I', 200, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: OXYTETRACYCLINE  AS OXYTETRACYCLINE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6514, 8652, 'OXYTETRACYCLINE', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: OXYTETRACYCLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7515, 8652, 'OXYTETRACYCLINE', 'I', 200, 'MG', '', '', 'N', 'ML', 'AS OXYTETRACYLINE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4156, 8652, 'OXYTETRACYCLINE (OXYTETRACYCLINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: OXYTETRACYCLINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60798, 8652, 'OXYTETRACYCLINE', 'I', 200, 'MG', '', '', 'N', 'ML', 'OXYTETRACYCLINE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61018, 8652, 'OXYTETRACYCLINE', 'I', 200, 'MG', '', '', 'N', 'ML', 'OXYTETRACYCLINE AS OXYTETRACYCLINE DIHYDRATE.EW');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73026, 8652, 'OXYTETRACYCLINE (OXYTETRACYCLINE DIHYDRATE)', 'I', 200, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73110, 8652, 'OXYTETRACYCLINE (OXYTETRACYCLINE DIHYDRATE)', 'I', 200, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74520, 8652, 'OXYTETRACYCLINE (OXYTETRACYCLINE DIHYDRATE)', 'I', 200, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76042, 8652, 'OXYTETRACYCLINE (OXYTETRACYCLINE DIHYDRATE)', 'I', 300, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: OXYTETRACYLINE ((AS DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11089, 8619, 'NARASIN', 'I', 70, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: NARASIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84183, 11702, 'VALSARTAN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77251, 8652, 'OXYTETRACYCLINE (OXYTETRACYCLINE DIHYDRATE)', 'I', 300, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: OXYTETRACYLINE ((AS DIHYDRATE))  AS PER STAN TWARDOWSKI''S REQUEST THE AI HAS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19260, 8652, 'OXYTETRACYCLINE', 'I', 440, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: OXYTETRACYCLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19261, 8652, 'OXYTETRACYCLINE', 'I', 110, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: OXYTETRACYCLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15673, 8652, 'OXYTETRACYCLINE', 'I', 220, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: OXYTETRACYCLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8377, 8652, 'OXYTETRACYCLINE (OXYTETRACYCLINE HYDROCHLORIDE)', 'I', 440, 'G', '', '', 'Y', 'KG', 'Historic Freeform Text: OXYTETRACYCLINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50391, 8652, 'OXYTETRACYCLINE (OXYTETRACYCLINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7337, 8668, 'CHLORTETRACYCLINE', 'I', 11, '%', '', '', 'N', '', 'Historic Freeform Text: CHLORTETRACYCLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6495, 8668, 'CHLORTETRACYCLINE', 'I', 110, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: CHLORTETRACYCLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6496, 8668, 'CHLORTETRACYCLINE', 'I', 44, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: CHLORTETRACYCLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6497, 8668, 'CHLORTETRACYCLINE', 'I', 77, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: CHLORTETRACYCLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66444, 8668, 'CHLORTETRACYCLINE', 'I', 44, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66503, 8668, 'CHLORTETRACYCLINE', 'I', 110, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66644, 8668, 'CHLORTETRACYCLINE', 'I', 77, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1142, 8671, 'CHLORTETRACYCLINE HYDROCHLORIDE', 'I', 125, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORTETRACYCLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1061, 8671, 'CHLORTETRACYCLINE HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORTETRACYCLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44179, 8671, 'CHLORTETRACYCLINE HYDROCHLORIDE', 'I', 110, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20106, 8671, 'CHLORTETRACYCLINE HYDROCHLORIDE', 'I', 110, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: CHLORTETRACYCLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20089, 8671, 'CHLORTETRACYCLINE HYDROCHLORIDE', 'I', 44, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: CHLORTETRACYCLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19635, 8671, 'CHLORTETRACYCLINE HYDROCHLORIDE', 'I', 4.4, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: CHLORTETRACYCLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16979, 8671, 'CHLORTETRACYCLINE HYDROCHLORIDE', 'I', 220, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: CHLORTETRACYCLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8267, 8671, 'CHLORTETRACYCLINE HYDROCHLORIDE', 'I', 4.4, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: CHLORTETRACYCLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5784, 8671, 'CHLORTETRACYCLINE HYDROCHLORIDE', 'I', 4.4, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: CHLORTETRACYCLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66485, 8671, 'CHLORTETRACYCLINE HYDROCHLORIDE (CHLORTETRACYCLINE CALCIUM)', 'I', 220, 'G', '', '', 'Y', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66645, 8671, 'CHLORTETRACYCLINE HYDROCHLORIDE (CHLORTETRACYCLINE CALCIUM)', 'I', 110, 'G', '', '', 'Y', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82282, 8671, 'CHLORTETRACYCLINE HYDROCHLORIDE', 'I', 4.4, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: CHLORTETRACYCLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14938, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN STEARATE)', 'I', 250, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: ERYTHROMYCIN ((AS ERYTHROMYCIN STEARATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11252, 8618, 'ERYTHROMYCIN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11929, 8618, 'ERYTHROMYCIN', 'I', 333, 'MG', '', '', 'N', '', 'Historic Freeform Text: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10707, 8618, 'ERYTHROMYCIN', 'I', 333, 'MG', '', '', 'N', '', 'Historic Freeform Text: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9162, 8618, 'ERYTHROMYCIN', 'I', 333, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9939, 8618, 'ERYTHROMYCIN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5599, 8618, 'ERYTHROMYCIN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6686, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN ETHYLSUCCINATE)', 'I', 600, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ERYTHROMYCIN ETHYL SUCCINATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6687, 8618, 'ERYTHROMYCIN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6688, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN STEARATE)', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ERYTHROMYCIN STEARATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5296, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN ETHYLSUCCINATE)', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: ERYTHROMYCIN ETHYLSUCCINATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4465, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN STEARATE)', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ERYTHROMYCIN STEARATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15893, 8618, 'ERYTHROMYCIN', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13524, 8618, 'ERYTHROMYCIN', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14397, 8618, 'ERYTHROMYCIN', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11432, 8618, 'ERYTHROMYCIN', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12859, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN LACTOBIONATE)', 'I', 1, 'G', '', '', 'Y', 'VIAL', 'Historic Freeform Text: ERYTHROMYCIN LACTOBIONATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9397, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN LACTOBIONATE)', 'I', 1, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: ERYTHROMYCIN LACTOBIONATE  2009.04.07. ACCORDING TO THE THE APPROVED/SCANNED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12858, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN LACTOBIONATE)', 'I', 500, 'MG', '', '', 'Y', 'VIAL', 'Historic Freeform Text: ERYTHROMYCIN LACTOBIONATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9396, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN LACTOBIONATE)', 'I', 500, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: ERYTHROMYCIN LACTOBIONATE  2009.04.07. ACCORDING TO THE THE APPROVED/SCANNED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44176, 8618, 'ERYTHROMYCIN', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44180, 8618, 'ERYTHROMYCIN', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44181, 8618, 'ERYTHROMYCIN', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44182, 8618, 'ERYTHROMYCIN', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6324, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN ETHYLSUCCINATE)', 'I', 400, 'MG', '', '5', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: ERYTHROMYCIN ETHYLSUCCINATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5603, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN ETHYLSUCCINATE)', 'I', 200, 'MG', '', '5', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: ERYTHROMYCIN ETHYLSUCCINATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47468, 6599, 'PILOCARPINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3172, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN ETHYLSUCCINATE)', 'I', 400, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ERYTHROMYCIN ETHYLSUCCINATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3698, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN ETHYLSUCCINATE)', 'I', 40, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ERYTHROMYCIN ETHYLSUCCINATE ((ERYTHROMYCIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5294, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN ETHYLSUCCINATE)', 'I', 200, 'MG', '', '5', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: ERYTHROMYCIN ETHYL SUCCINATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1642, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN ESTOLATE)', 'I', 250, 'MG', '', '5', 'Y', 'ML', 'Historic Freeform Text: ERYTHROMYCIN ESTOLATE ((ERYTHROMYCIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (901, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN ESTOLATE)', 'I', 125, 'MG', '', '5', 'Y', 'ML', 'Historic Freeform Text: ERYTHROMYCIN ESTOLATE ((ERYTHROMYCIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43428, 8618, 'ERYTHROMYCIN', 'I', 30, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31467, 8618, 'ERYTHROMYCIN', 'I', 5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26616, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN PHOSPHATE)', 'I', 115.6, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: ERYTHROMYCIN ((AS PHOSPHATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14405, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN PHOSPHATE)', 'I', 231.2, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: ERYTHROMYCIN PHOSPHATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12875, 8618, 'ERYTHROMYCIN', 'I', 5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11423, 8618, 'ERYTHROMYCIN', 'I', 5, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: ERYTHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4681, 8618, 'ERYTHROMYCIN (ERYTHROMYCIN PHOSPHATE)', 'I', 115.6, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: ERYTHROMYCIN PHOS ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11582, 8619, 'NARASIN', 'I', 80, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: NARASIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16701, 8625, 'PAROMOMYCIN (PAROMOMYCIN SULFATE)', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: PAROMOMYCIN ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37335, 8626, 'FRAMYCETIN SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: FRAMYCETIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37455, 8626, 'FRAMYCETIN SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FRAMYCETIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66276, 8626, 'FRAMYCETIN SULFATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72190, 8626, 'FRAMYCETIN SULFATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18285, 8626, 'FRAMYCETIN SULFATE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: FRAMYCETIN SULFATE Qty Unit: DRE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16888, 8626, 'FRAMYCETIN SULFATE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37384, 8626, 'FRAMYCETIN SULFATE', 'I', 12.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: FRAMYCETIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37386, 8626, 'FRAMYCETIN SULFATE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FRAMYCETIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37363, 8626, 'FRAMYCETIN SULFATE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FRAMYCETIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72229, 8626, 'FRAMYCETIN SULFATE', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37334, 8626, 'FRAMYCETIN SULFATE', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: FRAMYCETIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37454, 8626, 'FRAMYCETIN SULFATE', 'I', 10, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: FRAMYCETIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37387, 8626, 'FRAMYCETIN SULFATE', 'I', 5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: FRAMYCETIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37385, 8626, 'FRAMYCETIN SULFATE', 'I', 15, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: FRAMYCETIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66275, 8626, 'FRAMYCETIN SULFATE', 'I', 10, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71565, 8626, 'FRAMYCETIN SULFATE', 'I', 10, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76309, 8626, 'FRAMYCETIN SULFATE', 'I', 5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: FRAMYCETIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12265, 8630, 'GENTAMICIN SULFATE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GENTAMICIN SULFATE ((BASE 3MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44317, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 4.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GENTAMYCIN SULPHATE ((BASE EQ 4.5MG)) QTY UNIT: IMP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37211, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 0.3, '%', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: GENTAMICIN ((AS GENTAMICIN SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10751, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GENTAMICIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10752, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 0.1, '%', '', '', 'Y', '', 'Historic Freeform Text: GENTAMICIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3718, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GENTAMICIN SULFATE  2011.04.29. GENTAMICIN 0.1%, SUPPLIED AS GENTAMICIN SULF');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3719, 8632, 'GENTAMICIN (GENTAMYCIN SULFATE)', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GENTAMICIN SULFATE  2011.04.29. GENTAMICIN 0.1%, SUPPLIED AS GENTAMICIN SULF');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (703, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 0.3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GENTAMYCIN SULFATE ((GENTAMYCIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (816, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 0.1, '%', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: GENTAMYCIN SULFATE ((GENTAMYCIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16244, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 0.3, '%', '', '', 'N', '%', 'Historic Freeform Text: GENTAMYCIN ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16983, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 0.3, '%', '', '', 'N', '%', 'Historic Freeform Text: GENTAMICIN SULFATE ((GENTAMICIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16862, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 0.3, '%', '', '', 'N', '%', 'Historic Freeform Text: GENTAMYCIN ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18241, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 1.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GENTAMICIN ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18242, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GENTAMICIN ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18243, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 1.6, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GENTAMICIN ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12674, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 1.4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GENTAMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12675, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 0.8, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GENTAMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9617, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 3, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: GENTAMICIN SULFATE ((GENTAMICIN EQ 3MG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6528, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 0.57, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: GENTAMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7418, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GENTAMICIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5562, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GENTAMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4181, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 3, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GENTAMICIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4182, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 3, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GENTAMICIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1581, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 3, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GENTAMICIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2801, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 3, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GENTAMICIN SULFATE ((BASE 3MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47318, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 3, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47319, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 3, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50167, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 3, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66434, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 40, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68998, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 3, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75394, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 10, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11062, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 1, 'MG', '', '', 'Y', 'G', 'Historic Freeform Text: GENTAMICIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10995, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 1, 'MG', '', '', 'Y', 'G', 'Historic Freeform Text: GENTAMICIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10777, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 3, 'MG', '', '', 'Y', 'G', 'HISTORIC FREEFORM TEXT: GENTAMYCIN ((SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5315, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 3, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: GENTAMICIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1285, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 1, 'MG', '', '', 'Y', 'G', 'HISTORIC FREEFORM TEXT: GENTAMICIN SULFATE ((GENTAMICIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50166, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 3, 'MG', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83017, 8632, 'GENTAMICIN (GENTAMICIN SULFATE)', 'I', 3, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4088, 8636, 'NEOMYCIN SULFATE', 'I', 43.75, 'MG', '', '', 'N', '', 'Historic Freeform Text: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2587, 8636, 'NEOMYCIN SULFATE', 'I', 12.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2005, 8636, 'NEOMYCIN SULFATE', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: NEOMYCIN SULFATE ((BASE 350MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1612, 8636, 'NEOMYCIN SULFATE', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (753, 8636, 'NEOMYCIN SULFATE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66863, 8636, 'NEOMYCIN SULFATE', 'I', 357, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 8636, 'NEOMYCIN SULFATE', 'I', 0.19, 'MG', '', '', 'N', 'PATCH', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13146, 8636, 'NEOMYCIN SULFATE', 'I', 3.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12843, 8636, 'NEOMYCIN SULFATE', 'I', 3.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1993, 8636, 'NEOMYCIN SULFATE', 'I', 28.6, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NEOMYCIN SULFATE ((EQ 20MG BASE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1394, 8636, 'NEOMYCIN SULFATE', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1766, 8636, 'NEOMYCIN SULFATE', 'I', 28.6, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11033, 8636, 'NEOMYCIN SULFATE', 'I', 2.2, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1565, 8636, 'NEOMYCIN SULFATE', 'I', 110, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5967, 8636, 'NEOMYCIN SULFATE', 'I', 20, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5112, 8636, 'NEOMYCIN SULFATE', 'I', 81.25, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16648, 8636, 'NEOMYCIN SULFATE', 'I', 3.5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14166, 8636, 'NEOMYCIN SULFATE', 'I', 200, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14112, 8636, 'NEOMYCIN SULFATE', 'I', 200, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE. EQUIVALENT TO NEOMYCIN 140MG/G.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4811, 8636, 'NEOMYCIN SULFATE', 'I', 200, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5211, 8636, 'NEOMYCIN SULFATE', 'I', 200, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4060, 8636, 'NEOMYCIN SULFATE', 'I', 5, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3975, 8636, 'NEOMYCIN SULFATE', 'I', 5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: NEOMYCIN SULFATE ((BASE 3.5MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84909, 8636, 'NEOMYCIN SULFATE', 'I', 3500, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14115, 8602, 'STREPTOMYCIN SULFATE', 'I', 15333, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: STREPTOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5144, 8602, 'STREPTOMYCIN SULFATE', 'I', 15333, 'MG', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5125, 8602, 'STREPTOMYCIN SULFATE', 'I', 15.333, 'MG', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: STREPTOMYCIN SULFATE ((BASE EQ)). STRENGTH PER UNIT REVISED TO 15.333 MG FRO');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1617, 8602, 'STREPTOMYCIN SULFATE', 'I', 21000, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: STREPTOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69765, 8584, 'TYLOSIN TARTRATE', 'I', 29, 'MG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69850, 8584, 'TYLOSIN TARTRATE', 'I', 29, 'MG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69852, 8584, 'TYLOSIN TARTRATE', 'I', 29, 'MG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69853, 8584, 'TYLOSIN TARTRATE', 'I', 29, 'MG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12174, 8590, 'THIOSTREPTON (ANTIBIOTIC OF A STREPTOMYCES SPECIES)', 'I', 2500, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: THIOSTREPTON (ANTIBIOTIC OF A STREPTOMYCES SPECIES');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11867, 8590, 'THIOSTREPTON (ANTIBIOTIC OF A STREPTOMYCES SPECIES)', 'I', 2500, 'UNIT', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: THIOSTREPTON (ANTIBIOTIC OF A STREPTOMYCES SPECIES');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (148, 8591, 'TYLOSIN (TYLOSIN TARTRATE)', 'I', 100, 'G', '', '', 'Y', 'JAR', 'HISTORIC FREEFORM TEXT: TYLOSIN TARTARATE ((TYLOSIN EQ))  STRENGTH CHANGED FROM 100% TO 100GM/JAR AS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (596, 8591, 'TYLOSIN', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TYLOSIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78107, 8591, 'TYLOSIN', 'I', 150, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9706, 8591, 'TYLOSIN (TYLOSIN PHOSPHATE)', 'I', 22, 'G', '', '', 'Y', 'KG', 'Historic Freeform Text: TYLOSIN PHOSPHATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9705, 8591, 'TYLOSIN (TYLOSIN PHOSPHATE)', 'I', 88, 'G', '', '', 'Y', 'KG', 'HISTORIC FREEFORM TEXT: TYLOSIN (AS PHOSPHATE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4115, 8591, 'TYLOSIN (TYLOSIN PHOSPHATE)', 'I', 88, 'G', '', '', 'Y', 'KG', 'Historic Freeform Text: TYLOSIN PHOSPHATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (149, 8591, 'TYLOSIN (TYLOSIN PHOSPHATE)', 'I', 22, 'G', '', '', 'Y', 'KG', 'Historic Freeform Text: TYLOSIN PHOSPHATE ((TYLOSIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65694, 8591, 'TYLOSIN (TYLOSIN PHOSPHATE)', 'I', 220, 'G', '', '', 'Y', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15899, 6648, 'SODIUM CARBONATE (ANHYDROUS)', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CARBONATE (ANHYDR)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15508, 6648, 'SODIUM CARBONATE (ANHYDROUS)', 'I', 1.5, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CARBONATE (ANHYDR)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13767, 6648, 'SODIUM CARBONATE (ANHYDROUS)', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CARBONATE (ANHYDR)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3594, 6648, 'SODIUM CARBONATE (ANHYDROUS)', 'I', 3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM CARBONATE (ANHYDR)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2545, 6648, 'SODIUM CARBONATE (ANHYDROUS)', 'I', 3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM CARBONATE (ANHYDR)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2486, 6648, 'SODIUM CARBONATE (ANHYDROUS)', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM CARBONATE (ANHYDR)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2487, 6648, 'SODIUM CARBONATE (ANHYDROUS)', 'I', 1.2, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CARBONATE (ANHYDR)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2298, 6648, 'SODIUM CARBONATE (ANHYDROUS)', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CARBONATE (ANHYDR)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2679, 6648, 'SODIUM CARBONATE (ANHYDROUS)', 'I', 3.5, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CARBONATE (ANHYDR)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2122, 6648, 'SODIUM CARBONATE (ANHYDROUS)', 'I', 4.3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CARBONATE (ANHYDR)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (744, 6648, 'SODIUM CARBONATE (ANHYDROUS)', 'I', 2.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CARBONATE (ANHYDR)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8197, 6652, 'SAFFLOWER OIL', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: SAFFLOWER OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8198, 6652, 'SAFFLOWER OIL', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: SAFFLOWER OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47094, 6652, 'SAFFLOWER OIL', 'I', 5.0, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SAFFLOWER OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18744, 6598, 'PILOCARPINE NITRATE', 'I', 2, '%', '', '', 'N', 'W/V', 'HISTORIC FREEFORM TEXT: PILOCARPINE NITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43182, 6599, 'PILOCARPINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PILOCARPINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16241, 6599, 'PILOCARPINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PILOCARPINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16217, 6599, 'PILOCARPINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: PILOCARPINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16631, 6599, 'PILOCARPINE HYDROCHLORIDE', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: PILOCARPINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12257, 6599, 'PILOCARPINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: PILOCARPINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12258, 6599, 'PILOCARPINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: PILOCARPINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12259, 6599, 'PILOCARPINE HYDROCHLORIDE', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: PILOCARPINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6053, 6599, 'PILOCARPINE HYDROCHLORIDE', 'I', 4, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PILOCARPINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47466, 6599, 'PILOCARPINE HYDROCHLORIDE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47467, 6599, 'PILOCARPINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48923, 6599, 'PILOCARPINE HYDROCHLORIDE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2374, 6599, 'PILOCARPINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PILOCARPINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2375, 6599, 'PILOCARPINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PILOCARPINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2376, 6599, 'PILOCARPINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PILOCARPINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3028, 6614, 'ANTAZOLINE PHOSPHATE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: ANTAZOLINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80140, 6614, 'ANTAZOLINE PHOSPHATE', 'I', 0.51, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (772, 6617, 'THYROID', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: THYROID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (773, 6617, 'THYROID', 'I', 60, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: THYROID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (774, 6617, 'THYROID', 'I', 125, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: THYROID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19268, 6618, 'ISONIAZID', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ISONIAZID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19033, 6618, 'ISONIAZID', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: ISONIAZID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5718, 6618, 'ISONIAZID', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ISONIAZID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5719, 6618, 'ISONIAZID', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ISONIAZID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6752, 6618, 'ISONIAZID', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: ISONIAZID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2396, 6618, 'ISONIAZID', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ISONIAZID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2400, 6618, 'ISONIAZID', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ISONIAZID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2401, 6618, 'ISONIAZID', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ISONIAZID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5720, 6618, 'ISONIAZID', 'I', 50, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ISONIAZID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2865, 6618, 'ISONIAZID', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ISONIAZID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2553, 6618, 'ISONIAZID', 'I', 500, 'G', '', '', 'N', 'BOTTLE', 'HISTORIC FREEFORM TEXT: ISONIAZID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 6627, 'OLIVE OIL', 'I', 24, 'G', '', '', 'N', 'L', 'REFINED OLIVE OIL (APPROXIMATELY 80%) + REFINED SOYBEAN OIL  (APPROXIMATELY 20%) = 30G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 6627, 'OLIVE OIL', 'I', 32, 'G', '', '', 'N', 'L', 'REFINED OLIVE OIL (APPROXIMATELY 80%) + REFINED SOYBEAN OIL  (APPROXIMATELY 20%) = 40G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 6627, 'OLIVE OIL', 'I', 32, 'G', '', '', 'N', 'L', 'REFINED OLIVE OIL (APPROXIMATELY 80%) + REFINED SOYBEAN OIL  (APPROXIMATELY 20%) = 40G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 6627, 'OLIVE OIL', 'I', 32, 'G', '', '', 'N', 'L', 'REFINED OLIVE OIL (APPROXIMATELY 80%) + REFINED SOYBEAN OIL  (APPROXIMATELY 20%) = 40G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5347, 6628, 'ISOPROPYL MYRISTATE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: ISOPROPYL MYRISTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2256, 6628, 'ISOPROPYL MYRISTATE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: ISOPROPYL MYRISTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76520, 6628, 'ISOPROPYL MYRISTATE', 'I', 50, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (531, 6629, 'SQUALANE', 'I', 25, '%', '', '', 'N', '', 'Historic Freeform Text: SQUALANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1139, 6632, 'BUTACAINE SULFATE', 'I', 0.125, '%', '', '', 'N', '%', 'Historic Freeform Text: BUTACAINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5164, 6542, 'ARSONOACETIC ACID,DISODIUM SALT', 'I', 500, 'MG', '', '10', 'N', 'ML', 'Historic Freeform Text: ARSONOACETIC ACID,DISODIUM SALT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (682, 6547, 'CHLOROQUINE DIPHOSPHATE', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLOROQUINE DIPHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47572, 4492, 'PYRETHRUM', 'I', 0.33, '%', '', '', 'N', 'W/W', 'EXTRACT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41955, 4439, 'HYDROQUINONE', 'I', 1.8, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROQUINONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41956, 4439, 'HYDROQUINONE', 'I', 1.5, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROQUINONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41957, 4439, 'HYDROQUINONE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROQUINONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37415, 4439, 'HYDROQUINONE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROQUINONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33818, 4439, 'HYDROQUINONE', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROQUINONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (32776, 4439, 'HYDROQUINONE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROQUINONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16271, 4439, 'HYDROQUINONE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROQUINONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16272, 4439, 'HYDROQUINONE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROQUINONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12972, 4439, 'HYDROQUINONE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROQUINONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12973, 4439, 'HYDROQUINONE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROQUINONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13382, 4439, 'HYDROQUINONE', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROQUINONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13899, 4439, 'HYDROQUINONE', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROQUINONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14324, 4439, 'HYDROQUINONE', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROQUINONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11207, 4439, 'HYDROQUINONE', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROQUINONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61543, 4439, 'HYDROQUINONE', 'I', 1.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61544, 4439, 'HYDROQUINONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66771, 4439, 'HYDROQUINONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66772, 4439, 'HYDROQUINONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66848, 4439, 'HYDROQUINONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72192, 4439, 'HYDROQUINONE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69834, 4439, 'HYDROQUINONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76383, 4439, 'HYDROQUINONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75425, 4439, 'HYDROQUINONE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74229, 4439, 'HYDROQUINONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73220, 4439, 'HYDROQUINONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73222, 4439, 'HYDROQUINONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73488, 4439, 'HYDROQUINONE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73651, 4439, 'HYDROQUINONE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80960, 4439, 'HYDROQUINONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80453, 4439, 'HYDROQUINONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (32777, 4439, 'HYDROQUINONE', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: HYDROQUINONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (32778, 4439, 'HYDROQUINONE', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: HYDROQUINONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15518, 4439, 'HYDROQUINONE', 'I', 4, 'G', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: HYDROQUINONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15591, 4365, 'NICOTINE', 'I', 30, 'MG', '', '7', 'N', 'SQ CM', 'HISTORIC FREEFORM TEXT: NICOTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 4381, 'CINNAMALDEHYDE', 'I', 0.034, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS FRAGRANCE MIX 0.35MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1291, 4381, 'CINNAMALDEHYDE', 'I', 5, 'ML', '', '100', 'N', 'ML', 'Historic Freeform Text: CINNAMALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9361, 4322, 'CANTHARIDIN', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: CANTHARIDIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5314, 4322, 'CANTHARIDIN', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: CANTHARIDIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1895, 4327, 'ETHYL CELLULOSE', 'I', 3.63, '%', '', '', 'N', '%', 'Historic Freeform Text: ETHYL CELLULOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60547, 11744, 'EPRINOMECTIN', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60641, 11746, 'INTERFERON BETA-1A', 'I', 22, 'µG', '', '0.5', 'N', 'ML', '1 PRE-FILLED SYRINGE CONTAINING 22 MCG (6 MIU)/0.5 ML INTERFERON BETA-1A INJECTION.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60642, 11746, 'INTERFERON BETA-1A', 'I', 44, 'µG', '', '0.5', 'N', 'ML', '1 PRE-FILLED SYRINGE CONTAINING 44 MCG (12 MIU)/0.5 ML INTERFERON BETA-1A INJECTION.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76736, 11746, 'INTERFERON BETA-1A', 'I', 8.8, 'µG', '', '0.2', 'N', 'ML', 'SOLN FOR INJECTION IN PRE-FILLED SYRINGE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76736, 11746, 'INTERFERON BETA-1A', 'I', 22.0, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75459, 11746, 'INTERFERON BETA-1A', 'I', 30, 'µG', '', '0.5', 'N', 'ML', '30MCG PER PREFILLED SYRINGE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76312, 11746, 'INTERFERON BETA-1A', 'I', 8.8, 'µG', '', '0.2', 'N', 'ML', 'SOLN FOR INJECTION IN PRE-FILLED SYRINGE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80377, 11746, 'INTERFERON BETA-1A', 'I', 132, 'µG', '', '1.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80376, 11746, 'INTERFERON BETA-1A', 'I', 66, 'µG', '', '1.5', 'N', 'ML', '1 PRE-FILLED SYRINGE CONTAINING 22 MCG (6 MIU)/0.5 ML INTERFERON BETA-1A INJECTION.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60663, 11748, 'TRAZODONE (TRAZODONE HYDROCHLORIDE)', 'I', 68.25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73464, 11748, 'TRAZODONE (TRAZODONE HYDROCHLORIDE)', 'I', 68.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60149, 11707, 'ANAGRELIDE (ANAGRELIDE HYDROCHLORIDE)', 'I', 0.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75588, 11702, 'VALSARTAN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76693, 11707, 'ANAGRELIDE (ANAGRELIDE HYDROCHLORIDE MONOHYDRATE)', 'I', 0.5, 'MG', '', '', 'N', '', '((ANAGRELIDE HYDROCHLORIDE MONOHYDRATE 0.57MG )).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74534, 11707, 'ANAGRELIDE (ANAGRELIDE HYDROCHLORIDE MONOHYDRATE)', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76047, 11707, 'ANAGRELIDE (ANAGRELIDE HYDROCHLORIDE MONOHYDRATE)', 'I', 0.5, 'MG', '', '', 'N', '', '((ANAGRELIDE HYDROCHLORIDE MONOHYDRATE 0.57MG )).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73797, 11707, 'ANAGRELIDE (ANAGRELIDE HYDROCHLORIDE)', 'I', 0.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 11709, 'L-ORNITHINE DIHYDROCHLORIDE', 'I', 318, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60166, 11710, 'BRIMONIDINE TARTRATE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66888, 11710, 'BRIMONIDINE TARTRATE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70445, 11710, 'BRIMONIDINE TARTRATE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74531, 11710, 'BRIMONIDINE TARTRATE', 'I', 0.2, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72483, 11710, 'BRIMONIDINE TARTRATE', 'I', 0.15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72692, 11710, 'BRIMONIDINE TARTRATE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78666, 11710, 'BRIMONIDINE TARTRATE', 'I', 0.15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79097, 11710, 'BRIMONIDINE TARTRATE', 'I', 0.2, '%', '', '', 'N', '', '2MG/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60186, 11711, 'GLYCEROL MONOLAURATE', 'I', 1, '%', '', '', 'N', '', 'PART OF LAURICIDIN 5.5% WHICH IS A MIXTURE OF GLYCEROL MONOLAURATE 1.0% AND CAPRYLIC/CAPRIC ACID 5.0');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60186, 11712, 'CAPRYLIC/CAPRIC ACID MONOESTERS', 'I', 5, '%', '', '', 'N', '', 'PART OF LAURICIDIN 5.5% WHICH IS A MIXTURE OF GLYCEROL MONOLAURATE 1.0% AND CAPRYLIC/CAPRIC ACID 5.0');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60205, 11714, 'NADROPARIN CALCIUM', 'I', 9500, 'UNIT', '', '1.0', 'N', 'ML', '9500 IU ANTI-XA IN SINGLE DOSE DISPOSABLE PREFILLED GRADUATED 1.0 ML SYRINGE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63628, 11714, 'NADROPARIN CALCIUM', 'I', 19000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60245, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60246, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60247, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 200, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68066, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78440, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78441, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78443, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 200, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78444, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78445, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78446, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78448, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 200, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78449, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76981, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 200, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76980, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76982, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78188, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78189, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78191, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 200, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78192, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76978, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76979, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78550, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78551, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 200, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78552, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78553, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 400, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81615, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81616, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81618, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 200, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81619, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79725, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79726, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79729, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 200, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79730, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80341, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80342, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80344, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 200, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80345, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79348, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79349, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79351, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 200, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79352, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79951, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79952, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79953, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79954, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80220, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80221, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80223, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80224, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80161, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80162, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80164, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80165, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79943, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79944, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79945, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79946, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80692, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80287, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80288, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80289, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80290, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83838, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83839, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83841, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83842, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84693, 11718, 'QUETIAPINE (QUETIAPINE FUMARATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43833, 11700, 'SOMATOSTATIN (SOMATOSTATIN ACETATE)', 'I', 250, 'µG', '', '', 'N', 'KIT', 'HISTORIC FREEFORM TEXT: SOMATOSTATIN ((AS ACETATE HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43834, 11700, 'SOMATOSTATIN (SOMATOSTATIN ACETATE)', 'I', 3, 'MG', '', '', 'N', 'AMP', 'HISTORIC FREEFORM TEXT: SOMATOSTATIN ((AS ACETATE HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60097, 11702, 'VALSARTAN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60098, 11702, 'VALSARTAN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65570, 11702, 'VALSARTAN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65571, 11702, 'VALSARTAN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68771, 11702, 'VALSARTAN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68772, 11702, 'VALSARTAN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71182, 11702, 'VALSARTAN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77486, 11702, 'VALSARTAN', 'I', 320, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79451, 11702, 'VALSARTAN', 'I', 320, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79452, 11702, 'VALSARTAN', 'I', 320, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82307, 11702, 'VALSARTAN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82308, 11702, 'VALSARTAN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82309, 11702, 'VALSARTAN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82310, 11702, 'VALSARTAN', 'I', 320, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84178, 11702, 'VALSARTAN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84179, 11702, 'VALSARTAN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84180, 11702, 'VALSARTAN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84184, 11702, 'VALSARTAN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84185, 11702, 'VALSARTAN', 'I', 320, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84186, 11702, 'VALSARTAN', 'I', 320, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84187, 11702, 'VALSARTAN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84188, 11702, 'VALSARTAN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84189, 11702, 'VALSARTAN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84190, 11702, 'VALSARTAN', 'I', 320, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84210, 11702, 'VALSARTAN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84211, 11702, 'VALSARTAN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84212, 11702, 'VALSARTAN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84213, 11702, 'VALSARTAN', 'I', 320, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84214, 11702, 'VALSARTAN', 'I', 320, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84808, 11702, 'VALSARTAN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84812, 11702, 'VALSARTAN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84813, 11702, 'VALSARTAN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85256, 11702, 'VALSARTAN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85257, 11702, 'VALSARTAN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85258, 11702, 'VALSARTAN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85259, 11702, 'VALSARTAN', 'I', 320, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85260, 11702, 'VALSARTAN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85261, 11702, 'VALSARTAN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85262, 11702, 'VALSARTAN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60122, 11704, 'MYRISTAMIDOPROPYL DIMETHYLAMINE', 'I', 0.0005, '%', '', '', 'N', '', 'PREFERRED NAME AS PER OUR REF. TEXT HIERARCHY (INCI)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78302, 11704, 'MYRISTAMIDOPROPYL DIMETHYLAMINE', 'I', 0.0005, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60130, 11705, 'LEVOFLOXACIN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60131, 11705, 'LEVOFLOXACIN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71004, 11705, 'LEVOFLOXACIN', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72599, 11705, 'LEVOFLOXACIN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72600, 11705, 'LEVOFLOXACIN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78395, 11705, 'LEVOFLOXACIN (LEVOFLOXACIN HEMIHYDRATE)', 'I', 250, 'MG', '', '', 'N', '', 'SUPPLIED AS LEVOFLOXACIN HEMIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78396, 11705, 'LEVOFLOXACIN (LEVOFLOXACIN HEMIHYDRATE)', 'I', 500, 'MG', '', '', 'N', '', 'SUPPLIED AS LEVOFLOXACIN HEMIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78397, 11705, 'LEVOFLOXACIN (LEVOFLOXACIN HEMIHYDRATE)', 'I', 750, 'MG', '', '', 'N', '', 'SUPPLIED AS LEVOFLOXACIN HEMIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77026, 11705, 'LEVOFLOXACIN (LEVOFLOXACIN HEMIHYDRATE)', 'I', 250, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77027, 11705, 'LEVOFLOXACIN (LEVOFLOXACIN HEMIHYDRATE)', 'I', 500, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77023, 11705, 'LEVOFLOXACIN (LEVOFLOXACIN HEMIHYDRATE)', 'I', 250, 'MG', '', '', 'N', '', 'SUPPLIED AS LEVOFLOXACIN HEMIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77024, 11705, 'LEVOFLOXACIN (LEVOFLOXACIN HEMIHYDRATE)', 'I', 500, 'MG', '', '', 'N', '', 'SUPPLIED AS LEVOFLOXACIN HEMIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77115, 11705, 'LEVOFLOXACIN (LEVOFLOXACIN HEMIHYDRATE)', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79949, 11705, 'LEVOFLOXACIN (LEVOFLOXACIN HEMIHYDRATE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79950, 11705, 'LEVOFLOXACIN (LEVOFLOXACIN HEMIHYDRATE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80096, 11705, 'LEVOFLOXACIN (LEVOFLOXACIN HEMIHYDRATE)', 'I', 250, 'MG', '', '', 'Y', '', 'SUPPLIED AS LEVOFLOXACIN HEMIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80097, 11705, 'LEVOFLOXACIN (LEVOFLOXACIN HEMIHYDRATE)', 'I', 500, 'MG', '', '', 'Y', '', 'SUPPLIED AS LEVOFLOXACIN HEMIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80098, 11705, 'LEVOFLOXACIN (LEVOFLOXACIN HEMIHYDRATE)', 'I', 750, 'MG', '', '', 'Y', '', 'SUPPLIED AS LEVOFLOXACIN HEMIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79115, 11705, 'LEVOFLOXACIN (LEVOFLOXACIN HEMIHYDRATE)', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81129, 11705, 'LEVOFLOXACIN (LEVOFLOXACIN HEMIHYDRATE)', 'I', 750, 'MG', '', '', 'Y', '', 'SUPPLIED AS LEVOFLOXACIN HEMIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60128, 11705, 'LEVOFLOXACIN', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6249, 11684, 'CAPSICUM', 'I', 336, 'MG', '', '470', 'N', 'ML', 'Historic Freeform Text: CAPSICUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18637, 11684, 'CAPSICUM', 'I', 75, 'MG', '', '28.35', 'N', 'G', 'Historic Freeform Text: CAPSICUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59964, 11685, 'ZAFIRLUKAST', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10817, 8595, 'DIHYDROSTREPTOMYCIN (DIHYDROSTREPTOMYCIN SULFATE)', 'I', 100, 'MG', '', '10', 'Y', 'ML', 'Historic Freeform Text: DIHYDROSTREPTOMYCIN SULF ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1588, 8595, 'DIHYDROSTREPTOMYCIN (DIHYDROSTREPTOMYCIN SULFATE)', 'I', 500, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: DIHYDROSTREPTOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18244, 8535, 'MILBEMYCIN OXIME', 'I', 11.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: MILBEMYCIN OXIME');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18245, 8535, 'MILBEMYCIN OXIME', 'I', 2.3, 'MG', '', '', 'N', '', 'Historic Freeform Text: MILBEMYCIN OXIME');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18536, 8535, 'MILBEMYCIN OXIME', 'I', 23, 'MG', '', '', 'N', '', 'Historic Freeform Text: MILBEMYCIN OXIME');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18537, 8535, 'MILBEMYCIN OXIME', 'I', 5.75, 'MG', '', '', 'N', '', 'Historic Freeform Text: MILBEMYCIN OXIME');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61538, 8535, 'MILBEMYCIN OXIME', 'I', 23, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61539, 8535, 'MILBEMYCIN OXIME', 'I', 11.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61540, 8535, 'MILBEMYCIN OXIME', 'I', 5.75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61541, 8535, 'MILBEMYCIN OXIME', 'I', 2.3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77731, 8535, 'MILBEMYCIN OXIME', 'I', 4, 'MG', '', '', 'N', '', 'MFR STD.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77732, 8535, 'MILBEMYCIN OXIME', 'I', 16, 'MG', '', '', 'N', '', 'MFR. STD');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71115, 8535, 'MILBEMYCIN OXIME', 'I', 0.1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15953, 8539, 'BAMBERMYCIN', 'I', 4, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: BAMBERMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9593, 8541, 'VANCOMYCIN (VANCOMYCIN HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: VANCOMYCIN HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9594, 8541, 'VANCOMYCIN (VANCOMYCIN HYDROCHLORIDE)', 'I', 125, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: VANCOMYCIN HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43933, 8541, 'VANCOMYCIN (VANCOMYCIN HYDROCHLORIDE)', 'I', 5, 'G', '', '', 'Y', 'VIAL', 'Historic Freeform Text: VANCOMYCIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19705, 8541, 'VANCOMYCIN (VANCOMYCIN HYDROCHLORIDE)', 'I', 1, 'G', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: VANCOMYCIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65472, 8541, 'VANCOMYCIN (VANCOMYCIN HYDROCHLORIDE)', 'I', 10, 'G', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65486, 8541, 'VANCOMYCIN (VANCOMYCIN HYDROCHLORIDE)', 'I', 1.0, 'G', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19703, 8541, 'VANCOMYCIN (VANCOMYCIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: VANCOMYCIN  ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82835, 8541, 'VANCOMYCIN (VANCOMYCIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48884, 8541, 'VANCOMYCIN (VANCOMYCIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'Y', 'VIAL', 'VIAL = 10 ML. ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48885, 8541, 'VANCOMYCIN (VANCOMYCIN HYDROCHLORIDE)', 'I', 1000, 'MG', '', '', 'Y', 'VIAL', 'VIAL = 20 ML. ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65485, 8541, 'VANCOMYCIN (VANCOMYCIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82836, 8541, 'VANCOMYCIN (VANCOMYCIN HYDROCHLORIDE)', 'I', 1000, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14036, 8547, 'NOVOBIOCIN (NOVOBIOCIN SODIUM)', 'I', 400, 'MG', '', '10', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NOVOBIOCIN SOD. ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10817, 8547, 'NOVOBIOCIN (NOVOBIOCIN SODIUM)', 'I', 150, 'MG', '', '10', 'Y', 'ML', 'Historic Freeform Text: NOVOBIOCIN SOD ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19455, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12918, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: CLINDAMYCIN ((HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66864, 11171, 'VITAMIN B2', 'I', 7, 'MG', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11623, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLINDAMYCIN ((HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11365, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: CLINDAMYCIN ((HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (874, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65371, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65372, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66121, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66122, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69247, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69248, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69946, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69947, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69948, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72878, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72879, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74355, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74356, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76333, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76334, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76335, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77875, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77876, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78015, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78016, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11260, 8551, 'CLINDAMYCIN (CLINDAMYCIN PHOSPHATE)', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66809, 8551, 'CLINDAMYCIN (CLINDAMYCIN PHOSPHATE)', 'I', 1.0, '%', '', '', 'Y', '', 'CLINDAMYCIN 10MG/G CHANGED TO 1% DURING CONTROL NO. 138717');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66912, 8551, 'CLINDAMYCIN (CLINDAMYCIN PHOSPHATE)', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67589, 8551, 'CLINDAMYCIN (CLINDAMYCIN PHOSPHATE)', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72824, 8551, 'CLINDAMYCIN (CLINDAMYCIN PHOSPHATE)', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75233, 8551, 'CLINDAMYCIN (CLINDAMYCIN PHOSPHATE)', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18964, 8551, 'CLINDAMYCIN (CLINDAMYCIN PHOSPHATE)', 'I', 150, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: CLINDAMYCIN ((AS PHOSPHATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10456, 8551, 'CLINDAMYCIN (CLINDAMYCIN HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CLINDAMYCIN ((HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1225, 8551, 'CLINDAMYCIN (CLINDAMYCIN 2-PALMITATE HYDROCHLORIDE)', 'I', 75, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1620, 8551, 'CLINDAMYCIN (CLINDAMYCIN PHOSPHATE)', 'I', 150, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49605, 8551, 'CLINDAMYCIN (CLINDAMYCIN PHOSPHATE)', 'I', 150, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49612, 8551, 'CLINDAMYCIN (CLINDAMYCIN PHOSPHATE)', 'I', 150, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15942, 8551, 'CLINDAMYCIN (CLINDAMYCIN PHOSPHATE)', 'I', 20, 'MG', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67033, 8551, 'CLINDAMYCIN (CLINDAMYCIN PHOSPHATE)', 'I', 10, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15910, 8558, 'MONENSIN (MONENSIN SODIUM)', 'I', 32, 'G', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: MONENSIN ((AS CRYSTALLINE MONENSIN SODIUM)) QTY UNIT: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50479, 8558, 'MONENSIN (MONENSIN SODIUM)', 'I', 200, 'G', '', '', 'Y', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50480, 8558, 'MONENSIN (MONENSIN SODIUM)', 'I', 200, 'G', '', '', 'Y', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67118, 8558, 'MONENSIN (MONENSIN SODIUM)', 'I', 200, 'G', '', '', 'Y', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6166, 8564, 'STREPTOZOCIN', 'I', 1, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19033, 8566, 'RIFAMPIN', 'I', 120, 'MG', '', '', 'N', '', 'Historic Freeform Text: RIFAMPIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19034, 8566, 'RIFAMPIN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: RIFAMPIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17105, 8566, 'RIFAMPIN', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: RIFAMPIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2863, 8566, 'RIFAMPIN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: RIFAMPIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2866, 8566, 'RIFAMPIN', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: RIFAMPIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11014, 8500, 'BACITRACIN ZINC', 'I', 110, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: BACITRACIN ZINC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20134, 8500, 'BACITRACIN ZINC', 'I', 500, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: BACITRACIN ZINC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16650, 8500, 'BACITRACIN ZINC', 'I', 400, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: BACITRACIN ZINC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4060, 8500, 'BACITRACIN ZINC', 'I', 400, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: BACITRACIN ZINC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3975, 8500, 'BACITRACIN ZINC', 'I', 400, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: BACITRACIN ZINC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48982, 8500, 'BACITRACIN ZINC', 'I', 500, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60545, 8500, 'BACITRACIN ZINC', 'I', 500, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60546, 8500, 'BACITRACIN ZINC', 'I', 500, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60248, 8500, 'BACITRACIN ZINC', 'I', 500, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64139, 8500, 'BACITRACIN ZINC', 'I', 500, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70888, 8500, 'BACITRACIN ZINC', 'I', 500, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73188, 8500, 'BACITRACIN ZINC', 'I', 500, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76903, 8500, 'BACITRACIN ZINC', 'I', 500, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77712, 8500, 'BACITRACIN ZINC', 'I', 500, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78327, 8500, 'BACITRACIN ZINC', 'I', 500, 'UNIT', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78975, 8500, 'BACITRACIN ZINC', 'I', 500, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83729, 8500, 'BACITRACIN ZINC', 'I', 500, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69667, 8502, 'BACITRACIN', 'I', 50000, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16174, 8502, 'BACITRACIN', 'I', 430, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: BACITRACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (431, 8502, 'BACITRACIN', 'I', 50000, 'UNIT', '', '10', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BACITRACIN PREVIOUSLY: 50000 UNITS PER VIAL. REPLACED VIAL BY 10ML AS PER 30');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43017, 8502, 'BACITRACIN (BACITRACIN METHYLENE DISALICYLATE)', 'I', 110, 'G', '', '', 'Y', 'KG', 'HISTORIC FREEFORM TEXT: BACITRACIN ((AS METHYLENE DISALICYLATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60514, 8502, 'BACITRACIN (BACITRACIN ZINC)', 'I', 110, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81364, 8502, 'BACITRACIN (BACITRACIN METHYLENE DISALICYLATE)', 'I', 440, 'MG', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42145, 8502, 'BACITRACIN', 'I', 500, 'UNIT', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: BACITRACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19303, 8502, 'BACITRACIN (BACITRACIN ZINC)', 'I', 500, 'UNIT', '', '', 'Y', 'G', 'HISTORIC FREEFORM TEXT: BACITRACIN ((AS ZINC))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20131, 8502, 'BACITRACIN', 'I', 500, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: BACITRACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17895, 8502, 'BACITRACIN', 'I', 500, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: BACITRACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16171, 8502, 'BACITRACIN (BACITRACIN ZINC)', 'I', 500, 'UNIT', '', '', 'Y', 'G', 'Historic Freeform Text: BACITRACIN ((AS BACITRACIN ZINC))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8398, 8502, 'BACITRACIN', 'I', 500, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: BACITRACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8528, 8502, 'BACITRACIN (BACITRACIN ZINC)', 'I', 400, 'UNIT', '', '', 'Y', 'G', 'HISTORIC FREEFORM TEXT: BACITRACIN ZINC ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7030, 8502, 'BACITRACIN (BACITRACIN ZINC)', 'I', 400, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: BACITRACIN ZINC ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5863, 8502, 'BACITRACIN', 'I', 500, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: BACITRACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62613, 8502, 'BACITRACIN (BACITRACIN ZINC)', 'I', 500, 'UNIT', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60209, 8502, 'BACITRACIN', 'I', 500, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66223, 8502, 'BACITRACIN (BACITRACIN ZINC)', 'I', 400, 'UNIT', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78976, 8502, 'BACITRACIN', 'I', 500, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83697, 8502, 'BACITRACIN', 'I', 500, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5144, 11171, 'VITAMIN B2', 'I', 333, 'MG', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76309, 8503, 'DIETHANOLAMINE FUSIDATE', 'I', 5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: DIETHANOLAMINE FUSIDATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5637, 8504, 'FUSIDIC ACID', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: FUSIDIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62005, 8504, 'FUSIDIC ACID', 'I', 2, '%', '', '', 'N', '', 'AS HEMIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67802, 8504, 'FUSIDIC ACID', 'I', 10, 'MG', '', '', 'N', 'G', 'FOR DETAILS SEE ANIMAL SOURCE UNDER MANUFACTURING');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67803, 8504, 'FUSIDIC ACID', 'I', 10, 'MG', '', '', 'N', 'G', 'FOR DETAILS SEE ANIMAL SOURCE UNDER MANUFACTURING');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76538, 8504, 'FUSIDIC ACID', 'I', 10, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76041, 8504, 'FUSIDIC ACID', 'I', 5, 'MG', '', '', 'N', 'G', 'AS FUSIDIC ACID HEMIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5638, 8505, 'FUSIDATE SODIUM', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FUSIDATE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35797, 8508, 'NYSTATIN', 'I', 500000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12654, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35798, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30739, 8508, 'NYSTATIN', 'I', 100, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16174, 8508, 'NYSTATIN', 'I', 86000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10435, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12174, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9973, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35795, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35799, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35800, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15598, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12996, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '4.5', 'N', 'G', 'HISTORIC FREEFORM TEXT: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11867, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12862, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9277, 8508, 'NYSTATIN', 'I', 25000, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8977, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8978, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9448, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9449, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76309, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: NYSTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84909, 8508, 'NYSTATIN', 'I', 100000, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5524, 8513, 'COLISTIN (COLISTIMETHATE SODIUM)', 'I', 150, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: COLISTIMETHATE SODIUM ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68839, 8513, 'COLISTIN (COLISTIMETHATE SODIUM)', 'I', 150, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: COLISTIMETHATE SODIUM ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50488, 8516, 'FUMAGILLIN (FUMAGILLIN DICYCLOHEXYLAMINE)', 'I', 21, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10300, 8519, 'POLYMYXIN B SULFATE', 'I', 0.5293, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POLYMYXIN B SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16624, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POLYMYXIN B SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13328, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POLYMYXIN B SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13146, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: POLYMYXIN B SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11287, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POLYMYXIN B SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12843, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: POLYMYXIN B SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10912, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POLYMYXIN B SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10817, 8519, 'POLYMYXIN B SULFATE', 'I', 50000, 'UNIT', '', '10', 'N', 'ML', 'Historic Freeform Text: POLYMYXIN B SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (259, 8519, 'POLYMYXIN B SULFATE', 'I', 6000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POLYMYXIN B SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63906, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20134, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: POLYMYXIN B SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16648, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: POLYMYXIN B SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16650, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: POLYMYXIN B SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4060, 8519, 'POLYMYXIN B SULFATE', 'I', 5000, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: POLYMYXIN B SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3975, 8519, 'POLYMYXIN B SULFATE', 'I', 5000, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: POLYMYXIN B SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2423, 8519, 'POLYMYXIN B SULFATE', 'I', 6000, 'UNIT', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: POLYMYXIN B SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48982, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60248, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77712, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78327, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78975, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79738, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80057, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78974, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80317, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80335, 8519, 'POLYMYXIN B SULFATE', 'I', 10000, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13628, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'ML', 'Historic Freeform Text: POLYMYXIN B ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10062, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: POLYMYXIN B SULFATE ((POLYMYXIN B EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10025, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: POLYMYXIN B SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6727, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 200000, 'UNIT', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: POLYMYXIN B SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49184, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62611, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62612, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42145, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'G', 'Historic Freeform Text: POLYMIXIN B SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19303, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'G', 'Historic Freeform Text: POLYMYXIN B ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20131, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: POLYMYXIN B SULFATE ((POLYMYXIN B EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16171, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'G', 'Historic Freeform Text: POLYMYXIN B ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8398, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: POLYMIXIN B SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8528, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 5000, 'UNIT', '', '', 'Y', 'G', 'HISTORIC FREEFORM TEXT: POLYMYXIN B SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7030, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 5000, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: POLYMYXIN B SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50105, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50407, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62613, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62658, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60545, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60546, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60209, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64139, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66223, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70888, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73188, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72525, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76903, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78976, 8520, 'POLYMYXIN B (POLYMYXIN B SULFATE)', 'I', 10000, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37384, 8523, 'GRAMICIDIN', 'I', 0.05, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GRAMICIDIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37363, 8523, 'GRAMICIDIN', 'I', 0.05, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GRAMICIDIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13328, 8523, 'GRAMICIDIN', 'I', 0.025, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GRAMICIDIN D');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10062, 8523, 'GRAMICIDIN', 'I', 0.025, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GRAMICIDIN  ANIMAL COUNTRY OF ORIGIN IS EUROPEAN COMMUNITY STATES EXCEPT THE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10025, 8523, 'GRAMICIDIN', 'I', 0.025, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GRAMICIDIN  ANIMAL COUNTRY OF ORIGIN IS THE EUROPEAN COMMUNITY STATES EXCEPT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62612, 8523, 'GRAMICIDIN', 'I', 0.025, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72229, 8523, 'GRAMICIDIN', 'I', 0.05, 'MG', '', '', 'N', 'ML', 'ANIMAL SOURCE COUNTRY IS EUROPEAN COMMUNITY STATES EXCEPT THE UNITED KINGDOM.  OTHER TISSUE AND/OR F');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37385, 8523, 'GRAMICIDIN', 'I', 50, 'µG', '', '', 'N', 'G', 'Historic Freeform Text: GRAMICIDIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16171, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: GRAMICIDIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15598, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: GRAMICIDIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12862, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: GRAMICIDIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9448, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: GRAMICIDIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9449, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: GRAMICIDIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50105, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50407, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', 'ANIMAL COUNTRY OF ORIGIN IS EUROPEAN COMMUNITY STATES EXCEPT UK. ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62658, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60545, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64139, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70888, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73188, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72525, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78327, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78975, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79738, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80057, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78974, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80317, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80335, 8523, 'GRAMICIDIN', 'I', 0.25, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3269, 8526, 'TYROTHRICIN', 'I', 0.039, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16984, 8471, 'CEPHALOTHIN (CEPHALOTHIN SODIUM)', 'I', 1, 'G', '', '', 'N', 'VIAL', 'Historic Freeform Text: CEPHALOTHIN SODIUM ((CEPHALOTHIN EQ.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67747, 8479, 'MADURAMICIN AMMONIUM', 'I', 10, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (250, 8486, 'DACTINOMYCIN', 'I', 0.5, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: ACTINOMYCIN D');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (933, 8493, 'AMPHOTERICIN B', 'I', 50, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: AMPHOTERICIN B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65288, 8493, 'AMPHOTERICIN B', 'I', 50, 'MG', '', '', 'N', 'VIAL', 'LIPOSOMAL AMPHOTERICIN B AS LYOPHILIZED PRODUCT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65412, 8493, 'AMPHOTERICIN B', 'I', 100, 'MG', '', '', 'Y', 'VIAL', 'AS AMPHOTERICIN B CHOLESTERYL SULFATE COMPLEX FOR INJECTABLE SUSPENSION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65413, 8493, 'AMPHOTERICIN B', 'I', 50, 'MG', '', '', 'Y', 'VIAL', 'AS AMPHOTERICIN B CHOLESTERYL SULFATE COMPLEX FOR INJECTABLE SUSPENSION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50926, 8493, 'AMPHOTERICIN B', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6421, 8426, 'PENICILLIN V POTASSIUM', 'I', 500000, 'UNIT', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3375, 8426, 'PENICILLIN V POTASSIUM', 'I', 500000, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PENICILLIN V POT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (295, 8426, 'PENICILLIN V POTASSIUM', 'I', 500000, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PENICILLIN V POT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6422, 8426, 'PENICILLIN V POTASSIUM', 'I', 200000, 'UNIT', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6423, 8426, 'PENICILLIN V POTASSIUM', 'I', 500000, 'UNIT', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2814, 8426, 'PENICILLIN V POTASSIUM', 'I', 500000, 'UNIT', '', '5', 'N', 'ML', 'Historic Freeform Text: PENICILLIN V POT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 6487, 'MAGNESIUM (MAGNESIUM OXIDE)', 'I', 40, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71557, 6487, 'MAGNESIUM (MAGNESIUM HYDROXIDE)', 'I', 56, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70202, 6487, 'MAGNESIUM (MAGNESIUM OXIDE)', 'I', 50, 'MG', '', '', 'N', '', 'PINK TABLET A.M.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76186, 6487, 'MAGNESIUM (MAGNESIUM OXIDE)', 'I', 50, 'MG', '', '', 'N', '', 'PINK TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9526, 6487, 'MAGNESIUM (MAGNESIUM CHLORIDE)', 'I', 2.76, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((MAG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13000, 6487, 'MAGNESIUM (MAGNESIUM BOROGLUCONATE)', 'I', 3.12, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM BOROGLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6404, 6487, 'MAGNESIUM (MAGNESIUM CHLORIDE)', 'I', 6, 'MEQ', '', '', 'N', 'L', 'Historic Freeform Text: MAG CHLORIDE ((MAG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17121, 6487, 'MAGNESIUM (MAGNESIUM CHLORIDE)', 'I', 1.82, 'G', '', '400', 'Y', 'G', 'HISTORIC FREEFORM TEXT: MG ((AS CHLORIDE 7.14GM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47167, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41753, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42082, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41830, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41831, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37037, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37150, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34150, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33120, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27225, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25897, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25898, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22846, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22847, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19429, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PSEUDOEPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17887, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17880, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77674, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19103, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18539, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17113, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13120, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13607, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14492, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13804, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12461, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11646, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11041, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 7.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11921, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8250, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8251, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8252, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8249, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8247, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 7.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7081, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1224, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (955, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62610, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62614, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62615, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60817, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61704, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63999, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64001, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64134, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64135, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63341, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', 'EACH CAPLET CONTAINS IMMEDIATE-RELEASE FEXOFENADINE HYDROCHLORIDE 60MG, AND SUSTAINED-RELEASE PSEUDO');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65178, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65249, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65250, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65897, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66847, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66950, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65665, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67104, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69017, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69018, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68103, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68104, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72216, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72217, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70284, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70285, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70286, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70312, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70399, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71047, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71201, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72935, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74005, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74007, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74016, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74017, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75302, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75304, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75315, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76544, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76681, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73002, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73003, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74181, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75371, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73064, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74415, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74414, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74549, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74550, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73565, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73592, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73702, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73703, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73704, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73705, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78062, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77185, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78348, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81657, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82152, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79084, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79088, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79269, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78913, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80988, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79278, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82084, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77675, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83056, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83258, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83303, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PSEUDOEPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83304, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PSEUDOEPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83343, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83344, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83757, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84427, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35886, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: PSEUDOEPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37105, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65873, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65633, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75146, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83004, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36232, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PSEUDOEPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37183, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34650, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31502, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30945, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27462, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27463, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26863, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19625, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20329, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19129, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19060, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PSEUDOEPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16698, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16177, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15618, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14551, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13440, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13960, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13361, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12410, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12719, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12722, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '20', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12718, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12192, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12504, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8324, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4124, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (956, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (957, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1497, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1498, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47448, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52513, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60207, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63140, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66361, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66840, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66928, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66929, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66947, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66983, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65129, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65130, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65133, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65132, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67954, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67672, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72095, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69813, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69814, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75087, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72786, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75412, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26864, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74333, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74797, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74799, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74852, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74853, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73724, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77475, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79105, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80682, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 30, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71050, 6492, 'PSEUDOEPHEDRINE HYDROCHLORIDE', 'I', 60, 'MG', '', '24', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (130, 6495, 'CADMIUM OXIDE', 'I', 1.5, '%', '', '', 'N', '', 'Historic Freeform Text: CADMIUM OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14735, 6506, 'HYDROXYCHLOROQUINE SULFATE', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROXYCHLOROQUINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70886, 6506, 'HYDROXYCHLOROQUINE SULFATE', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROXYCHLOROQUINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73748, 6506, 'HYDROXYCHLOROQUINE SULFATE', 'I', 200, 'MG', '', '', 'N', '', 'EQUIVALENT TO 155MG HYDROXYCHLOROQUINE BASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79662, 6506, 'HYDROXYCHLOROQUINE SULFATE', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROXYCHLOROQUINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2015, 6482, 'ETHYLENEDIAMINE DIHYDROIODIDE', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHYLENEDIAMINE DIHYDRIODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64083, 6482, 'ETHYLENEDIAMINE DIHYDROIODIDE', 'I', 0.008, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2007, 6482, 'ETHYLENEDIAMINE DIHYDROIODIDE', 'I', 9.4, '%', '', '', 'N', '%', 'Historic Freeform Text: ETHYLENEDIAMINE DIHYDRIODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5925, 6482, 'ETHYLENEDIAMINE DIHYDROIODIDE', 'I', 0.44, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ETHYLENEDIAMINE DIHYDRIODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5147, 6482, 'ETHYLENEDIAMINE DIHYDROIODIDE', 'I', 0.44, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ETHYLENEDIAMINE DIHYDRIODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2480, 6482, 'ETHYLENEDIAMINE DIHYDROIODIDE', 'I', 16.6, 'G', '', '454', 'N', 'G', 'Historic Freeform Text: ETHYLENEDIAMINE DIHYDRIODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1613, 6482, 'ETHYLENEDIAMINE DIHYDROIODIDE', 'I', 75, 'G', '', '454', 'N', 'G', 'Historic Freeform Text: ETHYLENEDIAMINE DIHYDRIODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2195, 6482, 'ETHYLENEDIAMINE DIHYDROIODIDE', 'I', 16.6, 'G', '', '454', 'N', 'G', 'Historic Freeform Text: ETHYLENEDIAMINE DIHYDRIODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35469, 6482, 'ETHYLENEDIAMINE DIHYDROIODIDE', 'I', 12.5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: ETHYLENEDIAMINE DIHYDROIODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19544, 6482, 'ETHYLENEDIAMINE DIHYDROIODIDE', 'I', 105, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: ETHYLENEDIAMINE DIHYDRIODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1320, 6446, 'THYMOL IODIDE', 'I', 0.1, '%', '', '', 'N', '%', 'Historic Freeform Text: THYMOL IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1251, 6446, 'THYMOL IODIDE', 'I', 25, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: THYMOL IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8567, 6446, 'THYMOL IODIDE', 'I', 1, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: THYMOL IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71475, 6457, 'NITARSONE', 'I', 500, 'G', '', '', 'N', 'KG', '4-NITROPHENYLARSONIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5701, 6458, 'AMPROLIUM', 'I', 9.6, '%', '', '', 'N', 'W/V', 'HISTORIC FREEFORM TEXT: AMPROLIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5702, 6458, 'AMPROLIUM', 'I', 250, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: AMPROLIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3670, 6465, 'ROXARSONE', 'I', 17.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: ROXARSONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37256, 6465, 'ROXARSONE', 'I', 20, '%', '', '', 'N', '', 'Historic Freeform Text: ROXARSONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13156, 6469, 'GOLD SODIUM THIOMALATE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GOLD SODIUM THIOMALATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12845, 6469, 'GOLD SODIUM THIOMALATE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GOLD SODIUM THIOMALATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12846, 6469, 'GOLD SODIUM THIOMALATE', 'I', 25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GOLD SODIUM THIOMALATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69514, 6469, 'GOLD SODIUM THIOMALATE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69515, 6469, 'GOLD SODIUM THIOMALATE', 'I', 25, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69516, 6469, 'GOLD SODIUM THIOMALATE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71959, 6417, 'METHADONE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71963, 6417, 'METHADONE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71964, 6417, 'METHADONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71965, 6417, 'METHADONE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65010, 6417, 'METHADONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68257, 6417, 'METHADONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71958, 6417, 'METHADONE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17842, 6425, 'DICYCLOMINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICYCLOMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18227, 6425, 'DICYCLOMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICYCLOMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4223, 6425, 'DICYCLOMINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICYCLOMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4710, 6425, 'DICYCLOMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DICYCLOMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3556, 6425, 'DICYCLOMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICYCLOMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2623, 6425, 'DICYCLOMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICYCLOMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1857, 6425, 'DICYCLOMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICYCLOMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85095, 6425, 'DICYCLOMINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17841, 6425, 'DICYCLOMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DICYCLOMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3555, 6425, 'DICYCLOMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DICYCLOMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18634, 6438, 'PIPERONYL BUTOXIDE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: PIPERONYL BUTOXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3269, 6438, 'PIPERONYL BUTOXIDE', 'I', 0.49, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78333, 6438, 'PIPERONYL BUTOXIDE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47572, 6438, 'PIPERONYL BUTOXIDE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18634, 6441, 'PYRETHRINS', 'I', 0.33, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PYRETHRINS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3269, 6441, 'PYRETHRINS', 'I', 0.04, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78333, 6441, 'PYRETHRINS', 'I', 0.33, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42736, 6404, 'BISMUTH SUBSALICYLATE', 'I', 262, 'MG', '', '', 'N', '', 'Historic Freeform Text: BISMUTH SUBSALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60637, 6404, 'BISMUTH SUBSALICYLATE', 'I', 262, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64038, 6404, 'BISMUTH SUBSALICYLATE', 'I', 262, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69837, 6404, 'BISMUTH SUBSALICYLATE', 'I', 262, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69838, 6404, 'BISMUTH SUBSALICYLATE', 'I', 262, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79987, 6404, 'BISMUTH SUBSALICYLATE', 'I', 262, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81124, 6404, 'BISMUTH SUBSALICYLATE', 'I', 262, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80534, 6404, 'BISMUTH SUBSALICYLATE', 'I', 262, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81194, 6404, 'BISMUTH SUBSALICYLATE', 'I', 262, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42395, 6404, 'BISMUTH SUBSALICYLATE', 'I', 17.6, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: BISMUTH SUBSALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33448, 6404, 'BISMUTH SUBSALICYLATE', 'I', 17.6, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BISMUTH SUBSALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47656, 6404, 'BISMUTH SUBSALICYLATE', 'I', 35.2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66286, 6404, 'BISMUTH SUBSALICYLATE', 'I', 35, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71331, 6404, 'BISMUTH SUBSALICYLATE', 'I', 35, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74775, 6404, 'BISMUTH SUBSALICYLATE', 'I', 35, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78167, 6404, 'BISMUTH SUBSALICYLATE', 'I', 17.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81398, 6404, 'BISMUTH SUBSALICYLATE', 'I', 35, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79869, 6404, 'BISMUTH SUBSALICYLATE', 'I', 17.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (763, 6367, 'METHSUXIMIDE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHSUXIMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 6372, 'ETHYLENEDIAMINE DIHYDROCHLORIDE', 'I', 0.041, 'MG', '', '', 'N', 'PATCH', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53273, 6375, 'MALIC ACID', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12874, 6385, 'MANGANESE HYPOPHOSPHITE', 'I', 68, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: MANGANESE HYPOPHOSPHITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6732, 4358, 'CLOPIDOL', 'I', 25, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75693, 4315, 'CHLORINE PEROXIDE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84428, 4235, 'COAGULATION FACTOR VII (HUMAN)', 'I', 500, 'UNIT', '', '', 'N', '', '200-500IU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79791, 11461, 'IRINOTECAN HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'AS THE TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78001, 4235, 'COAGULATION FACTOR VII (HUMAN)', 'I', 480, 'UNIT', '', '', 'N', 'VIAL', '180-480 INTERN. UNIT; AFTER RECONSTITUTION: 9-24 IU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84428, 4229, 'COAGULATION FACTOR X (HUMAN)', 'I', 1020, 'UNIT', '', '', 'N', '', '500-1020IU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78001, 4229, 'COAGULATION FACTOR X (HUMAN)', 'I', 600, 'UNIT', '', '', 'N', 'VIAL', '360-600 INTERN. UNIT; AFTER RECONSTITUTION:18-30 IU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 4156, 'GERANIOL', 'I', 0.07, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS FRAGRANCE MIX 0.35MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1090, 4161, 'BISMUTH DIPROPYLACETATE', 'I', 135, 'MG', '', '', 'N', '', 'Historic Freeform Text: BISMUTH DIPROPYLACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52041, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52043, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52044, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52047, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80234, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80235, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80236, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80237, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79955, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79957, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79958, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79959, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81195, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81197, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81198, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81199, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83760, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83761, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83762, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83763, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83827, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83828, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83829, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83830, 11516, 'ROPINIROLE (ROPINIROLE HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19090, 11521, 'PENICILLIN G BENZATHINE', 'I', 150000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: BENZATHINE PENICILLIN G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14301, 11521, 'PENICILLIN G BENZATHINE', 'I', 150000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: BENZATHINE PENICILLIN G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5449, 11521, 'PENICILLIN G BENZATHINE', 'I', 150000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: BENZATHINE PENICILLIN G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75694, 11521, 'PENICILLIN G BENZATHINE', 'I', 150000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77729, 11521, 'PENICILLIN G BENZATHINE', 'I', 1200000, 'UNIT', '', '2', 'N', 'ML', 'UNIT IS IU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51491, 11485, 'DONEPEZIL HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51492, 11485, 'DONEPEZIL HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75483, 11485, 'DONEPEZIL HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75484, 11485, 'DONEPEZIL HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10457, 11487, 'DINOPROST (DINOPROST TROMETHAMINE)', 'I', 5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DINOPROST TROMETHAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2224, 11487, 'DINOPROST (DINOPROST TROMETHAMINE)', 'I', 5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DINOPROST TROMETHAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66152, 11463, 'FOLLITROPIN BETA', 'I', 50, 'UNIT', '', '0.5', 'N', 'ML', '50 IU FSH ACTIVITY PER VIAL (0.5ML).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66154, 11463, 'FOLLITROPIN BETA', 'I', 100, 'UNIT', '', '0.5', 'N', 'ML', '100 IU FSH ACTIVITY PER VIAL (0.5ML).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67891, 11463, 'FOLLITROPIN BETA', 'I', 833, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50424, 11431, 'TOPOTECAN (TOPOTECAN HYDROCHLORIDE)', 'I', 4, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81957, 11431, 'TOPOTECAN (TOPOTECAN HYDROCHLORIDE)', 'I', 4, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82941, 11431, 'TOPOTECAN (TOPOTECAN HYDROCHLORIDE)', 'I', 4, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42902, 11439, 'NAFARELIN (NAFARELIN ACETATE)', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50773, 11443, 'TRANDOLAPRIL', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50775, 11443, 'TRANDOLAPRIL', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50776, 11443, 'TRANDOLAPRIL', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61488, 11443, 'TRANDOLAPRIL', 'I', 4, 'MG', '', '', 'N', '', 'FORM = FILM COATED TABLET, CONTAINING 4MG TRANDOLAPRIL IN AN IMMEDIATE RELEASE FORM AND 240MG VERAPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62731, 11443, 'TRANDOLAPRIL', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64537, 11443, 'TRANDOLAPRIL', 'I', 2, 'MG', '', '', 'N', '', 'FORM = FILM COATED TABLET, CONTAINING 2MG TRANDOLAPRIL IN AN IMMEDIATE RELEASE FORM AND 240MG VERAPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50690, 11445, 'DOLASETRON MESYLATE', 'I', 100, 'MG', '', '', 'N', '', 'AS MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50695, 11446, 'LETROZOLE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79471, 11446, 'LETROZOLE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80777, 11446, 'LETROZOLE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82411, 11446, 'LETROZOLE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83029, 11446, 'LETROZOLE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83335, 11446, 'LETROZOLE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83427, 11446, 'LETROZOLE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4114, 11447, 'CROMOLYN SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DISODIUM CROMOGLYCATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13857, 11447, 'CROMOLYN SODIUM', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DISODIUM CROMOGLYCATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14758, 11447, 'CROMOLYN SODIUM', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: DISODIUM CROMOGLYCATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50704, 11447, 'CROMOLYN SODIUM', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50747, 11447, 'CROMOLYN SODIUM', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14565, 11447, 'CROMOLYN SODIUM', 'I', 2, '%', '', '', 'N', 'W/V', 'HISTORIC FREEFORM TEXT: DISODIUM CROMOGLYCATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49797, 11447, 'CROMOLYN SODIUM', 'I', 2, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51046, 11447, 'CROMOLYN SODIUM', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43892, 11448, 'BLEOMYCIN (BLEOMYCIN SULFATE)', 'I', 15, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: BLEOMYCIN ((AS SULPHATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75142, 11448, 'BLEOMYCIN (BLEOMYCIN SULFATE)', 'I', 15, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50779, 11456, 'FEXOFENADINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16991, 8447, 'PENICILLIN G (PENICILLIN G SODIUM)', 'I', 10000000, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: PENICILLIN G ((AS PENICILLIN G SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63341, 11456, 'FEXOFENADINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', 'EACH CAPLET CONTAINS IMMEDIATE-RELEASE FEXOFENADINE HYDROCHLORIDE 60MG, AND SUSTAINED-RELEASE PSEUDO');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66647, 11456, 'FEXOFENADINE HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72486, 11457, 'FOLLITROPIN ALPHA', 'I', 5.5, 'µG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72488, 11457, 'FOLLITROPIN ALPHA', 'I', 33, 'µG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72489, 11457, 'FOLLITROPIN ALPHA', 'I', 77, 'µG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50782, 11457, 'FOLLITROPIN ALPHA', 'I', 150, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68777, 11457, 'FOLLITROPIN ALPHA', 'I', 1200, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75576, 11457, 'FOLLITROPIN ALPHA', 'I', 900, 'UNIT', '', '1.5', 'N', 'ML', 'EQUIVALENT TO 66MCG/1.5ML. PRE-FILLED PEN. R-DNA ORIGIN.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75577, 11457, 'FOLLITROPIN ALPHA', 'I', 450, 'UNIT', '', '0.75', 'N', 'ML', 'EQUIVALENT TO 33MCG/0.75ML. PRE-FILLED PEN. R-DNA ORIGIN.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75578, 11457, 'FOLLITROPIN ALPHA', 'I', 300, 'UNIT', '', '0.5', 'N', 'ML', 'EQUIVALENT TO 22MCG/0.5ML. PRE-FILLED PEN. RDNA ORIGIN.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50823, 11458, 'LATANOPROST', 'I', 50, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70807, 11458, 'LATANOPROST', 'I', 50, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50960, 11460, 'CARBETOCIN', 'I', 100, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50993, 11461, 'IRINOTECAN HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'AS THE TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74343, 11461, 'IRINOTECAN HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'AS THE TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79064, 11461, 'IRINOTECAN HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'AS THE TRIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83053, 11461, 'IRINOTECAN HYDROCHLORIDE (IRINOTECAN HYDROCHLORIDE TRIHYDRATE)', 'I', 20, 'MG', '', '', 'N', 'ML', 'AS THE TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13600, 11394, 'IODIDE (SODIUM IODIDE)', 'I', 100, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM IODINE ((IODIDE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17813, 11396, 'CICLOSPORIN', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CYCLOSPORINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17814, 11396, 'CICLOSPORIN', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CYCLOSPORINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17799, 11396, 'CICLOSPORIN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: CYCLOSPORINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61016, 11396, 'CICLOSPORIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66649, 11396, 'CICLOSPORIN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71308, 11396, 'CICLOSPORIN', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71309, 11396, 'CICLOSPORIN', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76769, 11396, 'CICLOSPORIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76770, 11396, 'CICLOSPORIN', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76771, 11396, 'CICLOSPORIN', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76772, 11396, 'CICLOSPORIN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84087, 11396, 'CICLOSPORIN', 'I', 0.05, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17801, 11396, 'CICLOSPORIN', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CYCLOSPORINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5790, 11396, 'CICLOSPORIN', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CYCLOSPORINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68291, 11396, 'CICLOSPORIN', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CYCLOSPORINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18252, 11396, 'CICLOSPORIN', 'I', 2, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: CYCLOSPORINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77915, 11417, 'COAGULATION FACTOR IX (RECOMBINANT)', 'I', 250, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77916, 11417, 'COAGULATION FACTOR IX (RECOMBINANT)', 'I', 500, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77917, 11417, 'COAGULATION FACTOR IX (RECOMBINANT)', 'I', 1000, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77918, 11417, 'COAGULATION FACTOR IX (RECOMBINANT)', 'I', 2000, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75022, 11418, 'PIRLIMYCIN (PIRLIMYCIN HYDROCHLORIDE)', 'I', 50, 'MG', '', '10', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75249, 8433, 'PENICILLIN G PROCAINE', 'I', 300000, 'UNIT', '', '', 'N', '', '(EQUIVALENT TO 296.7MG/ML).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43447, 8433, 'PENICILLIN G PROCAINE', 'I', 300, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PENICILLIN G PROCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51048, 8433, 'PENICILLIN G PROCAINE', 'I', 300, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62606, 8433, 'PENICILLIN G PROCAINE', 'I', 300, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62607, 8433, 'PENICILLIN G PROCAINE', 'I', 300, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19090, 8433, 'PENICILLIN G PROCAINE', 'I', 150000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: PENICILLIN G PROCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19093, 8433, 'PENICILLIN G PROCAINE', 'I', 300000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: PENICILLIN G PROCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14036, 8433, 'PENICILLIN G PROCAINE', 'I', 200000, 'UNIT', '', '10', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PENICILLIN G PROCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14300, 8433, 'PENICILLIN G PROCAINE', 'I', 300000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: PENICILLIN G PROCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14301, 8433, 'PENICILLIN G PROCAINE', 'I', 150000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: PENICILLIN G PROCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12796, 8433, 'PENICILLIN G PROCAINE', 'I', 300000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: PENICILLIN G PROCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10817, 8433, 'PENICILLIN G PROCAINE', 'I', 100000, 'UNIT', '', '10', 'N', 'ML', 'Historic Freeform Text: PENICILLIN G PROCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8084, 8433, 'PENICILLIN G PROCAINE', 'I', 300000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: PENICILLIN G PROCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5449, 8433, 'PENICILLIN G PROCAINE', 'I', 150000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: PENICILLIN G PROCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78607, 8433, 'PENICILLIN G PROCAINE', 'I', 300000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3568, 8433, 'PENICILLIN G PROCAINE', 'I', 300000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: PENICILLIN G PROCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5114, 8433, 'PENICILLIN G PROCAINE', 'I', 300000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: PENICILLIN G PROCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61193, 8433, 'PENICILLIN G PROCAINE', 'I', 300000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69819, 8433, 'PENICILLIN G PROCAINE', 'I', 300000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75694, 8433, 'PENICILLIN G PROCAINE', 'I', 150000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30580, 8433, 'PENICILLIN G PROCAINE', 'I', 1000, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: PENICILLIN G PROCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26370, 8433, 'PENICILLIN G PROCAINE', 'I', 110, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: PENICILLIN G PROCAINE ((PENICIL.EQ.66.2G))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6213, 8433, 'PENICILLIN G PROCAINE', 'I', 110, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: PENICILLIN G PROCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14339, 8433, 'PENICILLIN G PROCAINE', 'I', 110, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PENICILLIN G PROCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12394, 8435, 'PENICILLIN G SODIUM', 'I', 1000000, 'UNIT', '', '', 'N', 'VIAL', 'Historic Freeform Text: PENICILLIN G SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12395, 8435, 'PENICILLIN G SODIUM', 'I', 10000000, 'UNIT', '', '', 'N', 'VIAL', 'Historic Freeform Text: PENICILLIN G SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12343, 8435, 'PENICILLIN G SODIUM', 'I', 5000000, 'UNIT', '', '', 'N', 'VIAL', 'Historic Freeform Text: PENICILLIN G SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44205, 8439, 'PENICILLIN G POTASSIUM', 'I', 100, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18630, 8439, 'PENICILLIN G POTASSIUM', 'I', 500000000, 'UNIT', '', '', 'N', 'JAR', 'HISTORIC FREEFORM TEXT: PENICILLIN G POTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14115, 8439, 'PENICILLIN G POTASSIUM', 'I', 4961333, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: PENICILLIN G POTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12922, 8439, 'PENICILLIN G POTASSIUM', 'I', 31500000, 'UNIT', '', '400', 'N', 'G', 'Historic Freeform Text: PENICILLIN G POTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5144, 8439, 'PENICILLIN G POTASSIUM', 'I', 4961333, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: PENICILLIN G POTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5125, 8439, 'PENICILLIN G POTASSIUM', 'I', 4961333, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: PENICILLIN G POTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1617, 8439, 'PENICILLIN G POTASSIUM', 'I', 7010000, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: PENICILLIN G POTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37244, 8447, 'PENICILLIN G (PENICILLIN G SODIUM)', 'I', 1000000, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: PENICILLIN G SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37245, 8447, 'PENICILLIN G (PENICILLIN G SODIUM)', 'I', 5000000, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: PENICILLIN G SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37246, 8447, 'PENICILLIN G (PENICILLIN G SODIUM)', 'I', 10000000, 'UNIT', '', '', 'N', 'VIAL', 'Historic Freeform Text: PENICILLIN G SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75197, 8318, 'CLARITHROMYCIN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16992, 8447, 'PENICILLIN G (PENICILLIN G SODIUM)', 'I', 5000000, 'UNIT', '', '', 'N', 'VIAL', 'Historic Freeform Text: PENICILLIN G ((AS PENICILLIN G SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16993, 8447, 'PENICILLIN G (PENICILLIN G SODIUM)', 'I', 1000000, 'UNIT', '', '', 'N', 'VIAL', 'Historic Freeform Text: PENICILLIN G ((AS PENICILLIN G SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78574, 8447, 'PENICILLIN G (PENICILLIN G SODIUM)', 'I', 5000000, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20089, 8447, 'PENICILLIN G (PENICILLIN G PROCAINE)', 'I', 22, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: PENICILLIN ((AS PENICILLIN G PROCAINE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6496, 8447, 'PENICILLIN G (PENICILLIN G PROCAINE)', 'I', 22, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: PENICILLIN G PROCAINE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11857, 8452, 'TRIMETHOPRIM', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11858, 8452, 'TRIMETHOPRIM', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11953, 8452, 'TRIMETHOPRIM', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11954, 8452, 'TRIMETHOPRIM', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6037, 8452, 'TRIMETHOPRIM', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3677, 8452, 'TRIMETHOPRIM', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3678, 8452, 'TRIMETHOPRIM', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3679, 8452, 'TRIMETHOPRIM', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4610, 8452, 'TRIMETHOPRIM', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4611, 8452, 'TRIMETHOPRIM', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66985, 8452, 'TRIMETHOPRIM', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66986, 8452, 'TRIMETHOPRIM', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43987, 8452, 'TRIMETHOPRIM', 'I', 80, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43988, 8452, 'TRIMETHOPRIM', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43982, 8452, 'TRIMETHOPRIM', 'I', 40, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42854, 8452, 'TRIMETHOPRIM', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19182, 8452, 'TRIMETHOPRIM', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13628, 8452, 'TRIMETHOPRIM (TRIMETHOPRIM SULFATE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: TRIMETHOPRIM ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11859, 8452, 'TRIMETHOPRIM', 'I', 8, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10535, 8452, 'TRIMETHOPRIM', 'I', 8, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11977, 8452, 'TRIMETHOPRIM', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11955, 8452, 'TRIMETHOPRIM', 'I', 8, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6880, 8452, 'TRIMETHOPRIM', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7313, 8452, 'TRIMETHOPRIM', 'I', 8, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4703, 8452, 'TRIMETHOPRIM', 'I', 16, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63636, 8452, 'TRIMETHOPRIM', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63906, 8452, 'TRIMETHOPRIM (TRIMETHOPRIM SULFATE)', 'I', 1, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77098, 8452, 'TRIMETHOPRIM', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43986, 8452, 'TRIMETHOPRIM', 'I', 66.7, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: TRIMETHOPRIM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65007, 8452, 'TRIMETHOPRIM', 'I', 67, 'MG', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80624, 8452, 'TRIMETHOPRIM', 'I', 67, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1589, 8453, 'BLEOMYCIN SULFATE', 'I', 15, 'UNIT', '', '', 'N', 'AMP', 'Historic Freeform Text: BLEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19065, 8376, 'CEPHALEXIN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19066, 8376, 'CEPHALEXIN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19042, 8376, 'CEPHALEXIN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19043, 8376, 'CEPHALEXIN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11962, 8376, 'CEPHALEXIN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11963, 8376, 'CEPHALEXIN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9170, 8376, 'CEPHALEXIN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9171, 8376, 'CEPHALEXIN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9907, 8376, 'CEPHALEXIN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9908, 8376, 'CEPHALEXIN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5181, 8376, 'CEPHALEXIN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEPHALEXIN ((AS MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5182, 8376, 'CEPHALEXIN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEPHALEXIN ((AS MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3945, 8376, 'CEPHALEXIN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3946, 8376, 'CEPHALEXIN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2809, 8376, 'CEPHALEXIN', 'I', 250, 'MG', '', '', 'Y', '', 'EQUIVALENT TO 266 MG CEPHALEXIN MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1434, 8376, 'CEPHALEXIN', 'I', 500, 'MG', '', '', 'Y', '', 'EQUIVALENT TO 500 MG OF CEPHALEXIN MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19068, 8376, 'CEPHALEXIN', 'I', 125, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19069, 8376, 'CEPHALEXIN', 'I', 250, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19070, 8376, 'CEPHALEXIN', 'I', 125, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19072, 8376, 'CEPHALEXIN', 'I', 250, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5072, 8376, 'CEPHALEXIN', 'I', 250, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5073, 8376, 'CEPHALEXIN', 'I', 125, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CEPHALEXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1212, 8376, 'CEPHALEXIN', 'I', 250, 'MG', '', '5', 'Y', 'ML', 'EQUIVALENT TO 278.66 MG/5 ML CEPHALEXIN FOR SUSPENSION ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1184, 8376, 'CEPHALEXIN', 'I', 125, 'MG', '', '5', 'Y', 'ML', 'EQUIVALENT TO 139.33 MG/5 ML CEPHALEXIN FOR SUSPENSION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83913, 8376, 'CEPHALEXIN (CEPHALEXIN MONOHYDRATE)', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83914, 8376, 'CEPHALEXIN (CEPHALEXIN MONOHYDRATE)', 'I', 250, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43411, 8349, 'CEFOTAXIME SODIUM', 'I', 1, 'G', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: CEFOTAXIME SODIUM ((CEFOTAXIME EQ.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43412, 8349, 'CEFOTAXIME SODIUM', 'I', 2, 'G', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: CEFOTAXIME SODIUM ((CEFOTAXIME EQ.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43410, 8349, 'CEFOTAXIME SODIUM', 'I', 500, 'MG', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: CEFOTAXIME SODIUM ((CEFOTAXIME EQ.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60505, 8313, 'IDOXURIDINE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18081, 8316, 'RIFABUTIN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61542, 8317, 'ATOVAQUONE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75044, 8317, 'ATOVAQUONE', 'I', 62.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43212, 8317, 'ATOVAQUONE', 'I', 750, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ATOVAQUONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17240, 8318, 'CLARITHROMYCIN', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLARITHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12779, 8318, 'CLARITHROMYCIN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68745, 8318, 'CLARITHROMYCIN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLARITHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72112, 8318, 'CLARITHROMYCIN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72114, 8318, 'CLARITHROMYCIN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71828, 8318, 'CLARITHROMYCIN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71829, 8318, 'CLARITHROMYCIN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75196, 8318, 'CLARITHROMYCIN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73227, 8318, 'CLARITHROMYCIN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73228, 8318, 'CLARITHROMYCIN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76021, 8318, 'CLARITHROMYCIN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76022, 8318, 'CLARITHROMYCIN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80993, 8318, 'CLARITHROMYCIN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80994, 8318, 'CLARITHROMYCIN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83195, 8318, 'CLARITHROMYCIN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83196, 8318, 'CLARITHROMYCIN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83618, 8318, 'CLARITHROMYCIN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84648, 8318, 'CLARITHROMYCIN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84649, 8318, 'CLARITHROMYCIN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61948, 8318, 'CLARITHROMYCIN', 'I', 500, 'MG', '', '', 'N', 'TAB', 'UNIT = TAB.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18066, 8318, 'CLARITHROMYCIN', 'I', 125, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CLARITHROMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68628, 8318, 'CLARITHROMYCIN', 'I', 250, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81558, 8325, 'AZTREONAM', 'I', 75, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6471, 8343, 'PIVMECILLINAM (PIVMECILLINAM HYDROCHLORIDE)', 'I', 185, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: PIVMECILLINAM HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61918, 6333, 'STANDARDIZED TIMOTHY GRASS POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '100,000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61919, 6333, 'STANDARDIZED TIMOTHY GRASS POLLEN', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '10,000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66453, 6333, 'STANDARDIZED TIMOTHY GRASS POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '(PHLEUM PRATENSE). 100000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81085, 6333, 'STANDARDIZED TIMOTHY GRASS POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '100000 BAU/ML (BAU STANDS FOR BIO-EQUIVALENT ALLERGY UNIT)./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81091, 6333, 'STANDARDIZED TIMOTHY GRASS POLLEN', 'I', 25000, 'UNIT', '', '', 'N', 'ML', '25000 BAU/ML (BAU STANDS FOR BIOEQUIVALENT ALLERGY UNIT)./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81092, 6333, 'STANDARDIZED TIMOTHY GRASS POLLEN', 'I', 20000, 'UNIT', '', '', 'N', 'ML', '20000 BAU/ML (BAU STANDS FOR BIOEQUIVALENT ALLERGY UNIT)./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23354, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHOCARBAMOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23355, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHOCARBAMOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22274, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHOCARBAMOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13624, 6340, 'METHOCARBAMOL', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12946, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHOCARBAMOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12942, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHOCARBAMOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12943, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHOCARBAMOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12944, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHOCARBAMOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14508, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHOCARBAMOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14509, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHOCARBAMOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13297, 6340, 'METHOCARBAMOL', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49590, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50062, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50227, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50484, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62483, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62597, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61372, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61576, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60162, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60916, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60917, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60918, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60919, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63223, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', 'POWDER.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63224, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', 'POWDER.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65859, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66799, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66818, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66910, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66913, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', 'POWDER.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66916, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', 'POWDER.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66917, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67870, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71388, 6340, 'METHOCARBAMOL', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73359, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73537, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73656, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73677, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73678, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73680, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73709, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73710, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77584, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77593, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82770, 6340, 'METHOCARBAMOL', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82772, 6340, 'METHOCARBAMOL', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82306, 6340, 'METHOCARBAMOL', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84247, 6340, 'METHOCARBAMOL', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19287, 6340, 'METHOCARBAMOL', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METHOCARBAMOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9776, 6340, 'METHOCARBAMOL', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METHOCARBAMOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8576, 6340, 'METHOCARBAMOL', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METHOCARBAMOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71195, 6340, 'METHOCARBAMOL', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METHOCARBAMOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12763, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: PRAMOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4629, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: PRAMOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64442, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66620, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15948, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PRAMOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12764, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10052, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: PRAMOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9335, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: PRAMOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4390, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: PRAMOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3492, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: PRAMOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (55837, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60289, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63619, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63620, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70300, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1.0, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75230, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73264, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73689, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77276, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37185, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1.0, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: PRAMOXINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80391, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80397, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13570, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80442, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71956, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72775, 6343, 'PRAMOXINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12801, 6358, 'OIL OF CEDAR LEAF', 'I', 0.62, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: OIL OF CEDAR LEAF');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5076, 6358, 'OIL OF CEDAR LEAF', 'I', 0.62, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: OIL OF CEDAR LEAF');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8259, 6327, 'LINDANE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LINDANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8213, 6327, 'LINDANE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: LINDANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69989, 6327, 'LINDANE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10506, 6327, 'LINDANE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: LINDANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (771, 6363, 'ETHOSUXIMIDE', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHOSUXIMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (731, 6363, 'ETHOSUXIMIDE', 'I', 250, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ETHOSUXIMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11691, 6291, 'NEOSTIGMINE BROMIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: NEOSTIGMINE BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10567, 6296, 'PYRIDOSTIGMINE BROMIDE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: PYRIDOSTIGMINE BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11135, 6296, 'PYRIDOSTIGMINE BROMIDE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4899, 6299, 'ACETAZOLAMIDE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1886, 6299, 'ACETAZOLAMIDE', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAZOLAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84336, 6299, 'ACETAZOLAMIDE (ACETAZOLAMIDE SODIUM)', 'I', 500, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6039, 6301, 'CLIDINIUM BROMIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLIDINIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80419, 774, 'CHLOROXYLENOL', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6283, 6301, 'CLIDINIUM BROMIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLIDINIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (728, 6301, 'CLIDINIUM BROMIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLIDINIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6566, 6319, 'SODIUM SELENITE', 'I', 85, 'µG', '', '', 'N', 'G', 'Historic Freeform Text: SODIUM SELENITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2119, 6319, 'SODIUM SELENITE', 'I', 2, 'MG', '', '30', 'N', 'G', 'Historic Freeform Text: SODIUM SELENITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5708, 6321, 'ZINC CHLORIDE', 'I', 1.67, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ZINC CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2003, 6270, 'MAGNESIUM HYPOPHOSPHITE', 'I', 3, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM HYPOPHOSPHITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1614, 6270, 'MAGNESIUM HYPOPHOSPHITE', 'I', 3, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM HYPOPHOSPHITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76261, 6275, 'ATTAPULGITE (ACTIVATED)', 'I', 1.29, 'G', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13284, 6278, 'DIETHYLAMINE SALICYLATE', 'I', 100, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: DIETHYLAMINE SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79617, 6278, 'DIETHYLAMINE SALICYLATE', 'I', 100, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: DIETHYLAMINE SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16997, 6216, 'HISTAMINE PHOSPHATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HISTAMINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5537, 6216, 'HISTAMINE PHOSPHATE', 'I', 2.75, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HISTAMINE PHOSPH ((BASE 1:1000EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5538, 6216, 'HISTAMINE PHOSPHATE', 'I', 0.275, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HISTAMINE PHOSPHATE ((BASE 1:10000 EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19307, 4179, 'CYCLOPENTOLATE HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', 'W/V', 'HISTORIC FREEFORM TEXT: CYCLOPENTOLATE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18742, 4179, 'CYCLOPENTOLATE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', 'W/V', 'Historic Freeform Text: CYCLOPENTOLATE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16242, 4179, 'CYCLOPENTOLATE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: CYCLOPENTOLATE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16651, 4179, 'CYCLOPENTOLATE HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: CYCLOPENTOLATE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12417, 4179, 'CYCLOPENTOLATE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: CYCLOPENTOLATE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5997, 4179, 'CYCLOPENTOLATE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: CYCLOPENTOLATE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5998, 4179, 'CYCLOPENTOLATE HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: CYCLOPENTOLATE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1530, 4179, 'CYCLOPENTOLATE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: CYCLOPENTOLATE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14941, 4182, 'CARBAMAZEPINE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBAMAZEPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9242, 4182, 'CARBAMAZEPINE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBAMAZEPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8373, 4182, 'CARBAMAZEPINE', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBAMAZEPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8374, 4182, 'CARBAMAZEPINE', 'I', 400, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBAMAZEPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6049, 4182, 'CARBAMAZEPINE', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBAMAZEPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6463, 4182, 'CARBAMAZEPINE', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBAMAZEPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6819, 4182, 'CARBAMAZEPINE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBAMAZEPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4582, 4182, 'CARBAMAZEPINE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBAMAZEPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5107, 4182, 'CARBAMAZEPINE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBAMAZEPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3920, 4182, 'CARBAMAZEPINE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBAMAZEPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (777, 4182, 'CARBAMAZEPINE', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBAMAZEPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50883, 4182, 'CARBAMAZEPINE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50885, 4182, 'CARBAMAZEPINE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50886, 4182, 'CARBAMAZEPINE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50887, 4182, 'CARBAMAZEPINE', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61270, 4182, 'CARBAMAZEPINE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61271, 4182, 'CARBAMAZEPINE', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65552, 4182, 'CARBAMAZEPINE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65553, 4182, 'CARBAMAZEPINE', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68372, 4182, 'CARBAMAZEPINE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68373, 4182, 'CARBAMAZEPINE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74720, 4182, 'CARBAMAZEPINE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBAMAZEPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74721, 4182, 'CARBAMAZEPINE', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBAMAZEPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74722, 4182, 'CARBAMAZEPINE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBAMAZEPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74723, 4182, 'CARBAMAZEPINE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBAMAZEPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61615, 4182, 'CARBAMAZEPINE', 'I', 200, 'MG', '', '', 'N', 'SRT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61616, 4182, 'CARBAMAZEPINE', 'I', 400, 'MG', '', '', 'N', 'SRT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19729, 4182, 'CARBAMAZEPINE', 'I', 100, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CARBAMAZEPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34513, 4106, 'P-TERT-PENTYLPHENOL', 'I', 7.6, '%', '', '', 'N', '', 'Historic Freeform Text: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26739, 4106, 'P-TERT-PENTYLPHENOL', 'I', 0.046, '%', '', '', 'N', '', 'Historic Freeform Text: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25672, 4106, 'P-TERT-PENTYLPHENOL', 'I', 0.03, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19768, 4106, 'P-TERT-PENTYLPHENOL', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: P-TERT-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17426, 4106, 'P-TERT-PENTYLPHENOL', 'I', 1.7, '%', '', '', 'N', '', 'Historic Freeform Text: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16133, 4106, 'P-TERT-PENTYLPHENOL', 'I', 1.75, '%', '', '', 'N', '', 'Historic Freeform Text: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13706, 4106, 'P-TERT-PENTYLPHENOL', 'I', 0.045, '%', '', '', 'N', '', 'Historic Freeform Text: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77048, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14368, 4106, 'P-TERT-PENTYLPHENOL', 'I', 1.75, '%', '', '', 'N', '', 'Historic Freeform Text: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13830, 4106, 'P-TERT-PENTYLPHENOL', 'I', 0.045, '%', '', '', 'N', '', 'Historic Freeform Text: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12288, 4106, 'P-TERT-PENTYLPHENOL', 'I', 0.03, '%', '', '', 'N', '', 'Historic Freeform Text: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12254, 4106, 'P-TERT-PENTYLPHENOL', 'I', 0.03, '%', '', '', 'N', '', 'Historic Freeform Text: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11343, 4106, 'P-TERT-PENTYLPHENOL', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6212, 4106, 'P-TERT-PENTYLPHENOL', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3797, 4106, 'P-TERT-PENTYLPHENOL', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4201, 4106, 'P-TERT-PENTYLPHENOL', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60627, 4106, 'P-TERT-PENTYLPHENOL', 'I', 0.046, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62881, 4106, 'P-TERT-PENTYLPHENOL', 'I', 4.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66340, 4106, 'P-TERT-PENTYLPHENOL', 'I', 1.81, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70166, 4106, 'P-TERT-PENTYLPHENOL', 'I', 0.045, '%', '', '', 'N', '', 'Historic Freeform Text: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70589, 4106, 'P-TERT-PENTYLPHENOL', 'I', 1.81, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76472, 4106, 'P-TERT-PENTYLPHENOL', 'I', 7.8, '%', '', '', 'N', '', 'QTY OF THE INGREDIENT P-TERT-PENTYLPHENOL CHANGED FROM 7.95% TO 7.8% AFTER REFERRING THE CR FILE AND');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74949, 4106, 'P-TERT-PENTYLPHENOL', 'I', 0.03, '%', '', '', 'N', '', 'Historic Freeform Text: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76854, 4106, 'P-TERT-PENTYLPHENOL', 'I', 0.03, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80691, 4106, 'P-TERT-PENTYLPHENOL', 'I', 0.03, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82117, 4106, 'P-TERT-PENTYLPHENOL', 'I', 0.03, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83945, 4106, 'P-TERT-PENTYLPHENOL', 'I', 0.03, '%', '', '', 'N', '', 'Historic Freeform Text: P-T-PENTYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19919, 4108, 'DECOQUINATE', 'I', 60, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: DECOQUINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79787, 4108, 'DECOQUINATE', 'I', 8, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12930, 4122, 'MAGNESIUM BOROGLUCONATE', 'I', 6.5, '%', '', '', 'N', '', 'Historic Freeform Text: MAGNESIUM BOROGLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1062, 4070, 'METHYL HEPTYL COLAMINO FORMYLMETHYL PYRIDINIUM CHL', 'I', 0.1, '%', '', '', 'N', '%', 'Historic Freeform Text: N-             METHYL HEPTYL COLAMINO FORMYLMETHYL PYRIDINIUM CHL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76471, 4046, 'ALKYL DIMETHYL BENZYL AMMONIUM SACCHARINATE', 'I', 0.1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5272, 4002, 'PYRANTEL TARTRATE', 'I', 106, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: PYRANTEL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81380, 4003, 'PYRANTEL PAMOATE', 'I', 28.8, 'MG', '', '', 'N', '', 'PYRANTEL PAMOATE 28.8MG (10MG BASE) PER TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81381, 4003, 'PYRANTEL PAMOATE', 'I', 144.0, 'MG', '', '', 'N', '', 'PYRANTEL PAMOATE 144.0MG (50MG BASE) PER TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81382, 4003, 'PYRANTEL PAMOATE', 'I', 360.0, 'MG', '', '', 'N', '', 'PYRANTEL PAMOATE 360.0MG (125MG BASE) PER TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37356, 4007, 'GLYBURIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37357, 4007, 'GLYBURIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14094, 4007, 'GLYBURIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14095, 4007, 'GLYBURIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11780, 4007, 'GLYBURIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11781, 4007, 'GLYBURIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11727, 4007, 'GLYBURIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11728, 4007, 'GLYBURIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11122, 4007, 'GLYBURIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11120, 4007, 'GLYBURIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12865, 4007, 'GLYBURIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11472, 4007, 'GLYBURIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11473, 4007, 'GLYBURIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10834, 4007, 'GLYBURIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (55852, 4007, 'GLYBURIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60020, 4007, 'GLYBURIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59930, 4007, 'GLYBURIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65770, 4007, 'GLYBURIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65771, 4007, 'GLYBURIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72325, 4007, 'GLYBURIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72324, 4007, 'GLYBURIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80203, 4007, 'GLYBURIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83566, 4007, 'GLYBURIDE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83567, 4007, 'GLYBURIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYBURIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44146, 11389, 'LEUCOVORIN (LEUCOVORIN CALCIUM)', 'I', 5, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: FOLINIC ACID ((FROM LEUCOVORIN CALCIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44265, 11389, 'LEUCOVORIN (LEUCOVORIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44266, 11389, 'LEUCOVORIN (LEUCOVORIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LEUCOVORIN ((AS LEUCOVORIN CALCIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18209, 11389, 'LEUCOVORIN (LEUCOVORIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LEUCOVORIN ((AS CALCIUM SALT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50369, 11426, 'DORAMECTIN', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59934, 11426, 'DORAMECTIN', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16228, 11357, 'BROMINE-PHENOL-BENZETHONIUM CHLORIDE COMPLEX', 'I', 0.852, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: BROMINE-PHENOL-BENZETH CL ((MIXTURE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5740, 11357, 'BROMINE-PHENOL-BENZETHONIUM CHLORIDE COMPLEX', 'I', 0.852, '%', '', '', 'N', 'W/W', 'Historic Freeform Text: BROMINE-PHENOL-BENZETH CL ((MIXTURE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83578, 11357, 'BROMINE-PHENOL-BENZETHONIUM CHLORIDE COMPLEX', 'I', 0.852, '%', '', '', 'N', 'W/W', 'Historic Freeform Text: BROMINE-PHENOL-BENZETH CL ((MIXTURE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8120, 11358, 'MEPERIDINE (MEPERIDINE HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: MEPERIDINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8121, 11358, 'MEPERIDINE (MEPERIDINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: MEPERIDINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8487, 11358, 'MEPERIDINE (MEPERIDINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: MEPERIDINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20003, 11359, 'CEFEPIME (CEFEPIME HYDROCHLORIDE)', 'I', 2, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: CEFEPIME ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20004, 11359, 'CEFEPIME (CEFEPIME HYDROCHLORIDE)', 'I', 1, 'G', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: CEFEPIME ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80452, 11359, 'CEFEPIME (CEFEPIME HYDROCHLORIDE)', 'I', 2, 'G', '', '', 'N', 'VIAL', 'L-ARGININE 1450 MG/VIAL IS AN NMI ADDED TO CONTROL THE PH OF THE RECONSTITUTED SOLUTION AS PER PM./K');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10521, 11364, 'HEPARIN (HEPARIN SODIUM)', 'I', 2, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: HEPARIN SOD ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49955, 11365, 'IMIGLUCERASE', 'I', 200, 'UNIT', '', '20', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65414, 11365, 'IMIGLUCERASE', 'I', 400, 'UNIT', '', '20', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77377, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77378, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49973, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49974, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49975, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66964, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75873, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75874, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75875, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75876, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75877, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75878, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75879, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75880, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78058, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM PROPYLENE GLYCOL SOLVATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78059, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM PROPYLENE GLYCOL SOLVATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78060, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM PROPYLENE GLYCOL SOLVATE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78061, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM PROPYLENE GLYCOL SOLVATE)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77379, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77380, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79895, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79897, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79898, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79899, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79921, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79922, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79923, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79925, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79651, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79652, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79653, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 40, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79654, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 80, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78797, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78798, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78799, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78801, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81036, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81037, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81038, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81039, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83185, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM PROPYLENE GLYCOL SOLVATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83192, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM PROPYLENE GLYCOL SOLVATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83193, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM PROPYLENE GLYCOL SOLVATE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83194, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM PROPYLENE GLYCOL SOLVATE)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83397, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83398, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83399, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83400, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83405, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83406, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83407, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83408, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83551, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83553, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83554, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83555, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84083, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84084, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84085, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84776, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84775, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84777, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84778, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84779, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84780, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84781, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84782, 11366, 'ATORVASTATIN (ATORVASTATIN CALCIUM)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50069, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50070, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50071, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50072, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (55839, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (55840, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (55841, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (55842, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52538, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'Y', '', 'AS TERAZOSIN HYDROCHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52543, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'Y', '', 'AS TERAZOSIN HYDROCHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52544, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'Y', '', 'AS TERAZOSIN HYDROCHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52545, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', 'AS TERAZOSIN HYDROCHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60810, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'Y', '', 'AS TERAZOSIN HYDROCHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60811, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'Y', '', 'AS TERAZOSIN HYDROCHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60812, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'Y', '', 'AS TERAZOSIN HYDROCHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60813, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', 'AS TERAZOSIN HYDROCHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67437, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67438, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67439, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67440, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67679, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67680, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67681, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67682, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70727, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70728, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70729, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70730, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83568, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83569, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83570, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83571, 11368, 'TERAZOSIN (TERAZOSIN HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19918, 11371, 'SAQUINAVIR (SAQUINAVIR MESYLATE)', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SAQUINAVIR ((AS SAQUINAVIR MESYLATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76489, 11371, 'SAQUINAVIR (SAQUINAVIR MESYLATE)', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SAQUINAVIR ((AS SAQUINAVIR MESYLATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18228, 11372, 'APRACLONIDINE (APRACLONIDINE HYDROCHLORIDE)', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: APRACLONIDINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12993, 11372, 'APRACLONIDINE (APRACLONIDINE HYDROCHLORIDE)', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: APRACLONIDINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50053, 11373, 'TAZAROTENE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50054, 11373, 'TAZAROTENE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67835, 11373, 'TAZAROTENE', 'I', 0.05, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67836, 11373, 'TAZAROTENE', 'I', 0.1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50160, 11381, 'FORMOTEROL FUMARATE', 'I', 12, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19688, 11382, 'GRANISETRON (GRANISETRON HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: GRANISETRON ((AS GRANISET.HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79450, 11382, 'GRANISETRON (GRANISETRON HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: GRANISETRON ((AS GRANISET.HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19689, 11382, 'GRANISETRON (GRANISETRON HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: GRANISETRON ((AS HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78998, 11382, 'GRANISETRON (GRANISETRON HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80824, 11382, 'GRANISETRON (GRANISETRON HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4309, 11355, 'PHENELZINE (PHENELZINE SULFATE)', 'I', 15, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PHENELZINE SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13721, 11386, 'MEFLOQUINE (MEFLOQUINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MEFLOQUINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77198, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68334, 11386, 'MEFLOQUINE (MEFLOQUINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: MEFLOQUINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60600, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 37.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60601, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60603, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76413, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 37.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76414, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76415, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75942, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 37.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75943, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75944, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76054, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 37.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76055, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76056, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78960, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 37.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78961, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 75.0, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78962, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 150.0, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82485, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 37.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82486, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82487, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79596, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 37.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79597, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 75.0, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79598, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 150.0, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79345, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 37.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79346, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79347, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79592, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 37.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79593, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79594, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83988, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 37.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83989, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83990, 11336, 'VENLAFAXINE (VENLAFAXINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6404, 11338, 'ACETATE (SODIUM ACETATE)', 'I', 50, 'MEQ', '', '', 'N', 'L', 'Historic Freeform Text: SOD ACETATE ((ACETATE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43575, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: PAROXETINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14006, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PAROXETINE HYDRO ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14007, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PAROXETINE HYDRO ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64498, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64499, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64500, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72104, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PAROXETINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72105, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PAROXETINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72106, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PAROXETINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72042, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', 'ACETONE SOLVATE REMOVED FROM INGREDIENT NAME IN SUPPLIED AS FIELD AS REQUESTED BY BCANS (SEE BASSAM ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72043, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', '', 'ACETONE SOLVATE REMOVED FROM INGREDIENT NAME IN SUPPLIED AS FIELD AS REQUESTED BY BCANS (SEE BASSAM ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72044, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'N', '', 'ACETONE SOLVATE REMOVED FROM INGREDIENT NAME IN SUPPLIED AS FIELD AS REQUESTED BY BCANS (SEE BASSAM ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72911, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE ACETONE SOLVATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77058, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72912, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE ACETONE SOLVATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72913, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE ACETONE SOLVATE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72914, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE ACETONE SOLVATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72915, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE, ISOPROPYL SOLVATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72916, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE, ISOPROPYL SOLVATE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72798, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE ACETONE SOLVATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72799, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE ACETONE SOLVATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72800, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE ACETONE SOLVATE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72801, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE ACETONE SOLVATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72802, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE ACETONE SOLVATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72803, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE ACETONE SOLVATE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72855, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 12.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72856, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73992, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE, ISOPROPYL SOLVATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73993, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE, ISOPROPYL SOLVATE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75480, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75481, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75482, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72328, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE, ISOPROPYL SOLVATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72329, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE, ISOPROPYL SOLVATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72330, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE, ISOPROPYL SOLVATE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73287, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73288, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73289, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74810, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', 'SUPPLIED AS PAROXETINE HYDROCHLORIDE ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74811, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', '', 'SUPPLIED AS PAROXETINE HYDROCHLORIDE ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74812, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'N', '', 'SUPPLIED AS PAROXETINE HYDROCHLORIDE ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76846, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE, ISOPROPYL SOLVATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76847, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE, ISOPROPYL SOLVATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76848, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE, ISOPROPYL SOLVATE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77913, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77199, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78734, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE ACETONE SOLVATE)', 'I', 10, 'MG', '', '', 'N', '', 'ACETONE SOLVATE REMOVED FROM INGREDIENT NAME IN SUPPLIED AS FIELD AS REQUESTED BY BCANS (SEE BASSAM ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78735, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE ACETONE SOLVATE)', 'I', 20, 'MG', '', '', 'N', '', 'ACETONE SOLVATE REMOVED FROM INGREDIENT NAME IN SUPPLIED AS FIELD AS REQUESTED BY BCANS (SEE BASSAM ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78736, 11340, 'PAROXETINE (PAROXETINE HYDROCHLORIDE ACETONE SOLVATE)', 'I', 30, 'MG', '', '', 'N', '', 'ACETONE SOLVATE REMOVED FROM INGREDIENT NAME IN SUPPLIED AS FIELD AS REQUESTED BY BCANS (SEE BASSAM ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19742, 11341, 'DESLORELIN (DESLORELIN ACETATE)', 'I', 2.1, 'MG', '', '', 'Y', 'IMP', 'HISTORIC FREEFORM TEXT: DESLORELIN ((AS ACETATE)) QTY UNIT: IMP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68601, 11343, 'MITOXANTRONE (MITOXANTRONE HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75294, 11343, 'MITOXANTRONE (MITOXANTRONE HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77176, 11343, 'MITOXANTRONE (MITOXANTRONE HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12938, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: AMLODIPINE BESYLATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12939, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: AMLODIPINE BESYLATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76581, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'Y', '', 'Historic Freeform Text: AMLODIPINE BESYLATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76582, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: AMLODIPINE BESYLATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74489, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74490, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75765, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5.0, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75766, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10.0, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75873, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75874, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75875, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75876, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75877, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75878, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75879, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75880, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73529, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73530, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76997, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5.0, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76998, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10.0, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78282, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 2.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78283, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78284, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78046, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76963, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76964, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81210, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81211, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81212, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81213, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81214, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81215, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81216, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81217, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81218, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82829, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82830, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82664, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82666, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80727, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80726, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81620, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81699, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81700, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82866, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82867, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82868, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81681, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81682, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81717, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 2.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81718, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81719, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84231, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 2.5, 'MG', '', '', 'N', '', '  ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84232, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '  ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84233, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '  ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84280, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 2.5, 'MG', '', '', 'N', '', '  ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84281, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84282, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84766, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84767, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84775, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84776, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84777, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84778, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84779, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84780, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84781, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84782, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85622, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85623, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85624, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85625, 11344, 'AMLODIPINE (AMLODIPINE BESYLATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18739, 11347, 'FLUPENTIXOL (FLUPENTIXOL DIHYDROCHLORIDE)', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUPENTHIXOL ((AS DIHYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18740, 11347, 'FLUPENTIXOL (FLUPENTIXOL DIHYDROCHLORIDE)', 'I', 3, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUPENTHIXOL ((AS DIHYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16101, 11350, 'VINORELBINE (VINORELBINE TARTRATE)', 'I', 10, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: VINORELBINE ((AS VINORELBINE TARTRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75143, 11350, 'VINORELBINE (VINORELBINE TARTRATE)', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74301, 11350, 'VINORELBINE (VINORELBINE TARTRATE)', 'I', 10, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: VINORELBINE ((AS VINORELBINE TARTRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75669, 11350, 'VINORELBINE (VINORELBINE TARTRATE)', 'I', 10, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (938, 11354, 'PROCARBAZINE (PROCARBAZINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: PROCARBAZINE HCL ((PROCARBAZINE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43518, 11269, 'INDINAVIR (INDINAVIR SULFATE)', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDINAVIR ((AS INDINAVIR SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43520, 11269, 'INDINAVIR (INDINAVIR SULFATE)', 'I', 400, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: INDINAVIR ((AS INDINAVIR SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62666, 11271, 'MUMPS VIRUS VACCINE LIVE ATTENUATED JERYL LYNN STRAIN', 'I', 10000, 'UNIT', '', '0.5', 'N', 'ML', 'MUMPS VIRUS VACCINE LIVE ATTENUATED:  RIT4385 STRAIN   >= 10 TO THE POWER OF 3.7CCID SUBSCRIPT 50 PE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3569, 11271, 'MUMPS VIRUS VACCINE LIVE ATTENUATED JERYL LYNN STRAIN', 'I', 5000, 'UNIT', '', '0.5', 'N', 'ML', 'UNIT=CCID50');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78322, 11271, 'MUMPS VIRUS VACCINE LIVE ATTENUATED JERYL LYNN STRAIN', 'I', 25118.9, 'UNIT', '', '0.5', 'N', 'ML', 'MUMPS VIRUS VACCINE LIVE ATTENUATED:  RIT4385 STRAIN   >= 10 TO THE POWER OF 4.4 CCID SUBSCRIPT 50 P');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36988, 11282, 'SALMETEROL (SALMETEROL XINAFOATE)', 'I', 50, 'µG', '', '', 'N', 'DOSE', 'HISTORIC FREEFORM TEXT: SALMETEROL ((AS XINAFOATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50436, 11282, 'SALMETEROL (SALMETEROL XINAFOATE)', 'I', 50, 'µG', '', '', 'Y', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64426, 11282, 'SALMETEROL (SALMETEROL XINAFOATE)', 'I', 50, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64427, 11282, 'SALMETEROL (SALMETEROL XINAFOATE)', 'I', 50, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64428, 11282, 'SALMETEROL (SALMETEROL XINAFOATE)', 'I', 50, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69136, 11282, 'SALMETEROL (SALMETEROL XINAFOATE)', 'I', 25, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69137, 11282, 'SALMETEROL (SALMETEROL XINAFOATE)', 'I', 25, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8074, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 1, 'G', '', '', 'Y', 'VIAL', 'Historic Freeform Text: CEFTRIAXONE DISODIUM ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73509, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 1, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73510, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 2, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77304, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 1, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77306, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 10, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77762, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 0.25, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77763, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 1.0, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77764, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 2.0, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77765, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 10.0, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77822, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 1.0, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77823, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 2.0, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77825, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 10.0, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77817, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 10, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81098, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 1, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81099, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 2, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81100, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 10, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8037, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 250, 'MG', '', '', 'Y', 'VIAL', 'Historic Freeform Text: CEFTRIAXONE DISODIUM ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73507, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 250, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77821, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 250, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81096, 11309, 'CEFTRIAXONE (CEFTRIAXONE SODIUM)', 'I', 250, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49266, 11311, 'REMIFENTANIL (REMIFENTANIL HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49270, 11311, 'REMIFENTANIL (REMIFENTANIL HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49272, 11311, 'REMIFENTANIL (REMIFENTANIL HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19030, 11313, 'GONADORELIN (GONADORELIN ACETATE)', 'I', 100, 'µG', '', '', 'Y', 'VIAL', 'Historic Freeform Text: GONADORELIN ((AS ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16878, 11313, 'GONADORELIN (GONADORELIN ACETATE)', 'I', 500, 'µG', '', '', 'Y', 'VIAL', 'Historic Freeform Text: GONADORELIN ((AS ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77611, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16433, 11313, 'GONADORELIN (GONADORELIN DECAPEPTIDE (GNRH))', 'I', 100, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: GONADORELIN ((AS THE DECAPEPTIDE-GNRH))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5110, 11313, 'GONADORELIN (GONADORELIN HYDROCHLORIDE)', 'I', 50, 'µG', '', '', 'Y', 'ML', 'Historic Freeform Text: GONADORELIN HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80160, 11313, 'GONADORELIN (GONADORELIN ACETATE)', 'I', 43, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2987, 11315, 'OXANTEL (OXANTEL PAMOATE)', 'I', 140, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: OXANTEL PAMOATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4459, 11318, 'BENSERAZIDE (BENSERAZIDE HYDROCHLORIDE)', 'I', 12.5, 'MG', '', '', 'Y', '', 'Historic Freeform Text: BENSERAZIDE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2723, 11318, 'BENSERAZIDE (BENSERAZIDE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: BENSERAZIDE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2724, 11318, 'BENSERAZIDE (BENSERAZIDE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', 'Historic Freeform Text: BENSERAZIDE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84256, 11321, 'CILASTATIN (CILASTATIN SODIUM)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8348, 11321, 'CILASTATIN (CILASTATIN SODIUM)', 'I', 250, 'MG', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: CILASTATIN SODIUM ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8054, 11321, 'CILASTATIN (CILASTATIN SODIUM)', 'I', 500, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: CILASTATIN SODIUM ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83695, 11321, 'CILASTATIN (CILASTATIN SODIUM)', 'I', 250, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83696, 11321, 'CILASTATIN (CILASTATIN SODIUM)', 'I', 500, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84339, 11321, 'CILASTATIN (CILASTATIN SODIUM)', 'I', 250, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84340, 11321, 'CILASTATIN (CILASTATIN SODIUM)', 'I', 500, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43076, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SUMATRIPTAN ((AS SUCCINATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43077, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SUMATRIPTAN ((AS SUCCINATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62836, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74163, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74164, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74165, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75377, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75378, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75430, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75431, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75432, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74311, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74312, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74313, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75608, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75609, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75610, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75611, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75612, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75613, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75655, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75656, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74843, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74844, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77197, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77533, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77227, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77228, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77229, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81009, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81010, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49288, 11323, 'SUMATRIPTAN (SUMATRIPTAN HEMISULFATE)', 'I', 5, 'MG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49290, 11323, 'SUMATRIPTAN (SUMATRIPTAN HEMISULFATE)', 'I', 20, 'MG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43078, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 12, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: SUMATRIPTAN ((AS SUCCINATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84675, 11323, 'SUMATRIPTAN (SUMATRIPTAN SUCCINATE)', 'I', 6, 'MG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48929, 11229, 'FLUNARIZINE (FLUNARIZINE HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70217, 11229, 'FLUNARIZINE (FLUNARIZINE HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11822, 11238, 'BUTORPHANOL (BUTORPHANOL TARTRATE)', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BUTORPHANOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11817, 11238, 'BUTORPHANOL (BUTORPHANOL TARTRATE)', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BUTORPHANOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10672, 11238, 'BUTORPHANOL (BUTORPHANOL TARTRATE)', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BUTORPHANOL TARTRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (405, 8282, 'PHENOBARBITAL', 'I', 15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PHENOBARBITONE (TAL)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (406, 8282, 'PHENOBARBITAL', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PHENOBARBITONE (TAL)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (407, 8282, 'PHENOBARBITAL', 'I', 60, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PHENOBARBITONE (TAL)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (408, 8282, 'PHENOBARBITAL', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: PHENOBARBITONE (TAL)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48361, 8282, 'PHENOBARBITAL', 'I', 40, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PHENOBARBITONE (TAL)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6095, 8282, 'PHENOBARBITAL', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PHENOBARBITONE (TAL)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73177, 8295, 'DEXTROAMPHETAMINE SACCHARATE', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73178, 8295, 'DEXTROAMPHETAMINE SACCHARATE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73179, 8295, 'DEXTROAMPHETAMINE SACCHARATE', 'I', 3.75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73180, 8295, 'DEXTROAMPHETAMINE SACCHARATE', 'I', 5.00, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73181, 8295, 'DEXTROAMPHETAMINE SACCHARATE', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73182, 8295, 'DEXTROAMPHETAMINE SACCHARATE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15225, 8298, 'DEXTROAMPHETAMINE SULFATE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROAMPHETAMINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15210, 8298, 'DEXTROAMPHETAMINE SULFATE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROAMPHETAMINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15211, 8298, 'DEXTROAMPHETAMINE SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROAMPHETAMINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73177, 8298, 'DEXTROAMPHETAMINE SULFATE', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73178, 8298, 'DEXTROAMPHETAMINE SULFATE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73179, 8298, 'DEXTROAMPHETAMINE SULFATE', 'I', 3.75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73180, 8298, 'DEXTROAMPHETAMINE SULFATE', 'I', 5.00, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73181, 8298, 'DEXTROAMPHETAMINE SULFATE', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73182, 8298, 'DEXTROAMPHETAMINE SULFATE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73177, 8300, 'AMPHETAMINE ASPARTATE MONOHYDRATE', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73178, 8300, 'AMPHETAMINE ASPARTATE MONOHYDRATE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73179, 8300, 'AMPHETAMINE ASPARTATE MONOHYDRATE', 'I', 3.75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73180, 8300, 'AMPHETAMINE ASPARTATE MONOHYDRATE', 'I', 5.00, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73181, 8300, 'AMPHETAMINE ASPARTATE MONOHYDRATE', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73182, 8300, 'AMPHETAMINE ASPARTATE MONOHYDRATE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2750, 8265, 'PRIMIDONE', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: PRIMIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2751, 8265, 'PRIMIDONE', 'I', 125, 'MG', '', '', 'N', '', 'Historic Freeform Text: PRIMIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1343, 8207, 'SULFANILAMIDE', 'I', 1.92, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFANILAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1616, 8207, 'SULFANILAMIDE', 'I', 5.85, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFANILAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2046, 8207, 'SULFANILAMIDE', 'I', 1.92, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFANILAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2006, 8207, 'SULFANILAMIDE', 'I', 5.85, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFANILAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5698, 8207, 'SULFANILAMIDE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFANILAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2181, 8207, 'SULFANILAMIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: SULFANILAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (233, 8207, 'SULFANILAMIDE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: SULFANILAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3830, 8207, 'SULFANILAMIDE', 'I', 38.8, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SULFANILAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3773, 8207, 'SULFANILAMIDE', 'I', 38.8, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SULFANILAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14476, 8209, 'PROPOFOL', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: PROPOFOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17419, 8209, 'PROPOFOL', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PROPOFOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60178, 8209, 'PROPOFOL', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66813, 8209, 'PROPOFOL', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65144, 8209, 'PROPOFOL', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68347, 8209, 'PROPOFOL', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68673, 8209, 'PROPOFOL', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5380, 8228, 'PENTOBARBITAL SODIUM', 'I', 340, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PENTOBARBITAL SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1387, 8228, 'PENTOBARBITAL SODIUM', 'I', 540, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PENTOBARBITAL SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (274, 8228, 'PENTOBARBITAL SODIUM', 'I', 240, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PENTOBARBITAL SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (232, 8228, 'PENTOBARBITAL SODIUM', 'I', 65, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PENTOBARBITAL SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76727, 8228, 'PENTOBARBITAL SODIUM', 'I', 200, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81932, 8228, 'PENTOBARBITAL SODIUM', 'I', 240, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23671, 8231, 'BUTALBITAL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUTALBITAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23672, 8231, 'BUTALBITAL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUTALBITAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23669, 8231, 'BUTALBITAL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUTALBITAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6480, 8231, 'BUTALBITAL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUTALBITAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6479, 8231, 'BUTALBITAL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUTALBITAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6419, 8231, 'BUTALBITAL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUTALBITAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5779, 8231, 'BUTALBITAL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUTALBITAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1233, 8231, 'BUTALBITAL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUTALBITAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (873, 8231, 'BUTALBITAL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUTALBITAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (872, 8231, 'BUTALBITAL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUTALBITAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47953, 8231, 'BUTALBITAL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUTALBITAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47954, 8231, 'BUTALBITAL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUTALBITAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47955, 8231, 'BUTALBITAL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUTALBITAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47956, 8231, 'BUTALBITAL', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BUTALBITAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66118, 8231, 'BUTALBITAL', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11857, 8174, 'SULFAMETHOXAZOLE', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11858, 8174, 'SULFAMETHOXAZOLE', 'I', 800, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11953, 8174, 'SULFAMETHOXAZOLE', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11954, 8174, 'SULFAMETHOXAZOLE', 'I', 800, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77540, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6037, 8174, 'SULFAMETHOXAZOLE', 'I', 800, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3677, 8174, 'SULFAMETHOXAZOLE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3678, 8174, 'SULFAMETHOXAZOLE', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3679, 8174, 'SULFAMETHOXAZOLE', 'I', 800, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4610, 8174, 'SULFAMETHOXAZOLE', 'I', 800, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4611, 8174, 'SULFAMETHOXAZOLE', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2888, 8174, 'SULFAMETHOXAZOLE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11859, 8174, 'SULFAMETHOXAZOLE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFAMETHOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10535, 8174, 'SULFAMETHOXAZOLE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFAMETHOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11955, 8174, 'SULFAMETHOXAZOLE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFAMETHOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7313, 8174, 'SULFAMETHOXAZOLE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFAMETHOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4703, 8174, 'SULFAMETHOXAZOLE', 'I', 80, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFAMETHOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4989, 8178, 'SULFISOXAZOLE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFISOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2591, 8178, 'SULFISOXAZOLE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFISOXAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5294, 8178, 'SULFISOXAZOLE (SULFISOXAZOLE ACETYL)', 'I', 600, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ACETYL SULFISOXAZOLE ACTIVE INGREDIENT CORRECTED TO SULFISOXAZOLE SUPPLIED A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1993, 8181, 'SUCCINYLSULFATHIAZOLE', 'I', 96, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SUCCINYLSULFATHIAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1766, 8181, 'SUCCINYLSULFATHIAZOLE', 'I', 96, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SUCCINYLSULFATHIAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43400, 8187, 'SULFAMETHAZINE', 'I', 32.1, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15809, 8187, 'SULFAMETHAZINE', 'I', 2, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15808, 8187, 'SULFAMETHAZINE', 'I', 2, 'G', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11850, 8187, 'SULFAMETHAZINE', 'I', 8, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6202, 8187, 'SULFAMETHAZINE', 'I', 2, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2004, 8187, 'SULFAMETHAZINE', 'I', 15, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1142, 8187, 'SULFAMETHAZINE', 'I', 2.5, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1616, 8187, 'SULFAMETHAZINE', 'I', 3.9, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1515, 8187, 'SULFAMETHAZINE', 'I', 15.0475, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2006, 8187, 'SULFAMETHAZINE', 'I', 3.9, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5698, 8187, 'SULFAMETHAZINE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66863, 8187, 'SULFAMETHAZINE', 'I', 2000, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7337, 8187, 'SULFAMETHAZINE', 'I', 11, '%', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12797, 8187, 'SULFAMETHAZINE', 'I', 8.8, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3404, 8187, 'SULFAMETHAZINE', 'I', 8.8, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2262, 8187, 'SULFAMETHAZINE', 'I', 45, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63847, 8187, 'SULFAMETHAZINE', 'I', 45, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20106, 8187, 'SULFAMETHAZINE', 'I', 110, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20089, 8187, 'SULFAMETHAZINE', 'I', 44, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8267, 8187, 'SULFAMETHAZINE', 'I', 4.4, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6496, 8187, 'SULFAMETHAZINE', 'I', 44, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6497, 8187, 'SULFAMETHAZINE', 'I', 77, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66444, 8187, 'SULFAMETHAZINE', 'I', 44, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66503, 8187, 'SULFAMETHAZINE', 'I', 110, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66644, 8187, 'SULFAMETHAZINE', 'I', 77, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82282, 8187, 'SULFAMETHAZINE', 'I', 4.4, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: SULFAMETHAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 8191, 'SULFAMERAZINE SODIUM', 'I', 65.2, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: SULFAMERAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14165, 8191, 'SULFAMERAZINE SODIUM', 'I', 67.4, 'G', '', '450', 'N', 'G', 'Historic Freeform Text: SULFAMERAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8101, 8191, 'SULFAMERAZINE SODIUM', 'I', 60, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: SULFAMERAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3926, 8191, 'SULFAMERAZINE SODIUM', 'I', 67.4, 'G', '', '450', 'N', 'G', 'Historic Freeform Text: SULFAMERAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7049, 6243, 'NEATSFOOT OIL', 'I', 22, '%', '', '', 'N', '', 'Historic Freeform Text: NEATSFOOT OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5577, 6243, 'NEATSFOOT OIL', 'I', 22.95, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: NEATSFOOT OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5167, 6243, 'NEATSFOOT OIL', 'I', 150.4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NEATSFOOT OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30780, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30781, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10398, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLPHENIDATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10399, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLPHENIDATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6067, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLPHENIDATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (800, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLPHENIDATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (801, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLPHENIDATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49089, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49090, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (55866, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71609, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71223, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72012, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 18, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLPHENIDATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72013, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 36, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLPHENIDATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72014, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 54, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METHYLPHENIDATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75209, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76279, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76280, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76281, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76282, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76283, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76284, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76285, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76286, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75941, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73416, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLPHENIDATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73417, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLPHENIDATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73505, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 27, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METHYLPHENIDATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80510, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80575, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLPHENIDATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81157, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81158, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METHYLPHENIDATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81159, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METHYLPHENIDATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80062, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 18, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80063, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 27, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80064, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 36, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80065, 6186, 'METHYLPHENIDATE HYDROCHLORIDE', 'I', 54, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37090, 6189, 'BENOXINATE HYDROCHLORIDE', 'I', 0.4, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENOXINATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61132, 6189, 'BENOXINATE HYDROCHLORIDE', 'I', 0.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8274, 6212, 'SODIUM TETRADECYL SULFATE', 'I', 30, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM TETRADECYL SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8275, 6212, 'SODIUM TETRADECYL SULFATE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM TETRADECYL SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18417, 6214, 'INDIGO CARMINE', 'I', 0.8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: INDIGO CARMINE 2010.04.14. PREFERRED NAME (INN) CHANGED TO INDIGO CARMINE FR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20173, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20174, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20175, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20176, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17235, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15514, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13316, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10433, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXYCODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5778, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYCODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5777, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYCODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3550, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYCODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3551, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXYCODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3996, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYCODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51386, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63645, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63646, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74336, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74839, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYCODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81249, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79356, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82520, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82521, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82522, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81005, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80544, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80542, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80543, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81130, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81131, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81132, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80870, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80868, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80869, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84644, 6165, 'OXYCODONE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66193, 6167, 'OXYCODONE (OXYCODONE HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69866, 6167, 'OXYCODONE (OXYCODONE HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6751, 4015, 'FLURAZEPAM HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLURAZEPAM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4239, 4015, 'FLURAZEPAM HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLURAZEPAM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4240, 4015, 'FLURAZEPAM HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLURAZEPAM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4728, 4015, 'FLURAZEPAM HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLURAZEPAM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4729, 4015, 'FLURAZEPAM HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLURAZEPAM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4697, 4015, 'FLURAZEPAM HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLURAZEPAM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5108, 4015, 'FLURAZEPAM HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLURAZEPAM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5109, 4015, 'FLURAZEPAM HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLURAZEPAM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4545, 4015, 'FLURAZEPAM HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLURAZEPAM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4546, 4015, 'FLURAZEPAM HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLURAZEPAM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1466, 4015, 'FLURAZEPAM HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLURAZEPAM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72453, 4015, 'FLURAZEPAM HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLURAZEPAM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72454, 4015, 'FLURAZEPAM HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLURAZEPAM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17752, 4028, 'SODIUM POLYSTYRENE SULFONATE', 'I', 100, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM POLYSTYRENE SULFONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8468, 4028, 'SODIUM POLYSTYRENE SULFONATE', 'I', 100, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM POLYSTYRENE SULFONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9611, 4028, 'SODIUM POLYSTYRENE SULFONATE', 'I', 250, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM POLYSTYRENE SULFONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9612, 4028, 'SODIUM POLYSTYRENE SULFONATE', 'I', 250, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM POLYSTYRENE SULFONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8918, 4028, 'SODIUM POLYSTYRENE SULFONATE', 'I', 94.3, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: SODIUM PS SULFONATE ((SOD 4.1 AND POTAS 3.1MEQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74705, 4028, 'SODIUM POLYSTYRENE SULFONATE', 'I', 94.3, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: SODIUM PS SULFONATE ((SOD 4.1 AND POTAS 3.1MEQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19633, 3962, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX', 'I', 9, '%', '', '', 'N', '', 'Historic Freeform Text: NONYLPHENOXYPOLYETHOX(12MOL EO)ET-I ((20%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19634, 3962, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX', 'I', 5, '%', '', '', 'N', '', 'PROVIDING 1% TITRATABLE IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16108, 3962, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX', 'I', 8.74, '%', '', '', 'N', '', 'Historic Freeform Text: NONOXYNOL IODOPHOR ((IODINE 1.6%EQ.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3890, 3962, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX', 'I', 10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NONOXYNOL IODOPHOR ((IODINE 1% EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51033, 3962, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX', 'I', 5, '%', '', '', 'N', '', 'NONYL PHENOXY POLYETHOXY (12 MOLES E.O.) ETHANOL-IODINE COMPLEX, 20% (TITRATABLE IODINE 1% OR 10,000');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71847, 3962, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX', 'I', 10, '%', '', '', 'N', '', 'W/W  EQUIV TO 1% TITRATABLE IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71848, 3962, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX', 'I', 10, '%', '', '', 'N', '', 'W/W  EQUIV TO 1% TITRATABLE IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75216, 3962, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX', 'I', 7.5, '%', '', '', 'N', '', 'W/W EQUIV. TO 0.75% TITRATABLE IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78464, 3962, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX', 'I', 10, '%', '', '', 'N', '', 'W/W  EQUIV TO 1% TITRATABLE IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50391, 11171, 'VITAMIN B2', 'I', 0.7, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78465, 3962, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX', 'I', 10, '%', '', '', 'N', '', 'W/W  EQUIV TO 1% TITRATABLE IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76818, 3962, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX', 'I', 5.0, '%', '', '', 'N', '', 'W/W 1% IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37925, 3963, 'POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL - IODINE COMPLEX', 'I', 11.06, '%', '', '', 'N', '', 'Historic Freeform Text: POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL IODINE C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34205, 3963, 'POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL - IODINE COMPLEX', 'I', 25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL IODINE C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26011, 3963, 'POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL - IODINE COMPLEX', 'I', 4.85, '%', '', '', 'N', '', 'Historic Freeform Text: POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL IODINE C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16108, 3963, 'POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL - IODINE COMPLEX', 'I', 9.1, '%', '', '', 'N', '', 'Historic Freeform Text: POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL IODINE C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9555, 3963, 'POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL - IODINE COMPLEX', 'I', 4.25, '%', '', '', 'N', '', 'Historic Freeform Text: POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL IODINE C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75118, 3963, 'POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL - IODINE COMPLEX', 'I', 25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24726, 3963, 'POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL - IODINE COMPLEX', 'I', 4.82, '%', '', '', 'N', '%', 'Historic Freeform Text: POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL IODINE C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9453, 3963, 'POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL - IODINE COMPLEX', 'I', 16.6, '%', '', '', 'N', '%', 'Historic Freeform Text: POLYETHYLOXY ETHANOL COMP ((IODINE 1.8% EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5428, 3963, 'POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL - IODINE COMPLEX', 'I', 5.69, '%', '', '', 'N', '%', 'Historic Freeform Text: POLYETHOXY POLYPROPOXY POLYETHOXY ETHANOL IODINE C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49958, 3965, 'IODOPHOR', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76196, 3965, 'IODOPHOR', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5480, 3975, 'BRONOPOL', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: BRONOPOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12215, 3977, 'HYDROXYETHYLCELLULOSE', 'I', 0.35, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROXYETHYLCELLULOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16652, 3977, 'HYDROXYETHYLCELLULOSE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: HYDROXYETHYLCELLULOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (188, 3980, 'ALUMINUM HYDROXIDE-MAGNESIUM CARBONATE-CO DRIED GEL', 'I', 300, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALUMINUM HYDROXIDE MAGNESIUM CARBONATE-CO DRIED GE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9572, 3980, 'ALUMINUM HYDROXIDE-MAGNESIUM CARBONATE-CO DRIED GEL', 'I', 400, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ALUMINUM HYDROXIDE MAGNESIUM CARBONATE-CO DRIED GE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1103, 3989, 'DICHLOROBENZENE', 'I', 0.22, 'G', '', '11', 'N', 'ML', 'HISTORIC FREEFORM TEXT: P-             DICHLOROBENZENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6399, 3991, 'UREA HYDROGEN PEROXIDE', 'I', 6.5, '%', '', '', 'N', '%', 'Historic Freeform Text: UREA HYDROGEN PEROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4212, 3854, 'NON POLLEN', 'I', 0, 'NIL', '', '', 'N', 'NIL', 'HISTORIC FREEFORM TEXT: NON POLLEN  CONTACTED THE COMPANY SEVERAL TIMES TO UPDATE THE CONCENTRATION ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37486, 3854, 'NON POLLEN', 'I', 500, 'UNIT', '', '', 'N', 'ML', 'POTENCY EXPRESSED IN PNU/ML UP TO AND INCLUDING 500 PNU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1913, 3854, 'NON POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', 'POTENCY EXPRESSED IN PNU/ML UP TO AND INCLUDING 1000000 PNU/ML  DIN 00299979: THE MEDICINAL INGREDIE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65669, 10271, 'MEPIVACAINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MEPIVACAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65670, 10271, 'MEPIVACAINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: MEPIVACAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12867, 10271, 'MEPIVACAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEPIVACAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10038, 10271, 'MEPIVACAINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MEPIVACAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3804, 10271, 'MEPIVACAINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEPIVACAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3805, 10271, 'MEPIVACAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEPIVACAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2743, 10271, 'MEPIVACAINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MEPIVACAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2744, 10271, 'MEPIVACAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MEPIVACAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65671, 10271, 'MEPIVACAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEPIVACAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76704, 10271, 'MEPIVACAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MEPIVACAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75732, 10271, 'MEPIVACAINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MEPIVACAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79940, 10271, 'MEPIVACAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'MEPIVACAINE HYDROCHLORIDE 20 MG/ML = MEPIVACAINE HYDROCHLORIDE 2% ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81649, 10271, 'MEPIVACAINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEPIVACAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69524, 10282, 'PHOSPHOLIPID', 'I', 27, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81942, 10230, 'THYMOL', 'I', 0.18, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66200, 10230, 'THYMOL (THYME OIL)', 'I', 0.23, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74263, 10230, 'THYMOL', 'I', 0.36, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78664, 10230, 'THYMOL (THYME OIL)', 'I', 0.092, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78914, 10230, 'THYMOL (THYME OIL)', 'I', 0.23, '%', '', '', 'N', '', 'V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82551, 10230, 'THYMOL (THYME OIL)', 'I', 0.23, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79099, 10230, 'THYMOL', 'I', 18.02, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84154, 10230, 'THYMOL (THYME OIL)', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84667, 10230, 'THYMOL', 'I', 0.18, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85436, 10230, 'THYMOL', 'I', 0.18, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84146, 10230, 'THYMOL (THYME OIL)', 'I', 0.05, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84148, 10230, 'THYMOL (THYME OIL)', 'I', 0.05, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81943, 10230, 'THYMOL', 'I', 18.02, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84544, 10230, 'THYMOL', 'I', 18.02, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82559, 10230, 'THYMOL (THYME OIL)', 'I', 0.23, '%', '', '', 'N', 'V/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3665, 10230, 'THYMOL', 'I', 0.25, '%', '', '', 'N', '%', 'Historic Freeform Text: THYMOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4553, 10230, 'THYMOL', 'I', 1.2, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: THYMOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6564, 10230, 'THYMOL', 'I', 500, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THYMOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66168, 10230, 'THYMOL', 'I', 0.70, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2842, 10230, 'THYMOL', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2977, 10230, 'THYMOL', 'I', 50, 'MG', '', '1', 'N', 'G', 'Historic Freeform Text: THYMOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66399, 10230, 'THYMOL', 'I', 0.7, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62075, 10233, 'MEPROBAMATE', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MEPROBAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44252, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17903, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16709, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16636, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16903, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13431, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10494, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11176, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12430, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10913, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10806, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11966, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8594, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5862, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5858, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5820, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5821, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6390, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6892, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5672, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6163, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3311, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4280, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4281, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5316, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5156, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5157, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4523, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1404, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1829, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1723, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2170, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (812, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (778, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48580, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77614, 755, 'AVOBENZONE', 'I', 2.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60690, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60691, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60692, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64599, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64437, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65483, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65484, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65570, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65571, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68312, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67964, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71412, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71413, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71631, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71632, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71182, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76589, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74257, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72463, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72464, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75953, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74732, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74733, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74734, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73546, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73547, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLOROTHIAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73859, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76876, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76877, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76878, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76879, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76880, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78307, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78308, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78309, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78318, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77051, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80418, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81403, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81404, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81405, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78744, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78745, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78746, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78710, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78711, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78712, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81335, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79451, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79452, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82763, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82764, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82765, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82766, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82767, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81625, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81624, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81626, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79924, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81838, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81839, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81840, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81841, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81858, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81859, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78769, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78770, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78771, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80508, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80509, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82301, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82302, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82303, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78554, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78555, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80153, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80154, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80155, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83816, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83817, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84182, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84183, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84184, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84185, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84186, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84210, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84211, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84212, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84213, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84214, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84252, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84253, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84254, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84556, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84557, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84793, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84794, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84795, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84821, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84822, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84823, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85001, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85002, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85003, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85260, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85261, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85262, 10234, 'HYDROCHLOROTHIAZIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18069, 10235, 'CHOLESTYRAMINE RESIN', 'I', 4, 'G', '', '', 'N', 'DOSE', 'Historic Freeform Text: CHOLESTYRAMINE RESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18070, 10235, 'CHOLESTYRAMINE RESIN', 'I', 4, 'G', '', '', 'N', 'DOSE', 'Historic Freeform Text: CHOLESTYRAMINE RESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19757, 10235, 'CHOLESTYRAMINE RESIN', 'I', 4, 'G', '', '9', 'N', 'G', 'HISTORIC FREEFORM TEXT: CHOLESTYRAMINE RESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14332, 10235, 'CHOLESTYRAMINE RESIN', 'I', 4, 'G', '', '5', 'N', 'G', 'HISTORIC FREEFORM TEXT: CHOLESTYRAMINE RESIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7264, 10238, 'TRYPTOPHAN', 'I', 1, 'G', '', '', 'N', '', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48900, 10238, 'TRYPTOPHAN', 'I', 1, 'G', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60571, 10238, 'TRYPTOPHAN', 'I', 1, 'G', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60252, 10238, 'TRYPTOPHAN', 'I', 1, 'G', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72893, 10238, 'TRYPTOPHAN', 'I', 1, 'G', '', '', 'N', '', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15485, 10238, 'TRYPTOPHAN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7263, 10238, 'TRYPTOPHAN', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 10238, 'TRYPTOPHAN', 'I', 140, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63994, 10238, 'TRYPTOPHAN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64617, 10238, 'TRYPTOPHAN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62795, 10238, 'TRYPTOPHAN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62796, 10238, 'TRYPTOPHAN', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63872, 10238, 'TRYPTOPHAN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63873, 10238, 'TRYPTOPHAN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72892, 10238, 'TRYPTOPHAN', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72895, 10238, 'TRYPTOPHAN', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74780, 10238, 'TRYPTOPHAN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74781, 10238, 'TRYPTOPHAN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 10238, 'TRYPTOPHAN', 'I', 85, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44068, 10238, 'TRYPTOPHAN', 'I', 130, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43947, 10238, 'TRYPTOPHAN', 'I', 320, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20278, 10238, 'TRYPTOPHAN', 'I', 90, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 10238, 'TRYPTOPHAN', 'I', 76.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19306, 10238, 'TRYPTOPHAN', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19610, 10238, 'TRYPTOPHAN', 'I', 90, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20303, 10238, 'TRYPTOPHAN', 'I', 76.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20302, 10238, 'TRYPTOPHAN', 'I', 90, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 10238, 'TRYPTOPHAN', 'I', 76.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 10238, 'TRYPTOPHAN', 'I', 90, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 10238, 'TRYPTOPHAN', 'I', 90, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20289, 10238, 'TRYPTOPHAN', 'I', 76.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 10238, 'TRYPTOPHAN', 'I', 45, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 10238, 'TRYPTOPHAN', 'I', 90, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 10238, 'TRYPTOPHAN', 'I', 90, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20279, 10238, 'TRYPTOPHAN', 'I', 90, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 10238, 'TRYPTOPHAN', 'I', 85, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 10238, 'TRYPTOPHAN', 'I', 85, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 10238, 'TRYPTOPHAN', 'I', 70, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 10238, 'TRYPTOPHAN', 'I', 85, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 10238, 'TRYPTOPHAN', 'I', 85, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19143, 10238, 'TRYPTOPHAN', 'I', 90, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 10238, 'TRYPTOPHAN', 'I', 70, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 10238, 'TRYPTOPHAN', 'I', 100, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 10238, 'TRYPTOPHAN', 'I', 70, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 10238, 'TRYPTOPHAN', 'I', 85, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 10238, 'TRYPTOPHAN', 'I', 125, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18644, 10238, 'TRYPTOPHAN', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 10238, 'TRYPTOPHAN', 'I', 70, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 10238, 'TRYPTOPHAN', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18608, 10238, 'TRYPTOPHAN', 'I', 140, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18607, 10238, 'TRYPTOPHAN', 'I', 170, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 10238, 'TRYPTOPHAN', 'I', 180, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18550, 10238, 'TRYPTOPHAN', 'I', 90, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 10238, 'TRYPTOPHAN', 'I', 90, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15493, 10238, 'TRYPTOPHAN', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14077, 10238, 'TRYPTOPHAN', 'I', 90, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 10238, 'TRYPTOPHAN', 'I', 90, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 10238, 'TRYPTOPHAN', 'I', 90, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14073, 10238, 'TRYPTOPHAN', 'I', 76, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 10238, 'TRYPTOPHAN', 'I', 76, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14071, 10238, 'TRYPTOPHAN', 'I', 76, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 10238, 'TRYPTOPHAN', 'I', 45, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 10238, 'TRYPTOPHAN', 'I', 90, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14067, 10238, 'TRYPTOPHAN', 'I', 90, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 10238, 'TRYPTOPHAN', 'I', 76, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11329, 10238, 'TRYPTOPHAN', 'I', 180, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 10238, 'TRYPTOPHAN', 'I', 0.7, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7163, 10238, 'TRYPTOPHAN', 'I', 165, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5890, 10238, 'TRYPTOPHAN', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 10238, 'TRYPTOPHAN', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 10238, 'TRYPTOPHAN', 'I', 0.3, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4661, 10238, 'TRYPTOPHAN', 'I', 180, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3468, 10238, 'TRYPTOPHAN', 'I', 160, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4560, 10238, 'TRYPTOPHAN', 'I', 120, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 10238, 'TRYPTOPHAN', 'I', 180, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2776, 10238, 'TRYPTOPHAN', 'I', 80, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 10238, 'TRYPTOPHAN', 'I', 1, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 10238, 'TRYPTOPHAN', 'I', 1, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TRYPTOPHAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 10238, 'TRYPTOPHAN', 'I', 27, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 10238, 'TRYPTOPHAN', 'I', 200, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 10238, 'TRYPTOPHAN', 'I', 0.42, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 10238, 'TRYPTOPHAN', 'I', 0.74, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 10238, 'TRYPTOPHAN', 'I', 0.95, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 10238, 'TRYPTOPHAN', 'I', 0.95, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3297, 10240, 'CHLOROFORM', 'I', 112.5, 'G', '', '237', 'N', 'ML', 'Historic Freeform Text: CHLOROFORM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 10242, 'ARGININE', 'I', 730, 'MG', '', '', 'N', '', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43947, 10242, 'ARGININE', 'I', 1.96, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11329, 10242, 'ARGININE', 'I', 1.15, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4661, 10242, 'ARGININE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 10242, 'ARGININE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44068, 10242, 'ARGININE', 'I', 810, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 10242, 'ARGININE', 'I', 2.2, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7163, 10242, 'ARGININE', 'I', 600, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 10242, 'ARGININE', 'I', 850, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 10242, 'ARGININE', 'I', 1, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 10242, 'ARGININE', 'I', 2, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 10242, 'ARGININE', 'I', 2, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 10242, 'ARGININE', 'I', 107.1, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 10243, 'THREONINE', 'I', 375, 'MG', '', '', 'N', '', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43947, 10243, 'THREONINE', 'I', 980, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11329, 10243, 'THREONINE', 'I', 420, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 10243, 'THREONINE', 'I', 2.7, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 10243, 'THREONINE', 'I', 460, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 10243, 'THREONINE', 'I', 1.4, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 10243, 'THREONINE', 'I', 420, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 10243, 'THREONINE', 'I', 2, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 10243, 'THREONINE', 'I', 2, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (921, 10244, 'SODIUM P-DIMETHYL AMINO ORTHOLOLUENE PHOSPH TRIHYD', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM 4-DIMETHYLAMINO-S-TOLUENEPHOSPHONITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13009, 10257, 'SODIUM HYPOPHOSPHITE', 'I', 2.85, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM HYPOPHOSPHITE ((EQ TO 1% P)) ----------------------------------------');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12924, 10257, 'SODIUM HYPOPHOSPHITE', 'I', 2.85, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3326, 10257, 'SODIUM HYPOPHOSPHITE', 'I', 3.43, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM HYPOPHOSPHITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12874, 10257, 'SODIUM HYPOPHOSPHITE', 'I', 550, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: SODIUM HYPOPHOSPHYTE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42382, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16752, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66958, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68230, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68231, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76427, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76429, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75158, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75727, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75728, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75828, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75895, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75896, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75929, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75930, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75939, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76130, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76137, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76138, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76167, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76168, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76170, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76171, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76172, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73502, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76178, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76185, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76189, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76188, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76190, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76192, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76236, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76238, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76288, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77849, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77891, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77892, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77847, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79195, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80829, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79146, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36788, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 0.25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17733, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 0.125, '%', '', '', 'N', '', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16632, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6057, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5.0, '%', '', '', 'N', '', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6773, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 0.125, '%', '', '', 'N', '', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3319, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 2.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PHENYLEPHRINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49424, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 0.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65650, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75545, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 0.125, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41952, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 0.50, '%', '', '', 'N', 'W/V', 'HISTORIC FREEFORM TEXT: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18860, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 2.5, '%', '', '', 'N', 'W/V', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18759, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, '%', '', '', 'N', 'W/V', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16652, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 0.12, '%', '', '', 'N', '%', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16477, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 2.5, '%', '', '', 'N', '%', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6361, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 2.5, '%', '', '', 'N', '%', 'Historic Freeform Text: PHENYLEPHRINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1139, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 0.125, '%', '', '', 'N', '%', 'Historic Freeform Text: PHENYLEPHRINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2963, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 0.12, '%', '', '', 'N', '%', 'Historic Freeform Text: PHENYLEPHRINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2716, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 0.12, '%', '', '', 'N', '%', 'Historic Freeform Text: PHENYLEPHRINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37051, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26396, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26397, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21167, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21168, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11901, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10188, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70790, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76387, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76511, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77936, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80466, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37384, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16635, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 20, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16640, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5431, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 2, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PHENYLEPHRINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7082, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 20, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4252, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 3.75, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PHENYLEPHRINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61817, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '1', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67912, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67924, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68031, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68034, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68035, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69079, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69080, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76388, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75162, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75163, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75189, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75190, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75283, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5.0, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75285, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5.0, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75286, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10.0, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76376, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76233, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75558, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 1.25, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75559, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75827, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10.0, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76164, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76166, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76254, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76366, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77628, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81394, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78620, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81392, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79002, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81416, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80939, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80101, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80102, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80103, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62576, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '22', 'N', 'MG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31530, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '22', 'N', 'G', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (32780, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '23', 'N', 'G', 'HISTORIC FREEFORM TEXT: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19088, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '23', 'N', 'G', 'Historic Freeform Text: PHENYLEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62330, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '23', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65060, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '22', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73067, 10258, 'PHENYLEPHRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '22', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41734, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 12, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41738, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42382, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41831, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34150, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25898, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORPHENIRAMINE  NOTE: INGRED CHG''D TO FROM CHLORPHENIRAMINE TO CHLORPHENIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22847, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17887, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16752, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17113, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13804, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11646, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11041, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11921, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8249, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8251, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8247, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (579, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1224, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63999, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64001, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65249, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66958, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68103, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68104, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68230, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68231, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70286, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69737, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69738, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71094, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75101, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75304, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76278, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '', 'N', '', 'YELLOW DAY TABLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76278, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 12, 'MG', '', '', 'N', '', 'EXTENDED RELEASE RED NIGHT TABLET.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73002, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75371, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75896, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76138, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76170, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76171, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76172, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76188, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76190, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76192, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73702, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73704, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77849, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77892, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79195, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79504, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80829, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79071, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83258, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83344, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84427, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35886, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37105, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65873, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75146, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83004, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26863, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 1, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26864, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 1, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13479, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13361, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 1, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12722, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '20', 'N', 'ML', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12718, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10675, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4124, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1497, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1498, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CHLORPHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63140, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 1, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66361, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 1, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67672, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 1, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75412, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 1, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75882, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73724, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77675, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77749, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 1, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81390, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 1, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79105, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 1, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81392, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 1, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79763, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71050, 10259, 'CHLORPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '24', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80577, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6039, 10260, 'CHLORDIAZEPOXIDE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORDIAZEPOXIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6283, 10260, 'CHLORDIAZEPOXIDE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORDIAZEPOXIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4277, 10260, 'CHLORDIAZEPOXIDE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4278, 10260, 'CHLORDIAZEPOXIDE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORDIAZEPOXIDE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4279, 10260, 'CHLORDIAZEPOXIDE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (728, 10260, 'CHLORDIAZEPOXIDE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORDIAZEPOXIDE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41903, 10195, 'OXYMETAZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYMETAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42643, 10195, 'OXYMETAZOLINE HYDROCHLORIDE', 'I', 0.025, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33430, 10195, 'OXYMETAZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: OXYMETAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67620, 10195, 'OXYMETAZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: OXYMETAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70148, 10195, 'OXYMETAZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: OXYMETAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69670, 10195, 'OXYMETAZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'Y', '', '2009.02.04. EQUIVALENT TO 0.5MG/ML AS PER REVIEWER REPORT./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69673, 10195, 'OXYMETAZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'Y', '', '0.5MG/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69676, 10195, 'OXYMETAZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'Y', '', '2009.02.04. EQUIVALENT TO 0.5MG/ML AS PER REVIEWER REPORT./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73581, 10195, 'OXYMETAZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84725, 10195, 'OXYMETAZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'Y', '', '2009.02.04. EQUIVALENT TO 0.5MG/ML AS PER REVIEWER REPORT./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41970, 10195, 'OXYMETAZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'N', 'W/V', 'ACTIVE INGREDIENT STRENGTH REVISED TO 0.05% FROM 0.0525 AS PER THE REVIEW AREA (JOHNSON JOHN)./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41954, 10195, 'OXYMETAZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'N', 'W/V', 'HISTORIC FREEFORM TEXT: OXYMETAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42497, 10195, 'OXYMETAZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'N', '%', 'Historic Freeform Text: OXYMETAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67618, 10195, 'OXYMETAZOLINE HYDROCHLORIDE', 'I', 0.25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: OXYMETAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15173, 10196, 'NITROFURANTOIN', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NITROFURANTOIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2093, 10196, 'NITROFURANTOIN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2094, 10196, 'NITROFURANTOIN', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: NITROFURANTOIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50295, 10196, 'NITROFURANTOIN', 'I', 50, 'MG', '', '', 'N', '', 'NITROFURANTOIN MACROCRYSTAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50297, 10196, 'NITROFURANTOIN', 'I', 100, 'MG', '', '', 'N', '', 'NITROFURANTOIN MACROCRYSTAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13755, 10196, 'NITROFURANTOIN', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NITROFURANTOIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80493, 10198, 'DOXAPRAM HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1299, 10207, 'PHENYTOIN SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENYLHYDANTOIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1036, 10207, 'PHENYTOIN SODIUM', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIPHENYLHYDANTOIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1037, 10207, 'PHENYTOIN SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENYLHYDANTOIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13063, 10207, 'PHENYTOIN SODIUM', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PHENYTOIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12697, 10207, 'PHENYTOIN SODIUM', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PHENYTOIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9398, 10207, 'PHENYTOIN SODIUM', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PHENYTOIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37257, 10219, 'PROPYLENE GLYCOL', 'I', 20, '%', '', '', 'N', '', 'Historic Freeform Text: PROPYLENE GLYCOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8563, 10219, 'PROPYLENE GLYCOL', 'I', 5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PROPYLENE GLYCOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4885, 10219, 'PROPYLENE GLYCOL', 'I', 20, '%', '', '', 'N', '', 'Historic Freeform Text: PROPYLENE GLYCOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4886, 10219, 'PROPYLENE GLYCOL', 'I', 20, '%', '', '', 'N', '', 'Historic Freeform Text: PROPYLENE GLYCOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67103, 10219, 'PROPYLENE GLYCOL', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72560, 10219, 'PROPYLENE GLYCOL', 'I', 5.9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73342, 10219, 'PROPYLENE GLYCOL', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80709, 10219, 'PROPYLENE GLYCOL', 'I', 1, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2536, 10219, 'PROPYLENE GLYCOL', 'I', 4, '%', '', '', 'N', '%', 'Historic Freeform Text: PROPYLENE GLYCOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2000, 10219, 'PROPYLENE GLYCOL', 'I', 0, 'NIL', '', '', 'N', 'NIL', 'HISTORIC FREEFORM TEXT: PROPYLENE GLYCOL  CONTACTED THE COMPANY SEVERAL TIMES TO UPDATE THE CONCENTR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1564, 10219, 'PROPYLENE GLYCOL', 'I', 0, 'NIL', '', '', 'N', 'NIL', 'HISTORIC FREEFORM TEXT: PROPYLENE GLYCOL  CONTACTED THE COMPANY SEVERAL TIMES TO UPDATE THE CONCENTR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11232, 10219, 'PROPYLENE GLYCOL', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PROPYLENE GLYCOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66081, 10219, 'PROPYLENE GLYCOL', 'I', 10, 'MG', '', '', 'N', 'ML', 'APPROVED LABEL HAS 1.0% W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5925, 10219, 'PROPYLENE GLYCOL', 'I', 0.67, 'ML', '', '', 'N', 'ML', 'Historic Freeform Text: PROPYLENE GLYCOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5147, 10219, 'PROPYLENE GLYCOL', 'I', 0.667, 'ML', '', '', 'N', 'ML', 'Historic Freeform Text: PROPYLENE GLYCOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10299, 10219, 'PROPYLENE GLYCOL', 'I', 200, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PROPYLENE GLYCOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6716, 10221, 'LINOLEIC ACID', 'I', 3.4, 'G', '', '7.5', 'N', 'ML', 'Historic Freeform Text: LINOLEIC ACID ((AS GLYCERIDES))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80280, 10221, 'LINOLEIC ACID', 'I', 0.023, 'G', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 10223, 'PHENYLALANINE', 'I', 595, 'MG', '', '', 'N', '', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43947, 10223, 'PHENYLALANINE', 'I', 1, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44068, 10223, 'PHENYLALANINE', 'I', 480, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15493, 10223, 'PHENYLALANINE', 'I', 880, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11329, 10223, 'PHENYLALANINE', 'I', 560, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 10223, 'PHENYLALANINE', 'I', 2.9, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7163, 10223, 'PHENYLALANINE', 'I', 726, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 10223, 'PHENYLALANINE', 'I', 380, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 10223, 'PHENYLALANINE', 'I', 1, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4661, 10223, 'PHENYLALANINE', 'I', 620, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 10223, 'PHENYLALANINE', 'I', 620, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 10223, 'PHENYLALANINE', 'I', 3, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 10223, 'PHENYLALANINE', 'I', 3, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 10223, 'PHENYLALANINE', 'I', 57, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19933, 10227, 'LITHIUM CARBONATE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: LITHIUM CARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19893, 10227, 'LITHIUM CARBONATE', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: LITHIUM CARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19894, 10227, 'LITHIUM CARBONATE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: LITHIUM CARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13626, 10227, 'LITHIUM CARBONATE', 'I', 150, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LITHIUM CARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13429, 10227, 'LITHIUM CARBONATE', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: LITHIUM CARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3192, 10227, 'LITHIUM CARBONATE', 'I', 300, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LITHIUM CARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80580, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3414, 10227, 'LITHIUM CARBONATE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: LITHIUM CARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1327, 10227, 'LITHIUM CARBONATE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: LITHIUM CARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60306, 10227, 'LITHIUM CARBONATE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60307, 10227, 'LITHIUM CARBONATE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60308, 10227, 'LITHIUM CARBONATE', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66667, 10227, 'LITHIUM CARBONATE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66668, 10227, 'LITHIUM CARBONATE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75210, 10227, 'LITHIUM CARBONATE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78979, 10227, 'LITHIUM CARBONATE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78980, 10227, 'LITHIUM CARBONATE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37582, 10193, 'BISACODYL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: BISACODYL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37161, 10193, 'BISACODYL', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BISACODYL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19925, 10193, 'BISACODYL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: BISACODYL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11680, 10193, 'BISACODYL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: BISACODYL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12877, 10193, 'BISACODYL', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BISACODYL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7456, 10193, 'BISACODYL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: BISACODYL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4900, 10193, 'BISACODYL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: BISACODYL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4262, 10193, 'BISACODYL', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BISACODYL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1627, 10193, 'BISACODYL', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: BISACODYL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1553, 10193, 'BISACODYL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: BISACODYL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1554, 10193, 'BISACODYL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: BISACODYL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1555, 10193, 'BISACODYL', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BISACODYL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47962, 10193, 'BISACODYL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61546, 10193, 'BISACODYL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64686, 10193, 'BISACODYL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67779, 10193, 'BISACODYL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70170, 10193, 'BISACODYL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76622, 10193, 'BISACODYL', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: BISACODYL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75889, 10193, 'BISACODYL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84063, 10193, 'BISACODYL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9011, 10193, 'BISACODYL', 'I', 10, 'MG', '', '', 'N', 'SUP', 'Historic Freeform Text: BISACODYL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47963, 10193, 'BISACODYL', 'I', 10, 'MG', '', '', 'N', 'SUP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81164, 10193, 'BISACODYL', 'I', 5, 'MG', '', '', 'N', 'TAB', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74372, 10170, 'ETHACRYNIC ACID', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHACRYNIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (615, 10170, 'ETHACRYNIC ACID (SODIUM ETHACRYNATE)', 'I', 50, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: SODIUM ETHACRYNATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6716, 10186, 'LINOLENIC ACID', 'I', 440, 'MG', '', '7.5', 'N', 'ML', 'Historic Freeform Text: LINOLENIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82159, 10186, 'LINOLENIC ACID', 'I', 4080, 'MG', '', '8', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80280, 10186, 'LINOLENIC ACID', 'I', 5.167, 'G', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11176, 10190, 'TRIAMTERENE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIAMTERENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6390, 10190, 'TRIAMTERENE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIAMTERENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5672, 10190, 'TRIAMTERENE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIAMTERENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4523, 10190, 'TRIAMTERENE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIAMTERENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64437, 10190, 'TRIAMTERENE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIAMTERENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11642, 10114, 'ISOPROTERENOL HYDROCHLORIDE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ISOPROTERENOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5698, 8193, 'SULFAMERAZINE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFAMERAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2005, 8194, 'SULFAGUANIDINE', 'I', 1.33705, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFAGUANIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1612, 8194, 'SULFAGUANIDINE', 'I', 1.33705, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFAGUANIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4088, 8194, 'SULFAGUANIDINE', 'I', 486, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFAGUANIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2587, 8194, 'SULFAGUANIDINE', 'I', 97.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFAGUANIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (753, 8194, 'SULFAGUANIDINE', 'I', 195, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFAGUANIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (231, 8194, 'SULFAGUANIDINE', 'I', 24.7, 'MG', '', '2.9', 'N', 'G', 'Historic Freeform Text: SULFAGUANIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14024, 8195, 'SILVER SULFADIAZINE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SILVER SULFADIAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2146, 8195, 'SILVER SULFADIAZINE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SILVER SULFADIAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70910, 8195, 'SILVER SULFADIAZINE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13126, 8133, 'METOLAZONE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOLAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1991, 8136, 'SULFAQUINOXALINE (SULFAQUINOXALINE SODIUM)', 'I', 19.2, '%', '', '', 'Y', '%', 'Historic Freeform Text: SULFAQUINOXALINE SODIUM ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1670, 8136, 'SULFAQUINOXALINE (SULFAQUINOXALINE SODIUM)', 'I', 19.2, '%', '', '', 'Y', '%', 'Historic Freeform Text: SULFAQUINOXALINE SODIUM ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19091, 8136, 'SULFAQUINOXALINE', 'I', 32.5, 'G', '', '', 'N', 'L', 'HISTORIC FREEFORM TEXT: SULFAQUINOXALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5892, 8136, 'SULFAQUINOXALINE', 'I', 32.5, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SULFAQUINOXALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17416, 8138, 'SULFASALAZINE', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SALICYLAZOSULFAPYRIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17417, 8138, 'SULFASALAZINE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: SALICYLAZOSULFAPYRIDINE Qty Unit: ECT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5864, 8138, 'SULFASALAZINE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: SALICYLAZOSULFAPYRIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5728, 8138, 'SULFASALAZINE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: SALICYLAZOSULFAPYRIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2908, 8138, 'SULFASALAZINE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: SALICYLAZOSULFAPYRIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4088, 8144, 'SULFACETAMIDE', 'I', 324, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFACETAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2587, 8144, 'SULFACETAMIDE', 'I', 65, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFACETAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (753, 8144, 'SULFACETAMIDE', 'I', 130, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFACETAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37254, 8145, 'SULFACETAMIDE SODIUM', 'I', 10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SULFACETAMIDE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16625, 8145, 'SULFACETAMIDE SODIUM', 'I', 10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SULFACETAMIDE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10169, 8145, 'SULFACETAMIDE SODIUM', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: SULFACETAMIDE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1971, 8145, 'SULFACETAMIDE SODIUM', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: SULFACETAMIDE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16623, 8145, 'SULFACETAMIDE SODIUM', 'I', 10, '%', '', '', 'N', '%', 'Historic Freeform Text: SULFACETAMIDE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11868, 8145, 'SULFACETAMIDE SODIUM', 'I', 10, '%', '', '', 'N', '%', 'Historic Freeform Text: SULFACETAMIDE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6055, 8145, 'SULFACETAMIDE SODIUM', 'I', 10, '%', '', '', 'N', '%', 'Historic Freeform Text: SULFACETAMIDE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11424, 8145, 'SULFACETAMIDE SODIUM', 'I', 300, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFACETAMIDE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6365, 8145, 'SULFACETAMIDE SODIUM', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFACETAMIDE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (371, 8145, 'SULFACETAMIDE SODIUM', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SULFACETAMIDE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64903, 11171, 'VITAMIN B2', 'I', 5, 'MG', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16649, 8145, 'SULFACETAMIDE SODIUM', 'I', 100, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SULFACETAMIDE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43982, 8152, 'SULFADOXINE', 'I', 200, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SULFADOXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42854, 8152, 'SULFADOXINE', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFADOXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19182, 8152, 'SULFADOXINE', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFADOXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11977, 8152, 'SULFADOXINE', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFADOXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6880, 8152, 'SULFADOXINE', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFADOXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63636, 8152, 'SULFADOXINE', 'I', 200, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77098, 8152, 'SULFADOXINE', 'I', 200, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9799, 8165, 'SULFADIMETHOXINE', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFADIMETHOXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9783, 8165, 'SULFADIMETHOXINE', 'I', 125, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFADIMETHOXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66793, 8165, 'SULFADIMETHOXINE', 'I', 250, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (132, 8130, 'SULFATHIAZOLE SODIUM', 'I', 12.5, '%', '', '', 'N', '', 'Historic Freeform Text: SULFATHIAZOLE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3357, 8130, 'SULFATHIAZOLE SODIUM', 'I', 3.5, 'G', '', '4.5', 'N', 'L', 'Historic Freeform Text: SULFATHIAZOLE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 8130, 'SULFATHIAZOLE SODIUM', 'I', 250, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: SULFATHIAZOLE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23683, 8130, 'SULFATHIAZOLE SODIUM', 'I', 33, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: SULFATHIAZOLE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14165, 8130, 'SULFATHIAZOLE SODIUM', 'I', 136.3, 'G', '', '450', 'N', 'G', 'Historic Freeform Text: SULFATHIAZOLE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8101, 8130, 'SULFATHIAZOLE SODIUM', 'I', 120, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: SULFATHIAZOLE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1143, 8130, 'SULFATHIAZOLE SODIUM', 'I', 189, 'G', '', '590', 'N', 'G', 'HISTORIC FREEFORM TEXT: SULFATHIAZOLE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1613, 8130, 'SULFATHIAZOLE SODIUM', 'I', 180, 'G', '', '454', 'N', 'G', 'Historic Freeform Text: SULFATHIAZOLE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2126, 8130, 'SULFATHIAZOLE SODIUM', 'I', 151, 'G', '', '454', 'N', 'G', 'Historic Freeform Text: SULFATHIAZOLE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26617, 8130, 'SULFATHIAZOLE SODIUM', 'I', 315, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: SULFATHIAZOLE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7178, 8130, 'SULFATHIAZOLE SODIUM', 'I', 333, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SULFATHIAZOLE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1970, 8130, 'SULFATHIAZOLE SODIUM', 'I', 315, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SULFATHIAZOLE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47385, 8130, 'SULFATHIAZOLE SODIUM', 'I', 315, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9362, 8095, 'IOXAGLATE SODIUM', 'I', 123, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: IOXAGLATE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5554, 8095, 'IOXAGLATE SODIUM', 'I', 196, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: IOXAGLATE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16584, 8120, 'DAPSONE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DAPSONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23257, 8029, 'METHOTRIMEPRAZINE (METHOTRIMEPRAZINE MALEATE)', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METHOTRIMEPRAZINE MALEATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19668, 8029, 'METHOTRIMEPRAZINE (METHOTRIMEPRAZINE MALEATE)', 'I', 25, 'MG', '', '', 'Y', '', 'Historic Freeform Text: METHOTRIMEPRAZINE MALEATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52422, 8029, 'METHOTRIMEPRAZINE (METHOTRIMEPRAZINE MALEATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52423, 8029, 'METHOTRIMEPRAZINE (METHOTRIMEPRAZINE MALEATE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52424, 8029, 'METHOTRIMEPRAZINE (METHOTRIMEPRAZINE MALEATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61820, 8029, 'METHOTRIMEPRAZINE (METHOTRIMEPRAZINE MALEATE)', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61821, 8029, 'METHOTRIMEPRAZINE (METHOTRIMEPRAZINE MALEATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61822, 8029, 'METHOTRIMEPRAZINE (METHOTRIMEPRAZINE MALEATE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61823, 8029, 'METHOTRIMEPRAZINE (METHOTRIMEPRAZINE MALEATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13163, 8029, 'METHOTRIMEPRAZINE (METHOTRIMEPRAZINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: METHOTRIMEPRAZINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6694, 6101, 'MERCURIC CHLORIDE', 'I', 3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MERCURIC CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6392, 6030, 'PROCYCLIDINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROCYCLIDINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6394, 6030, 'PROCYCLIDINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROCYCLIDINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5725, 6030, 'PROCYCLIDINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PROCYCLIDINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84045, 6036, 'THALIDOMIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84046, 6036, 'THALIDOMIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84048, 6036, 'THALIDOMIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12217, 6044, 'PHENYLTOLOXAMINE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PHENYLTOLOXAMINE CITRATE PHENYLTOLOXAMINE RESIN COMPOUND EQUIVALENT TO 10 MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12216, 6044, 'PHENYLTOLOXAMINE', 'I', 10, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PHENYLTOLOXAMINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42015, 6057, 'TETRAHYDROZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42685, 6057, 'TETRAHYDROZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73019, 6057, 'TETRAHYDROZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77592, 6057, 'TETRAHYDROZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78699, 6057, 'TETRAHYDROZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81391, 6057, 'TETRAHYDROZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'N', 'W/V', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82979, 6057, 'TETRAHYDROZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11133, 6057, 'TETRAHYDROZOLINE HYDROCHLORIDE', 'I', 0.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TETRYZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75893, 6057, 'TETRAHYDROZOLINE HYDROCHLORIDE', 'I', 0.5, 'MG', '', '', 'N', 'ML', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17279, 5991, 'STREPTOKINASE', 'I', 250000, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: STREPTOKINASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16299, 5991, 'STREPTOKINASE', 'I', 750000, 'UNIT', '', '', 'N', 'VIAL', 'Historic Freeform Text: STREPTOKINASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16422, 5991, 'STREPTOKINASE', 'I', 1500000, 'UNIT', '', '', 'N', 'VIAL', 'Historic Freeform Text: STREPTOKINASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5813, 5999, 'CHLOROPROCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CHLOROPROCAINE HCL (2) 2007.03.06 (2) REMOVED FROM ACTIVE INGREDIENT NAME./K');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42946, 6010, 'TOLAZOLINE (TOLAZOLINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: TOLAZOLINE ((AS TOLAZOLINE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (875, 5970, 'PIPERAZINE PHOSPHATE', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: PIPERAZINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1516, 5970, 'PIPERAZINE PHOSPHATE', 'I', 50, '%', '', '', 'N', '%', 'Historic Freeform Text: PIPERAZINE PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66819, 5974, 'PHENTOLAMINE MESYLATE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67670, 5974, 'PHENTOLAMINE MESYLATE', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28979, 5913, 'DEQUALINIUM CHLORIDE', 'I', 0.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEQUALINIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19449, 5913, 'DEQUALINIUM CHLORIDE', 'I', 0.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DEQUALINIUM CHLORIDE 0.5% W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66519, 3876, 'ALLERGENIC EXTRACTS', 'I', 0, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 3841, 'EPOXY RESIN', 'I', 0.041, 'MG', '', '', 'N', 'PATCH', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 3843, 'P-PHENYLENEDIAMINE', 'I', 0.073, 'MG', '', '', 'N', 'PATCH', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1494, 3762, 'SULFATED OILS', 'I', 6.3, '%', '', '', 'N', '', 'Historic Freeform Text: SULFATED OILS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62300, 3781, 'BENTONITE', 'I', 167, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48860, 3781, 'BENTONITE', 'I', 69.5, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48974, 3781, 'BENTONITE', 'I', 63.4, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2932, 3783, 'POLYETHYLENE GLYCOL P-ISOOCTYLPHENYL ETHER', 'I', 3.5, '%', '', '', 'N', '', 'Historic Freeform Text: POLYETHYLENE GLYCOL P-ISOOCTYLPHENYL ETHER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5504, 3795, 'WILD LETTUCE', 'I', 1.36, 'MG', '', '1', 'N', 'ML', 'Historic Freeform Text: WILD LETTUCE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2196, 3707, 'SODIUM METASILICATE', 'I', 2.4, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM METASILICATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84220, 3707, 'SODIUM METASILICATE', 'I', 2.4, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM METASILICATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84223, 3707, 'SODIUM METASILICATE', 'I', 2.4, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM METASILICATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65822, 3714, 'EPHEDRINE HYDROCHLORIDE', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13758, 3714, 'EPHEDRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DL-EPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75771, 3714, 'EPHEDRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13861, 3714, 'EPHEDRINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: DL-EPHEDRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50687, 11240, 'CLEMASTINE (CLEMASTINE HYDROGEN FUMARATE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44168, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 3, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: PIPERACILLIN ((AS PIPERACILLIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44169, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 4, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: PIPERACILLIN ((AS PIPERACILLIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44170, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 2, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: PIPERACILLIN ((AS PIPERACILLIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70832, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 2, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: PIPERACILLIN ((AS PIPERACILLIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70833, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 3, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: PIPERACILLIN ((AS PIPERACILLIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70834, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 4, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: PIPERACILLIN ((AS PIPERACILLIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73314, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 2, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73315, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 3, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73316, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 4, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78500, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 2, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: PIPERACILLIN ((AS PIPERACILLIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78501, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 3, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: PIPERACILLIN ((AS PIPERACILLIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78502, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 4, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: PIPERACILLIN ((AS PIPERACILLIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79116, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 2, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79117, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 3, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79118, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 4, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81627, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 12, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79408, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 2, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79409, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 3.0, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79410, 11241, 'PIPERACILLIN (PIPERACILLIN SODIUM)', 'I', 4.0, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78500, 11242, 'TAZOBACTAM (TAZOBACTAM SODIUM)', 'I', 0.25, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: TAZOBACTAM ((AS TAZOBACTAM SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78501, 11242, 'TAZOBACTAM (TAZOBACTAM SODIUM)', 'I', 0.375, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: TAZOBACTAM ((AS TAZOBACTAM SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78502, 11242, 'TAZOBACTAM (TAZOBACTAM SODIUM)', 'I', 0.5, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: TAZOBACTAM ((AS TAZOBACTAM SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79116, 11242, 'TAZOBACTAM (TAZOBACTAM SODIUM)', 'I', 0.25, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79117, 11242, 'TAZOBACTAM (TAZOBACTAM SODIUM)', 'I', 0.375, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79118, 11242, 'TAZOBACTAM (TAZOBACTAM SODIUM)', 'I', 0.5, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81627, 11242, 'TAZOBACTAM (TAZOBACTAM SODIUM)', 'I', 1.5, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79408, 11242, 'TAZOBACTAM (TAZOBACTAM SODIUM)', 'I', 0.25, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79409, 11242, 'TAZOBACTAM (TAZOBACTAM SODIUM)', 'I', 0.375, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79410, 11242, 'TAZOBACTAM (TAZOBACTAM SODIUM)', 'I', 0.5, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44168, 11242, 'TAZOBACTAM (TAZOBACTAM SODIUM)', 'I', 375, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: TAZOBACTAM ((AS TAZOBACTAM SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44169, 11242, 'TAZOBACTAM (TAZOBACTAM SODIUM)', 'I', 500, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: TAZOBACTAM ((AS TAZOBACTAM SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44170, 11242, 'TAZOBACTAM (TAZOBACTAM SODIUM)', 'I', 250, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: TAZOBACTAM ((AS TAZOBACTAM SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15903, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 125, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLAVULINIC ACID POTASS ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15006, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 75, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLAVULANIC ACID ((AS POTASSIUM SALT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15007, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLAVULANIC ACID ((AS POTASSIUM SALT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15008, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLAVULANIC ACID ((AS POTASSIUM SALT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15003, 11247, 'CLAVULANIC ACID (POTASSIUM CLAVULANATE)', 'I', 12.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLAVULANIC ACID ((AS POTASSIUM SALT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62267, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 125, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67257, 11247, 'CLAVULANIC ACID (POTASSIUM CLAVULANATE)', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67258, 11247, 'CLAVULANIC ACID (POTASSIUM CLAVULANATE)', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67706, 11247, 'CLAVULANIC ACID (POTASSIUM CLAVULANATE)', 'I', 125, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLAVULINIC ACID POTASS ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69723, 11247, 'CLAVULANIC ACID (POTASSIUM CLAVULANATE)', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71255, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 125, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72467, 11247, 'CLAVULANIC ACID (POTASSIUM CLAVULANATE)', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78478, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78479, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78480, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78481, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81188, 11247, 'CLAVULANIC ACID (POTASSIUM CLAVULANATE)', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81189, 11247, 'CLAVULANIC ACID (POTASSIUM CLAVULANATE)', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80240, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80241, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80242, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80933, 11247, 'CLAVULANIC ACID (POTASSIUM CLAVULANATE)', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80934, 11247, 'CLAVULANIC ACID (POTASSIUM CLAVULANATE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80936, 11247, 'CLAVULANIC ACID (POTASSIUM CLAVULANATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80937, 11247, 'CLAVULANIC ACID (POTASSIUM CLAVULANATE)', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72188, 11247, 'CLAVULANIC ACID (POTASSIUM CLAVULANATE)', 'I', 1, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15224, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 100, 'MG', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: CLAVULINIC ACID POTASS ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43574, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 12.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CLAVULANIC ACID ((AS POTASSIUM SALT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15208, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 31.25, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CLAVULINIC ACID POTASS ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15209, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 62.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CLAVULINIC ACID POTASS ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62268, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 57, 'MG', '', '5', 'Y', 'ML', '2 PACKAGE SIZES: 70ML BOTTLE:  5600MG AMOXICILLIN (AS AMOXICILLIN               TRIHYDRATE)  AND  83');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62269, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 28.5, 'MG', '', '5', 'Y', 'ML', '2 PACKAGE SIZES: 70ML BOTTLE:  2800MG AMOXICILLIN (AS AMOXICILLIN               TRIHYDRATE)  AND  41');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67930, 11247, 'CLAVULANIC ACID (POTASSIUM CLAVULANATE)', 'I', 31.25, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67931, 11247, 'CLAVULANIC ACID (POTASSIUM CLAVULANATE)', 'I', 62.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68633, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 31.25, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CLAVULINIC ACID POTASS ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68634, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 62.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CLAVULINIC ACID POTASS ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77397, 11247, 'CLAVULANIC ACID (CLAVULANATE POTASSIUM)', 'I', 57, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62566, 11249, 'MICONAZOLE (MICONAZOLE NITRATE)', 'I', 2, '%', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43499, 11250, 'BUSERELIN (BUSERELIN ACETATE)', 'I', 6.3, 'MG', '', '', 'Y', 'IMP', 'HISTORIC FREEFORM TEXT: BUSERELIN ((AS BUSERELIN ACETATE)) QTY UNIT: IMP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64338, 11250, 'BUSERELIN (BUSERELIN ACETATE)', 'I', 9.45, 'MG', '', '', 'Y', 'IMP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43416, 11250, 'BUSERELIN (BUSERELIN ACETATE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: BUSERELIN ACETATE ((BUSERELIN EQ.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43417, 11250, 'BUSERELIN (BUSERELIN ACETATE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: BUSERELIN ACETATE ((BUSERELIN EQ.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44134, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 72.6, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PYRANTEL ((AS PYRANTEL PAMOATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44136, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 22.7, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PYRANTEL ((AS PYRANTEL PAMOATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44137, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 68, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PYRANTEL ((AS PYRANTEL PAMOATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42855, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 35, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PYRANTEL ((AS PYRANTEL PAMOATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20090, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 125, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PYRANTEL ((AS PYRANTEL PAMOATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12926, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 125, 'MG', '', '', 'N', '', 'Historic Freeform Text: PYRANTEL PAMOATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12688, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 57, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PYRANTEL PAMOATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12689, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 114, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PYRANTEL PAMOA\\E ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12690, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 227, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PYRANTEL PAMOATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10128, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 35, 'MG', '', '', 'N', '', 'Historic Freeform Text: PYRANTEL PAMOATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5212, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 125, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: PYRANTEL PAMOATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5032, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 35, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PYRANTEL PAMOATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2987, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 35, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PYRANTEL PAMOATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62729, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2988, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 3.58, 'G', '', '', 'Y', 'SYR', 'Historic Freeform Text: PYRANTEL PAMOATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18664, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRANTEL PAMOATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12925, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PYRANTEL PAMOATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1924, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 50, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: PYRANTEL PAMOATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70966, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 3.6, 'G', '', '23.6', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70967, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 7.2, 'G', '', '47.2', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19275, 11253, 'PYRANTEL (PYRANTEL PAMOATE)', 'I', 125, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PYRANTEL ((AS PYRANTEL PAMOATE 360MG/G))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19200, 11254, 'CEFOXITIN (CEFOXITIN SODIUM)', 'I', 1, 'G', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: CEFOXITIN ((AS CEFOXITIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19201, 11254, 'CEFOXITIN (CEFOXITIN SODIUM)', 'I', 2, 'G', '', '', 'Y', 'VIAL', 'Historic Freeform Text: CEFOXITIN ((AS CEFOXITIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64362, 11254, 'CEFOXITIN (CEFOXITIN SODIUM)', 'I', 10, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77707, 11254, 'CEFOXITIN (CEFOXITIN SODIUM)', 'I', 1, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77708, 11254, 'CEFOXITIN (CEFOXITIN SODIUM)', 'I', 2, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18726, 11257, 'HALOFUGINONE (HALOFUGINONE HYDROBROMIDE)', 'I', 6, 'G', '', '', 'Y', 'KG', 'Historic Freeform Text: HALOFUGINONE ((AS HYDROBROMIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49241, 11264, 'ZUCLOPENTHIXOL (ZUCLOPENTHIXOL HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', 'ACCORDING TO DPIF, INGREDIENT IS ZUCLOPENTHIXOL DIHYDROCHLORIDE. CALCULATED AS A BASE. MAR.10,2005.M');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49242, 11264, 'ZUCLOPENTHIXOL (ZUCLOPENTHIXOL HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10832, 11175, 'KETOTIFEN (KETOTIFEN FUMARATE)', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: KETOTIFEN FUMARATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51056, 11175, 'KETOTIFEN (KETOTIFEN FUMARATE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49992, 11175, 'KETOTIFEN (KETOTIFEN FUMARATE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19550, 11175, 'KETOTIFEN (KETOTIFEN FUMARATE)', 'I', 1, 'MG', '', '5', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: KETOTIFEN ((AS KETOTIFEN FUMARATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10860, 11175, 'KETOTIFEN (KETOTIFEN FUMARATE)', 'I', 1, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: KETOTIFEN FUMARATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51055, 11175, 'KETOTIFEN (KETOTIFEN FUMARATE)', 'I', 1, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66035, 11175, 'KETOTIFEN (KETOTIFEN FUMARATE)', 'I', 0.25, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76476, 11175, 'KETOTIFEN (KETOTIFEN FUMARATE)', 'I', 0.25, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19752, 11176, 'CARFENTANIL (CARFENTANIL CITRATE)', 'I', 3, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CARFENTANIL ((AS CITRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44142, 11179, 'XYLAZINE (XYLAZINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: XYLAZINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44143, 11179, 'XYLAZINE (XYLAZINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: XYLAZINE ((AS XYLAZINE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19124, 11179, 'XYLAZINE (XYLAZINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: XYLAZINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11004, 11179, 'XYLAZINE (XYLAZINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: XYLAZINE((HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10031, 11179, 'XYLAZINE (XYLAZINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: XYLAZINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62549, 11179, 'XYLAZINE (XYLAZINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62550, 11179, 'XYLAZINE (XYLAZINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19534, 11180, 'CEFAZOLIN (CEFAZOLIN SODIUM)', 'I', 10, 'G', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: CEFAZOLIN ((AS CEFAZOLIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19532, 11180, 'CEFAZOLIN (CEFAZOLIN SODIUM)', 'I', 1, 'G', '', '', 'Y', 'VIAL', 'Historic Freeform Text: CEFAZOLIN ((AS CEFAZOLIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60453, 11180, 'CEFAZOLIN (CEFAZOLIN SODIUM)', 'I', 1.0, 'G', '', '', 'Y', 'VIAL', 'PRODUCT DILUTED WITH 2ML STERILE WATER FOR INJECTION  (10ML VIAL).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60455, 11180, 'CEFAZOLIN (CEFAZOLIN SODIUM)', 'I', 10, 'G', '', '', 'Y', 'VIAL', 'PRODUCT DILUTED WITH 45 OR 96ML STERILE WATER FOR INJECTION TO PROVIDE 200 OR 100MG/ML CEFAZOLIN STO');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60456, 11180, 'CEFAZOLIN (CEFAZOLIN SODIUM)', 'I', 20, 'G', '', '', 'Y', 'VIAL', 'PRODUCT DILUTED WITH 87ML STERILE WATER FOR INJECTION TO PROVIDE 200MG/ML CEFAZOLIN STOCK SOLUTION (');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78258, 11180, 'CEFAZOLIN (CEFAZOLIN SODIUM)', 'I', 1, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78259, 11180, 'CEFAZOLIN (CEFAZOLIN SODIUM)', 'I', 10, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79456, 11180, 'CEFAZOLIN (CEFAZOLIN SODIUM)', 'I', 1, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79457, 11180, 'CEFAZOLIN (CEFAZOLIN SODIUM)', 'I', 10, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19521, 11180, 'CEFAZOLIN (CEFAZOLIN SODIUM)', 'I', 500, 'MG', '', '', 'Y', 'VIAL', 'Historic Freeform Text: CEFAZOLIN ((AS CEFAZOLIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60452, 11180, 'CEFAZOLIN (CEFAZOLIN SODIUM)', 'I', 500, 'MG', '', '', 'Y', 'VIAL', 'PRODUCT DILUTED WITH 2ML STERILE WATER FOR INJECTION (10ML VIAL).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79454, 11180, 'CEFAZOLIN (CEFAZOLIN SODIUM)', 'I', 500, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20021, 11181, 'DESIPRAMINE (DESIPRAMINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DESIPRAMINE ((DESIPRAMINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20022, 11181, 'DESIPRAMINE (DESIPRAMINE HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DESIPRAMINE ((DESIPRAMINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20023, 11181, 'DESIPRAMINE (DESIPRAMINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DESIPRAMINE ((DESIPRAMINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20014, 11181, 'DESIPRAMINE (DESIPRAMINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DESIPRAMINE ((DESIPRAMINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20015, 11181, 'DESIPRAMINE (DESIPRAMINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DESIPRAMINE ((DESIPRAMINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34671, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: MINOCYCLINE ((AS MINOCYCLINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34672, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: MINOCYCLINE ((AS MINOCYCLINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19204, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', 'Historic Freeform Text: MINOCYCLINE ((AS HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19207, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: MINOCYCLINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16949, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: MINOCYCLINE ((AS HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16950, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: MINOCYCLINE ((AS HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15925, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MINOCYCLINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15927, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MINOCYCLINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13943, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: MINOCYCLINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13948, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', 'Historic Freeform Text: MINOCYCLINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49998, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49999, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60635, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60636, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63489, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62699, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62700, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63141, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63142, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65754, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: MINOCYCLINE ((AS HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65755, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: MINOCYCLINE ((AS HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77264, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77265, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77976, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77977, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77949, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77950, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76380, 11182, 'MINOCYCLINE (MINOCYCLINE HYDROCHLORIDE)', 'I', 1, 'MG', '', '4', 'N', 'MG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44189, 11190, 'KETAMINE (KETAMINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: KETAMINE ((AS KETAMINE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14691, 11190, 'KETAMINE (KETAMINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', 'ML', 'STAN TWARDOWSKI FROM VDD APPROVED THE ADDITION OF THE STRENGTH 115.4MG/ML TO THE SALT KETAMINE HYDRO');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6011, 11190, 'KETAMINE (KETAMINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: KETAMINE (AS HYDROCHLORIDE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5374, 11190, 'KETAMINE (KETAMINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: KETAMINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1214, 11190, 'KETAMINE (KETAMINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: KETAMINE HYDROCHLORIDE EACH ML CONTAINS KETAMINE HCL. EQUIV.  TO 10MG KETAMI');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1215, 11190, 'KETAMINE (KETAMINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: KETAMINE HYDROCHLORIDE EACH ML CONTAINS KETAMINE HCL EQUIV. TO 50MG KETAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70995, 11190, 'KETAMINE (KETAMINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70996, 11190, 'KETAMINE (KETAMINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50566, 11202, 'PNEUMOCOCCAL VACCINE POLYVALENT', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16486, 11205, 'LIVER (LIVER EXTRACT)', 'I', 25, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: LIVER ((EXTRACT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44201, 11211, 'SPECTINOMYCIN (SPECTINOMYCIN DIHYDROCHLORIDE PENTAHYDRATE)', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SPECTINOMYCIN ((AS SPECT.DIHCL PENTAHYDR.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44203, 11211, 'SPECTINOMYCIN (SPECTINOMYCIN DIHYDROCHLORIDE PENTAHYDRATE)', 'I', 50, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: SPECTINOMYCIN ((AS SPECT.DIHCL PENTAHYDR.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44175, 11211, 'SPECTINOMYCIN (SPECTINOMYCIN DIHYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: SPECTINOMYCIN ((AS DIHYDROCHLOR.PENTAHYD.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10785, 11211, 'SPECTINOMYCIN (SPECTINOMYCIN SULFATE)', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SPECTINOMYCIN SULF ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20102, 11211, 'SPECTINOMYCIN (SPECTINOMYCIN HYDROCHLORIDE)', 'I', 22, 'G', '', '', 'Y', 'KG', 'Historic Freeform Text: SPECTINOMYCIN ((AS SPECTIN. HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10168, 11211, 'SPECTINOMYCIN (SPECTINOMYCIN SULFATE)', 'I', 22, 'G', '', '', 'Y', 'KG', 'HISTORIC FREEFORM TEXT: SPECTINOMYCIN SULF ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13676, 11211, 'SPECTINOMYCIN (SPECTINOMYCIN SULFATE)', 'I', 66.7, 'G', '', '150', 'N', 'G', 'Historic Freeform Text: SPECTINOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10030, 11211, 'SPECTINOMYCIN (SPECTINOMYCIN SULFATE)', 'I', 66.7, 'G', '', '150', 'N', 'G', 'Historic Freeform Text: SPECTINOMYCIN SULF ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44202, 11211, 'SPECTINOMYCIN (SPECTINOMYCIN DIHYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'Y', 'G', 'SPECTINOMYCIN AS SPECTINOMYCIN DIHYDROCHLORIDE PENTAHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4865, 11211, 'SPECTINOMYCIN (SPECTINOMYCIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'Y', 'G', 'HISTORIC FREEFORM TEXT: SPECTINOMYCINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50225, 11211, 'SPECTINOMYCIN (SPECTINOMYCIN HYDROCHLORIDE)', 'I', 444, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59722, 11219, 'BETAXOLOL (BETAXOLOL HYDROCHLORIDE)', 'I', 0.5, '%', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15625, 11219, 'BETAXOLOL (BETAXOLOL HYDROCHLORIDE)', 'I', 0.25, '%', '', '', 'N', '%', 'Historic Freeform Text: BETAXOLOL HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43367, 11121, 'NORTRIPTYLINE (NORTRIPTYLINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NORTRIPTYLINE ((AS NORTRIPT.HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43368, 11121, 'NORTRIPTYLINE (NORTRIPTYLINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NORTRIPTYLINE ((AS NORTRIPT.HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43346, 11121, 'NORTRIPTYLINE (NORTRIPTYLINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: NORTRIPTYLINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43347, 11121, 'NORTRIPTYLINE (NORTRIPTYLINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: NORTRIPTYLINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44225, 11121, 'NORTRIPTYLINE (NORTRIPTYLINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', 'Historic Freeform Text: NORTRIPTYLINE ((AS NORTRIPTYLINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66631, 11171, 'VITAMIN B2', 'I', 50, 'MG', '', '300', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44226, 11121, 'NORTRIPTYLINE (NORTRIPTYLINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: NORTRIPTYLINE ((AS NORTRIPTYLINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49159, 11121, 'NORTRIPTYLINE (NORTRIPTYLINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49161, 11121, 'NORTRIPTYLINE (NORTRIPTYLINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47991, 11121, 'NORTRIPTYLINE (NORTRIPTYLINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47992, 11121, 'NORTRIPTYLINE (NORTRIPTYLINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15, 11121, 'NORTRIPTYLINE (NORTRIPTYLINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16, 11121, 'NORTRIPTYLINE (NORTRIPTYLINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51213, 11121, 'NORTRIPTYLINE (NORTRIPTYLINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51214, 11121, 'NORTRIPTYLINE (NORTRIPTYLINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60699, 11121, 'NORTRIPTYLINE (NORTRIPTYLINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60700, 11121, 'NORTRIPTYLINE (NORTRIPTYLINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12331, 11161, 'QUINAPRIL (QUINAPRIL HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: QUINAPRIL HYDROCHL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12332, 11161, 'QUINAPRIL (QUINAPRIL HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: QUINAPRIL HYDROCHL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12333, 11161, 'QUINAPRIL (QUINAPRIL HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: QUINAPRIL HYDROCHL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12334, 11161, 'QUINAPRIL (QUINAPRIL HYDROCHLORIDE)', 'I', 40, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: QUINAPRIL HYDROCHL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60690, 11161, 'QUINAPRIL (QUINAPRIL HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60691, 11161, 'QUINAPRIL (QUINAPRIL HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60692, 11161, 'QUINAPRIL (QUINAPRIL HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42996, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACEBUTOLOL ((AS HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42997, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACEBUTOLOL ((AS HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42998, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACEBUTOLOL ((AS HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19939, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACEBUTOLOL ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19940, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACEBUTOLOL ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19941, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 400, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACEBUTOLOL ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18843, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: ACEBUTOLOL ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18844, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 400, 'MG', '', '', 'Y', '', 'Historic Freeform Text: ACEBUTOLOL ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18845, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 200, 'MG', '', '', 'Y', '', 'Historic Freeform Text: ACEBUTOLOL ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17826, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACEBUTOLOL ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17827, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACEBUTOLOL ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17828, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 400, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACEBUTOLOL ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12421, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: ACEBUTOLOL HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12422, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 200, 'MG', '', '', 'Y', '', 'Historic Freeform Text: ACEBUTOLOL HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12423, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 400, 'MG', '', '', 'Y', '', 'Historic Freeform Text: ACEBUTOLOL HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61246, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61247, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 200, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61248, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 400, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61076, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 200, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61075, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61077, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 400, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74284, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74285, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACEBUTOLOL ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74286, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77170, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77171, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 200, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77172, 11162, 'ACEBUTOLOL (ACEBUTOLOL HYDROCHLORIDE)', 'I', 400, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43718, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.5, '%', '', '', 'Y', '', 'Historic Freeform Text: TIMOLOL ((AS MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43719, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.25, '%', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TIMOLOL ((AS MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19252, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TIMOLOL ((AS MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19242, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: TIMOLOL ((AS MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18777, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.25, '%', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TIMOLOL ((AS TIMOLOL MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18778, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.5, '%', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TIMOLOL ((AS MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15253, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.25, '%', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TIMOLOL ((AS MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15254, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.5, '%', '', '', 'Y', '', 'Historic Freeform Text: TIMOLOL ((AS MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13095, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TIMOLOL MALEATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13177, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.25, '%', '', '', 'N', '', 'Historic Freeform Text: TIMOLOL MALEATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8958, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TIMOLOL ((AS MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8959, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TIMOLOL ((AS MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3186, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.5, '%', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TIMOLOL MALEATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62206, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.25, '%', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62207, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.5, '%', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65975, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.25, '%', '', '', 'Y', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65976, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.50, '%', '', '', 'Y', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76384, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.5, '%', '', '', 'N', '', 'W/V.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72692, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77623, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81730, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63627, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 5, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70807, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74388, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 5, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78499, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 5, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82984, 11163, 'TIMOLOL (TIMOLOL MALEATE)', 'I', 5, 'MG', '', '', 'N', 'ML', '0.5% TIMOLOL AS TIMOLOL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18639, 11164, 'TAMOXIFEN (TAMOXIFEN CITRATE)', 'I', 20, 'MG', '', '', 'Y', '', 'Historic Freeform Text: TAMOXIFEN ((AS CITRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16663, 11164, 'TAMOXIFEN (TAMOXIFEN CITRATE)', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: TAMOXIFEN ((AS CITRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16664, 11164, 'TAMOXIFEN (TAMOXIFEN CITRATE)', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: TAMOXIFEN ((AS CITRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10790, 11164, 'TAMOXIFEN (TAMOXIFEN CITRATE)', 'I', 10, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TAMOXIFEN CITRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10791, 11164, 'TAMOXIFEN (TAMOXIFEN CITRATE)', 'I', 20, 'MG', '', '', 'Y', '', 'Historic Freeform Text: TAMOXIFEN CITRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10762, 11164, 'TAMOXIFEN (TAMOXIFEN CITRATE)', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TAMOXIFEN CITRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10664, 11164, 'TAMOXIFEN (TAMOXIFEN CITRATE)', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TAMOXIFEN CITRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60793, 11164, 'TAMOXIFEN (TAMOXIFEN CITRATE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60794, 11164, 'TAMOXIFEN (TAMOXIFEN CITRATE)', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60935, 11164, 'TAMOXIFEN (TAMOXIFEN CITRATE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60936, 11164, 'TAMOXIFEN (TAMOXIFEN CITRATE)', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16216, 11167, 'GOSERELIN (GOSERELIN ACETATE)', 'I', 3.6, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: GOSERELINE ((AS ACETATE)) QTY UNIT: IMP EQUIV TO 20%W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43433, 11167, 'GOSERELIN (GOSERELIN ACETATE)', 'I', 10.8, 'MG', '', '', 'Y', '', 'EQUIV TO 30%W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 11170, 'VITAMIN B1 (THIAMINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70202, 11170, 'VITAMIN B1 (THIAMINE MONONITRATE)', 'I', 3, 'MG', '', '', 'N', '', 'PINK TABLET A.M.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76186, 11170, 'VITAMIN B1 (THIAMINE MONONITRATE)', 'I', 3, 'MG', '', '', 'N', '', 'PINK TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66277, 11170, 'VITAMIN B1 (THIAMINE HYDROCHLORIDE)', 'I', 1.2, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22007, 11170, 'VITAMIN B1', 'I', 0.88, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: THIAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16462, 11170, 'VITAMIN B1 (THIAMINE HYDROCHLORIDE)', 'I', 0.6, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: THIAMINE ((AS HCL - VIAL 1))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9527, 11170, 'VITAMIN B1 (THIAMINE HYDROCHLORIDE)', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT B1 ((HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9372, 11170, 'VITAMIN B1', 'I', 0.88, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: THIAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5613, 11170, 'VITAMIN B1 (THIAMINE HYDROCHLORIDE)', 'I', 4.5, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: VIT. B1 ((THIAMINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 11170, 'VITAMIN B1', 'I', 10, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THIAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 11170, 'VITAMIN B1', 'I', 10, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THIAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31, 11170, 'VITAMIN B1', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: THIAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68684, 11170, 'VITAMIN B1 (THIAMINE HYDROCHLORIDE)', 'I', 0.6, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12922, 11170, 'VITAMIN B1', 'I', 1.984, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: THIAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1617, 11170, 'VITAMIN B1', 'I', 225, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: THIAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7144, 11171, 'VITAMIN B2', 'I', 3, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 11171, 'VITAMIN B2 (RIBOFLAVIN)', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70202, 11171, 'VITAMIN B2 (RIBOFLAVIN)', 'I', 3.4, 'MG', '', '', 'N', '', 'PINK TABLET A.M.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76186, 11171, 'VITAMIN B2 (RIBOFLAVIN)', 'I', 3.4, 'MG', '', '', 'N', '', 'PINK TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66277, 11171, 'VITAMIN B2 (RIBOFLAVIN-5-PHOSPHATE)', 'I', 1.4, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 11171, 'VITAMIN B2', 'I', 0.04, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22007, 11171, 'VITAMIN B2', 'I', 2.07, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19369, 11171, 'VITAMIN B2', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18602, 11171, 'VITAMIN B2', 'I', 0.111, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16462, 11171, 'VITAMIN B2 (RIBOFLAVIN-5-PHOSPHATE)', 'I', 0.72, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: RIBOFLAVIN ((AS PHOSPHATE - VIAL 1))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10470, 11171, 'VITAMIN B2 (RIBOFLAVIN 5''-PHOSPHATE SODIUM)', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT B2 ((RIBOFLAVIN-5-PHOSPHATE SOD))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9527, 11171, 'VITAMIN B2 (RIBOFLAVIN 5''-PHOSPHATE SODIUM)', 'I', 4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT B2 ((RIBOFLAVIN 5 PHOS SOD EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9372, 11171, 'VITAMIN B2', 'I', 2.07, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7179, 11171, 'VITAMIN B2', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6072, 11171, 'VITAMIN B2', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 11171, 'VITAMIN B2', 'I', 4, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6339, 11171, 'VITAMIN B2', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6341, 11171, 'VITAMIN B2', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7329, 11171, 'VITAMIN B2 (RIBOFLAVIN 5''-PHOSPHATE SODIUM)', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5613, 11171, 'VITAMIN B2 (RIBOFLAVIN-5-PHOSPHATE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: RIBOFLAVIN ((PHOSPHATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3497, 11171, 'VITAMIN B2 (RIBOFLAVIN 5''-PHOSPHATE SODIUM)', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: RIBOFLAVIN SOD PHOS ((VIT B2 EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3498, 11171, 'VITAMIN B2 (RIBOFLAVIN 5''-PHOSPHATE SODIUM)', 'I', 50, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: RIBOFLAVIN SOD. PHOS. ((VIT. B2 EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 11171, 'VITAMIN B2', 'I', 4, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 11171, 'VITAMIN B2', 'I', 4, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2871, 11171, 'VITAMIN B2 (RIBOFLAVIN 5''-PHOSPHATE SODIUM)', 'I', 30, 'MG', '', '10', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: RIBOFLAVIN 5 PHOSPHATE SODIUM ((VIT B2 EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31, 11171, 'VITAMIN B2 (RIBOFLAVIN 5''-PHOSPHATE SODIUM)', 'I', 7.5, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: RIBOFLAVIN SODIUM PHOSPHATE ((RIBOFLAVINE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68684, 11171, 'VITAMIN B2', 'I', 0.72, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 11171, 'VITAMIN B2', 'I', 1.1, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 11171, 'VITAMIN B2', 'I', 0.88, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 11171, 'VITAMIN B2', 'I', 232, 'MG', '', '', 'N', 'KG', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17121, 11171, 'VITAMIN B2', 'I', 1.28, 'G', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14119, 11171, 'VITAMIN B2', 'I', 1.28, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14113, 11171, 'VITAMIN B2', 'I', 1.122, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12922, 11171, 'VITAMIN B2', 'I', 1.984, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8101, 11171, 'VITAMIN B2', 'I', 175, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36843, 11171, 'VITAMIN B2 (RIBOFLAVIN)', 'I', 1280, 'MG', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33790, 11171, 'VITAMIN B2 (RIBOFLAVIN)', 'I', 1.6, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24471, 11171, 'VITAMIN B2', 'I', 187, 'MG', '', '170', 'N', 'G', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24400, 11171, 'VITAMIN B2', 'I', 310, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17818, 11171, 'VITAMIN B2', 'I', 1280, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18635, 11171, 'VITAMIN B2', 'I', 3, 'MG', '', '19', 'N', 'G', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 11171, 'VITAMIN B2', 'I', 1122, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14165, 11171, 'VITAMIN B2', 'I', 200, 'MG', '', '450', 'N', 'G', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14115, 11171, 'VITAMIN B2', 'I', 333, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15001, 11171, 'VITAMIN B2', 'I', 1.6, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5125, 11171, 'VITAMIN B2', 'I', 333, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3926, 11171, 'VITAMIN B2', 'I', 200, 'MG', '', '450', 'N', 'G', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1617, 11171, 'VITAMIN B2', 'I', 1110, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1613, 11171, 'VITAMIN B2', 'I', 300, 'MG', '', '454', 'N', 'G', 'Historic Freeform Text: RIBOFLAVIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72517, 11173, 'ALFENTANIL (ALFENTANIL HYDROCHLORIDE)', 'I', 500, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: ALFENTANIL HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70202, 11079, 'BETA-CAROTENE', 'I', 2700, 'UNIT', '', '', 'N', '', 'PINK TABLET A.M.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76186, 11079, 'BETA-CAROTENE', 'I', 2700, 'UNIT', '', '', 'N', '', 'PINK TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47220, 11081, 'ROPIVACAINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', 'AS THE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47225, 11081, 'ROPIVACAINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'AS THE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47216, 11081, 'ROPIVACAINE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', 'ML', 'AS THE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83320, 11081, 'ROPIVACAINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83319, 11081, 'ROPIVACAINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7337, 11083, 'PENICILLIN (PENICILLIN G PROCAINE)', 'I', 5.5, '%', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: PENICILLIN G PROCAINE ((PENICILLIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20106, 11083, 'PENICILLIN (PENICILLIN G PROCAINE)', 'I', 55, 'G', '', '', 'Y', 'KG', 'HISTORIC FREEFORM TEXT: PENICILLIN ((AS PENICILLIN G PROCAINE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66444, 11083, 'PENICILLIN (PENICILLIN G PROCAINE)', 'I', 22, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66503, 11083, 'PENICILLIN (PENICILLIN G PROCAINE)', 'I', 55, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47231, 11084, 'CISATRACURIUM (CISATRACURIUM BESYLATE)', 'I', 2, 'MG', '', '', 'N', 'ML', 'HAS 5% OVERAGE = 2.1 MG PER VIAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47339, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80417, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65469, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM)', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75263, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE MAGNESIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78496, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM SESQUIHYDRATE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77096, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM SESQUIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77097, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM SESQUIHYDRATE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77826, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77827, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79432, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM SESQUIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79433, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM SESQUIHYDRATE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78576, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM SESQUIHYDRATE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79586, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM)', 'I', 40, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79354, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM)', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79355, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM)', 'I', 40, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80197, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM)', 'I', 40, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78642, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM SESQUIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78643, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM SESQUIHYDRATE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79040, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM)', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79041, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79555, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM)', 'I', 40, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79554, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM)', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63087, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM)', 'I', 40, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77703, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM SESQUIHYDRATE)', 'I', 40, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79242, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM)', 'I', 40, 'MG', '', '', 'N', 'VIAL', 'SUPPLIED AS PANTOPRAZOLE SODIUM SESQUIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83745, 11086, 'PANTOPRAZOLE (PANTOPRAZOLE SODIUM)', 'I', 40, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47454, 11092, 'SEMDURAMICIN (SEMDURAMICIN SODIUM)', 'I', 50, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43092, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: RANITIDINE ((AS RANITIDINE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43093, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: RANITIDINE ((AS RANITIDINE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19910, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', 'Historic Freeform Text: RANITIDINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19914, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: RANITIDINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11177, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: RANITIDINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11417, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: RANITIDINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10390, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RANITIDINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10208, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RANITIDINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8482, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', 'Historic Freeform Text: RANITIDINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8483, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'Y', '', 'Historic Freeform Text: RANITIDINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9890, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'Y', '', 'Historic Freeform Text: RANITIDINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9891, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: RANITIDINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7426, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RANITIDINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7427, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: RANITIDINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49044, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49561, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61188, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62006, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67115, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RANITIDINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67116, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RANITIDINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65255, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81413, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65256, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66172, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66173, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66900, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66901, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72108, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72109, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71801, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69895, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69896, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72925, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72926, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76295, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78405, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78429, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77158, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', 'Historic Freeform Text: RANITIDINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77159, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: RANITIDINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77884, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78868, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78870, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82205, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82207, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83824, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83825, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85222, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RANITIDINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85223, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RANITIDINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43094, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: RANITIDINE ((AS RANITIDINE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43095, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: RANITIDINE ((AS RANITIDINE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66779, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76651, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74194, 11096, 'RANITIDINE (RANITIDINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47482, 11098, 'RALTITREXED (RALTITREXED DISODIUM)', 'I', 2, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42859, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMOXICILLIN ((AS AMOXICILLIN TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15903, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMOXYCILLINE TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15559, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 125, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMOXICILLIN ((AS AMOXICILLIN TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14573, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMOXICILLIN ((AS TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14574, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 400, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMOXICILLIN ((AS TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14572, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMOXICILLIN ((AS TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14571, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMOXICILLIN ((AS TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14506, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMOXICILLIN ((AS AMOXICILLIN TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15006, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMOXICILLIN ((AS TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15007, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMOXICILLIN ((AS TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15008, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMOXICILLIN ((AS TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15003, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMOXICILLIN ((AS TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11853, 11101, 'AMOXICILLIN (AMOXICILLIN)', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMOXYCILLIN TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11854, 11101, 'AMOXICILLIN (AMOXICILLIN)', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMOXYCILLIN TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11949, 11101, 'AMOXICILLIN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMOXICILLINE TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11950, 11101, 'AMOXICILLIN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMOXICILLINE TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6510, 11101, 'AMOXICILLIN (AMOXICILLIN)', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMOXICILLIN TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6403, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 400, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMOXICILLIN TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5822, 11101, 'AMOXICILLIN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMOXICILLIN TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5823, 11101, 'AMOXICILLIN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMOXICILLIN TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3264, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMOXYCILLIN TRIHYDRATE ((BASE 250MG EQ)). 287 MG IS THE STRENGTH FOR THE SAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3263, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 500, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: AMOXYCILLIN TRIHYDRATE ((BASE 500MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5191, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMOXICILLIN TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48975, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 250, 'MG', '', '', 'N', '', 'SUPPLY AS HAS BEEN CHANGED FROM AMOXICILLIN TO AMOXICILLIN TRIHYDRATE AS PER PM, AND 3011. 2002.09.2');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48976, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 500, 'MG', '', '', 'N', '', 'SUPPLY AS HAS BEEN CHANGED FROM AMOXICILLIN TO AMOXICILLIN TRIHYDRATE AS PER PM, 3011. 2002.09.23 / ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62267, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 875, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61563, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 500, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61562, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 250, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67257, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67258, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67706, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMOXYCILLINE TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69723, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 875, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71255, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 875, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72467, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 875, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74824, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74827, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81415, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78478, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78479, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78480, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78481, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81188, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81189, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 875, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80240, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 40, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80241, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 200, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80242, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 400, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80933, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80934, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80936, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80937, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83797, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 250, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: AMOXYCILLIN TRIHYDRATE 287MG ((BASE 250MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83798, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 500, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: AMOXYCILLIN TRIHYDRATE 574MG ((BASE 500MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83799, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 250, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: AMOXICILLIN ((AS AMOXICILLIN TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79178, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE)', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43574, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: AMOXICILLIN ((AS TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15208, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 125, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: AMOXYCILLINE TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15209, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 250, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: AMOXYCILLINE TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16954, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: AMOXICILLIN TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16955, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 25, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: AMOXICILLIN TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11855, 11101, 'AMOXICILLIN (AMOXICILLIN)', 'I', 250, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: AMOXYCILLIN TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11856, 11101, 'AMOXICILLIN (AMOXICILLIN)', 'I', 125, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: AMOXYCILLIN TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11951, 11101, 'AMOXICILLIN (AMOXICILLIN)', 'I', 125, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: AMOXICILLINE TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11952, 11101, 'AMOXICILLIN (AMOXICILLIN)', 'I', 250, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: AMOXICILLINE TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6511, 11101, 'AMOXICILLIN (AMOXICILLIN)', 'I', 250, 'MG', '', '5', 'Y', 'ML', 'Historic Freeform Text: AMOXICILLIN TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5824, 11101, 'AMOXICILLIN', 'I', 125, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: AMOXICILLIN TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5825, 11101, 'AMOXICILLIN', 'I', 250, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: AMOXICILLIN TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5141, 11101, 'AMOXICILLIN', 'I', 750, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: AMOXICILLIN TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3344, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 250, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: AMOXYCILLIN TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3345, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 125, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: AMOXYCILLIN TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48977, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 125, 'MG', '', '5', 'N', 'ML', 'SUPPLY AS HAS BEEN CHANGED FROM AMOXICILLIN TO AMOXICILLIN TRIHYDTRARE AS PER PM, AND 3011. 2002.09.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48978, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 250, 'MG', '', '5', 'N', 'ML', 'SUPPY AS HAS BEEN CHANGED TO AMOXICILLIN TRIHYDRATE AS PER PM, AND 3011. 2002.09.23 / AT.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50155, 11101, 'AMOXICILLIN (AMOXICILLIN)', 'I', 125, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50157, 11101, 'AMOXICILLIN (AMOXICILLIN)', 'I', 250, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62269, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 200, 'MG', '', '5', 'Y', 'ML', '2 PACKAGE SIZES: 70ML BOTTLE:  2800MG AMOXICILLIN (AS AMOXICILLIN               TRIHYDRATE)  AND  41');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62268, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 400, 'MG', '', '5', 'Y', 'ML', '2 PACKAGE SIZES: 70ML BOTTLE:  5600MG AMOXICILLIN (AS AMOXICILLIN               TRIHYDRATE)  AND  83');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67930, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 125, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67931, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 250, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68633, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 125, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: AMOXYCILLINE TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68634, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 250, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: AMOXYCILLINE TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74828, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 125, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74829, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 250, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77397, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 400, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83800, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 125, 'MG', '', '5', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: AMOXYCILLIN TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83801, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 250, 'MG', '', '5', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: AMOXYCILLIN TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83802, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 125, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: AMOXICILLIN TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83803, 11101, 'AMOXICILLIN (AMOXICILLIN TRIHYDRATE)', 'I', 250, 'MG', '', '5', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: AMOXICILLIN TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61948, 11101, 'AMOXICILLIN', 'I', 500, 'MG', '', '', 'N', 'CAP', 'UNIT = CAP.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28513, 10303, 'ACETYLCYSTEINE', 'I', 200, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ACETYLCYSTEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20133, 10303, 'ACETYLCYSTEINE', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ACETYLCYSTEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66965, 10303, 'ACETYLCYSTEINE', 'I', 200, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78573, 10303, 'ACETYLCYSTEINE', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ACETYLCYSTEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7144, 11103, 'YEAST', 'I', 2000, 'MG', '', '', 'N', '', 'AUTOLYZED YEAST EXTRACT.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18635, 11103, 'YEAST', 'I', 2, 'G', '', '19', 'N', 'G', 'Historic Freeform Text: YEAST ((AUTOLYZED YEAST EXTRACT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43116, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 4, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43117, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 8, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ONDANSETRON ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62841, 11104, 'ONDANSETRON', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62842, 11104, 'ONDANSETRON', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76400, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 4, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76401, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 8, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76411, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 4, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76412, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 8, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76418, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 4, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76419, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 8, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74341, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 4, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74342, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 8, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75976, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75977, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74947, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74948, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78168, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 4, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78169, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 8, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77362, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77363, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78319, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78320, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79776, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE)', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79777, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE)', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81057, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 8, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82995, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82996, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79919, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE)', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79920, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE)', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79079, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE)', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79080, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE)', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79177, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE)', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83152, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83158, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43137, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 2, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: ONDANSETRON ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47565, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 4, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75098, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 2, 'MG', '', '', 'N', 'ML', 'PRESERVATIVE-FREE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75099, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76501, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76502, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75730, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75731, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75987, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75988, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78432, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 2.00, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77733, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 4, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80811, 11104, 'ONDANSETRON (ONDANSETRON HYDROCHLORIDE DIHYDRATE)', 'I', 2.00, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10828, 11108, 'PRAZOSIN (PRAZOSIN HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PRAZOSIN HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10829, 11108, 'PRAZOSIN (PRAZOSIN HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: PRAZOSIN HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10830, 11108, 'PRAZOSIN (PRAZOSIN HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PRAZOSIN HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5359, 11108, 'PRAZOSIN (PRAZOSIN HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: PRAZOSIN HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5357, 11108, 'PRAZOSIN (PRAZOSIN HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: PRAZOSIN HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5358, 11108, 'PRAZOSIN (PRAZOSIN HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PRAZOSIN HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70742, 11114, 'VALACYCLOVIR (VALACYCLOVIR HYDROCHLORIDE)', 'I', 1, 'G', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20218, 11114, 'VALACYCLOVIR (VALACYCLOVIR HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: VALACYCLOVIR ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78376, 11114, 'VALACYCLOVIR (VALACYCLOVIR HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78118, 11114, 'VALACYCLOVIR (VALACYCLOVIR HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79359, 11114, 'VALACYCLOVIR (VALACYCLOVIR HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79360, 11114, 'VALACYCLOVIR (VALACYCLOVIR HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80195, 11114, 'VALACYCLOVIR (VALACYCLOVIR HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81743, 11114, 'VALACYCLOVIR (VALACYCLOVIR HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80073, 11114, 'VALACYCLOVIR (VALACYCLOVIR HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83683, 11114, 'VALACYCLOVIR (VALACYCLOVIR HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83684, 11114, 'VALACYCLOVIR (VALACYCLOVIR HYDROCHLORIDE)', 'I', 1000, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47871, 11115, 'INSULIN LISPRO', 'I', 100, 'UNIT', '', '', 'N', 'ML', 'RDNA ORIGIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47872, 11115, 'INSULIN LISPRO', 'I', 100, 'UNIT', '', '', 'N', 'ML', 'RDNA ORIGIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63832, 11115, 'INSULIN LISPRO', 'I', 25, 'UNIT', '', '', 'N', 'ML', '100 UNITS/ML: 25% INSULIN LISPRO INJECTION, 75% INSULIN LISPRO PROTAMINE SUSPENSION (RDNA ORIGIN).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63835, 11115, 'INSULIN LISPRO', 'I', 50, 'UNIT', '', '', 'N', 'ML', '100 UNITS/ML: 50% INSULIN LISPRO INJECTION, 50% INSULIN LISPRO PROTAMINE SUSPENSION (RDNA ORIGIN).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9420, 7996, 'TRIFLUOPERAZINE (TRIFLUOPERAZINE HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'Y', '', 'Historic Freeform Text: TRIFLUOPERAZINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9421, 7996, 'TRIFLUOPERAZINE (TRIFLUOPERAZINE HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'Y', '', 'Historic Freeform Text: TRIFLUOPERAZINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9350, 7996, 'TRIFLUOPERAZINE (TRIFLUOPERAZINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TRIFLUOPERAZINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5732, 7996, 'TRIFLUOPERAZINE (TRIFLUOPERAZINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TRIFLUOPERAZINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2308, 7996, 'TRIFLUOPERAZINE (TRIFLUOPERAZINE HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'Y', '', 'PREVIOUSLY INPUT AS TRIFLUOPERAZINE HCL 1.18MG  HISTORIC FREEFORM TEXT: TRIFLUOPERAZINE HCL ((EQ TO ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2300, 7996, 'TRIFLUOPERAZINE (TRIFLUOPERAZINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', 'PREVIOUSLY ENTERED AS TRIFLUOPERAZINE HCL 11.78MG  HISTORIC FREEFORM TEXT: TRIFLUOPERAZINE ((AS 10MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2209, 7996, 'TRIFLUOPERAZINE (TRIFLUOPERAZINE HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'Y', '', 'PREVIOUSLY ENTERED AS TRIFLUOPERAZINE HCL 5.89MG  HISTORIC FREEFORM TEXT: TRIFLUOPERAZINE HCL ((BASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2210, 7996, 'TRIFLUOPERAZINE (TRIFLUOPERAZINE HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'Y', '', 'PREVIOUSLY ENTERED AS TRIFLUOPERAZINE HCL 2.36MG  HISTORIC FREEFORM TEXT: TRIFLUOPERAZINE HCL ((BASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9416, 7996, 'TRIFLUOPERAZINE (TRIFLUOPERAZINE HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: TRIFLUOPERAZINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8564, 7996, 'TRIFLUOPERAZINE (TRIFLUOPERAZINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: TRIFLUOPERAZINE HCL ((BASE 10MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1303, 7997, 'TRIFLUOPERAZINE HYDROCHLORIDE', 'I', 2.36, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIFLUOPERAZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75387, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1304, 7997, 'TRIFLUOPERAZINE HYDROCHLORIDE', 'I', 5.9, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIFLUOPERAZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1305, 7997, 'TRIFLUOPERAZINE HYDROCHLORIDE', 'I', 11.8, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRIFLUOPERAZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12437, 7999, 'THIOPROPERAZINE (THIOPROPERAZINE MESYLATE)', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: THIOPROPERAZINE MESYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8219, 8003, 'PERPHENAZINE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: PERPHENAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8214, 8003, 'PERPHENAZINE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: PERPHENAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8215, 8003, 'PERPHENAZINE', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: PERPHENAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8216, 8003, 'PERPHENAZINE', 'I', 16, 'MG', '', '', 'N', '', 'Historic Freeform Text: PERPHENAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5717, 8003, 'PERPHENAZINE', 'I', 3, 'MG', '', '', 'N', '', 'Historic Freeform Text: PERPHENAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5726, 8003, 'PERPHENAZINE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: PERPHENAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5727, 8003, 'PERPHENAZINE', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: PERPHENAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2365, 8003, 'PERPHENAZINE', 'I', 16, 'MG', '', '', 'N', '', 'Historic Freeform Text: PERPHENAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2366, 8003, 'PERPHENAZINE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: PERPHENAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2367, 8003, 'PERPHENAZINE', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: PERPHENAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2368, 8003, 'PERPHENAZINE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: PERPHENAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8565, 8003, 'PERPHENAZINE', 'I', 3.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PERPHENAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16523, 8007, 'FLUPHENAZINE DECANOATE', 'I', 25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FLUPHENAZINE DECANOATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10488, 8007, 'FLUPHENAZINE DECANOATE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FLUPHENAZINE DECANOATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63107, 8007, 'FLUPHENAZINE DECANOATE', 'I', 25, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65598, 8007, 'FLUPHENAZINE DECANOATE', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66341, 8007, 'FLUPHENAZINE DECANOATE', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68128, 8007, 'FLUPHENAZINE DECANOATE', 'I', 25, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5368, 7952, 'PROMETHAZINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROMETHAZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5369, 7952, 'PROMETHAZINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROMETHAZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5721, 7952, 'PROMETHAZINE HYDROCHLORIDE', 'I', 10, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PROMETHAZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17003, 7954, 'PROMETHAZINE (PROMETHAZINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PROMETHAZINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5089, 7954, 'PROMETHAZINE (PROMETHAZINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PROMETHAZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1079, 7960, 'TRIMEPRAZINE TARTRATE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIMEPRAZINE TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12419, 7961, 'TRIMEPRAZINE (TRIMEPRAZINE TARTRATE)', 'I', 2.5, 'MG', '', '', 'Y', '', 'Historic Freeform Text: TRIMEPRAZINE TARTRAT ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12651, 7961, 'TRIMEPRAZINE (TRIMEPRAZINE TARTRATE)', 'I', 5, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TRIMEPRAZINE TARTRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9508, 7972, 'AZAPERONE', 'I', 40, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: AZAPERONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49960, 7918, 'RABIES IMMUNE GLOBULIN HUMAN', 'I', 150, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60651, 7918, 'RABIES IMMUNE GLOBULIN HUMAN', 'I', 150, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69061, 7920, 'MENINGOCOCCAL POLYSACCHARIDE VACCINE GRP C', 'I', 10, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49957, 7931, 'TETANUS IMMUNE GLOBULIN (HUMAN)', 'I', 250, 'UNIT', '', '', 'N', 'DOSE', 'SOLVENT/DETERGENT TREATED.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4109, 7934, 'TETANUS TOXOID ADSORBED', 'I', 5, 'LF', '', '0.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: TETANUS TOXOID ADSORBED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79806, 7934, 'TETANUS TOXOID ADSORBED', 'I', 5.0, 'LF', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73878, 7934, 'TETANUS TOXOID ADSORBED', 'I', 40, 'µG', '', '0.5', 'N', 'ML', 'TETANUS TOXOID 20-40 µG CONJUGATED TO 10 µG OF ADSORBED PURIFIED CAPSULAR POLYSACCHARIDE OF HAEMOPHI');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43396, 7935, 'TETANUS TOXOID', 'I', 5, 'LF', '', '0.5', 'N', 'ML', 'Historic Freeform Text: TETANUS TOXOID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5907, 7935, 'TETANUS TOXOID', 'I', 5, 'LF', '', '0.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: TETANUS TOXOID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50651, 7935, 'TETANUS TOXOID', 'I', 5, 'LF', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50224, 7935, 'TETANUS TOXOID', 'I', 5, 'LF', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63789, 7935, 'TETANUS TOXOID', 'I', 5, 'LF', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67042, 7935, 'TETANUS TOXOID', 'I', 5, 'LF', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73878, 7935, 'TETANUS TOXOID', 'I', 10, 'LF', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83726, 7935, 'TETANUS TOXOID', 'I', 5, 'LF', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69061, 7935, 'TETANUS TOXOID', 'I', 20, 'µG', '', '0.5', 'N', 'ML', 'QUANTITY VARIES FROM 10 TO 20 MCG PER DOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71860, 7935, 'TETANUS TOXOID', 'I', 20, 'UNIT', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4109, 7940, 'DIPHTHERIA TOXOID ADSORBED', 'I', 2, 'LF', '', '0.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DIPHTHERIA TOXOID ADSORBED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79806, 7940, 'DIPHTHERIA TOXOID ADSORBED', 'I', 2.5, 'LF', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43396, 7941, 'DIPHTHERIA TOXOID', 'I', 15, 'LF', '', '0.5', 'N', 'ML', 'Historic Freeform Text: DIPHTHERIA TOXOID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5907, 7941, 'DIPHTHERIA TOXOID', 'I', 2, 'LF', '', '0.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DIPHTHERIA TOXOID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50651, 7941, 'DIPHTHERIA TOXOID', 'I', 15, 'LF', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50224, 7941, 'DIPHTHERIA TOXOID', 'I', 15, 'LF', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63789, 7941, 'DIPHTHERIA TOXOID', 'I', 2, 'LF', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67042, 7941, 'DIPHTHERIA TOXOID', 'I', 15, 'LF', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73878, 7941, 'DIPHTHERIA TOXOID', 'I', 25, 'LF', '', '0.5', 'N', 'ML', 'IU(LF)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83726, 7941, 'DIPHTHERIA TOXOID', 'I', 2, 'LF', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71860, 7941, 'DIPHTHERIA TOXOID', 'I', 2, 'UNIT', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2059, 7944, 'PIMOZIDE', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: PIMOZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2058, 7944, 'PIMOZIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: PIMOZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63316, 7944, 'PIMOZIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63317, 7944, 'PIMOZIDE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69484, 7944, 'PIMOZIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69485, 7944, 'PIMOZIDE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19356, 5917, 'BRETYLIUM TOSYLATE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: BRETYLIUM TOSYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18418, 5920, 'INDOCYANINE GREEN', 'I', 25, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10713, 5922, 'BENZTROPINE MESYLATE', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: BENZTROPINE METHANESULFONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8060, 5922, 'BENZTROPINE MESYLATE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: BENZTROPINE METHANESULFONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5724, 5922, 'BENZTROPINE MESYLATE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: BENZTROPINE METHANESULFONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3003, 5922, 'BENZTROPINE MESYLATE', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZTROPINE METHANESULFONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37223, 5922, 'BENZTROPINE MESYLATE', 'I', 0.4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: BENZTROPINE MESYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62344, 5922, 'BENZTROPINE MESYLATE', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79099, 5935, 'CARVACROL', 'I', 2.37, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81942, 5935, 'CARVACROL', 'I', 0.02, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84667, 5935, 'CARVACROL', 'I', 0.02, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85436, 5935, 'CARVACROL', 'I', 0.02, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81943, 5935, 'CARVACROL', 'I', 2.37, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84544, 5935, 'CARVACROL', 'I', 2.37, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19033, 5937, 'PYRAZINAMIDE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: PYRAZINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6130, 5937, 'PYRAZINAMIDE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: PYRAZINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1828, 5937, 'PYRAZINAMIDE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: PYRAZINAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15231, 5882, 'TRANYLCYPROMINE (TRANYLCYPROMINE SULFATE)', 'I', 10, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TRANYLCYPROMINE SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19624, 5883, 'CHLORZOXAZONE', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORZOXAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11427, 5883, 'CHLORZOXAZONE', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORZOXAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11339, 5883, 'CHLORZOXAZONE', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORZOXAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44267, 5895, 'VINCRISTINE SULFATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VINCRISTINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19756, 5895, 'VINCRISTINE SULFATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VINCRISTINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18602, 5898, 'PIPRADROL HYDROCHLORIDE', 'I', 0.044, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PIPRADROL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44263, 5900, 'METHOTREXATE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHOTREXATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44161, 5900, 'METHOTREXATE (METHOTREXATE SODIUM)', 'I', 2.5, 'MG', '', '', 'Y', '', 'Historic Freeform Text: METHOTREXATE ((AS METHOTREXATE SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42842, 5900, 'METHOTREXATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHOTREXATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68788, 5900, 'METHOTREXATE (METHOTREXATE SODIUM)', 'I', 2.5, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: METHOTREXATE ((AS METHOTREXATE SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44264, 5900, 'METHOTREXATE (METHOTREXATE SODIUM)', 'I', 25, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: METHOTREXATE ((AS METHOTREXATE SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44261, 5900, 'METHOTREXATE (METHOTREXATE SODIUM)', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: METHOTREXATE ((AS METHOTREXATE SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44262, 5900, 'METHOTREXATE (METHOTREXATE SODIUM)', 'I', 25, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: METHOTREXATE ((AS METHOTREXATE SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42844, 5900, 'METHOTREXATE (METHOTREXATE SODIUM)', 'I', 25, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: METHOTREXATE ((AS METHOTREXATE SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19681, 5900, 'METHOTREXATE (METHOTREXATE SODIUM)', 'I', 25, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: METHOTREXATE ((AS METHOTREXATE SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80549, 5900, 'METHOTREXATE (METHOTREXATE SODIUM)', 'I', 7.5, 'MG', '', '0.75', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80550, 5900, 'METHOTREXATE (METHOTREXATE SODIUM)', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80551, 5900, 'METHOTREXATE (METHOTREXATE SODIUM)', 'I', 15, 'MG', '', '1.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80552, 5900, 'METHOTREXATE (METHOTREXATE SODIUM)', 'I', 25, 'MG', '', '2.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79004, 5900, 'METHOTREXATE (METHOTREXATE SODIUM)', 'I', 20, 'MG', '', '2', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7153, 5904, 'DOMIPHEN BROMIDE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: DOMIPHEN BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69999, 5863, 'METHAZOLAMIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41683, 5869, 'XYLOMETAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41684, 5869, 'XYLOMETAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36767, 5869, 'XYLOMETAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15478, 5869, 'XYLOMETAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: XYLOMETAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11904, 5869, 'XYLOMETAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: XYLOMETAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11887, 5869, 'XYLOMETAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: XYLOMETAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51892, 5869, 'XYLOMETAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62307, 5869, 'XYLOMETAZOLINE HYDROCHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65399, 5869, 'XYLOMETAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '0.1% W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70147, 5869, 'XYLOMETAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: XYLOMETAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70149, 5869, 'XYLOMETAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '0.1% W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73579, 5869, 'XYLOMETAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73580, 5869, 'XYLOMETAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78557, 5869, 'XYLOMETAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: XYLOMETAZOLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81710, 5869, 'XYLOMETAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78558, 5869, 'XYLOMETAZOLINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (623, 5798, 'FURFURAL', 'I', 0.58, '%', '', '', 'N', '', 'Historic Freeform Text: FURFURAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1593, 5798, 'FURFURAL', 'I', 0.96, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FURFURAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14119, 5820, 'MAGNESIUM CITRATE', 'I', 6.5, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: MAGNESIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2645, 5821, 'ALUMINUM CHLORIDE', 'I', 25, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: ALUMINUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3189, 3671, 'BILE SALTS', 'I', 65, 'MG', '', '', 'N', '', 'Historic Freeform Text: BILE SALTS ((AS MIXED CONJUGATED))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5276, 3671, 'BILE SALTS', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: BILE SALTS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2493, 3701, 'SODIUM ORTHO-PHENYLPHENATE', 'I', 3.1, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL SODIUM SALT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2494, 3701, 'SODIUM ORTHO-PHENYLPHENATE', 'I', 3.1, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL SODIUM SALT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2495, 3701, 'SODIUM ORTHO-PHENYLPHENATE', 'I', 3.1, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL SODIUM SALT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80107, 3610, 'CAPSAICIN', 'I', 0.035, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50027, 3611, 'CAPSICUM OLEORESIN', 'I', 0.05, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2842, 3611, 'CAPSICUM OLEORESIN', 'I', 0.05, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4553, 3557, 'CLOVE OIL', 'I', 2.7, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: OIL OF CLOVE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1291, 3557, 'CLOVE OIL', 'I', 63.4, 'ML', '', '100', 'N', 'ML', 'Historic Freeform Text: OIL OF CLOVE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48860, 3562, 'PEPPERMINT OIL', 'I', 0.10, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3829, 3578, 'PINE OIL', 'I', 1.87, '%', '', '', 'N', '', 'Historic Freeform Text: PINE OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (621, 3578, 'PINE OIL', 'I', 15, '%', '', '', 'N', '', 'Historic Freeform Text: PINE OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69615, 3578, 'PINE OIL', 'I', 15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71718, 3578, 'PINE OIL', 'I', 15, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70553, 3578, 'PINE OIL', 'I', 2.50, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76448, 3578, 'PINE OIL', 'I', 8.7, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80032, 3578, 'PINE OIL', 'I', 8.7, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4161, 3578, 'PINE OIL', 'I', 7.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PINE OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5348, 3510, 'OIL OF TURPENTINE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: OIL OF TURPENTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3621, 3510, 'OIL OF TURPENTINE', 'I', 6, '%', '', '', 'N', '%', 'Historic Freeform Text: OIL OF TURPENTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6694, 3510, 'OIL OF TURPENTINE', 'I', 0.05, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: OIL OF TURPENTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5167, 3510, 'OIL OF TURPENTINE', 'I', 79.1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: OIL OF TURPENTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2842, 3510, 'OIL OF TURPENTINE', 'I', 125, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1103, 3510, 'OIL OF TURPENTINE', 'I', 1.1, 'ML', '', '11', 'N', 'ML', 'HISTORIC FREEFORM TEXT: OIL OF TURPENTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2443, 3510, 'OIL OF TURPENTINE', 'I', 1.92, 'KG', '', '4.8', 'N', 'KG', 'Historic Freeform Text: OIL OF TURPENTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18611, 10123, 'DROPERIDOL', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DROPERIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13558, 10126, 'INDOMETHACIN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDOMETHACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11166, 10126, 'INDOMETHACIN', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDOMETHACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11160, 10126, 'INDOMETHACIN', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDOMETHACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6558, 10126, 'INDOMETHACIN', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDOMETHACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 897, 'L-TYROSINE', 'I', 0.15, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6559, 10126, 'INDOMETHACIN', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDOMETHACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5918, 10126, 'INDOMETHACIN', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDOMETHACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5919, 10126, 'INDOMETHACIN', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDOMETHACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4129, 10126, 'INDOMETHACIN', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDOMETHACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4130, 10126, 'INDOMETHACIN', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDOMETHACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51232, 10126, 'INDOMETHACIN', 'I', 50, 'MG', '', '', 'N', 'SUP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51233, 10126, 'INDOMETHACIN', 'I', 100, 'MG', '', '', 'N', 'SUP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6040, 10126, 'INDOMETHACIN (SODIUM INDOMETHACIN)', 'I', 1, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: INDOMETHACIN SOD TRIHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19750, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19751, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20305, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17780, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16123, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16124, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16579, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14933, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14934, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14935, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14936, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14937, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7349, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6685, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3810, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3811, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3812, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4254, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4255, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4256, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5307, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5308, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5309, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5310, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4071, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43431, 10127, 'PROPRANOLOL HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PROPRANOLOL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1192, 10128, 'AZATHIOPRINE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AZATHIOPRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50821, 10128, 'AZATHIOPRINE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60109, 10128, 'AZATHIOPRINE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67279, 10128, 'AZATHIOPRINE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66740, 10128, 'AZATHIOPRINE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82849, 10128, 'AZATHIOPRINE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68893, 10128, 'AZATHIOPRINE (AZATHIOPRINE SODIUM)', 'I', 50, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: AZATHIOPRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37570, 10131, 'DIATRIZOATE MEGLUMINE', 'I', 66, '%', '', '', 'N', '', 'Historic Freeform Text: MEGLUMINE DIATRIZOATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37573, 10131, 'DIATRIZOATE MEGLUMINE', 'I', 52.7, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: MEGLUMINE DIATRIZOATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3453, 10140, 'HYDROXYUREA', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROXYUREA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66754, 10140, 'HYDROXYUREA', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72247, 10140, 'HYDROXYUREA', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82857, 10140, 'HYDROXYUREA', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43371, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METFORMIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18835, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', 'Historic Freeform Text: METFORMIN HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18416, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: METFORMIN HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19231, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: METFORMIN HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18058, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: METFORMIN HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17104, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: METFORMIN HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15115, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: METFORMIN HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47421, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47422, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47631, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48078, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49444, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48453, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METFORMIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62536, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62674, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66363, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66533, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66606, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66616, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66617, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66769, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66814, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71020, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71021, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71193, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METFORMIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71194, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71322, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71323, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71324, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72791, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 1000, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72792, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 1000, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75444, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75445, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74296, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74297, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77033, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77034, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78575, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 1000, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81954, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81955, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81956, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 1000, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80042, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80043, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METFORMIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83857, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83858, 10147, 'METFORMIN HYDROCHLORIDE', 'I', 850, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18900, 10103, 'HYDROCHLORIC ACID', 'I', 36.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROCHLORIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3456, 10103, 'HYDROCHLORIC ACID', 'I', 0.4, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCHLORIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76446, 10103, 'HYDROCHLORIC ACID', 'I', 10.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74298, 10103, 'HYDROCHLORIC ACID', 'I', 23.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74536, 10103, 'HYDROCHLORIC ACID', 'I', 9.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75753, 10103, 'HYDROCHLORIC ACID', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77549, 10103, 'HYDROCHLORIC ACID', 'I', 9.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79867, 10103, 'HYDROCHLORIC ACID', 'I', 9.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78665, 10103, 'HYDROCHLORIC ACID', 'I', 9.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76110, 10103, 'HYDROCHLORIC ACID', 'I', 9.5, '%', '', '', 'N', 'W/V', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20200, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20028, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20017, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20018, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16754, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16755, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16756, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15585, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11174, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 897, 'L-TYROSINE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11175, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11534, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10807, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9264, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9731, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9732, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10034, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9940, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51052, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51053, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61148, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61286, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61287, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61488, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', 'FORM = FILM COATED TABLET, CONTAINING 4MG TRANDOLAPRIL IN AN IMMEDIATE RELEASE FORM AND 240MG VERAPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61673, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64537, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', 'FORM = FILM COATED TABLET, CONTAINING 2MG TRANDOLAPRIL IN AN IMMEDIATE RELEASE FORM AND 240MG VERAPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63861, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71120, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71121, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71122, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72404, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73465, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80963, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80964, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78885, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79822, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18614, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17234, 10110, 'VERAPAMIL HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VERAPAMIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (783, 10039, 'THIOTHIXENE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: THIOTHIXENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (784, 10039, 'THIOTHIXENE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: THIOTHIXENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (785, 10039, 'THIOTHIXENE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: THIOTHIXENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43291, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXYBUTYNIN CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43268, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXYBUTYNIN CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18355, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXYBUTYNIN CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18073, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXYBUTYNIN CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49219, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50065, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64119, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYBUTYNIN CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64120, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYBUTYNIN CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65784, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64895, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYBUTYNIN CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67903, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67904, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69943, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYBUTYNIN CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74619, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYBUTYNIN CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75905, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75906, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78474, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83545, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43358, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: OXYBUTYNIN CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50373, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74620, 10040, 'OXYBUTYNIN CHLORIDE', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: OXYBUTYNIN CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37068, 10043, 'ETHYLENE OXIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: ETHYLENE OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27931, 10043, 'ETHYLENE OXIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: ETHYLENE OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27932, 10043, 'ETHYLENE OXIDE', 'I', 8.6, '%', '', '', 'N', '', 'Historic Freeform Text: ETHYLENE OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27366, 10043, 'ETHYLENE OXIDE', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: ETHYLENE OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19413, 10043, 'ETHYLENE OXIDE', 'I', 100, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHYLENE OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62746, 10043, 'ETHYLENE OXIDE', 'I', 100, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65825, 10043, 'ETHYLENE OXIDE', 'I', 10.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66070, 10043, 'ETHYLENE OXIDE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74114, 10043, 'ETHYLENE OXIDE', 'I', 8.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2791, 10052, 'SELENIUM SULFIDE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: SELENIUM DISULFIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48143, 10068, 'CHLORAL HYDRATE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORAL HYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10976, 10068, 'CHLORAL HYDRATE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHLORAL HYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71882, 10068, 'CHLORAL HYDRATE', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CHLORAL HYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6245, 9999, 'POTASSIUM P-AMINOBENZOATE', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: POTASSIUM P-AMINOBENZOATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6246, 9999, 'POTASSIUM P-AMINOBENZOATE', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: POTASSIUM P-AMINOBENZOATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7024, 9999, 'POTASSIUM P-AMINOBENZOATE', 'I', 2, 'G', '', '', 'N', 'PCK', 'Historic Freeform Text: POTASSIUM P-AMINOBENZOATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1598, 10002, 'MEFENAMIC ACID', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MEFENAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47492, 10002, 'MEFENAMIC ACID', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47338, 10002, 'MEFENAMIC ACID', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50515, 10002, 'MEFENAMIC ACID', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61185, 10002, 'MEFENAMIC ACID', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4088, 10005, 'PECTIN', 'I', 162, 'MG', '', '', 'N', '', 'Historic Freeform Text: PECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2005, 10005, 'PECTIN', 'I', 260, 'MG', '', '', 'N', '', 'Historic Freeform Text: PECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2587, 10005, 'PECTIN', 'I', 32.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1612, 10005, 'PECTIN', 'I', 260, 'MG', '', '', 'N', '', 'Historic Freeform Text: PECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (753, 10005, 'PECTIN', 'I', 65, 'MG', '', '', 'N', '', 'Historic Freeform Text: PECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42486, 10005, 'PECTIN', 'I', 13.3, '%', '', '', 'N', '', 'Historic Freeform Text: PECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1993, 10005, 'PECTIN', 'I', 8, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1766, 10005, 'PECTIN', 'I', 8, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78861, 10005, 'PECTIN', 'I', 4.53, 'MG', '', '', 'N', 'ML', '0.42% W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12206, 10006, 'PIPERAZINE (PIPERAZINE CITRATE)', 'I', 140, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PIPERAZINE CITRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8110, 10006, 'PIPERAZINE (PIPERAZINE ADIPATE)', 'I', 110, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PIPERAZINE ADIPATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50230, 10006, 'PIPERAZINE (PIPERAZINE CITRATE)', 'I', 160, 'MG', '', '', 'N', '', 'PINK TABLET. SUBMISSION 130047. ACTIVE INGREDIENT REVISED FROM PIPERAZINE 400 MG TO PIPERAZINE 160MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50331, 10006, 'PIPERAZINE (PIPERAZINE CITRATE)', 'I', 50, 'MG', '', '', 'N', '', 'PINK TABLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63927, 10006, 'PIPERAZINE (PIPERAZINE CITRATE)', 'I', 140, 'MG', '', '', 'N', '', 'Historic Freeform Text: PIPERAZINE CITRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1996, 10006, 'PIPERAZINE (PIPERAZINE HYDROCHLORIDE)', 'I', 53, '%', '', '', 'Y', '', 'Historic Freeform Text: PIPERAZINE HYDROCHLORIDE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1992, 10006, 'PIPERAZINE (PIPERAZINE HYDROBROMIDE)', 'I', 34, '%', '', '', 'Y', '%', 'Historic Freeform Text: PIPERAZINE MONOHYDROCHLORIDE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37422, 10006, 'PIPERAZINE (PIPERAZINE SULFATE)', 'I', 34, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PIPERAZINE ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3228, 10006, 'PIPERAZINE', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PIPERAZINE ((AS HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62998, 10006, 'PIPERAZINE (PIPERAZINE CITRATE)', 'I', 250, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 10009, 'PROTEIN HYDROLYSATES', 'I', 12, 'G', '', '', 'N', '', 'Historic Freeform Text: PROTEIN HYDROLYZATES');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11852, 10010, 'NEOSTIGMINE METHYLSULFATE', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NEOSTIGMINE METHYLSULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11131, 10010, 'NEOSTIGMINE METHYLSULFATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NEOSTIGMINE METHYLSULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11095, 10010, 'NEOSTIGMINE METHYLSULFATE', 'I', 0.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NEOSTIGMINE METHYLSULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10876, 10010, 'NEOSTIGMINE METHYLSULFATE', 'I', 0.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NEOSTIGMINE METHYLSULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10877, 10010, 'NEOSTIGMINE METHYLSULFATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NEOSTIGMINE METHYLSULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49701, 10010, 'NEOSTIGMINE METHYLSULFATE', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49702, 10010, 'NEOSTIGMINE METHYLSULFATE', 'I', 0.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62666, 7897, 'RUBELLA VIRUS VACCINE LIVE ATTENUATED WISTAR RA27/3 STRAIN', 'I', 1000, 'UNIT', '', '0.5', 'N', 'ML', 'RUBELLA VIRUS VACCINE LIVE ATTENUATED:  WISTAR RA 27/3         STRAIN >= 10 TO THE POWER OF 3.0 CCID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3569, 7897, 'RUBELLA VIRUS VACCINE LIVE ATTENUATED WISTAR RA27/3 STRAIN', 'I', 1000, 'UNIT', '', '0.5', 'N', 'ML', 'UNIT=CCID50');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78322, 7897, 'RUBELLA VIRUS VACCINE LIVE ATTENUATED WISTAR RA27/3 STRAIN', 'I', 1000, 'UNIT', '', '0.5', 'N', 'ML', 'RUBELLA VIRUS VACCINE LIVE ATTENUATED:  WISTAR RA 27/3         STRAIN >= 10 TO THE POWER OF 3.0 CCID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2964, 7903, 'YELLOW FEVER VACCINE', 'I', 109648, 'PFU', '', '0.5', 'N', 'ML', 'PFU (PLAQUE-FORMING UNITS) STRENGTH UPDATED TO 109648PFU/0.5ML AS PER BGTD, ALSO EQUIV. TO NLT 5.04 ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62666, 7908, 'MEASLES VIRUS VACCINE LIVE ATTENUATED', 'I', 1000, 'UNIT', '', '0.5', 'N', 'ML', 'MEASLES VIRUS VACCINE LIVE ATTENUATED:   SCHWARZ STRAIN >=  10 TO THE POWER OF 3.0 CCID SUBSCRIPT 50');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3569, 7908, 'MEASLES VIRUS VACCINE LIVE ATTENUATED', 'I', 1000, 'UNIT', '', '0.5', 'N', 'ML', 'UNIT=CCID50');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78322, 7908, 'MEASLES VIRUS VACCINE LIVE ATTENUATED', 'I', 1000, 'UNIT', '', '0.5', 'N', 'ML', 'MEASLES VIRUS VACCINE LIVE ATTENUATED:   SCHWARZ STRAIN >=  10 TO THE POWER OF 3.0 CCID SUBSCRIPT 50');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (663, 7826, 'BOTULINUM ANTITOXIN', 'I', 5000, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: BOTULINUM ANTITOXIN ((TYPE E)) -UNIT IS IU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13630, 7832, 'TYPHOID VACCINE (SALMONELLA TYPHI TY21A)', 'I', 10, 'B', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TYPHOID VACCINE ((SALMONELLA TYPHI 2-6B CFU))  ADDITIONAL INFO FROM DPIF DAT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50867, 7832, 'TYPHOID VACCINE (SALMONELLA TYPHI TY21A)', 'I', 10, 'B', '', '', 'N', 'PCK', 'TYPHOID VACCINE (SALMONELLA TYPHI  2-10B CFU/SACHET).  ADDITIONAL INFO FROM DPIF DATED 2005-1-24 VIA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67247, 7852, 'VARICELLA ZOSTER IMMUNE GLOBULIN HUMAN', 'I', 125, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13140, 7795, 'HAEMOPHILUS INFLUENZAE TYPE B-PRP', 'I', 10, 'µG', '', '0.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POLYRIBOSE RIBITAL PHOSPHATE POLYSACCHARIDE (PRP) 10 MCG PER SINGLE-DOSE VIA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50651, 7795, 'HAEMOPHILUS INFLUENZAE TYPE B-PRP', 'I', 10, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59709, 7795, 'HAEMOPHILUS INFLUENZAE TYPE B-PRP', 'I', 7.5, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67042, 7795, 'HAEMOPHILUS INFLUENZAE TYPE B-PRP', 'I', 10, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73878, 7795, 'HAEMOPHILUS INFLUENZAE TYPE B-PRP', 'I', 10, 'µG', '', '0.5', 'N', 'ML', '10 µG OF ADSORBED PURIFIED CAPSULAR POLYSACCHARIDE OF HAEMOPHILUS INFLUENZAE TYPE B (HIB) (PRP) COVA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12398, 5759, 'SODIUM DICHLOROISOCYANURATE', 'I', 2.5, 'G', '', '', 'N', '', 'Historic Freeform Text: SODIUM TROCLOSENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12399, 5759, 'SODIUM DICHLOROISOCYANURATE', 'I', 5, 'G', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM TROCLOSENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12400, 5759, 'SODIUM DICHLOROISOCYANURATE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: SODIUM TROCLOSENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8505, 5759, 'SODIUM DICHLOROISOCYANURATE', 'I', 55, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM TROCLOSENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4791, 5759, 'SODIUM DICHLOROISOCYANURATE', 'I', 26.5, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM TROCLOSENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4191, 5759, 'SODIUM DICHLOROISOCYANURATE', 'I', 25.8, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM TROCLOSENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71548, 5759, 'SODIUM DICHLOROISOCYANURATE', 'I', 5, '%', '', '', 'N', '', 'AVAILABLE CHLORINE: 3.1%. ACTIVE INGREDIENT SWITCHED FROM CHLORINE TO SODIUM DICHLOROISOCYANURATE 5.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75119, 5759, 'SODIUM DICHLOROISOCYANURATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76528, 5759, 'SODIUM DICHLOROISOCYANURATE', 'I', 7.0, '%', '', '', 'N', '', 'SODIUM DICHLOROISOCYANURATE DIHYDRATE-PROVIDES CHLORINE DIOXIDE IN SOLUTION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75485, 5759, 'SODIUM DICHLOROISOCYANURATE', 'I', 1.2, '%', '', '', 'N', '', 'AS DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61905, 5784, 'STANDARDIZED ORCHARD GRASS POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '100,000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61906, 5784, 'STANDARDIZED ORCHARD GRASS POLLEN', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '10,000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66463, 5784, 'STANDARDIZED ORCHARD GRASS POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '(DACTYLIS GLOMERATA). 100000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81086, 5784, 'STANDARDIZED ORCHARD GRASS POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '100000 BAU/ML (BAU STANDS FOR BIOEQUIVALENT ALLERGY UNIT)./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81091, 5784, 'STANDARDIZED ORCHARD GRASS POLLEN', 'I', 25000, 'UNIT', '', '', 'N', 'ML', '25000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81092, 5784, 'STANDARDIZED ORCHARD GRASS POLLEN', 'I', 20000, 'UNIT', '', '', 'N', 'ML', '20000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61914, 5788, 'SWEET VERNAL GRASS', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '10,000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61913, 5788, 'SWEET VERNAL GRASS', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '100,000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66457, 5788, 'SWEET VERNAL GRASS', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '(ANTHOXANTHUM ODORATUM). 100000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81083, 5790, 'STANDARDIZED JUNE GRASS POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '100000 BAU/ML (BAU STANDS FOR BIOEQUIVALENT ALLERGY UNIT)./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81091, 5790, 'STANDARDIZED JUNE GRASS POLLEN', 'I', 25000, 'UNIT', '', '', 'N', 'ML', '25000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81092, 5790, 'STANDARDIZED JUNE GRASS POLLEN', 'I', 20000, 'UNIT', '', '', 'N', 'ML', '20000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47738, 5669, 'DYCLONINE HYDROCHLORIDE', 'I', 1.2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75400, 5669, 'DYCLONINE HYDROCHLORIDE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76114, 5669, 'DYCLONINE HYDROCHLORIDE', 'I', 3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62080, 5669, 'DYCLONINE HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9818, 5672, 'DINITOLMIDE', 'I', 25, 'G', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: ZOALENE ((FEED-MIX)). ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67886, 5686, 'TRICHLORFON', 'I', 459, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5730, 5689, 'NICARBAZIN', 'I', 25, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: NICARBAZIN 250G/KG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11582, 5689, 'NICARBAZIN', 'I', 80, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: NICARBAZIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77476, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12671, 5691, 'DOXEPIN HYDROCHLORIDE', 'I', 75, 'MG', '', '', 'N', '', 'Historic Freeform Text: DOXEPIN HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12672, 5691, 'DOXEPIN HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DOXEPIN HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12673, 5691, 'DOXEPIN HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: DOXEPIN HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12669, 5691, 'DOXEPIN HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DOXEPIN HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12670, 5691, 'DOXEPIN HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DOXEPIN HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17850, 5691, 'DOXEPIN HYDROCHLORIDE', 'I', 5, '%', '', '', 'N', '%', 'Historic Freeform Text: DOXEPIN HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5644, 5632, 'MECHLORETHAMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: MECHLORETHAMINE ((HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2744, 5645, 'CORBADRINE (CORBADRINE HYDROCHLORIDE)', 'I', 50, 'µG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LEVONORDEFRIN HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76704, 5645, 'CORBADRINE (CORBADRINE HYDROCHLORIDE)', 'I', 50, 'µG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LEVONORDEFRIN HCL ((BASE EQ)).  INGREDIENT CORBADRINE SHOULD BE ENTERED AS A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79940, 5645, 'CORBADRINE (CORBADRINE HYDROCHLORIDE)', 'I', 0.05, 'MG', '', '', 'N', 'ML', 'LEVONORDEFRIN 1:20000 =1000MG/20000ML=0.05MG/ML LEVONORDEFRIN 50 µG/ML = LEVONORDEFRIN 0.05MG/ML THE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2357, 3436, 'DIETHYLCARBAMAZINE CITRATE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIETHYLCARBAMAZINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2358, 3436, 'DIETHYLCARBAMAZINE CITRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIETHYLCARBAMAZINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2359, 3436, 'DIETHYLCARBAMAZINE CITRATE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIETHYLCARBAMAZINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2360, 3436, 'DIETHYLCARBAMAZINE CITRATE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIETHYLCARBAMAZINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2361, 3436, 'DIETHYLCARBAMAZINE CITRATE', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIETHYLCARBAMAZINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18330, 3336, 'PRIMAQUINE PHOSPHATE', 'I', 26.3, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: PRIMAQUINE PHOSPHATE ((PRIMAQUINE EQ.15MG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (40420, 10029, 'CYPROHEPTADINE HYDROCHLORIDE', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: CYPROHEPTADINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69767, 10029, 'CYPROHEPTADINE HYDROCHLORIDE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81790, 10029, 'CYPROHEPTADINE HYDROCHLORIDE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69768, 10029, 'CYPROHEPTADINE HYDROCHLORIDE', 'I', 2, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6696, 10033, 'ALUMINUM ACETATE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALUMINUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14577, 9967, 'GLYCOPYRROLATE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GLYCOPYRROLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 9928, 'VALINE', 'I', 535, 'MG', '', '', 'N', '', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43947, 9928, 'VALINE', 'I', 1.44, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44068, 9928, 'VALINE', 'I', 560, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15493, 9928, 'VALINE', 'I', 640, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11329, 9928, 'VALINE', 'I', 580, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 9928, 'VALINE', 'I', 4.2, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7163, 9928, 'VALINE', 'I', 528, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 9928, 'VALINE', 'I', 680, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 9928, 'VALINE', 'I', 2, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4661, 9928, 'VALINE', 'I', 460, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 9928, 'VALINE', 'I', 460, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 9928, 'VALINE', 'I', 3, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 9928, 'VALINE', 'I', 3, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 9928, 'VALINE', 'I', 139.3, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15908, 9954, 'LIOTHYRONINE', 'I', 25, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LIOTHYRONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 897, 'L-TYROSINE', 'I', 0.15, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15909, 9954, 'LIOTHYRONINE', 'I', 5, 'µG', '', '', 'N', '', 'Historic Freeform Text: LIOTHYRONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12221, 9880, 'METRONIDAZOLE', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METRONIDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12654, 9880, 'METRONIDAZOLE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: METRONIDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9910, 9880, 'METRONIDAZOLE', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METRONIDAZOLE. STRENGTH VALUE PER DOSAGE UNIT 500MG REMOVED./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5722, 9880, 'METRONIDAZOLE', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: METRONIDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4902, 9880, 'METRONIDAZOLE', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: METRONIDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3010, 9880, 'METRONIDAZOLE', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: METRONIDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1033, 9880, 'METRONIDAZOLE', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: METRONIDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68374, 9880, 'METRONIDAZOLE', 'I', 750, 'MG', '', '', 'N', '', 'Historic Freeform Text: METRONIDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72917, 9880, 'METRONIDAZOLE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19257, 9880, 'METRONIDAZOLE', 'I', 1, '%', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17824, 9880, 'METRONIDAZOLE', 'I', 0.75, '%', '', '', 'N', '', 'Historic Freeform Text: METRONIDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16852, 9880, 'METRONIDAZOLE', 'I', 0.75, '%', '', '', 'N', '', 'W/W. HISTORIC FREEFORM TEXT: METRONIDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12997, 9880, 'METRONIDAZOLE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: METRONIDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7425, 9880, 'METRONIDAZOLE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: METRONIDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66753, 9880, 'METRONIDAZOLE', 'I', 1.0, '%', '', '', 'N', '', 'STRENGTH CHANGED TO 1% FROM 10MG/G AS PER PM AND LABEL/JJ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72542, 9880, 'METRONIDAZOLE', 'I', 0.75, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78314, 9880, 'METRONIDAZOLE', 'I', 1, '%', '', '', 'N', '', 'W/W. HISTORIC FREEFORM TEXT: METRONIDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43445, 9880, 'METRONIDAZOLE', 'I', 0.75, '%', '', '', 'N', '%', 'Historic Freeform Text: METRONIDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10871, 9880, 'METRONIDAZOLE', 'I', 5, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: METRONIDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12996, 9880, 'METRONIDAZOLE', 'I', 500, 'MG', '', '4.5', 'N', 'G', 'HISTORIC FREEFORM TEXT: METRONIDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41971, 9887, 'TOLNAFTATE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TOLNAFTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41933, 9887, 'TOLNAFTATE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: TOLNAFTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33528, 9887, 'TOLNAFTATE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: TOLNAFTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27993, 9887, 'TOLNAFTATE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TOLNAFTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15558, 9887, 'TOLNAFTATE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59733, 9887, 'TOLNAFTATE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66930, 9887, 'TOLNAFTATE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78123, 9887, 'TOLNAFTATE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80479, 9887, 'TOLNAFTATE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80475, 9887, 'TOLNAFTATE', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42962, 9887, 'TOLNAFTATE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: TOLNAFTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11879, 9887, 'TOLNAFTATE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: TOLNAFTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62521, 9887, 'TOLNAFTATE', 'I', 1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42528, 9887, 'TOLNAFTATE', 'I', 1, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: TOLNAFTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62971, 9887, 'TOLNAFTATE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41611, 9887, 'TOLNAFTATE', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TOLNAFTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41612, 9887, 'TOLNAFTATE', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TOLNAFTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41608, 9887, 'TOLNAFTATE', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TOLNAFTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (186, 9900, 'CETALKONIUM CHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CETALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15592, 9906, 'TRIMIPRAMINE (TRIMIPRAMINE MALEATE)', 'I', 75, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TRIMIPRAMINE ((AS TRIMIPRAMINE MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14087, 9906, 'TRIMIPRAMINE (TRIMIPRAMINE MALEATE)', 'I', 25, 'MG', '', '', 'Y', '', 'Historic Freeform Text: TRIMIPRAMINE ((AS MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14083, 9906, 'TRIMIPRAMINE (TRIMIPRAMINE MALEATE)', 'I', 12.5, 'MG', '', '', 'Y', '', 'Historic Freeform Text: TRIMIPRAMINE ((AS MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14085, 9906, 'TRIMIPRAMINE (TRIMIPRAMINE MALEATE)', 'I', 100, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TRIMIPRAMINE ((AS MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14086, 9906, 'TRIMIPRAMINE (TRIMIPRAMINE MALEATE)', 'I', 50, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TRIMIPRAMINE ((AS MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11767, 9906, 'TRIMIPRAMINE (TRIMIPRAMINE MALEATE)', 'I', 50, 'MG', '', '', 'Y', '', 'Historic Freeform Text: TRIMIPRAMINE MALEATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11768, 9906, 'TRIMIPRAMINE (TRIMIPRAMINE MALEATE)', 'I', 25, 'MG', '', '', 'Y', '', 'Historic Freeform Text: TRIMIPRAMINE MALEATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11769, 9906, 'TRIMIPRAMINE (TRIMIPRAMINE MALEATE)', 'I', 100, 'MG', '', '', 'Y', '', 'Historic Freeform Text: TRIMIPRAMINE MALEATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8106, 9906, 'TRIMIPRAMINE (TRIMIPRAMINE MALEATE)', 'I', 100, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TRIMIPRAMINE ((AS MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8065, 9906, 'TRIMIPRAMINE (TRIMIPRAMINE MALEATE)', 'I', 12.5, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TRIMIPRAMINE ((AS MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8066, 9906, 'TRIMIPRAMINE (TRIMIPRAMINE MALEATE)', 'I', 25, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TRIMIPRAMINE ((AS MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8067, 9906, 'TRIMIPRAMINE (TRIMIPRAMINE MALEATE)', 'I', 50, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TRIMIPRAMINE ((AS MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44232, 9839, 'NORTRIPTYLINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORTRIPTYLINE ((AS NORTRIPTYLINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44233, 9839, 'NORTRIPTYLINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: NORTRIPTYLINE ((AS NORTRIPTYLINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8218, 9845, 'TRIHEXYPHENIDYL HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIHEXYPHENIDYL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8217, 9845, 'TRIHEXYPHENIDYL HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIHEXYPHENIDYL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4901, 9845, 'TRIHEXYPHENIDYL HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRIHEXYPHENIDYL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4903, 9845, 'TRIHEXYPHENIDYL HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIHEXYPHENIDYL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (45323, 9845, 'TRIHEXYPHENIDYL HYDROCHLORIDE', 'I', 0.4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRIHEXYPHENIDYL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74661, 9847, 'ANTIHEMOPHILIC FACTOR (HUMAN)', 'I', 300, 'UNIT', '', '5', 'N', 'ML', '200-300IU RECONSTITUTED WITH 5ML DILUENT  ANTIHEMOPHILIC FACTOR (HUMAN)/VON WILLEBRAND FACTOR (HUMAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74662, 9847, 'ANTIHEMOPHILIC FACTOR (HUMAN)', 'I', 600, 'UNIT', '', '10', 'N', 'ML', '400-600 IU RECONSTITUTED WITH 10ML DILUENT  ANTIHEMOPHILIC FACTOR (HUMAN)/VON WILLEBRAND FACTOR (HUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74663, 9847, 'ANTIHEMOPHILIC FACTOR (HUMAN)', 'I', 1200, 'UNIT', '', '15', 'N', 'ML', '810-1200 IU RECONSTITUTED WITH 15ML DILUENT  ANTIHEMOPHILIC FACTOR (HUMAN)/VON WILLEBRAND FACTOR (HU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77219, 9847, 'ANTIHEMOPHILIC FACTOR (HUMAN)', 'I', 500, 'UNIT', '', '5.0', 'N', 'ML', 'DURING S/NDS 140116 STRENGTH WAS INCREASED FROM 450  TO 500 IU/5ML APPROVED BY BGTD IT IS STILL THE ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77222, 9847, 'ANTIHEMOPHILIC FACTOR (HUMAN)', 'I', 1000, 'UNIT', '', '10.0', 'N', 'ML', 'DURING S/NDS 140116 STRENGTH WAS INCREASED FROM 900  TO 1000 IU/10ML APPROVED BY BGTD IT IS STILL TH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43004, 7762, 'ALPHA1-PROTEINASE INHIBITOR (HUMAN)', 'I', 1000, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: ALPHA 1-PROTEINASE INHIBITOR ((HUMAN))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50001, 7764, 'HEPATITIS B IMMUNE GLOBULIN HUMAN', 'I', 217, 'UNIT', '', '', 'N', 'ML', 'SOLVENT/DETERGENT TREATED.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77637, 7764, 'HEPATITIS B IMMUNE GLOBULIN HUMAN', 'I', 312, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78786, 7768, 'RHO D IMMUNE GLOBULIN HUMAN', 'I', 5000, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: RHO (D) IMMUNE GLOBULIN, HUMAN ((1000 MCG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81660, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78787, 7768, 'RHO D IMMUNE GLOBULIN HUMAN', 'I', 600, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: RHO (D) IMMUNE GLOBULIN, HUMAN ((120 MCG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78788, 7768, 'RHO D IMMUNE GLOBULIN HUMAN', 'I', 1500, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: RHO (D) IMMUNE GLOBULIN, HUMAN ((300 MCG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43216, 7768, 'RHO D IMMUNE GLOBULIN HUMAN', 'I', 600, 'UNIT', '', '', 'N', 'KIT', 'HISTORIC FREEFORM TEXT: RHO (D) IMMUNE GLOBULIN, HUMAN ((120 MCG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43217, 7768, 'RHO D IMMUNE GLOBULIN HUMAN', 'I', 1500, 'UNIT', '', '', 'N', 'KIT', 'HISTORIC FREEFORM TEXT: RHO (D) IMMUNE GLOBULIN, HUMAN ((300 MCG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49231, 7768, 'RHO D IMMUNE GLOBULIN HUMAN', 'I', 5000, 'UNIT', '', '', 'N', 'KIT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49688, 7773, 'IMMUNE GLOBULIN (HUMAN)', 'I', 18, '%', '', '', 'Y', '', '15-18%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49876, 7773, 'IMMUNE GLOBULIN (HUMAN)', 'I', 18, '%', '', '', 'N', '', 'IMMUNE GLOBULIN (HUMAN) - 15-18%.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76503, 7773, 'IMMUNE GLOBULIN (HUMAN)', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78988, 7773, 'IMMUNE GLOBULIN (HUMAN)', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50792, 7773, 'IMMUNE GLOBULIN (HUMAN)', 'I', 0.5, 'G', '', '', 'Y', 'VIAL', 'IMMNUNE GLOBULIN INTRAVENOUS HUMAN HAS CHANGED TO IMMUNE GLOBULIN (HUMAN) MAY 14, 2003 / AT.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50793, 7773, 'IMMUNE GLOBULIN (HUMAN)', 'I', 2.5, 'G', '', '', 'N', 'VIAL', 'IMMNUE GLOBULIN INTRAVENOUS HUMAN HAS CHANGED TO IMMNUE GLOBULIN (HUMAN) PREFERRED NAME MAY 14, 2003');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50794, 7773, 'IMMUNE GLOBULIN (HUMAN)', 'I', 5, 'G', '', '', 'N', 'VIAL', 'IMMUNE GLOBULIN INTRAVENOUS HUMAN HAS CHANGED TO IMMUNE GLOBULIN (HUMAN) PREFERRED NAME MAY 14, 2003');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50795, 7773, 'IMMUNE GLOBULIN (HUMAN)', 'I', 10, 'G', '', '', 'N', 'VIAL', 'IMMNE GLOBULIN INTRAVENOUS HUMAN HAS CHANGED TO IMMUNE GLOBULIN (HUMAN) PREFERRED NAME MAY 14, 2003 ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72002, 7773, 'IMMUNE GLOBULIN (HUMAN)', 'I', 10, 'G', '', '100', 'N', 'ML', '10%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76352, 7773, 'IMMUNE GLOBULIN (HUMAN)', 'I', 10, 'G', '', '100', 'N', 'ML', '10%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2087, 7783, 'PURIFIED PROTEIN DERIVATIVE OF TUBERCULIN', 'I', 5, 'TUB', '', '0.1', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PURIFIED PROTEIN DERIVATIVE OF TUBERCULIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11742, 7746, 'HEPATITIS B SURFACE ANTIGEN (RECOMBINANT)', 'I', 20, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: HEPATITIS B SURFACE ANTIGEN(RECOMBINANT)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49687, 7746, 'HEPATITIS B SURFACE ANTIGEN (RECOMBINANT)', 'I', 20, 'µG', '', '1.0', 'N', 'ML', '20MCG/1.0ML AS HEPATITIS B PURIFIED SURFACE ANTIGEN PROTEIN.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60885, 7746, 'HEPATITIS B SURFACE ANTIGEN (RECOMBINANT)', 'I', 10, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67606, 7746, 'HEPATITIS B SURFACE ANTIGEN (RECOMBINANT)', 'I', 10, 'µG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HEPATITIS B SURFACE ANTIGEN(RECOMBINANT)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70103, 7746, 'HEPATITIS B SURFACE ANTIGEN (RECOMBINANT)', 'I', 40, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: HEPATITIS B SURFACE ANTIGEN(RECOMBINANT)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73878, 7746, 'HEPATITIS B SURFACE ANTIGEN (RECOMBINANT)', 'I', 10, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78178, 7746, 'HEPATITIS B SURFACE ANTIGEN (RECOMBINANT)', 'I', 10, 'µG', '', '0.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HEPATITIS B SURFACE ANTIGEN(RECOMBINANT)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43207, 7661, 'DERMATOPHAGOIDES PTERONYSSINUS', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '10000 AU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37349, 7661, 'DERMATOPHAGOIDES PTERONYSSINUS', 'I', 10000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MITE (DERMATO.PTERONYSSINUS, 10000 AU/ML)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37350, 7661, 'DERMATOPHAGOIDES PTERONYSSINUS', 'I', 30000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MITE (DERMATO.PTERONYSSINUS, 30000 AU/ML)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37353, 7661, 'DERMATOPHAGOIDES PTERONYSSINUS', 'I', 15000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MITE (DERMATO.PTERONYSSINUS, 15000 AU/ML)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37354, 7661, 'DERMATOPHAGOIDES PTERONYSSINUS', 'I', 5000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MITE (DERMATOP.PTERONYSSINUS, 5000 AU/ML)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50631, 7661, 'DERMATOPHAGOIDES PTERONYSSINUS', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '10000 BAU/ML.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50632, 7661, 'DERMATOPHAGOIDES PTERONYSSINUS', 'I', 5000, 'UNIT', '', '', 'N', 'ML', '5000 BAU/ML.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75630, 7661, 'DERMATOPHAGOIDES PTERONYSSINUS', 'I', 5000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: DERMATOPHAGOIDES PTERONYSSINUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46485, 7667, 'MENINGOCOCCAL POLYSACCHARIDE ANTIGEN GROUP W-135', 'I', 50, 'µG', '', '0.5', 'N', 'ML', 'Historic Freeform Text: MENINGOCOCCAL POLYSACCHARIDE AG GRP W-135');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9222, 7667, 'MENINGOCOCCAL POLYSACCHARIDE ANTIGEN GROUP W-135', 'I', 500, 'µG', '', '', 'N', 'KIT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46485, 7668, 'MENINGOCOCCAL POLYSACCHARIDE ANTIGEN GROUP Y', 'I', 50, 'µG', '', '0.5', 'N', 'ML', 'Historic Freeform Text: MENINGOCOCCAL POLYSACCHARIDE ANTIGEN GROUP Y');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9222, 7668, 'MENINGOCOCCAL POLYSACCHARIDE ANTIGEN GROUP Y', 'I', 500, 'µG', '', '', 'N', 'KIT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46485, 7669, 'MENINGOCOCCAL POLYSACCHARIDE ANTIGEN GROUP C', 'I', 50, 'µG', '', '0.5', 'N', 'ML', 'Historic Freeform Text: MENINGOCOCCAL POLYSACCHARIDE ANTIGEN GROUP C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9222, 7669, 'MENINGOCOCCAL POLYSACCHARIDE ANTIGEN GROUP C', 'I', 500, 'µG', '', '', 'N', 'KIT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46485, 7670, 'MENINGOCOCCAL POLYSACCHARIDE ANTIGEN GROUP A', 'I', 50, 'µG', '', '0.5', 'N', 'ML', 'Historic Freeform Text: MENINGOCOCCAL POLYSACCHARIDE ANTIGEN GROUP A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9222, 7670, 'MENINGOCOCCAL POLYSACCHARIDE ANTIGEN GROUP A', 'I', 500, 'µG', '', '', 'N', 'KIT', 'HISTORIC FREEFORM TEXT: MENINGO. POLYSACCH. VACCINE ((GRP ACY-W 135))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14265, 7671, 'INSULIN ISOPHANE HUMAN BIOSYNTHETIC', 'I', 70, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: INSULIN ISOPHANE HUMAN BIOSYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14266, 7671, 'INSULIN ISOPHANE HUMAN BIOSYNTHETIC', 'I', 100, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: INSULIN ISOPHANE HUMAN BIOSYNTHETIC.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14269, 7671, 'INSULIN ISOPHANE HUMAN BIOSYNTHETIC', 'I', 70, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: INSULIN ISOPHANE HUMAN BIOSYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14270, 7671, 'INSULIN ISOPHANE HUMAN BIOSYNTHETIC', 'I', 50, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: INSULIN ISOPHANE HUMAN BIOSYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14261, 7671, 'INSULIN ISOPHANE HUMAN BIOSYNTHETIC', 'I', 100, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: INSULIN ISOPHANE HUMAN BIOSYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14262, 7671, 'INSULIN ISOPHANE HUMAN BIOSYNTHETIC', 'I', 60, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: INSULIN ISOPHANE HUMAN BIOSYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12568, 7671, 'INSULIN ISOPHANE HUMAN BIOSYNTHETIC', 'I', 70, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: INSULIN ISOPHANE HUMAN BIOSYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12570, 7671, 'INSULIN ISOPHANE HUMAN BIOSYNTHETIC', 'I', 100, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: INSULIN ISOPHANE HUMAN BIOSYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14459, 7672, 'INSULIN INJECTION HUMAN BIOSYNTHETIC', 'I', 100, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: INSULIN INJECTION HUMAN BIOSYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14269, 7672, 'INSULIN INJECTION HUMAN BIOSYNTHETIC', 'I', 30, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: INSULIN INJECTION HUMAN BIOSYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14270, 7672, 'INSULIN INJECTION HUMAN BIOSYNTHETIC', 'I', 50, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: INSULIN INJECTION HUMAN BIOSYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14265, 7672, 'INSULIN INJECTION HUMAN BIOSYNTHETIC', 'I', 30, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: INSULIN INJECTION HUMAN BIOSYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14260, 7672, 'INSULIN INJECTION HUMAN BIOSYNTHETIC', 'I', 100, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: INSULIN INJECTION HUMAN BIOSYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14262, 7672, 'INSULIN INJECTION HUMAN BIOSYNTHETIC', 'I', 40, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: INSULIN INJECTION HUMAN BIOSYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12568, 7672, 'INSULIN INJECTION HUMAN BIOSYNTHETIC', 'I', 30, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: INSULIN INJECTION HUMAN BIOSYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12569, 7672, 'INSULIN INJECTION HUMAN BIOSYNTHETIC', 'I', 100, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: INSULIN INJECTION HUMAN BIOSYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59709, 7674, 'NEISSERIA MENINGITIDIS OUTER MEMBRANE PROTEIN COMPLEX', 'I', 125, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84220, 3829, 'EDETIC ACID', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: EDETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18784, 7676, 'DIGOXIN IMMUNE FAB (OVINE)', 'I', 38, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: DIGOXIN IMMUNE FAB (OVINE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 5657, 'NICKEL SULFATE', 'I', 0.16, 'MG', '', '', 'N', 'PATCH', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31279, 5663, 'PARALDEHYDE', 'I', 100, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PARALDEHYDE STRENGTH WAS EXPRESSED AS 1ML/ML, WHICH IS THE SAME AS 100%./200');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19111, 5589, 'METHYL DODECYL BENZYL TRIMETHYL AMMONIUM CHLORIDE', 'I', 16, '%', '', '', 'N', '', 'Historic Freeform Text: METHYL DODECYL BENZYL TRIMETHYLAMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84678, 5525, 'SODIUM NITROPRUSSIDE', 'I', 25, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM NITROFERRICYANIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34944, 5532, 'FLUORESCEIN SODIUM', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUORESCEIN SODIUM Qty Unit: STP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16977, 5532, 'FLUORESCEIN SODIUM', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUORESCEIN SODIUM Qty Unit: STP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6722, 5532, 'FLUORESCEIN SODIUM', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUORESCEIN SODIUM Qty Unit: STP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80283, 5532, 'FLUORESCEIN SODIUM', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37090, 5532, 'FLUORESCEIN SODIUM', 'I', 0.25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUORESCEIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18747, 5532, 'FLUORESCEIN SODIUM', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: FLUORESCEIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16626, 5532, 'FLUORESCEIN SODIUM', 'I', 25, '%', '', '', 'N', '', 'Historic Freeform Text: FLUORESCEIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16627, 5532, 'FLUORESCEIN SODIUM', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: FLUORESCEIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6721, 5532, 'FLUORESCEIN SODIUM', 'I', 0.25, '%', '', '', 'N', '', 'Historic Freeform Text: FLUORESCEIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3781, 5532, 'FLUORESCEIN SODIUM', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: FLUORESCEIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61132, 5532, 'FLUORESCEIN SODIUM', 'I', 0.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19197, 5532, 'FLUORESCEIN SODIUM', 'I', 1, 'MG', '', '', 'N', 'STRIP', 'Historic Freeform Text: FLUORESCEIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5951, 5532, 'FLUORESCEIN SODIUM', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FLUORESCEIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6359, 5532, 'FLUORESCEIN SODIUM', 'I', 250, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FLUORESCEIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9740, 3275, 'ALBUMIN', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ALBUMIN ((HUMAN))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9700, 3275, 'ALBUMIN', 'I', 250, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ALBUMIN ((HUMAN))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82225, 3286, 'SQUALENE', 'I', 10.69, 'MG', '', '0.5', 'N', 'ML', 'ADJUVANT FULL DOSE, CLASSIFIED UNDER MI AS PER BGTD');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4161, 3311, 'OIL OF CAMPHOR', 'I', 7.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: OIL OF CAMPHOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3666, 3313, 'PINE TAR OIL', 'I', 0.75, '%', '', '', 'N', '%', 'Historic Freeform Text: PINE TAR OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5167, 3313, 'PINE TAR OIL', 'I', 36, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PINE TAR OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3666, 3194, 'OIL OF CAMPHOR RECTIFIED', 'I', 0.75, '%', '', '', 'N', '%', 'Historic Freeform Text: OIL OF CAMPHOR,RECTIFIED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12238, 3173, 'PANCRELIPASE', 'I', 77, '%', '', '', 'N', '', 'PANCRELIPASE POWDER W/W. LIPASE 8000UNIT,PROTEASE30000 UNIT,AMYLASE 30000UNIT/TAB.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75379, 15568, 'PREGABALIN', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75380, 15568, 'PREGABALIN', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75381, 15568, 'PREGABALIN', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75383, 15568, 'PREGABALIN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75385, 15568, 'PREGABALIN', 'I', 225, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75386, 15568, 'PREGABALIN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70202, 582, 'COPPER (CUPRIC OXIDE)', 'I', 2, 'MG', '', '', 'N', '', 'PINK TABLET A.M.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76186, 582, 'COPPER (CUPRIC OXIDE)', 'I', 2, 'MG', '', '', 'N', '', 'PINK TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81317, 582, 'COPPER (COPPER OXIDE)', 'I', 16187, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7388, 582, 'COPPER (COPPER SULFATE)', 'I', 0.83, '%', '', '', 'Y', '%', 'HISTORIC FREEFORM TEXT: COPPER SULFATE ((COPPER EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20314, 582, 'COPPER (COPPER SULFATE)', 'I', 0.4, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CU ((AS CUPRIC SULFATE.5H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19923, 582, 'COPPER (COPPER SULFATE)', 'I', 0.4, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CU ((AS CUPRIC SULFATE.5H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16226, 582, 'COPPER (COPPER SULFATE)', 'I', 0.4, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CU ((AS CUPRIC SULFATE.5H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16227, 582, 'COPPER (COPPER SULFATE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CU ((AS CUPRIC SULFATE.5H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16225, 582, 'COPPER (COPPER SULFATE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CU ((AS CUPRIC SULFATE.5H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 897, 'L-TYROSINE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16224, 582, 'COPPER (COPPER SULFATE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CU ((AS CUPRIC SULFATE.5H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15975, 582, 'COPPER (COPPER GLUCONATE)', 'I', 0.45, 'MG', '', '2', 'N', 'ML', 'HISTORIC FREEFORM TEXT: COPPER GLUCONATE ((COPPER EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13563, 582, 'COPPER (COPPER SULFATE)', 'I', 0.4, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: CUPRIC SULFATE ((COPPER EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 582, 'COPPER (COPPER SULFATE)', 'I', 250, 'MG', '', '', 'Y', 'KG', 'HISTORIC FREEFORM TEXT: COPPER SULF. ((COPP. EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 10041, 'L-CYSTEINE HYDROCHLORIDE', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: L-CYSTEINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 941, 'L-THREONINE', 'I', 170, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 941, 'L-THREONINE', 'I', 0.02, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20278, 941, 'L-THREONINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20279, 941, 'L-THREONINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 941, 'L-THREONINE', 'I', 178.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19306, 941, 'L-THREONINE', 'I', 600, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19610, 941, 'L-THREONINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20303, 941, 'L-THREONINE', 'I', 178.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20302, 941, 'L-THREONINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 941, 'L-THREONINE', 'I', 178.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 941, 'L-THREONINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 941, 'L-THREONINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20289, 941, 'L-THREONINE', 'I', 178.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 941, 'L-THREONINE', 'I', 105, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 941, 'L-THREONINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 941, 'L-THREONINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 941, 'L-THREONINE', 'I', 170, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 941, 'L-THREONINE', 'I', 170, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 941, 'L-THREONINE', 'I', 140, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 941, 'L-THREONINE', 'I', 170, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 941, 'L-THREONINE', 'I', 170, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19143, 941, 'L-THREONINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 941, 'L-THREONINE', 'I', 140, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 941, 'L-THREONINE', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 941, 'L-THREONINE', 'I', 140, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 941, 'L-THREONINE', 'I', 170, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 941, 'L-THREONINE', 'I', 360, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18644, 941, 'L-THREONINE', 'I', 400, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 941, 'L-THREONINE', 'I', 140, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 941, 'L-THREONINE', 'I', 400, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18608, 941, 'L-THREONINE', 'I', 280, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18607, 941, 'L-THREONINE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 941, 'L-THREONINE', 'I', 512, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18550, 941, 'L-THREONINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 941, 'L-THREONINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14077, 941, 'L-THREONINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 941, 'L-THREONINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 941, 'L-THREONINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14073, 941, 'L-THREONINE', 'I', 178, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 941, 'L-THREONINE', 'I', 178, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14071, 941, 'L-THREONINE', 'I', 178, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 941, 'L-THREONINE', 'I', 105, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 941, 'L-THREONINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14067, 941, 'L-THREONINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 941, 'L-THREONINE', 'I', 178, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5890, 941, 'L-THREONINE', 'I', 460, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3468, 941, 'L-THREONINE', 'I', 520, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4560, 941, 'L-THREONINE', 'I', 370, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2776, 941, 'L-THREONINE', 'I', 260, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 941, 'L-THREONINE', 'I', 370, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 941, 'L-THREONINE', 'I', 1.26, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 941, 'L-THREONINE', 'I', 2.21, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 941, 'L-THREONINE', 'I', 2.84, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 941, 'L-THREONINE', 'I', 2.84, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 942, 'L-PHENYLALANINE', 'I', 126, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20279, 942, 'L-PHENYLALANINE', 'I', 280, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20278, 942, 'L-PHENYLALANINE', 'I', 280, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 942, 'L-PHENYLALANINE', 'I', 238, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19306, 942, 'L-PHENYLALANINE', 'I', 447, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20303, 942, 'L-PHENYLALANINE', 'I', 238, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20302, 942, 'L-PHENYLALANINE', 'I', 280, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 942, 'L-PHENYLALANINE', 'I', 238, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 942, 'L-PHENYLALANINE', 'I', 280, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20289, 942, 'L-PHENYLALANINE', 'I', 238, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 942, 'L-PHENYLALANINE', 'I', 280, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 942, 'L-PHENYLALANINE', 'I', 140, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 942, 'L-PHENYLALANINE', 'I', 280, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 942, 'L-PHENYLALANINE', 'I', 280, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 942, 'L-PHENYLALANINE', 'I', 126, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 942, 'L-PHENYLALANINE', 'I', 126, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 942, 'L-PHENYLALANINE', 'I', 104, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 942, 'L-PHENYLALANINE', 'I', 126, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77550, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 942, 'L-PHENYLALANINE', 'I', 126, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 942, 'L-PHENYLALANINE', 'I', 104, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 942, 'L-PHENYLALANINE', 'I', 149, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 942, 'L-PHENYLALANINE', 'I', 104, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 942, 'L-PHENYLALANINE', 'I', 126, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 942, 'L-PHENYLALANINE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 942, 'L-PHENYLALANINE', 'I', 104, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18644, 942, 'L-PHENYLALANINE', 'I', 298, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 942, 'L-PHENYLALANINE', 'I', 298, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18608, 942, 'L-PHENYLALANINE', 'I', 209, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18607, 942, 'L-PHENYLALANINE', 'I', 253, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 942, 'L-PHENYLALANINE', 'I', 427, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5890, 942, 'L-PHENYLALANINE', 'I', 380, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3468, 942, 'L-PHENYLALANINE', 'I', 440, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4560, 942, 'L-PHENYLALANINE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2776, 942, 'L-PHENYLALANINE', 'I', 220, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 942, 'L-PHENYLALANINE', 'I', 420, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 942, 'L-PHENYLALANINE', 'I', 1.76, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 942, 'L-PHENYLALANINE', 'I', 3.07, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 942, 'L-PHENYLALANINE', 'I', 3.95, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 942, 'L-PHENYLALANINE', 'I', 3.95, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19306, 943, 'L-LEUCINE', 'I', 1.5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18644, 943, 'L-LEUCINE', 'I', 1, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 943, 'L-LEUCINE', 'I', 1, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 943, 'L-LEUCINE', 'I', 1.2, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 943, 'L-LEUCINE', 'I', 1, 'G', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 943, 'L-LEUCINE', 'I', 425, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 943, 'L-LEUCINE', 'I', 0.04, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20279, 943, 'L-LEUCINE', 'I', 365, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20278, 943, 'L-LEUCINE', 'I', 365, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81379, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 943, 'L-LEUCINE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20303, 943, 'L-LEUCINE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20302, 943, 'L-LEUCINE', 'I', 365, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 943, 'L-LEUCINE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 943, 'L-LEUCINE', 'I', 365, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20289, 943, 'L-LEUCINE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 943, 'L-LEUCINE', 'I', 365, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 943, 'L-LEUCINE', 'I', 182.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 943, 'L-LEUCINE', 'I', 365, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 943, 'L-LEUCINE', 'I', 365, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 943, 'L-LEUCINE', 'I', 425, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 943, 'L-LEUCINE', 'I', 425, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 943, 'L-LEUCINE', 'I', 350, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 943, 'L-LEUCINE', 'I', 425, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 943, 'L-LEUCINE', 'I', 425, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 943, 'L-LEUCINE', 'I', 350, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 943, 'L-LEUCINE', 'I', 500, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 943, 'L-LEUCINE', 'I', 350, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 943, 'L-LEUCINE', 'I', 425, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 943, 'L-LEUCINE', 'I', 831, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 943, 'L-LEUCINE', 'I', 350, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18608, 943, 'L-LEUCINE', 'I', 700, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18607, 943, 'L-LEUCINE', 'I', 850, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5890, 943, 'L-LEUCINE', 'I', 810, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3468, 943, 'L-LEUCINE', 'I', 940, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4560, 943, 'L-LEUCINE', 'I', 660, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2776, 943, 'L-LEUCINE', 'I', 470, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 943, 'L-LEUCINE', 'I', 1.76, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 943, 'L-LEUCINE', 'I', 3.07, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 943, 'L-LEUCINE', 'I', 3.95, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 943, 'L-LEUCINE', 'I', 3.95, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 944, 'L-ISOLEUCINE', 'I', 280, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20278, 944, 'L-ISOLEUCINE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20279, 944, 'L-ISOLEUCINE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 944, 'L-ISOLEUCINE', 'I', 255, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19306, 944, 'L-ISOLEUCINE', 'I', 990, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19610, 944, 'L-ISOLEUCINE', 'I', 240, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20303, 944, 'L-ISOLEUCINE', 'I', 255, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20302, 944, 'L-ISOLEUCINE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 944, 'L-ISOLEUCINE', 'I', 255, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 944, 'L-ISOLEUCINE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 944, 'L-ISOLEUCINE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20289, 944, 'L-ISOLEUCINE', 'I', 255, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 944, 'L-ISOLEUCINE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 944, 'L-ISOLEUCINE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 944, 'L-ISOLEUCINE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 944, 'L-ISOLEUCINE', 'I', 280, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 944, 'L-ISOLEUCINE', 'I', 280, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE ((AFTER MIX CONT OF BOTH CHAMBER))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 944, 'L-ISOLEUCINE', 'I', 231, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE ((AFTER MIX CONT OF BOTH CHAMBER))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 944, 'L-ISOLEUCINE', 'I', 280, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20289, 897, 'L-TYROSINE', 'I', 17, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 944, 'L-ISOLEUCINE', 'I', 280, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19143, 944, 'L-ISOLEUCINE', 'I', 240, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 944, 'L-ISOLEUCINE', 'I', 231, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 944, 'L-ISOLEUCINE', 'I', 330, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE ((AFTER MIX CONT OF BOTH CHAMBER))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 944, 'L-ISOLEUCINE', 'I', 231, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE ((AFTER MIX CONT OF BOTH CHAMBERS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 944, 'L-ISOLEUCINE', 'I', 280, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE ((AFTER MIX CONT OF BOTH CHAMBER))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 944, 'L-ISOLEUCINE', 'I', 534, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 944, 'L-ISOLEUCINE', 'I', 231, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE ((AFTER MIX CONT OF BOTH CHAMBER))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18644, 944, 'L-ISOLEUCINE', 'I', 660, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 944, 'L-ISOLEUCINE', 'I', 660, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18608, 944, 'L-ISOLEUCINE', 'I', 462, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18607, 944, 'L-ISOLEUCINE', 'I', 561, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 944, 'L-ISOLEUCINE', 'I', 760, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18550, 944, 'L-ISOLEUCINE', 'I', 240, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 944, 'L-ISOLEUCINE', 'I', 240, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14077, 944, 'L-ISOLEUCINE', 'I', 240, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 944, 'L-ISOLEUCINE', 'I', 240, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 944, 'L-ISOLEUCINE', 'I', 240, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14073, 944, 'L-ISOLEUCINE', 'I', 203, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 944, 'L-ISOLEUCINE', 'I', 203, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14071, 944, 'L-ISOLEUCINE', 'I', 203, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 944, 'L-ISOLEUCINE', 'I', 120, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14067, 944, 'L-ISOLEUCINE', 'I', 240, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 944, 'L-ISOLEUCINE', 'I', 240, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 944, 'L-ISOLEUCINE', 'I', 203, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79618, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5890, 944, 'L-ISOLEUCINE', 'I', 620, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3468, 944, 'L-ISOLEUCINE', 'I', 720, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4560, 944, 'L-ISOLEUCINE', 'I', 510, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2776, 944, 'L-ISOLEUCINE', 'I', 360, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 944, 'L-ISOLEUCINE', 'I', 670, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 944, 'L-ISOLEUCINE', 'I', 1.26, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 944, 'L-ISOLEUCINE', 'I', 2.21, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 944, 'L-ISOLEUCINE', 'I', 2.84, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 944, 'L-ISOLEUCINE', 'I', 2.84, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18783, 883, 'NONYLPHENOXYPOLY(ETHYLENEOXY)ETHANOL-IODINE COMPLEX', 'I', 11, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67103, 883, 'NONYLPHENOXYPOLY(ETHYLENEOXY)ETHANOL-IODINE COMPLEX', 'I', 6.6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5811, 883, 'NONYLPHENOXYPOLY(ETHYLENEOXY)ETHANOL-IODINE COMPLEX', 'I', 11.5, '%', '', '', 'N', '', 'PROVIDES 1% TITRATABLE IODINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74867, 883, 'NONYLPHENOXYPOLY(ETHYLENEOXY)ETHANOL-IODINE COMPLEX', 'I', 2.584, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74869, 883, 'NONYLPHENOXYPOLY(ETHYLENEOXY)ETHANOL-IODINE COMPLEX', 'I', 2.584, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74870, 883, 'NONYLPHENOXYPOLY(ETHYLENEOXY)ETHANOL-IODINE COMPLEX', 'I', 2.584, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74871, 883, 'NONYLPHENOXYPOLY(ETHYLENEOXY)ETHANOL-IODINE COMPLEX', 'I', 2.584, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74898, 883, 'NONYLPHENOXYPOLY(ETHYLENEOXY)ETHANOL-IODINE COMPLEX', 'I', 8.75, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79438, 883, 'NONYLPHENOXYPOLY(ETHYLENEOXY)ETHANOL-IODINE COMPLEX', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79247, 883, 'NONYLPHENOXYPOLY(ETHYLENEOXY)ETHANOL-IODINE COMPLEX', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79866, 883, 'NONYLPHENOXYPOLY(ETHYLENEOXY)ETHANOL-IODINE COMPLEX', 'I', 7.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80014, 883, 'NONYLPHENOXYPOLY(ETHYLENEOXY)ETHANOL-IODINE COMPLEX', 'I', 9.0, '%', '', '', 'N', 'W/W', 'PROVIDING 1.75% TITRABLE IODINE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28197, 883, 'NONYLPHENOXYPOLY(ETHYLENEOXY)ETHANOL-IODINE COMPLEX', 'I', 13.6, '%', '', '', 'N', '%', 'Historic Freeform Text: NONYLPHENOXYP.ETHY.CO. ((TITR.IODINE1.47%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66943, 893, 'DILUENT', 'I', 3.15, 'ML', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66944, 893, 'DILUENT', 'I', 3.15, 'ML', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66945, 893, 'DILUENT', 'I', 3.15, 'ML', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19952, 894, 'CALCIPOTRIOL', 'I', 50, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: CALCIPOTRIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18519, 894, 'CALCIPOTRIOL', 'I', 50, 'µG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: CALCIPOTRIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13340, 894, 'CALCIPOTRIOL', 'I', 50, 'µG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: CALCIPOTRIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68084, 894, 'CALCIPOTRIOL', 'I', 50, 'µG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80450, 894, 'CALCIPOTRIOL (CALCIPOTRIOL MONOHYDRATE)', 'I', 50, 'µG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19018, 896, 'PAMIDRONATE DISODIUM', 'I', 90, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: PAMIDRONATE DISODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19020, 896, 'PAMIDRONATE DISODIUM', 'I', 30, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: PAMIDRONATE DISODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70124, 896, 'PAMIDRONATE DISODIUM', 'I', 30, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: PAMIDRONATE DISODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70125, 896, 'PAMIDRONATE DISODIUM', 'I', 90, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: PAMIDRONATE DISODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68534, 896, 'PAMIDRONATE DISODIUM', 'I', 6, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PAMIDRONATE DISODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68533, 896, 'PAMIDRONATE DISODIUM', 'I', 3, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PAMIDRONATE DISODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68535, 896, 'PAMIDRONATE DISODIUM', 'I', 9, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PAMIDRONATE DISODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70784, 896, 'PAMIDRONATE DISODIUM', 'I', 3, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PAMIDRONATE DISODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70785, 896, 'PAMIDRONATE DISODIUM', 'I', 6, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PAMIDRONATE DISODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70786, 896, 'PAMIDRONATE DISODIUM', 'I', 9, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PAMIDRONATE DISODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73447, 896, 'PAMIDRONATE DISODIUM', 'I', 3.0, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73448, 896, 'PAMIDRONATE DISODIUM', 'I', 6.0, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73449, 896, 'PAMIDRONATE DISODIUM', 'I', 9.0, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75046, 896, 'PAMIDRONATE DISODIUM', 'I', 3, 'MG', '', '', 'N', 'ML', 'FORMED FROM 2.947 MG MONOSODIUM PAMIDRONATE AND 5.8MG NAOH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75047, 896, 'PAMIDRONATE DISODIUM', 'I', 6, 'MG', '', '', 'N', 'ML', 'FORMED FROM 5.894 MG MONOSODIUM PAMIDRONATE AND 11.6MG NAOH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75048, 896, 'PAMIDRONATE DISODIUM', 'I', 9, 'MG', '', '', 'N', 'ML', 'FORMED FROM 8.84 MG MONOSODIUM PAMIDRONATE AND17.4MG NAOH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20278, 897, 'L-TYROSINE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 897, 'L-TYROSINE', 'I', 17, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19610, 897, 'L-TYROSINE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20302, 897, 'L-TYROSINE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20303, 897, 'L-TYROSINE', 'I', 17, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 897, 'L-TYROSINE', 'I', 17, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 897, 'L-TYROSINE', 'I', 10, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 897, 'L-TYROSINE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 897, 'L-TYROSINE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20279, 897, 'L-TYROSINE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19143, 897, 'L-TYROSINE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 897, 'L-TYROSINE', 'I', 44, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 897, 'L-TYROSINE', 'I', 44, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18550, 897, 'L-TYROSINE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 897, 'L-TYROSINE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14077, 897, 'L-TYROSINE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 897, 'L-TYROSINE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 897, 'L-TYROSINE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14073, 897, 'L-TYROSINE', 'I', 17, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 897, 'L-TYROSINE', 'I', 17, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14071, 897, 'L-TYROSINE', 'I', 17, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 897, 'L-TYROSINE', 'I', 10, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 897, 'L-TYROSINE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14067, 897, 'L-TYROSINE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 897, 'L-TYROSINE', 'I', 17, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5890, 897, 'L-TYROSINE', 'I', 44, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3468, 897, 'L-TYROSINE', 'I', 44, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4560, 897, 'L-TYROSINE', 'I', 44, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2776, 897, 'L-TYROSINE', 'I', 44, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 897, 'L-TYROSINE', 'I', 45, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 897, 'L-TYROSINE', 'I', 0.06, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 897, 'L-TYROSINE', 'I', 0.11, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14518, 901, 'ITRACONAZOLE', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ITRACONAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50656, 901, 'ITRACONAZOLE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80231, 901, 'ITRACONAZOLE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46474, 905, 'MEDETOMIDINE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEDETOMIDINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82278, 905, 'MEDETOMIDINE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 855, 'DL-VALINE', 'I', 0.05, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DL-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 856, 'DL-TRYPTOPHANE', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DL-TRYPTOPHANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (45065, 774, 'CHLOROXYLENOL', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41477, 774, 'CHLOROXYLENOL', 'I', 4.8, '%', '', '', 'N', '', 'STRENGTH OF THE MEDICINAL INGREDIENT CHLOROXYLENOL IN DPD IS 1.44G/30 ML. THE VALUE CHANGED TO 4.8% ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42186, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42099, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42113, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42042, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42043, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41939, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41864, 774, 'CHLOROXYLENOL', 'I', 5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36721, 774, 'CHLOROXYLENOL', 'I', 0.2, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19577, 774, 'CHLOROXYLENOL', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19976, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18442, 774, 'CHLOROXYLENOL', 'I', 0.15, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18208, 774, 'CHLOROXYLENOL', 'I', 0.6, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15829, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13062, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13617, 774, 'CHLOROXYLENOL', 'I', 0.15, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12792, 774, 'CHLOROXYLENOL', 'I', 0.15, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11499, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12639, 774, 'CHLOROXYLENOL', 'I', 0.6, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12137, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9415, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7121, 774, 'CHLOROXYLENOL', 'I', 0.15, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7506, 774, 'CHLOROXYLENOL', 'I', 0.6, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLOROXYLENOL 0.6% V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6675, 774, 'CHLOROXYLENOL', 'I', 0.36, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1338, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (621, 774, 'CHLOROXYLENOL', 'I', 0.6, '%', '', '', 'N', '', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50083, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51009, 774, 'CHLOROXYLENOL', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59731, 774, 'CHLOROXYLENOL', 'I', 0.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62698, 774, 'CHLOROXYLENOL', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61646, 774, 'CHLOROXYLENOL', 'I', 0.52, '%', '', '', 'N', '', '2009.07.07. MEDICINAL INGREDIENT STRENGTH SLIGHTLY INCREASED FROM 0.5% TO 0.52%, WITH BGIV APPROVAL ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61647, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61042, 774, 'CHLOROXYLENOL', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67188, 774, 'CHLOROXYLENOL', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65308, 774, 'CHLOROXYLENOL', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65999, 774, 'CHLOROXYLENOL', 'I', 0.50, '%', '', '', 'N', '', '0.50% W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66677, 774, 'CHLOROXYLENOL', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67848, 774, 'CHLOROXYLENOL', 'I', 0.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67374, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68597, 774, 'CHLOROXYLENOL', 'I', 0.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69042, 774, 'CHLOROXYLENOL', 'I', 0.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70951, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76461, 774, 'CHLOROXYLENOL', 'I', 0.6, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLOROXYLENOL 0.6% V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75365, 774, 'CHLOROXYLENOL', 'I', 1.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75366, 774, 'CHLOROXYLENOL', 'I', 1.49, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76372, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75542, 774, 'CHLOROXYLENOL', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75901, 774, 'CHLOROXYLENOL', 'I', 0.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73589, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73604, 774, 'CHLOROXYLENOL', 'I', 0.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75040, 774, 'CHLOROXYLENOL', 'I', 0.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77286, 774, 'CHLOROXYLENOL', 'I', 0.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77673, 774, 'CHLOROXYLENOL', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77120, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79962, 774, 'CHLOROXYLENOL', 'I', 0.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77121, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', 'W/V', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3665, 774, 'CHLOROXYLENOL', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLOROXYLENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48988, 774, 'CHLOROXYLENOL', 'I', 8, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18636, 778, 'MAGNESIUM OXIDE', 'I', 26.2, 'G', '', '', 'N', '', 'Historic Freeform Text: MAGNESIUM OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5698, 778, 'MAGNESIUM OXIDE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: MAGNESIUM OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48421, 778, 'MAGNESIUM OXIDE', 'I', 96.9, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48434, 778, 'MAGNESIUM OXIDE', 'I', 63, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73995, 778, 'MAGNESIUM OXIDE', 'I', 3.5, 'G', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78587, 778, 'MAGNESIUM OXIDE', 'I', 3.5, 'G', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80347, 778, 'MAGNESIUM OXIDE', 'I', 3.5, 'G', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84334, 778, 'MAGNESIUM OXIDE', 'I', 3.5, 'G', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2122, 778, 'MAGNESIUM OXIDE', 'I', 3.8, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (744, 778, 'MAGNESIUM OXIDE', 'I', 1.9, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18637, 778, 'MAGNESIUM OXIDE', 'I', 15, 'G', '', '28.35', 'N', 'G', 'HISTORIC FREEFORM TEXT: MAGNESIUM OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70383, 12857, 'SUBSTITUTED PHENOLS', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70383, 12858, 'CARBOLIC OIL', 'I', 50, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3930, 12859, 'IOTHALAMATE MEGLUMINE', 'I', 430, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEGLUMINE IOTHALAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1201, 12859, 'IOTHALAMATE MEGLUMINE', 'I', 300, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MEGLUMINE IOTHALAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2949, 12859, 'IOTHALAMATE MEGLUMINE', 'I', 172, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEGLUMINE IOTHALAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (899, 12859, 'IOTHALAMATE MEGLUMINE', 'I', 600, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MEGLUMINE IOTHALAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77219, 12888, 'HUMAN PLASMA PROTEINS', 'I', 7.5, 'MG', '', '5.0', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77222, 12888, 'HUMAN PLASMA PROTEINS', 'I', 15.0, 'MG', '', '10.0', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70715, 12945, 'BIVALIRUDIN', 'I', 250, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2196, 3829, 'EDETIC ACID', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: EDETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60445, 3829, 'EDETIC ACID', 'I', 0.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60446, 3829, 'EDETIC ACID', 'I', 0.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84223, 3829, 'EDETIC ACID', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: EDETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78673, 14052, 'NESIRITIDE', 'I', 1.5, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78289, 14088, 'MESALAZINE', 'I', 1.2, 'G', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15218, 14088, 'MESALAZINE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: 5-AMINOSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14552, 14088, 'MESALAZINE', 'I', 400, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MESALAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65824, 14088, 'MESALAZINE', 'I', 1000, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75261, 14088, 'MESALAZINE', 'I', 800, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83673, 14088, 'MESALAZINE', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16855, 14088, 'MESALAZINE', 'I', 500, 'MG', '', '', 'N', 'SRT', 'Historic Freeform Text: MESALAMINE Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19524, 14088, 'MESALAZINE', 'I', 400, 'MG', '', '', 'N', 'ECT', 'HISTORIC FREEFORM TEXT: MESALAMINE QTY UNIT: ECT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18214, 14088, 'MESALAZINE', 'I', 500, 'MG', '', '', 'N', 'ECT', 'Historic Freeform Text: MESALAMINE Qty Unit: ECT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18493, 14088, 'MESALAZINE', 'I', 1, 'G', '', '', 'N', 'SUP', 'Historic Freeform Text: MESALAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18212, 14088, 'MESALAZINE', 'I', 500, 'MG', '', '', 'N', 'SUP', 'Historic Freeform Text: MESALAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18494, 14088, 'MESALAZINE', 'I', 4, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: MESALAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18496, 14088, 'MESALAZINE', 'I', 1, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: MESALAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18509, 14088, 'MESALAZINE', 'I', 4, 'G', '', '60', 'N', 'G', 'Historic Freeform Text: MESALAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18510, 14088, 'MESALAZINE', 'I', 2, 'G', '', '60', 'N', 'G', 'HISTORIC FREEFORM TEXT: MESALAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62067, 946, 'NABUMETONE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64458, 946, 'NABUMETONE', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NABUMETONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64459, 946, 'NABUMETONE', 'I', 750, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NABUMETONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68548, 946, 'NABUMETONE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82875, 946, 'NABUMETONE', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16968, 949, 'BEZAFIBRATE', 'I', 400, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BEZAFIBRATE QTY UNIT: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63870, 949, 'BEZAFIBRATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44252, 951, 'CILAZAPRIL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CILAZAPRIL ((AS CILAZAPRIL MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13834, 951, 'CILAZAPRIL', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CILAZAPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13835, 951, 'CILAZAPRIL', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CILAZAPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75177, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75178, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75179, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76610, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76611, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76612, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77651, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77652, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77653, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76935, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76936, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76937, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77072, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77073, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77051, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79497, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79498, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79499, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79924, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83615, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83616, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83617, 951, 'CILAZAPRIL (CILAZAPRIL MONOHYDRATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62432, 952, 'URSODIOL', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70011, 952, 'URSODIOL', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76694, 952, 'URSODIOL', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76695, 952, 'URSODIOL', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76696, 952, 'URSODIOL', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76697, 952, 'URSODIOL', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75898, 952, 'URSODIOL', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75899, 952, 'URSODIOL', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50873, 954, 'OFLOXACIN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50874, 954, 'OFLOXACIN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50875, 954, 'OFLOXACIN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67385, 954, 'OFLOXACIN', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67386, 954, 'OFLOXACIN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67387, 954, 'OFLOXACIN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73745, 954, 'OFLOXACIN', 'I', 0.3, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72744, 954, 'OFLOXACIN', 'I', 0.3, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18491, 954, 'OFLOXACIN', 'I', 0.3, '%', '', '', 'N', '%', 'Historic Freeform Text: OFLOXACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60138, 945, 'TICLOPIDINE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60898, 945, 'TICLOPIDINE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61047, 945, 'TICLOPIDINE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63226, 945, 'TICLOPIDINE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67230, 945, 'TICLOPIDINE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67505, 945, 'TICLOPIDINE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67746, 945, 'TICLOPIDINE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82853, 945, 'TICLOPIDINE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12196, 910, 'PODOPHYLLOTOXIN', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: PODOPHYLLOTOXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18274, 910, 'PODOPHYLLOTOXIN', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PODOPHYLLOTOXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5348, 912, 'EUCALYPTUS OIL', 'I', 0.25, '%', '', '', 'N', '', 'Historic Freeform Text: EUCALYPTUS OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (621, 912, 'EUCALYPTUS OIL', 'I', 0.95, '%', '', '', 'N', '', 'Historic Freeform Text: EUCALYPTUS OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22937, 912, 'EUCALYPTUS OIL', 'I', 1.5, '%', '', '', 'N', '%', 'Historic Freeform Text: EUCALYPTUS OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3666, 912, 'EUCALYPTUS OIL', 'I', 0.75, '%', '', '', 'N', '%', 'Historic Freeform Text: EUCALYPTUS OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6248, 912, 'EUCALYPTUS OIL', 'I', 29.4, 'G', '', '940', 'N', 'ML', 'Historic Freeform Text: EUCALYPTUS OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36844, 912, 'EUCALYPTUS OIL', 'I', 1.1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EUCALYPTUS OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4161, 912, 'EUCALYPTUS OIL', 'I', 7.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EUCALYPTUS OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48860, 912, 'EUCALYPTUS OIL', 'I', 0.10, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68582, 916, 'DIDANOSINE', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68583, 916, 'DIDANOSINE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68584, 916, 'DIDANOSINE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68585, 916, 'DIDANOSINE', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19655, 917, 'ACARBOSE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACARBOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19648, 917, 'ACARBOSE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACARBOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76425, 918, 'MIDODRINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76426, 918, 'MIDODRINE HYDROCHLORIDE', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70589, 735, 'O-PHENYLPHENOL', 'I', 3.55, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13796, 923, 'LEVOCABASTINE (LEVOCABASTINE HYDROCHLORIDE)', 'I', 0.5, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: LEVOCABASTINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13305, 925, 'CLODRONATE DISODIUM (CLODRONATE DISODIUM TETRAHYDRATE)', 'I', 400, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DISOD CLODRONATE TETRAHYDRATE ((ANHYD FRM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69944, 925, 'CLODRONATE DISODIUM', 'I', 400, 'MG', '', '', 'N', '', 'CLODRONATE DISODIUM AS TETRAHYDRATE/JJ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13304, 925, 'CLODRONATE DISODIUM (CLODRONATE DISODIUM TETRAHYDRATE)', 'I', 60, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DISOD CLODRONATE TETRAHYDRATE ((ANHYD FRM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50585, 928, 'TOLFENAMIC ACID', 'I', 6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50586, 928, 'TOLFENAMIC ACID', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61461, 928, 'TOLFENAMIC ACID', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62366, 928, 'TOLFENAMIC ACID', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12999, 931, 'EPSIPRANTEL', 'I', 12.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: EPSIPRANTEL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12869, 931, 'EPSIPRANTEL', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: EPSIPRANTEL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19306, 935, 'L-PROLINE', 'I', 1.083, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 935, 'L-PROLINE', 'I', 307, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20278, 935, 'L-PROLINE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 935, 'L-PROLINE', 'I', 289, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19610, 935, 'L-PROLINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20302, 935, 'L-PROLINE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20303, 935, 'L-PROLINE', 'I', 289, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 935, 'L-PROLINE', 'I', 289, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 935, 'L-PROLINE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 935, 'L-PROLINE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20289, 935, 'L-PROLINE', 'I', 289, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 935, 'L-PROLINE', 'I', 170, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 935, 'L-PROLINE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 935, 'L-PROLINE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20279, 935, 'L-PROLINE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 935, 'L-PROLINE', 'I', 307, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 935, 'L-PROLINE', 'I', 307, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 935, 'L-PROLINE', 'I', 307, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 935, 'L-PROLINE', 'I', 252, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19143, 935, 'L-PROLINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 935, 'L-PROLINE', 'I', 307, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 935, 'L-PROLINE', 'I', 252, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 935, 'L-PROLINE', 'I', 361, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 935, 'L-PROLINE', 'I', 252, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 935, 'L-PROLINE', 'I', 307, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 935, 'L-PROLINE', 'I', 570, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 935, 'L-PROLINE', 'I', 252, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18644, 935, 'L-PROLINE', 'I', 722, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 935, 'L-PROLINE', 'I', 722, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18607, 935, 'L-PROLINE', 'I', 614, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18608, 935, 'L-PROLINE', 'I', 505, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 935, 'L-PROLINE', 'I', 812, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18550, 935, 'L-PROLINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 935, 'L-PROLINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14077, 935, 'L-PROLINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 935, 'L-PROLINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 935, 'L-PROLINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14073, 935, 'L-PROLINE', 'I', 178, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 935, 'L-PROLINE', 'I', 178, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14071, 935, 'L-PROLINE', 'I', 178, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 935, 'L-PROLINE', 'I', 105, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 935, 'L-PROLINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14067, 935, 'L-PROLINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 935, 'L-PROLINE', 'I', 178, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5890, 935, 'L-PROLINE', 'I', 750, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3468, 935, 'L-PROLINE', 'I', 860, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4560, 935, 'L-PROLINE', 'I', 610, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2776, 935, 'L-PROLINE', 'I', 430, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PROLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 935, 'L-PROLINE', 'I', 300, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 935, 'L-PROLINE', 'I', 1.51, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 935, 'L-PROLINE', 'I', 2.64, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 935, 'L-PROLINE', 'I', 3.40, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 935, 'L-PROLINE', 'I', 3.40, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19306, 938, 'L-ARGININE', 'I', 1.527, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18644, 938, 'L-ARGININE', 'I', 1.018, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 938, 'L-ARGININE', 'I', 1.018, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 938, 'L-ARGININE', 'I', 1.227, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 938, 'L-ARGININE', 'I', 432, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20278, 938, 'L-ARGININE', 'I', 575, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 938, 'L-ARGININE', 'I', 489, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19610, 938, 'L-ARGININE', 'I', 520, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20303, 938, 'L-ARGININE', 'I', 489, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20302, 938, 'L-ARGININE', 'I', 575, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 938, 'L-ARGININE', 'I', 489, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 938, 'L-ARGININE', 'I', 575, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 938, 'L-ARGININE', 'I', 575, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20289, 938, 'L-ARGININE', 'I', 489, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 938, 'L-ARGININE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 938, 'L-ARGININE', 'I', 575, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 938, 'L-ARGININE', 'I', 575, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20279, 938, 'L-ARGININE', 'I', 575, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 938, 'L-ARGININE', 'I', 432, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 938, 'L-ARGININE', 'I', 432, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 938, 'L-ARGININE', 'I', 356, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 938, 'L-ARGININE', 'I', 432, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19143, 938, 'L-ARGININE', 'I', 520, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 938, 'L-ARGININE', 'I', 432, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 938, 'L-ARGININE', 'I', 356, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 938, 'L-ARGININE', 'I', 509, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 938, 'L-ARGININE', 'I', 356, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 938, 'L-ARGININE', 'I', 432, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 938, 'L-ARGININE', 'I', 356, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 938, 'L-ARGININE', 'I', 861, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18608, 938, 'L-ARGININE', 'I', 713, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18607, 938, 'L-ARGININE', 'I', 865, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18550, 938, 'L-ARGININE', 'I', 520, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 938, 'L-ARGININE', 'I', 520, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14077, 938, 'L-ARGININE', 'I', 520, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 938, 'L-ARGININE', 'I', 520, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 938, 'L-ARGININE', 'I', 520, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14073, 938, 'L-ARGININE', 'I', 440, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 938, 'L-ARGININE', 'I', 440, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14071, 938, 'L-ARGININE', 'I', 440, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 938, 'L-ARGININE', 'I', 260, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14067, 938, 'L-ARGININE', 'I', 520, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 938, 'L-ARGININE', 'I', 520, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 938, 'L-ARGININE', 'I', 440, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5890, 938, 'L-ARGININE', 'I', 850, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3468, 938, 'L-ARGININE', 'I', 980, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4560, 938, 'L-ARGININE', 'I', 690, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2776, 938, 'L-ARGININE', 'I', 490, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ARGININE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 938, 'L-ARGININE', 'I', 840, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 938, 'L-ARGININE', 'I', 2.48, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 938, 'L-ARGININE', 'I', 4.34, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 938, 'L-ARGININE', 'I', 5.58, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 938, 'L-ARGININE', 'I', 5.58, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8202, 13023, 'DEMBREXINE (DEMBREXINE HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: SPUTOLYSIN INGREDIENT CHANGED TO DEMBREXINE AS DEMBREXINE HYDROCHLORIDE AS P');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72966, 13026, 'ATAZANAVIR (ATAZANAVIR SULFATE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72967, 13026, 'ATAZANAVIR (ATAZANAVIR SULFATE)', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77952, 13026, 'ATAZANAVIR (ATAZANAVIR SULFATE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76788, 13030, 'ENTECAVIR', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72003, 13031, 'ENFUVIRTIDE', 'I', 108, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74782, 13053, 'BORTEZOMIB (BORTEZOMIB MANNITOL BORONIC ESTER)', 'I', 3.5, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70993, 13057, 'TIOTROPIUM (TIOTROPIUM BROMIDE MONOHYDRATE)', 'I', 18, 'µG', '', '', 'N', '', 'CAPSULE CONTAINS A DRY POWDER BLEND FOR ORAL INHALATION.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76261, 11791, 'ALUMINUM SILICATE, ANHYDROUS', 'I', 0.05, 'G', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62057, 11791, 'ALUMINUM SILICATE, ANHYDROUS', 'I', 13.62, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75121, 14148, 'DERACOXIB', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75122, 14148, 'DERACOXIB', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81434, 14148, 'DERACOXIB', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8427, 1403, 'LINEAR DODECYL BENZENE SULFONIC ACID', 'I', 1.94, '%', '', '', 'N', '', 'Historic Freeform Text: LINEAR DODECYL BENZENE SULFONIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 9750, 'TYROSINE', 'I', 410, 'MG', '', '', 'N', '', 'Historic Freeform Text: TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43947, 9750, 'TYROSINE', 'I', 50, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11329, 9750, 'TYROSINE', 'I', 40, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 9750, 'TYROSINE', 'I', 0.9, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 9750, 'TYROSINE', 'I', 44, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 9750, 'TYROSINE', 'I', 0.2, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4661, 9750, 'TYROSINE', 'I', 40, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 9750, 'TYROSINE', 'I', 40, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 9750, 'TYROSINE', 'I', 30, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 1361, 'PHENYLALANINE', 'I', 0.03, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DL-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 7292, 'SODIUM GLUTAMATE', 'I', 0.04, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM GLUTAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 7292, 'SODIUM GLUTAMATE', 'I', 4, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM GLUTAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15809, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 250, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULPHATE ((NEOMYCIN EQ.250MG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15808, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 357, 'MG', '', '', 'N', '', 'NEOMYCIN ((AS SULFATE EQ. TO 357MG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5698, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 100, 'MG', '', '', 'Y', '', 'Historic Freeform Text: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77551, 755, 'AVOBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6202, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 250, 'MG', '', '', 'Y', '', 'Historic Freeform Text: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22007, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 19.92, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16174, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 3, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: NEOMYCIN ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16624, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 3.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NEOMYCIN ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13328, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 1.75, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NEOMYCIN ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11287, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 3.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12797, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 4.4, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12799, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11003, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12174, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 2.5, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10062, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 1.75, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((BASE 1.75MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9372, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 19.92, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5346, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5700, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 3.2, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6727, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 40, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((BASE 40MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4882, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 35, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((BASE EQ 35MG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3466, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 29.6, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3404, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 4.4, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2782, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 35, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((BASE 35MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49184, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 3.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (259, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 3.5, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((NEOMYCIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14164, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 56.875, 'G', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5321, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 14, 'G', '', '100', 'Y', 'G', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (131, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 7.8, 'G', '', '30', 'Y', 'G', 'HISTORIC FREEFORM TEXT: NEOMYCIN ((NEOMYCIN SULFATE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16650, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 3.5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: NEOMYCIN ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15598, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 2.5, 'MG', '', '', 'Y', 'G', 'Historic Freeform Text: NEOMYCIN ((AS SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13027, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 140, 'MG', '', '', 'Y', 'G', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11867, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 2.5, 'MG', '', '', 'Y', 'G', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12862, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 2.5, 'MG', '', '', 'Y', 'G', 'Historic Freeform Text: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9448, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 2.5, 'MG', '', '', 'Y', 'G', 'Historic Freeform Text: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9449, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 2.5, 'MG', '', '', 'Y', 'G', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8528, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 3.5, 'MG', '', '', 'Y', 'G', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((BASE 3.5MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7030, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: NEOMYCIN SULFATE ((BASE 3.5MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2423, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 3.5, 'MG', '', '', 'Y', 'G', 'HISTORIC FREEFORM TEXT: NEOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66223, 8638, 'NEOMYCIN (NEOMYCIN SULFATE)', 'I', 3.5, 'MG', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76673, 732, 'PACLITAXEL', 'I', 100, 'MG', '', '', 'N', 'VIAL', 'RECONSTITUTED SUSPENSION CONTAINS 5MG/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14248, 732, 'PACLITAXEL', 'I', 6, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PACLITAXEL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68340, 732, 'PACLITAXEL (TAXUS CANADENSIS)', 'I', 6, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PACLITAXEL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73215, 732, 'PACLITAXEL', 'I', 6, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78198, 732, 'PACLITAXEL', 'I', 6, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80546, 732, 'PACLITAXEL', 'I', 6, 'MG', '', '', 'N', 'ML', 'MULTIDOSE VIALS OF 5ML, 16.7ML, 25ML, AND 50ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42930, 733, 'ANTITHROMBIN III (HUMAN)', 'I', 1000, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: ANTITHROMBIN III (HUMAN)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61169, 733, 'ANTITHROMBIN III (HUMAN)', 'I', 1100, 'UNIT', '', '', 'N', 'VIAL', '900-1100 IU/VIAL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61170, 733, 'ANTITHROMBIN III (HUMAN)', 'I', 550, 'UNIT', '', '', 'N', 'VIAL', '450-550 IU/VIAL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61171, 733, 'ANTITHROMBIN III (HUMAN)', 'I', 1650, 'UNIT', '', '', 'N', 'KIT', '1350-1650 IU/VIAL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36549, 735, 'O-PHENYLPHENOL', 'I', 12.4, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34513, 735, 'O-PHENYLPHENOL', 'I', 7.7, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26739, 735, 'O-PHENYLPHENOL', 'I', 0.199, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25672, 735, 'O-PHENYLPHENOL', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19364, 735, 'O-PHENYLPHENOL', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19768, 735, 'O-PHENYLPHENOL', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17426, 735, 'O-PHENYLPHENOL', 'I', 4.6, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15242, 735, 'O-PHENYLPHENOL', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16133, 735, 'O-PHENYLPHENOL', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15498, 735, 'O-PHENYLPHENOL', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15499, 735, 'O-PHENYLPHENOL', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15500, 735, 'O-PHENYLPHENOL', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13706, 735, 'O-PHENYLPHENOL', 'I', 0.176, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14368, 735, 'O-PHENYLPHENOL', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13830, 735, 'O-PHENYLPHENOL', 'I', 0.176, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12408, 735, 'O-PHENYLPHENOL', 'I', 0.28, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12396, 735, 'O-PHENYLPHENOL', 'I', 9, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12288, 735, 'O-PHENYLPHENOL', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12254, 735, 'O-PHENYLPHENOL', 'I', 0.10, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12247, 735, 'O-PHENYLPHENOL', 'I', 9, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11343, 735, 'O-PHENYLPHENOL', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6212, 735, 'O-PHENYLPHENOL', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3797, 735, 'O-PHENYLPHENOL', 'I', 0.10, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4201, 735, 'O-PHENYLPHENOL', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3093, 735, 'O-PHENYLPHENOL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (233, 735, 'O-PHENYLPHENOL', 'I', 2.4, '%', '', '', 'N', '', 'Historic Freeform Text: O-             PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50814, 735, 'O-PHENYLPHENOL', 'I', 0.28, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60627, 735, 'O-PHENYLPHENOL', 'I', 0.199, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61475, 735, 'O-PHENYLPHENOL', 'I', 0.28, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60158, 735, 'O-PHENYLPHENOL', 'I', 3.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61020, 735, 'O-PHENYLPHENOL', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62709, 735, 'O-PHENYLPHENOL', 'I', 0.10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63709, 735, 'O-PHENYLPHENOL', 'I', 0.10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62881, 735, 'O-PHENYLPHENOL', 'I', 12.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66340, 735, 'O-PHENYLPHENOL', 'I', 3.55, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69060, 735, 'O-PHENYLPHENOL', 'I', 0.28, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72119, 735, 'O-PHENYLPHENOL', 'I', 0.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70836, 735, 'O-PHENYLPHENOL', 'I', 0.10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70166, 735, 'O-PHENYLPHENOL', 'I', 0.176, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70443, 735, 'O-PHENYLPHENOL', 'I', 1.47, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70493, 735, 'O-PHENYLPHENOL', 'I', 0.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76438, 735, 'O-PHENYLPHENOL', 'I', 1.11, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76472, 735, 'O-PHENYLPHENOL', 'I', 7.9, '%', '', '', 'N', '', 'QTY 7.95% (99.0% ACTIVE) EQUVALENT TO 7.9%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75267, 735, 'O-PHENYLPHENOL', 'I', 0.1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72344, 735, 'O-PHENYLPHENOL', 'I', 0.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75587, 735, 'O-PHENYLPHENOL', 'I', 0.1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75848, 735, 'O-PHENYLPHENOL', 'I', 0.14, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74887, 735, 'O-PHENYLPHENOL', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74949, 735, 'O-PHENYLPHENOL', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72700, 735, 'O-PHENYLPHENOL', 'I', 0.10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76854, 735, 'O-PHENYLPHENOL', 'I', 0.10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77124, 735, 'O-PHENYLPHENOL', 'I', 0.41, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76811, 735, 'O-PHENYLPHENOL', 'I', 0.10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79967, 735, 'O-PHENYLPHENOL', 'I', 0.14, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80691, 735, 'O-PHENYLPHENOL', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82117, 735, 'O-PHENYLPHENOL', 'I', 0.10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83945, 735, 'O-PHENYLPHENOL', 'I', 0.10, '%', '', '', 'N', '', 'Historic Freeform Text: O-PHENYLPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50653, 735, 'O-PHENYLPHENOL', 'I', 0.28, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82418, 735, 'O-PHENYLPHENOL', 'I', 0.28, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13749, 737, 'HYDROCOTYLE', 'I', 89.5, '%', '', '', 'N', '', 'V/V. HISTORIC FREEFORM TEXT: HYDROCOTYLE ((TINCTURE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14318, 738, 'BERACTANT', 'I', 25, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BERACTANT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43507, 741, 'GADOTERIDOL', 'I', 279.3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GADOTERIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37348, 742, 'HAEMAGGLUTININ-STRAIN B', 'I', 15, 'µG', '', '0.5', 'N', 'ML', 'Historic Freeform Text: HAEMAGGLUTININ-STRAIN B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14488, 742, 'HAEMAGGLUTININ-STRAIN B', 'I', 15, 'µG', '', '0.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HAEMAGGLUTININ-STRAIN B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75489, 742, 'HAEMAGGLUTININ-STRAIN B', 'I', 15, 'µG', '', '0.5', 'N', 'ML', 'WITH NEURAMINIDASE, AMT NOT QUANTIFIED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83225, 742, 'HAEMAGGLUTININ-STRAIN B', 'I', 15, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83409, 742, 'HAEMAGGLUTININ-STRAIN B', 'I', 9, 'µG', '', '0.1', 'N', 'ML', 'B/MALAYSIA/2506/2004-LIKE STRAIN. 2008-2009 FORMULA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37348, 743, 'HAEMAGGLUTININ-STRAIN A(H3N2)', 'I', 15, 'µG', '', '0.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HAEMAGGLUTININ-STRAIN A(H3N2)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14488, 743, 'HAEMAGGLUTININ-STRAIN A(H3N2)', 'I', 15, 'µG', '', '0.5', 'N', 'ML', 'Historic Freeform Text: HAEMAGGLUTININ-STRAIN A(H3N2)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75489, 743, 'HAEMAGGLUTININ-STRAIN A(H3N2)', 'I', 15, 'µG', '', '0.5', 'N', 'ML', 'WITH NEURAMINIDASE, AMT NOT QUANTIFIED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83225, 743, 'HAEMAGGLUTININ-STRAIN A(H3N2)', 'I', 15, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83409, 743, 'HAEMAGGLUTININ-STRAIN A(H3N2)', 'I', 9, 'µG', '', '0.1', 'N', 'ML', 'STRAIN A/WISCONSIN/67/2005 NYMC X-161(H3N2)- REASSORTANT STRAIN BETWEEN A/WISCONSIN/67/2005 AND A/PR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37348, 744, 'HAEMAGGLUTININ-STRAIN A(H1N1)', 'I', 15, 'µG', '', '0.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HAEMAGGLUTININ-STRAIN A(H1N1)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14488, 744, 'HAEMAGGLUTININ-STRAIN A(H1N1)', 'I', 15, 'µG', '', '0.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HAEMAGGLUTININ-STRAIN A(H1N1)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75489, 744, 'HAEMAGGLUTININ-STRAIN A(H1N1)', 'I', 15, 'µG', '', '0.5', 'N', 'ML', 'WITH NEURAMINIDASE, AMT NOT QUANTIFIED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83225, 744, 'HAEMAGGLUTININ-STRAIN A(H1N1)', 'I', 15, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83409, 744, 'HAEMAGGLUTININ-STRAIN A(H1N1)', 'I', 9, 'µG', '', '0.1', 'N', 'ML', 'STRAIN A/NEW CALEDONIA/20/99 IVR-116 (H1N1) REASSORTANT STRAIN BETWEEN A/NEW CALEDONIA 20/99 AND IVR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67066, 745, 'ANTIHEMOPHILIC FACTOR (RECOMBINANT)', 'I', 250, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67067, 745, 'ANTIHEMOPHILIC FACTOR (RECOMBINANT)', 'I', 500, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67068, 745, 'ANTIHEMOPHILIC FACTOR (RECOMBINANT)', 'I', 1000, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73938, 745, 'ANTIHEMOPHILIC FACTOR (RECOMBINANT)', 'I', 500, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73937, 745, 'ANTIHEMOPHILIC FACTOR (RECOMBINANT)', 'I', 250, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73939, 745, 'ANTIHEMOPHILIC FACTOR (RECOMBINANT)', 'I', 1000, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76968, 745, 'ANTIHEMOPHILIC FACTOR (RECOMBINANT)', 'I', 250, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76969, 745, 'ANTIHEMOPHILIC FACTOR (RECOMBINANT)', 'I', 500, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76970, 745, 'ANTIHEMOPHILIC FACTOR (RECOMBINANT)', 'I', 1000, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76971, 745, 'ANTIHEMOPHILIC FACTOR (RECOMBINANT)', 'I', 1500, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79422, 745, 'ANTIHEMOPHILIC FACTOR (RECOMBINANT)', 'I', 2000, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82824, 745, 'ANTIHEMOPHILIC FACTOR (RECOMBINANT)', 'I', 3000, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79865, 745, 'ANTIHEMOPHILIC FACTOR (RECOMBINANT)', 'I', 2000, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78756, 745, 'ANTIHEMOPHILIC FACTOR (RECOMBINANT)', 'I', 2000, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82280, 745, 'ANTIHEMOPHILIC FACTOR (RECOMBINANT)', 'I', 3000, 'UNIT', '', '', 'N', 'VIAL', 'THE INGREDIENT ANTIHEMOPHILIC FACTOR (RECOMBINANT)PLASMA/ALBUMIN FREE METHOD (RAHF-PFM) IS A HIGHLY ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35468, 748, 'PIPERAZINE DIHYDROCHLORIDE', 'I', 388.0, 'G', '', '400', 'N', 'G', 'EQUIVALENT TO 203.7G PIPERAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1326, 748, 'PIPERAZINE DIHYDROCHLORIDE', 'I', 97, 'G', '', '100', 'N', 'G', 'PIPERAZINE EQ.TO 52.5%W/W,SOL.PWR.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19610, 750, 'L-PHENYLALANINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19143, 750, 'L-PHENYLALANINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18550, 750, 'L-PHENYLALANINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 750, 'L-PHENYLALANINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14077, 750, 'L-PHENYLALANINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 750, 'L-PHENYLALANINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 750, 'L-PHENYLALANINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14073, 750, 'L-PHENYLALANINE HYDROCHLORIDE', 'I', 263, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 750, 'L-PHENYLALANINE HYDROCHLORIDE', 'I', 263, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14071, 750, 'L-PHENYLALANINE HYDROCHLORIDE', 'I', 263, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 750, 'L-PHENYLALANINE HYDROCHLORIDE', 'I', 155, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 750, 'L-PHENYLALANINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14067, 750, 'L-PHENYLALANINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 750, 'L-PHENYLALANINE HYDROCHLORIDE', 'I', 263, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-PHENYLALANINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76702, 752, 'AMOXICILLIN TRIHYDRATE', 'I', 800, 'MG', '', '', 'N', 'G', 'ACTIVE INGREDIENT CORRECTED TO AMOXICILLIN TRIHYDRATE AS PER PRODUCT LABEL./2006.11.28./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19037, 755, 'AVOBENZONE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BUTYL METHOXYDIBENZOYL METHANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15893, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: BUTYL METHOXYDIBENZOYL METHANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13954, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: BUTYL METHOXYDIBENZOYL METHANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13958, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: BUTYL METHOXYDIBENZOYL METHANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13929, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: BUTYL METHOXYDIBENZOYL METHANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13930, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: BUTYL METHOXYDIBENZOYL METHANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51733, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61235, 755, 'AVOBENZONE', 'I', 2.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60497, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64701, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64702, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64225, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67232, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65907, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65424, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65426, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65425, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64883, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64887, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66772, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66892, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68325, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68818, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69344, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68355, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68850, 755, 'AVOBENZONE', 'I', 1.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67949, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68574, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68595, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68117, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68186, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71359, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72192, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72275, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70085, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69552, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70253, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70881, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70903, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70998, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70999, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71098, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71099, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71100, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71101, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70541, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72053, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72068, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76470, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73900, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75172, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76603, 755, 'AVOBENZONE', 'I', 3.50, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76604, 755, 'AVOBENZONE', 'I', 3.50, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76634, 755, 'AVOBENZONE', 'I', 2.8, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76635, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74004, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74039, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75298, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76744, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75409, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75413, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75414, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73044, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74244, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72332, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74321, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75527, 755, 'AVOBENZONE', 'I', 1.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75528, 755, 'AVOBENZONE', 'I', 1.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75557, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75594, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75596, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72392, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75676, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75677, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75697, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75709, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73166, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74434, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74447, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74448, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74500, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74548, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74554, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74651, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74654, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75989, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75990, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73324, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74735, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74749, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76004, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76007, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73436, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76108, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76146, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73522, 755, 'AVOBENZONE', 'I', 3.06, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74916, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76179, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76213, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76214, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73587, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74918, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74992, 755, 'AVOBENZONE', 'I', 2.44, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76247, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73755, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73756, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76325, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76328, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73821, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77488, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78164, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77531, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77577, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77578, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77610, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77612, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78218, 755, 'AVOBENZONE', 'I', 3.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77613, 755, 'AVOBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77122, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77123, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76897, 755, 'AVOBENZONE', 'I', 1.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76898, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77374, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77629, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77608, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77681, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77682, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77925, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78154, 755, 'AVOBENZONE', 'I', 1.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78156, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77812, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77383, 755, 'AVOBENZONE', 'I', 3.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78220, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78221, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76869, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78310, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78311, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78317, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76910, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77768, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77926, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76934, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78014, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78019, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78020, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77617, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78331, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78343, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78345, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77287, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82245, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79960, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79018, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78656, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78689, 755, 'AVOBENZONE', 'I', 3.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78690, 755, 'AVOBENZONE', 'I', 3.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79181, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79182, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80443, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78611, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78700, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78701, 755, 'AVOBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79265, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78709, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78989, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78990, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79294, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79798, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78957, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78958, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78959, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78813, 755, 'AVOBENZONE', 'I', 3.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79295, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79719, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79407, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80173, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80438, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78621, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78893, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78894, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78895, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79252, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79253, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79255, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79257, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78604, 755, 'AVOBENZONE', 'I', 3.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78929, 755, 'AVOBENZONE', 'I', 3.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78930, 755, 'AVOBENZONE', 'I', 3.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80565, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79238, 755, 'AVOBENZONE', 'I', 2.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79319, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79320, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79930, 755, 'AVOBENZONE', 'I', 1.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79931, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79197, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78629, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78635, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79982, 755, 'AVOBENZONE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79067, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79226, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79227, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79232, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79233, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79992, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80227, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80110, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80111, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80641, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81860, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81861, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78578, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78647, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82839, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82383, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79098, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79184, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79187, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79086, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82622, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80820, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66809, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84131, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84132, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84541, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84603, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85091, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66753, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65475, 755, 'AVOBENZONE', 'I', 2.50, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69095, 755, 'AVOBENZONE', 'I', 3.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76605, 755, 'AVOBENZONE', 'I', 3.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74228, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75689, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72549, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75980, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76030, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76200, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76215, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74967, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74968, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74969, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74970, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76204, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77368, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77389, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77391, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78219, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76938, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76863, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76891, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77633, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77721, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76941, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78297, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77340, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77341, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81654, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81656, 755, 'AVOBENZONE', 'I', 2.50, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81144, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81175, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79851, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81909, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79531, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81268, 755, 'AVOBENZONE', 'I', 2.85, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82780, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82843, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79579, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80128, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80480, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80566, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82206, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82242, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82930, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82931, 755, 'AVOBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82964, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79731, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78685, 755, 'AVOBENZONE', 'I', 3.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78686, 755, 'AVOBENZONE', 'I', 3.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79183, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80487, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80488, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80350, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79766, 755, 'AVOBENZONE', 'I', 3.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80723, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82834, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80748, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80791, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81406, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79217, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82015, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82016, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82018, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82268, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82269, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82161, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82592, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79044, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81716, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79468, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79469, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79470, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80088, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79605, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79747, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80025, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80026, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80027, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80174, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80175, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80176, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80435, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80436, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80398, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80400, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81454, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81366, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81367, 755, 'AVOBENZONE', 'I', 0.9, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81371, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81370, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81372, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79971, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81337, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80049, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80050, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80051, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80052, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80055, 755, 'AVOBENZONE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80056, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82493, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82494, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82987, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80198, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80199, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80200, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81604, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81605, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'Y', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81708, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81709, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77392, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77390, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81457, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81557, 755, 'AVOBENZONE', 'I', 1.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81779, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81842, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82013, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82014, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82508, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80219, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80327, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80328, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80478, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80568, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79980, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79983, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80810, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80023, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80024, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80022, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80411, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81076, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79524, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79595, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79989, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80113, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80460, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80069, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80070, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81829, 755, 'AVOBENZONE', 'I', 2.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81266, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82305, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82515, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80393, 755, 'AVOBENZONE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80858, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81926, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81927, 755, 'AVOBENZONE', 'I', 1.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81929, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81930, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81928, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81931, 755, 'AVOBENZONE', 'I', 0.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81892, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81893, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81894, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82381, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82415, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80362, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79484, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80383, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80425, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81911, 755, 'AVOBENZONE', 'I', 2.1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80061, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80515, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80516, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80517, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80525, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80526, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80524, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81043, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81044, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82367, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82017, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82019, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82020, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80669, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80670, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81912, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81913, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81914, 755, 'AVOBENZONE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81915, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81916, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81919, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81920, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81921, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82621, 755, 'AVOBENZONE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80503, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80504, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78222, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83050, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79249, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82244, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82373, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82462, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80254, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80256, 755, 'AVOBENZONE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80539, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82060, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82063, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82065, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82067, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80034, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80035, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80177, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80178, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81069, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82610, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80099, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80302, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82543, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78779, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80864, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80865, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83001, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79868, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80380, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80567, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82779, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79784, 755, 'AVOBENZONE', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81488, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82167, 755, 'AVOBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83072, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83098, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83101, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83388, 755, 'AVOBENZONE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83389, 755, 'AVOBENZONE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83391, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83403, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83420, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83564, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83580, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83581, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83677, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83772, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83773, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83775, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83785, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83786, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83787, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83859, 755, 'AVOBENZONE', 'I', 3.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83866, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83869, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83881, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80228, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83902, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83908, 755, 'AVOBENZONE', 'I', 2.85, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83983, 755, 'AVOBENZONE', 'I', 2.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83984, 755, 'AVOBENZONE', 'I', 2.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84003, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84004, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84006, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84032, 755, 'AVOBENZONE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84033, 755, 'AVOBENZONE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84034, 755, 'AVOBENZONE', 'I', 3.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84035, 755, 'AVOBENZONE', 'I', 2.80, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84036, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84039, 755, 'AVOBENZONE', 'I', 0.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84041, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84042, 755, 'AVOBENZONE', 'I', 2.85, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84061, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84076, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84092, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84118, 755, 'AVOBENZONE', 'I', 0.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84119, 755, 'AVOBENZONE', 'I', 0.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84207, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84257, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84262, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84291, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84403, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84414, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84415, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84423, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84424, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84431, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84472, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84519, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84520, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84530, 755, 'AVOBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84574, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84579, 755, 'AVOBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84706, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84707, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84713, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84715, 755, 'AVOBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84959, 755, 'AVOBENZONE', 'I', 3.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84962, 755, 'AVOBENZONE', 'I', 3.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84974, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84975, 755, 'AVOBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18554, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: BUTYL METHOXYDIBENZOYL METHANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15799, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: BUTYL METHOXYDIBENZOYL METHANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50132, 755, 'AVOBENZONE', 'I', 2, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50134, 755, 'AVOBENZONE', 'I', 2.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64736, 755, 'AVOBENZONE', 'I', 1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64737, 755, 'AVOBENZONE', 'I', 1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64739, 755, 'AVOBENZONE', 'I', 1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64738, 755, 'AVOBENZONE', 'I', 1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64740, 755, 'AVOBENZONE', 'I', 1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83672, 755, 'AVOBENZONE', 'I', 3, '%', '', '50', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61313, 755, 'AVOBENZONE', 'I', 2, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62467, 755, 'AVOBENZONE', 'I', 3, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62885, 755, 'AVOBENZONE', 'I', 30, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37925, 759, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE', 'I', 10.59, '%', '', '', 'N', '', 'Historic Freeform Text: NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26011, 759, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE', 'I', 12.6, '%', '', '', 'N', '', 'Historic Freeform Text: NONOXYNOL IODOPHOR ((IODINE 1.75%EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11677, 759, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NONYL PHENOXYPOLY IODINE COMP ((IODINE FREE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9160, 759, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE', 'I', 16.84, '%', '', '', 'N', '', 'Historic Freeform Text: NONOXYNOL IODOPHOR ((IODINE 1.75% EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9555, 759, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE', 'I', 4.25, '%', '', '', 'N', '', 'Historic Freeform Text: NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3774, 759, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE', 'I', 12.4, '%', '', '', 'N', '', 'Historic Freeform Text: NONOXYNOL IODOPHOR ((IODINE 1.75% EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3456, 759, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE', 'I', 3.5, '%', '', '', 'N', '', 'Historic Freeform Text: NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2305, 759, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE', 'I', 6, '%', '', '', 'N', '', 'Historic Freeform Text: NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2199, 759, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE', 'I', 18.05, '%', '', '', 'N', '', 'Historic Freeform Text: NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18043, 759, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE', 'I', 1.7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70180, 759, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE', 'I', 18.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2957, 759, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE', 'I', 18.5, '%', '', '', 'N', 'W/W', 'W/W HISTORIC FREEFORM TEXT: NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX (PROVIDING 1.9% AVAILABL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4067, 759, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE', 'I', 8.10, '%', '', '', 'N', 'W/V', 'Historic Freeform Text: NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1957, 759, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE', 'I', 2.584, '%', '', '', 'N', 'W/V', 'Historic Freeform Text: NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24726, 759, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE', 'I', 0.25, '%', '', '', 'N', '%', 'Historic Freeform Text: NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10387, 759, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE', 'I', 14.6, '%', '', '', 'N', '%', 'Historic Freeform Text: NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5428, 759, 'NONYL PHENOXYPOLY ETHOXY ETHANOL-IODINE', 'I', 5.46, '%', '', '', 'N', '%', 'Historic Freeform Text: NONOXYNOL IODOPHOR ((IODINE 1% EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26011, 761, 'PHOSPHORIC ACID', 'I', 15.95, '%', '', '', 'N', '', 'Historic Freeform Text: PHOSPHORIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19421, 761, 'PHOSPHORIC ACID', 'I', 30, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PHOSPHORIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19633, 761, 'PHOSPHORIC ACID', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: PHOSPHORIC ACID ((75%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18016, 761, 'PHOSPHORIC ACID', 'I', 30, '%', '', '', 'N', '', 'Historic Freeform Text: PHOSPHORIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2954, 761, 'PHOSPHORIC ACID', 'I', 6.5, '%', '', '', 'N', '', 'Historic Freeform Text: PHOSPHORIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2802, 761, 'PHOSPHORIC ACID', 'I', 21, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PHOSPHORIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2199, 761, 'PHOSPHORIC ACID', 'I', 16, '%', '', '', 'N', '', 'Historic Freeform Text: PHOSPHORIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71086, 761, 'PHOSPHORIC ACID', 'I', 17.4, '%', '', '', 'N', '', 'PHOSPHORIC ACID (75%)   -23.25% /WT.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74898, 761, 'PHOSPHORIC ACID', 'I', 12.75, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76049, 761, 'PHOSPHORIC ACID', 'I', 20.50, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2957, 761, 'PHOSPHORIC ACID', 'I', 2.25, '%', '', '', 'N', 'W/W', 'W/W HISTORIC FREEFORM TEXT: PHOSPHORIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80014, 761, 'PHOSPHORIC ACID', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4067, 761, 'PHOSPHORIC ACID', 'I', 12.7, '%', '', '', 'N', 'W/V', 'PHOSPORIC ACID ADDED AS AN ACTIVE INGREDIENT DURING CONTROL NO. 137262.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28197, 761, 'PHOSPHORIC ACID', 'I', 12, '%', '', '', 'N', '%', 'Historic Freeform Text: PHOSPHORIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11016, 761, 'PHOSPHORIC ACID', 'I', 10, '%', '', '', 'N', '%', 'Historic Freeform Text: PHOSPHORIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13988, 731, 'BENZYL DI-HYDROXYETHYL-COCOALKYL-AMMONIUM CHL', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZYL DI-HYDROXYETHYL-COCOALKYL-AMMONIUM CHL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81040, 698, 'POLYETHYLENE GLYCOL 3350', 'I', 100, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81606, 698, 'POLYETHYLENE GLYCOL 3350', 'I', 100, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83209, 698, 'POLYETHYLENE GLYCOL 3350', 'I', 100, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84310, 698, 'POLYETHYLENE GLYCOL 3350', 'I', 100, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80366, 698, 'POLYETHYLENE GLYCOL 3350', 'I', 100, '%', '', '', 'N', 'W/W', 'ONE DOSE IS 17G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81376, 698, 'POLYETHYLENE GLYCOL 3350', 'I', 100, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33649, 698, 'POLYETHYLENE GLYCOL 3350', 'I', 59.00, 'G', '', '', 'N', 'PCK', 'Historic Freeform Text: POLYETHYLENE GLYCOL 3350');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81164, 698, 'POLYETHYLENE GLYCOL 3350', 'I', 59.55, 'G', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84451, 698, 'POLYETHYLENE GLYCOL 3350', 'I', 100.0, 'G', '', '', 'N', 'PCK', 'SACHET A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80321, 698, 'POLYETHYLENE GLYCOL 3350', 'I', 1, 'G', '', '', 'N', 'G', '17G/DOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6616, 698, 'POLYETHYLENE GLYCOL 3350', 'I', 857.69, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: CARBOWAX POLYETHYLENE GLYCOL 3350/JJ ACTIVE CHANGED TO POLYETHYLENE GLYCOL (');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41796, 700, 'HEXYLRESORCINOL', 'I', 2.4, 'MG', '', '', 'N', '', 'Historic Freeform Text: 4-HEXYLRESORCINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33590, 700, 'HEXYLRESORCINOL', 'I', 2.4, 'MG', '', '', 'N', '', 'Historic Freeform Text: HEXYLRESORCINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11320, 700, 'HEXYLRESORCINOL', 'I', 3.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: 4-HEXYLRESORCINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11321, 700, 'HEXYLRESORCINOL', 'I', 3.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: 4-HEXYLRESORCINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48138, 700, 'HEXYLRESORCINOL', 'I', 3.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: 4-HEXYLRESORCINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67829, 700, 'HEXYLRESORCINOL', 'I', 2.4, 'MG', '', '', 'N', '', 'Historic Freeform Text: 4-HEXYLRESORCINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74940, 700, 'HEXYLRESORCINOL', 'I', 2.4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19363, 700, 'HEXYLRESORCINOL', 'I', 2.4, 'MG', '', '', 'N', 'LOZ', 'Historic Freeform Text: 4-HEXYLRESORCINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 701, 'VITAMIN E', 'I', 50, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: VIT. E.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (236, 701, 'VITAMIN E', 'I', 5, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: VIT. E.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 701, 'VITAMIN E (D-ALPHA TOCOPHERYL ACETATE)', 'I', 65, 'UNIT', '', '', 'Y', '', 'IU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70202, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 30, 'UNIT', '', '', 'N', '', 'PINK TABLET A.M.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76186, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 30, 'UNIT', '', '', 'N', '', 'PINK TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66277, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 7, 'UNIT', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82225, 701, 'VITAMIN E (DL-ALPHA TOCOPHEROL)', 'I', 11.86, 'MG', '', '0.5', 'N', 'ML', 'ADJUVANT FULL DOSE, CLASSIFIED UNDER MI AS PER BGTD');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16462, 701, 'VITAMIN E', 'I', 2, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VITAMIN E ((VIAL 1))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12954, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 136, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. E.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9325, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 100, 'UNIT', '', '', 'Y', 'ML', 'Historic Freeform Text: VIT E ((DL @ TOCOPH ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5613, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 1, 'UNIT', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: VIT. E ((DL@ TOCOPH. ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6716, 701, 'VITAMIN E', 'I', 14, 'UNIT', '', '7.5', 'N', 'ML', 'Historic Freeform Text: VIT. E.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6646, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 136, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. E.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4714, 701, 'VITAMIN E (D-ALPHA TOCOPHERYL ACETATE)', 'I', 68, 'UNIT', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: VIT. E ((AS D@  TOCOPHERYL ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4517, 701, 'VITAMIN E (D-ALPHA TOCOPHERYL ACETATE)', 'I', 68, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VIT E ((AS D@  TOCOPHERYL ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2473, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 136, 'UNIT', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: DL@TOCOPHERYL ACETATE ((VIT. E EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (870, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 136, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: TOCOPHERYL D-@ ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62354, 701, 'VITAMIN E (D-ALPHA TOCOPHEROL)', 'I', 300, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63765, 701, 'VITAMIN E (D-ALPHA TOCOPHERYL ACETATE)', 'I', 50, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63763, 701, 'VITAMIN E (D-ALPHA TOCOPHERYL ACETATE)', 'I', 50, 'UNIT', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68684, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 2, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74400, 701, 'VITAMIN E (D-ALPHA TOCOPHEROL)', 'I', 300, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82159, 701, 'VITAMIN E (ALPHA TOCOPHEROL ACETATE)', 'I', 15, 'UNIT', '', '8', 'N', 'ML', 'VITAMIN E SUPPLIED AS ALPHA TOCOPHEROL ACETATE LABEL MISSING SUPPLIED AS PART MISSING FROM LABEL VDD');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 701, 'VITAMIN E', 'I', 4400, 'UNIT', '', '', 'N', 'KG', 'Historic Freeform Text: VIT. E.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19635, 701, 'VITAMIN E', 'I', 550, 'UNIT', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: VITAMIN E');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11033, 701, 'VITAMIN E', 'I', 275, 'UNIT', '', '', 'N', 'KG', 'Historic Freeform Text: VIT. E.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 870, 'UNIT', '', '', 'Y', 'KG', 'HISTORIC FREEFORM TEXT: VIT. E ((DL @ TOCOPHERYL ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8267, 701, 'VITAMIN E', 'I', 572, 'UNIT', '', '', 'N', 'KG', 'Historic Freeform Text: VIT. E.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5784, 701, 'VITAMIN E', 'I', 550, 'UNIT', '', '', 'N', 'KG', 'Historic Freeform Text: VIT. E.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82282, 701, 'VITAMIN E', 'I', 572, 'UNIT', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36843, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 1500, 'UNIT', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: DL-ALPHA TOCOPHERYL ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33790, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 2, 'UNIT', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: TOCOPHERYL DL-ALPHA ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24471, 701, 'VITAMIN E', 'I', 1870, 'UNIT', '', '170', 'N', 'G', 'Historic Freeform Text: VIT. E.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24400, 701, 'VITAMIN E', 'I', 780, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: TOCOPHERYL DL-ALPHA ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17818, 701, 'VITAMIN E', 'I', 1500, 'UNIT', '', '400', 'N', 'G', 'Historic Freeform Text: TOCOPHERYL DL-ALPHA ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 701, 'VITAMIN E', 'I', 1870, 'UNIT', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: TOCOPHERYL DL-ALPHA ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14119, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 1500, 'UNIT', '', '400', 'N', 'G', 'Historic Freeform Text: VIT E ((DL @ TOCOPH ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14115, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 750, 'UNIT', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: TOCOPHERYL DL-ALPHA ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14113, 701, 'VITAMIN E', 'I', 1870, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: VIT. E.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12922, 701, 'VITAMIN E', 'I', 4500, 'UNIT', '', '400', 'N', 'G', 'Historic Freeform Text: VIT. E.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12923, 701, 'VITAMIN E', 'I', 2.42, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: VIT. E.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15001, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 2, 'UNIT', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: TOCOPHERYL DL-ALPHA ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6566, 701, 'VITAMIN E', 'I', 35, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: VIT. E.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5322, 701, 'VITAMIN E', 'I', 1.98, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: VIT. E.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5144, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 750, 'UNIT', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: VIT. E ((AS DL@ TOCOPHERYL ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5125, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 750, 'UNIT', '', '100', 'Y', 'G', 'HISTORIC FREEFORM TEXT: VIT. E ((FROM DL@ TOCOPH. ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1617, 701, 'VITAMIN E', 'I', 1150, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: VIT. E.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2119, 701, 'VITAMIN E', 'I', 1000, 'UNIT', '', '30', 'N', 'G', 'Historic Freeform Text: VIT. E.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64903, 701, 'VITAMIN E', 'I', 50, 'UNIT', '', '400', 'N', 'G', '50 IU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66631, 701, 'VITAMIN E (DL-ALPHA TOCOPHERYL ACETATE)', 'I', 100, 'UNIT', '', '300', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12345, 703, 'VITAMIN D (VITAMIN D3)', 'I', 10000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: VIT D ((CHOLECALCIFEROL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5698, 703, 'VITAMIN D', 'I', 2000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: VIT. D');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1142, 703, 'VITAMIN D', 'I', 6250, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: VIT. D');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 703, 'VITAMIN D', 'I', 5000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: VIT. D');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66277, 703, 'VITAMIN D', 'I', 400, 'UNIT', '', '', 'Y', 'VIAL', 'IU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16462, 703, 'VITAMIN D', 'I', 40, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VITAMIN D ((VIAL 1))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75457, 719, 'SIMETHICONE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12901, 703, 'VITAMIN D', 'I', 75000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. D');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12874, 703, 'VITAMIN D', 'I', 1500, 'UNIT', '', '30', 'N', 'ML', 'Historic Freeform Text: VIT. D');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6072, 703, 'VITAMIN D', 'I', 200, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. D');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5923, 703, 'VITAMIN D', 'I', 75000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. D');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5887, 703, 'VITAMIN D', 'I', 75000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. D');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5613, 703, 'VITAMIN D', 'I', 100, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VIT. D');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5698, 704, 'VITAMIN A', 'I', 10000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2005, 704, 'VITAMIN A', 'I', 50000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1142, 704, 'VITAMIN A', 'I', 62500, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: VIT. A (ALCOHOL)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1612, 704, 'VITAMIN A', 'I', 50000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 704, 'VITAMIN A', 'I', 50000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (502, 704, 'VITAMIN A', 'I', 25000, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: VIT. A (ALCOHOL)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (503, 704, 'VITAMIN A', 'I', 50000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: VIT. A (ALCOHOL)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (236, 704, 'VITAMIN A', 'I', 6000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: VIT. A (ALCOHOL)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 704, 'VITAMIN A (VITAMIN A PALMITATE)', 'I', 4000, 'UNIT', '', '', 'Y', '', 'IU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66277, 704, 'VITAMIN A', 'I', 2300, 'UNIT', '', '', 'Y', 'VIAL', 'IU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22007, 704, 'VITAMIN A', 'I', 958.3, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16462, 704, 'VITAMIN A', 'I', 660, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VITAMIN A ((VIAL 1))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12901, 704, 'VITAMIN A', 'I', 500000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12874, 704, 'VITAMIN A', 'I', 6000, 'UNIT', '', '30', 'N', 'ML', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9372, 704, 'VITAMIN A', 'I', 958.3, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6072, 704, 'VITAMIN A', 'I', 2000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5923, 704, 'VITAMIN A', 'I', 500000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5887, 704, 'VITAMIN A', 'I', 500000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5607, 704, 'VITAMIN A', 'I', 500000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5613, 704, 'VITAMIN A', 'I', 1000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6716, 704, 'VITAMIN A', 'I', 850, 'UNIT', '', '7.5', 'N', 'ML', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68684, 704, 'VITAMIN A', 'I', 660, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82159, 704, 'VITAMIN A (VITAMIN A PALMITATE)', 'I', 1088, 'UNIT', '', '8', 'N', 'ML', 'VITAMIN A SUPPLIED AS PALMITATE - THIS PART MISSING FROM LABEL, VDD HAS BEEN SENT AN E-MAIL.EW');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 704, 'VITAMIN A', 'I', 4400000, 'UNIT', '', '', 'N', 'KG', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19635, 704, 'VITAMIN A', 'I', 550000, 'UNIT', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: VITAMIN A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11033, 704, 'VITAMIN A', 'I', 275000, 'UNIT', '', '', 'N', 'KG', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 704, 'VITAMIN A (VITAMIN A ACETATE)', 'I', 348143, 'UNIT', '', '', 'Y', 'KG', 'HISTORIC FREEFORM TEXT: VIT. A ((ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8267, 704, 'VITAMIN A', 'I', 550000, 'UNIT', '', '', 'N', 'KG', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5784, 704, 'VITAMIN A', 'I', 550000, 'UNIT', '', '', 'N', 'KG', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 704, 'VITAMIN A', 'I', 1320000, 'UNIT', '', '', 'N', 'KG', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82282, 704, 'VITAMIN A', 'I', 550000, 'UNIT', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: VIT.A ((RETINYL ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36843, 704, 'VITAMIN A (VITAMIN A ACETATE)', 'I', 1280000, 'UNIT', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: VITAMIN A ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33790, 704, 'VITAMIN A (VITAMIN A ACETATE)', 'I', 6600, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: VIT. A ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24471, 704, 'VITAMIN A', 'I', 1870000, 'UNIT', '', '170', 'N', 'G', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24400, 704, 'VITAMIN A', 'I', 968750, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17818, 704, 'VITAMIN A (VITAMIN A ACETATE)', 'I', 1280000, 'UNIT', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: VIT. A ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14165, 704, 'VITAMIN A', 'I', 240000, 'UNIT', '', '450', 'N', 'G', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14115, 704, 'VITAMIN A', 'I', 750000, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14119, 704, 'VITAMIN A', 'I', 1280000, 'UNIT', '', '400', 'N', 'G', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14113, 704, 'VITAMIN A', 'I', 2566000, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12922, 704, 'VITAMIN A', 'I', 4500000, 'UNIT', '', '400', 'N', 'G', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8101, 704, 'VITAMIN A', 'I', 210000, 'UNIT', '', '400', 'N', 'G', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5322, 704, 'VITAMIN A', 'I', 6610.7, 'UNIT', '', '', 'N', 'G', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5144, 704, 'VITAMIN A', 'I', 750000, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5125, 704, 'VITAMIN A', 'I', 750000, 'UNIT', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3926, 704, 'VITAMIN A', 'I', 240000, 'UNIT', '', '450', 'N', 'G', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1617, 704, 'VITAMIN A', 'I', 1150000, 'UNIT', '', '100', 'N', 'G', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1613, 704, 'VITAMIN A', 'I', 400000, 'UNIT', '', '454', 'N', 'G', 'Historic Freeform Text: VIT. A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50391, 704, 'VITAMIN A (RETINOL)', 'I', 1200, 'UNIT', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66631, 704, 'VITAMIN A (VITAMIN A ACETATE)', 'I', 200000, 'UNIT', '', '300', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14532, 707, 'TERBINAFINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: TERBINAFINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62135, 707, 'TERBINAFINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37084, 710, 'DEXTRAN 70', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: DEXTRAN 70');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21686, 710, 'DEXTRAN 70', 'I', 6, '%', '', '', 'N', '', 'Historic Freeform Text: DEXTRAN ((70))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73019, 710, 'DEXTRAN 70', 'I', 0.1, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81391, 710, 'DEXTRAN 70', 'I', 0.1, '%', '', '', 'N', 'W/V', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82979, 710, 'DEXTRAN 70', 'I', 0.1, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14161, 716, 'PENTOSAN POLYSULFATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: PENTOSAN POLYSULFATE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19092, 716, 'PENTOSAN POLYSULFATE SODIUM', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PENTOSAN POLYSULFATE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41821, 719, 'SIMETHICONE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: SIMETHICONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19075, 719, 'SIMETHICONE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SIMETHICONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13362, 719, 'SIMETHICONE', 'I', 125, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SIMETHICONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11914, 719, 'SIMETHICONE', 'I', 125, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SIMETHICONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1889, 719, 'SIMETHICONE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (188, 719, 'SIMETHICONE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60618, 719, 'SIMETHICONE', 'I', 125, 'MG', '', '', 'N', '', 'FORM = CHEWABLE TABLET.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61044, 719, 'SIMETHICONE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63534, 719, 'SIMETHICONE', 'I', 51.2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62764, 719, 'SIMETHICONE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65429, 719, 'SIMETHICONE', 'I', 166, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SIMETHICONE DOSAGE FORM = SOFTGELS (CAPSULES)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67414, 719, 'SIMETHICONE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69154, 719, 'SIMETHICONE', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69155, 719, 'SIMETHICONE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68167, 719, 'SIMETHICONE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69200, 719, 'SIMETHICONE', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71367, 719, 'SIMETHICONE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71557, 719, 'SIMETHICONE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75572, 719, 'SIMETHICONE', 'I', 62.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78612, 719, 'SIMETHICONE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81363, 719, 'SIMETHICONE', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26833, 719, 'SIMETHICONE', 'I', 25, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SIMETHICONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19082, 719, 'SIMETHICONE', 'I', 25, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SIMETHICONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (198, 719, 'SIMETHICONE', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (187, 719, 'SIMETHICONE', 'I', 25, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68677, 719, 'SIMETHICONE', 'I', 20, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SIMETHICONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79827, 723, 'RISPERIDONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68678, 719, 'SIMETHICONE', 'I', 40, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SIMETHICONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69597, 719, 'SIMETHICONE', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75184, 719, 'SIMETHICONE', 'I', 20, 'MG', '', '0.3', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72943, 719, 'SIMETHICONE', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74304, 719, 'SIMETHICONE', 'I', 40, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74696, 719, 'SIMETHICONE', 'I', 20, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19075, 720, 'MAGNESIUM HYDROXIDE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: MAGNESIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (188, 720, 'MAGNESIUM HYDROXIDE', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MAGNESIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66915, 720, 'MAGNESIUM HYDROXIDE', 'I', 165, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44552, 720, 'MAGNESIUM HYDROXIDE', 'I', 200, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26833, 720, 'MAGNESIUM HYDROXIDE', 'I', 200, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19082, 720, 'MAGNESIUM HYDROXIDE', 'I', 200, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18186, 720, 'MAGNESIUM HYDROXIDE', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13074, 720, 'MAGNESIUM HYDROXIDE', 'I', 200, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MAGNESIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10217, 720, 'MAGNESIUM HYDROXIDE', 'I', 200, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1281, 720, 'MAGNESIUM HYDROXIDE', 'I', 60, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MAGNESIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (187, 720, 'MAGNESIUM HYDROXIDE', 'I', 200, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68677, 720, 'MAGNESIUM HYDROXIDE', 'I', 200, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MAGNESIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68678, 720, 'MAGNESIUM HYDROXIDE', 'I', 400, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MAGNESIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74304, 720, 'MAGNESIUM HYDROXIDE', 'I', 400, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74696, 720, 'MAGNESIUM HYDROXIDE', 'I', 200, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13922, 723, 'RISPERIDONE', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: RISPERIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13903, 723, 'RISPERIDONE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: RISPERIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13904, 723, 'RISPERIDONE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: RISPERIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13906, 723, 'RISPERIDONE', 'I', 3, 'MG', '', '', 'N', '', 'Historic Freeform Text: RISPERIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64121, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RISPERIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64122, 723, 'RISPERIDONE', 'I', 0.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RISPERIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71971, 723, 'RISPERIDONE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71973, 723, 'RISPERIDONE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71974, 723, 'RISPERIDONE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76402, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76403, 723, 'RISPERIDONE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76404, 723, 'RISPERIDONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76405, 723, 'RISPERIDONE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76406, 723, 'RISPERIDONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76407, 723, 'RISPERIDONE', 'I', 4.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76539, 723, 'RISPERIDONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76540, 723, 'RISPERIDONE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76541, 723, 'RISPERIDONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76542, 723, 'RISPERIDONE', 'I', 4.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76658, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RISPERIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76659, 723, 'RISPERIDONE', 'I', 0.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RISPERIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76660, 723, 'RISPERIDONE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: RISPERIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76663, 723, 'RISPERIDONE', 'I', 3, 'MG', '', '', 'N', '', 'Historic Freeform Text: RISPERIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76662, 723, 'RISPERIDONE', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: RISPERIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76664, 723, 'RISPERIDONE', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: RISPERIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75347, 723, 'RISPERIDONE', 'I', 3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75348, 723, 'RISPERIDONE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76778, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76780, 723, 'RISPERIDONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76779, 723, 'RISPERIDONE', 'I', 0.50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76781, 723, 'RISPERIDONE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76782, 723, 'RISPERIDONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76783, 723, 'RISPERIDONE', 'I', 4.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76790, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76791, 723, 'RISPERIDONE', 'I', 0.50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76792, 723, 'RISPERIDONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76793, 723, 'RISPERIDONE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76794, 723, 'RISPERIDONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76795, 723, 'RISPERIDONE', 'I', 4.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74364, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74365, 723, 'RISPERIDONE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74366, 723, 'RISPERIDONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74367, 723, 'RISPERIDONE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74368, 723, 'RISPERIDONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74369, 723, 'RISPERIDONE', 'I', 4.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74961, 723, 'RISPERIDONE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74963, 723, 'RISPERIDONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74964, 723, 'RISPERIDONE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74965, 723, 'RISPERIDONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74966, 723, 'RISPERIDONE', 'I', 4.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73690, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73691, 723, 'RISPERIDONE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73692, 723, 'RISPERIDONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73693, 723, 'RISPERIDONE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73694, 723, 'RISPERIDONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73695, 723, 'RISPERIDONE', 'I', 4.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75026, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75027, 723, 'RISPERIDONE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75028, 723, 'RISPERIDONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75029, 723, 'RISPERIDONE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75030, 723, 'RISPERIDONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75031, 723, 'RISPERIDONE', 'I', 4.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76833, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76916, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76917, 723, 'RISPERIDONE', 'I', 0.50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76918, 723, 'RISPERIDONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76919, 723, 'RISPERIDONE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76920, 723, 'RISPERIDONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76921, 723, 'RISPERIDONE', 'I', 4.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77713, 723, 'RISPERIDONE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77714, 723, 'RISPERIDONE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77715, 723, 'RISPERIDONE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76822, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76823, 723, 'RISPERIDONE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76824, 723, 'RISPERIDONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76825, 723, 'RISPERIDONE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76826, 723, 'RISPERIDONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76827, 723, 'RISPERIDONE', 'I', 4.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78879, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78880, 723, 'RISPERIDONE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78881, 723, 'RISPERIDONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78882, 723, 'RISPERIDONE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78883, 723, 'RISPERIDONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78884, 723, 'RISPERIDONE', 'I', 4.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79823, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79824, 723, 'RISPERIDONE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79825, 723, 'RISPERIDONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79826, 723, 'RISPERIDONE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79828, 723, 'RISPERIDONE', 'I', 4.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81383, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81384, 723, 'RISPERIDONE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81385, 723, 'RISPERIDONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81386, 723, 'RISPERIDONE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81388, 723, 'RISPERIDONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81389, 723, 'RISPERIDONE', 'I', 4.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78897, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78898, 723, 'RISPERIDONE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84200, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84201, 723, 'RISPERIDONE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84202, 723, 'RISPERIDONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84203, 723, 'RISPERIDONE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84204, 723, 'RISPERIDONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84205, 723, 'RISPERIDONE', 'I', 4.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84454, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84455, 723, 'RISPERIDONE', 'I', 0.50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84456, 723, 'RISPERIDONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84457, 723, 'RISPERIDONE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84458, 723, 'RISPERIDONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84459, 723, 'RISPERIDONE', 'I', 4.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84478, 723, 'RISPERIDONE', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84479, 723, 'RISPERIDONE', 'I', 0.50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84480, 723, 'RISPERIDONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84481, 723, 'RISPERIDONE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84482, 723, 'RISPERIDONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84483, 723, 'RISPERIDONE', 'I', 4.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74089, 723, 'RISPERIDONE', 'I', 25, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74091, 723, 'RISPERIDONE', 'I', 37.5, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74093, 723, 'RISPERIDONE', 'I', 50, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78377, 723, 'RISPERIDONE', 'I', 12.5, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60243, 723, 'RISPERIDONE (RISPERIDONE TARTRATE)', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76481, 723, 'RISPERIDONE (RISPERIDONE TARTRATE)', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76606, 723, 'RISPERIDONE (RISPERIDONE TARTRATE)', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37916, 727, 'TITANIUM DIOXIDE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: TITANIUM DIOXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19037, 727, 'TITANIUM DIOXIDE', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: TITANIUM DIOXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75823, 727, 'TITANIUM DIOXIDE', 'I', 3.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50939, 727, 'TITANIUM DIOXIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50532, 727, 'TITANIUM DIOXIDE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60497, 727, 'TITANIUM DIOXIDE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62357, 727, 'TITANIUM DIOXIDE', 'I', 0.75, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65907, 727, 'TITANIUM DIOXIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65423, 727, 'TITANIUM DIOXIDE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65427, 727, 'TITANIUM DIOXIDE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64887, 727, 'TITANIUM DIOXIDE', 'I', 2.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69393, 727, 'TITANIUM DIOXIDE', 'I', 1.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69394, 727, 'TITANIUM DIOXIDE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68570, 727, 'TITANIUM DIOXIDE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70904, 727, 'TITANIUM DIOXIDE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70260, 727, 'TITANIUM DIOXIDE', 'I', 1.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70261, 727, 'TITANIUM DIOXIDE', 'I', 15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70541, 727, 'TITANIUM DIOXIDE', 'I', 3.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72053, 727, 'TITANIUM DIOXIDE', 'I', 0.75, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76449, 727, 'TITANIUM DIOXIDE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76468, 727, 'TITANIUM DIOXIDE', 'I', 5.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75229, 727, 'TITANIUM DIOXIDE', 'I', 2.0, '%', '', '', 'N', '', 'V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76603, 727, 'TITANIUM DIOXIDE', 'I', 4.15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76604, 727, 'TITANIUM DIOXIDE', 'I', 4.15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76619, 727, 'TITANIUM DIOXIDE', 'I', 18.08, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75277, 727, 'TITANIUM DIOXIDE', 'I', 0.9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75296, 727, 'TITANIUM DIOXIDE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75392, 727, 'TITANIUM DIOXIDE', 'I', 2.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75413, 727, 'TITANIUM DIOXIDE', 'I', 4.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75414, 727, 'TITANIUM DIOXIDE', 'I', 3.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75425, 727, 'TITANIUM DIOXIDE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74217, 727, 'TITANIUM DIOXIDE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74229, 727, 'TITANIUM DIOXIDE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75513, 727, 'TITANIUM DIOXIDE', 'I', 6.6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73106, 727, 'TITANIUM DIOXIDE', 'I', 5.81, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74271, 727, 'TITANIUM DIOXIDE', 'I', 9.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75527, 727, 'TITANIUM DIOXIDE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75528, 727, 'TITANIUM DIOXIDE', 'I', 3.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75565, 727, 'TITANIUM DIOXIDE', 'I', 3.2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74412, 727, 'TITANIUM DIOXIDE', 'I', 3.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74430, 727, 'TITANIUM DIOXIDE', 'I', 7.7, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74441, 727, 'TITANIUM DIOXIDE', 'I', 4.84, '%', '', '', 'N', '', 'AS PER LABEL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74500, 727, 'TITANIUM DIOXIDE', 'I', 0.95, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75752, 727, 'TITANIUM DIOXIDE', 'I', 3.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75755, 727, 'TITANIUM DIOXIDE', 'I', 3.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75756, 727, 'TITANIUM DIOXIDE', 'I', 3.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72585, 727, 'TITANIUM DIOXIDE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74560, 727, 'TITANIUM DIOXIDE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74589, 727, 'TITANIUM DIOXIDE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75868, 727, 'TITANIUM DIOXIDE', 'I', 2.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75869, 727, 'TITANIUM DIOXIDE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74655, 727, 'TITANIUM DIOXIDE', 'I', 4.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75907, 727, 'TITANIUM DIOXIDE', 'I', 4.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75920, 727, 'TITANIUM DIOXIDE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74735, 727, 'TITANIUM DIOXIDE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73363, 727, 'TITANIUM DIOXIDE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75779, 727, 'TITANIUM DIOXIDE', 'I', 2.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72680, 727, 'TITANIUM DIOXIDE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73606, 727, 'TITANIUM DIOXIDE', 'I', 5.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73607, 727, 'TITANIUM DIOXIDE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74955, 727, 'TITANIUM DIOXIDE', 'I', 1.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72737, 727, 'TITANIUM DIOXIDE', 'I', 13.75, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72739, 727, 'TITANIUM DIOXIDE', 'I', 15.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75015, 727, 'TITANIUM DIOXIDE', 'I', 10.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76327, 727, 'TITANIUM DIOXIDE', 'I', 8.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76343, 727, 'TITANIUM DIOXIDE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76379, 727, 'TITANIUM DIOXIDE', 'I', 2.66, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73821, 727, 'TITANIUM DIOXIDE', 'I', 5.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78091, 727, 'TITANIUM DIOXIDE', 'I', 7.8, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77065, 727, 'TITANIUM DIOXIDE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77512, 727, 'TITANIUM DIOXIDE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77476, 727, 'TITANIUM DIOXIDE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77550, 727, 'TITANIUM DIOXIDE', 'I', 2.30, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77551, 727, 'TITANIUM DIOXIDE', 'I', 2.30, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77560, 727, 'TITANIUM DIOXIDE', 'I', 9.37, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77605, 727, 'TITANIUM DIOXIDE', 'I', 3.24, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77606, 727, 'TITANIUM DIOXIDE', 'I', 3.24, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77610, 727, 'TITANIUM DIOXIDE', 'I', 0.66, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77612, 727, 'TITANIUM DIOXIDE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78218, 727, 'TITANIUM DIOXIDE', 'I', 4.15, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77613, 727, 'TITANIUM DIOXIDE', 'I', 2.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78220, 727, 'TITANIUM DIOXIDE', 'I', 4.15, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78221, 727, 'TITANIUM DIOXIDE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77082, 727, 'TITANIUM DIOXIDE', 'I', 1.9, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77122, 727, 'TITANIUM DIOXIDE', 'I', 6.25, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77123, 727, 'TITANIUM DIOXIDE', 'I', 6.25, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77410, 727, 'TITANIUM DIOXIDE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77692, 727, 'TITANIUM DIOXIDE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78154, 727, 'TITANIUM DIOXIDE', 'I', 1.65, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77016, 727, 'TITANIUM DIOXIDE', 'I', 1.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77820, 727, 'TITANIUM DIOXIDE', 'I', 2.9, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77383, 727, 'TITANIUM DIOXIDE', 'I', 6.25, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78156, 727, 'TITANIUM DIOXIDE', 'I', 0.8, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77254, 727, 'TITANIUM DIOXIDE', 'I', 5.8, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78256, 727, 'TITANIUM DIOXIDE', 'I', 13, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78278, 727, 'TITANIUM DIOXIDE', 'I', 3.2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77434, 727, 'TITANIUM DIOXIDE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76910, 727, 'TITANIUM DIOXIDE', 'I', 3.75, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78023, 727, 'TITANIUM DIOXIDE', 'I', 1.83, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78024, 727, 'TITANIUM DIOXIDE', 'I', 1.83, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78025, 727, 'TITANIUM DIOXIDE', 'I', 2.92, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77322, 727, 'TITANIUM DIOXIDE', 'I', 1.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77325, 727, 'TITANIUM DIOXIDE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77411, 727, 'TITANIUM DIOXIDE', 'I', 1.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78047, 727, 'TITANIUM DIOXIDE', 'I', 5.50, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78656, 727, 'TITANIUM DIOXIDE', 'I', 3.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79081, 727, 'TITANIUM DIOXIDE', 'I', 3.16, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79221, 727, 'TITANIUM DIOXIDE', 'I', 3.32, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80443, 727, 'TITANIUM DIOXIDE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78813, 727, 'TITANIUM DIOXIDE', 'I', 4.15, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78893, 727, 'TITANIUM DIOXIDE', 'I', 2.9, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78895, 727, 'TITANIUM DIOXIDE', 'I', 4.6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78894, 727, 'TITANIUM DIOXIDE', 'I', 3.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78604, 727, 'TITANIUM DIOXIDE', 'I', 3.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78605, 727, 'TITANIUM DIOXIDE', 'I', 1.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78606, 727, 'TITANIUM DIOXIDE', 'I', 11, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79533, 727, 'TITANIUM DIOXIDE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79913, 727, 'TITANIUM DIOXIDE', 'I', 5.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80828, 727, 'TITANIUM DIOXIDE', 'I', 5.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78646, 727, 'TITANIUM DIOXIDE', 'I', 4.6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78901, 727, 'TITANIUM DIOXIDE', 'I', 11.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79098, 727, 'TITANIUM DIOXIDE', 'I', 3.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79185, 727, 'TITANIUM DIOXIDE', 'I', 1.7, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80281, 727, 'TITANIUM DIOXIDE', 'I', 7.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80821, 727, 'TITANIUM DIOXIDE', 'I', 8.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82313, 727, 'TITANIUM DIOXIDE', 'I', 5.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84130, 727, 'TITANIUM DIOXIDE', 'I', 2.22, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84133, 727, 'TITANIUM DIOXIDE', 'I', 2.22, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84266, 727, 'TITANIUM DIOXIDE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84443, 727, 'TITANIUM DIOXIDE', 'I', 5.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15968, 727, 'TITANIUM DIOXIDE', 'I', 4.0, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: TITANIUM DIOXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48991, 727, 'TITANIUM DIOXIDE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65475, 727, 'TITANIUM DIOXIDE', 'I', 2.00, '%', '', '', 'N', 'W/W', 'W/W 2010.11.02 AI STRENGTH CHANGED FROM 2.04% TO 2.0% APPROVED BY C.YEN/SIPD. EW 2011.02.22 STRENGTH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76605, 727, 'TITANIUM DIOXIDE', 'I', 4.15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75591, 727, 'TITANIUM DIOXIDE', 'I', 2.40, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76139, 727, 'TITANIUM DIOXIDE', 'I', 5.1, '%', '', '', 'N', 'W/W', 'W/W ACTIVE INGREDIENT STRENGTH CHANGED FROM 5.2% TO 5.1% AS PER POST CLEARANCE DATA THAT WAS APPROVE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74967, 727, 'TITANIUM DIOXIDE', 'I', 2.2, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74969, 727, 'TITANIUM DIOXIDE', 'I', 4.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74970, 727, 'TITANIUM DIOXIDE', 'I', 2.2, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77462, 727, 'TITANIUM DIOXIDE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77394, 727, 'TITANIUM DIOXIDE', 'I', 2.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77395, 727, 'TITANIUM DIOXIDE', 'I', 1.1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80859, 727, 'TITANIUM DIOXIDE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80135, 727, 'TITANIUM DIOXIDE', 'I', 5.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82154, 727, 'TITANIUM DIOXIDE', 'I', 4.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82930, 727, 'TITANIUM DIOXIDE', 'I', 4.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82931, 727, 'TITANIUM DIOXIDE', 'I', 2.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79674, 727, 'TITANIUM DIOXIDE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79607, 727, 'TITANIUM DIOXIDE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80747, 727, 'TITANIUM DIOXIDE', 'I', 2.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80435, 727, 'TITANIUM DIOXIDE', 'I', 5.85, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81451, 727, 'TITANIUM DIOXIDE', 'I', 3.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80484, 727, 'TITANIUM DIOXIDE', 'I', 5.81, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80977, 727, 'TITANIUM DIOXIDE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80112, 727, 'TITANIUM DIOXIDE', 'I', 1.4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80114, 727, 'TITANIUM DIOXIDE', 'I', 1.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81830, 727, 'TITANIUM DIOXIDE', 'I', 5.08, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81378, 727, 'TITANIUM DIOXIDE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79620, 727, 'TITANIUM DIOXIDE', 'I', 0.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80393, 727, 'TITANIUM DIOXIDE', 'I', 2.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80309, 727, 'TITANIUM DIOXIDE', 'I', 4.19, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80312, 727, 'TITANIUM DIOXIDE', 'I', 4.37, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80313, 727, 'TITANIUM DIOXIDE', 'I', 4.79, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80314, 727, 'TITANIUM DIOXIDE', 'I', 5.02, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80315, 727, 'TITANIUM DIOXIDE', 'I', 5.12, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82380, 727, 'TITANIUM DIOXIDE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80382, 727, 'TITANIUM DIOXIDE', 'I', 2.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80383, 727, 'TITANIUM DIOXIDE', 'I', 4.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80424, 727, 'TITANIUM DIOXIDE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79546, 727, 'TITANIUM DIOXIDE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81033, 727, 'TITANIUM DIOXIDE', 'I', 5.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82367, 727, 'TITANIUM DIOXIDE', 'I', 7.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81007, 727, 'TITANIUM DIOXIDE', 'I', 3.16, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81638, 727, 'TITANIUM DIOXIDE', 'I', 2.64, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81639, 727, 'TITANIUM DIOXIDE', 'I', 11.70, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82062, 727, 'TITANIUM DIOXIDE', 'I', 2.4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82066, 727, 'TITANIUM DIOXIDE', 'I', 2.4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80380, 727, 'TITANIUM DIOXIDE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81287, 727, 'TITANIUM DIOXIDE', 'I', 11.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82113, 727, 'TITANIUM DIOXIDE', 'I', 3.16, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82523, 727, 'TITANIUM DIOXIDE', 'I', 2.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82525, 727, 'TITANIUM DIOXIDE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83116, 727, 'TITANIUM DIOXIDE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83728, 727, 'TITANIUM DIOXIDE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83737, 727, 'TITANIUM DIOXIDE', 'I', 6.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83877, 727, 'TITANIUM DIOXIDE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83900, 727, 'TITANIUM DIOXIDE', 'I', 6.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84038, 727, 'TITANIUM DIOXIDE', 'I', 4.4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84244, 727, 'TITANIUM DIOXIDE', 'I', 5.81, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84292, 727, 'TITANIUM DIOXIDE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84344, 727, 'TITANIUM DIOXIDE', 'I', 3.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84420, 727, 'TITANIUM DIOXIDE', 'I', 1.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84423, 727, 'TITANIUM DIOXIDE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84425, 727, 'TITANIUM DIOXIDE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84975, 727, 'TITANIUM DIOXIDE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85096, 727, 'TITANIUM DIOXIDE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85097, 727, 'TITANIUM DIOXIDE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85098, 727, 'TITANIUM DIOXIDE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85099, 727, 'TITANIUM DIOXIDE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85135, 727, 'TITANIUM DIOXIDE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85228, 727, 'TITANIUM DIOXIDE', 'I', 7.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85515, 727, 'TITANIUM DIOXIDE', 'I', 7.94, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15799, 727, 'TITANIUM DIOXIDE', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: TITANIUM DIOXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53424, 727, 'TITANIUM DIOXIDE', 'I', 1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53425, 727, 'TITANIUM DIOXIDE', 'I', 1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53426, 727, 'TITANIUM DIOXIDE', 'I', 1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60302, 727, 'TITANIUM DIOXIDE', 'I', 1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64738, 727, 'TITANIUM DIOXIDE', 'I', 4, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64739, 727, 'TITANIUM DIOXIDE', 'I', 4, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63661, 727, 'TITANIUM DIOXIDE', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63662, 727, 'TITANIUM DIOXIDE', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63515, 727, 'TITANIUM DIOXIDE', 'I', 2, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63516, 727, 'TITANIUM DIOXIDE', 'I', 2, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14191, 660, 'DESOGESTREL', 'I', 0.15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DESOGESTREL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14354, 660, 'DESOGESTREL', 'I', 0.15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DESOGESTREL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14355, 660, 'DESOGESTREL', 'I', 0.15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DESOGESTREL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74243, 660, 'DESOGESTREL', 'I', 0.100, 'MG', '', '', 'N', '', 'YELLOW TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74243, 660, 'DESOGESTREL', 'I', 0.125, 'MG', '', '', 'N', '', 'ORANGE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74243, 660, 'DESOGESTREL', 'I', 0.150, 'MG', '', '', 'N', '', 'RED TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75841, 660, 'DESOGESTREL', 'I', 0.100, 'MG', '', '', 'N', '', 'YELLOW TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75841, 660, 'DESOGESTREL', 'I', 0.125, 'MG', '', '', 'N', '', 'ORANGE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75841, 660, 'DESOGESTREL', 'I', 0.150, 'MG', '', '', 'N', '', 'RED TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80270, 660, 'DESOGESTREL', 'I', 0.15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DESOGESTREL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80272, 660, 'DESOGESTREL', 'I', 0.15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DESOGESTREL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41695, 662, 'PYRITHIONE ZINC', 'I', 1.0, '%', '', '', 'N', '', 'Historic Freeform Text: ZINC PYRIDINETHIONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10999, 662, 'PYRITHIONE ZINC', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: ZINC PYRIDINETHIONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10673, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ZINC PYRIDINETHIONE.W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5557, 662, 'PYRITHIONE ZINC', 'I', 1.0, '%', '', '', 'N', '', 'Historic Freeform Text: ZINC PYRIDINETHIONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4544, 662, 'PYRITHIONE ZINC', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: ZINC PYRIDINETHIONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77856, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64533, 662, 'PYRITHIONE ZINC', 'I', 1.0, '%', '', '', 'N', '', 'Historic Freeform Text: ZINC PYRIDINETHIONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66499, 662, 'PYRITHIONE ZINC', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65136, 662, 'PYRITHIONE ZINC', 'I', 1.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68253, 662, 'PYRITHIONE ZINC', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70224, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71767, 662, 'PYRITHIONE ZINC', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69880, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72832, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74079, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75401, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74361, 662, 'PYRITHIONE ZINC', 'I', 1.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76023, 662, 'PYRITHIONE ZINC', 'I', 0.25, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73544, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73545, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73611, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77705, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78334, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'Y', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78335, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'Y', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78526, 662, 'PYRITHIONE ZINC', 'I', 0.1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78814, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78815, 662, 'PYRITHIONE ZINC', 'I', 0.1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79455, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79582, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79020, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78889, 662, 'PYRITHIONE ZINC', 'I', 1.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83584, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83582, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64845, 662, 'PYRITHIONE ZINC', 'I', 0.95, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75355, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72405, 662, 'PYRITHIONE ZINC', 'I', 2, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78321, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80396, 662, 'PYRITHIONE ZINC', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81015, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80576, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80426, 662, 'PYRITHIONE ZINC', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80329, 662, 'PYRITHIONE ZINC', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80831, 662, 'PYRITHIONE ZINC', 'I', 0.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83579, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83585, 662, 'PYRITHIONE ZINC', 'I', 0.1, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83604, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83605, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83606, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83733, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83734, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83735, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84283, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84406, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37795, 662, 'PYRITHIONE ZINC', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: PYRITHIONE ZINC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14533, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: ZINC PYRIDINETHIONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62742, 662, 'PYRITHIONE ZINC', 'I', 1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63067, 662, 'PYRITHIONE ZINC', 'I', 1.008, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69792, 662, 'PYRITHIONE ZINC', 'I', 1.0, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61824, 662, 'PYRITHIONE ZINC', 'I', 2.5, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19075, 671, 'CALCIUM CARBONATE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: CALCIUM CARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5698, 671, 'CALCIUM CARBONATE', 'I', 14, 'MG', '', '', 'N', '', 'Historic Freeform Text: CALCIUM CARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48421, 671, 'CALCIUM CARBONATE', 'I', 246.2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48434, 671, 'CALCIUM CARBONATE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60637, 671, 'CALCIUM CARBONATE', 'I', 350, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64038, 671, 'CALCIUM CARBONATE', 'I', 675, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63534, 671, 'CALCIUM CARBONATE', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66915, 671, 'CALCIUM CARBONATE', 'I', 800, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67414, 671, 'CALCIUM CARBONATE', 'I', 1000, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75457, 671, 'CALCIUM CARBONATE', 'I', 1177, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80534, 671, 'CALCIUM CARBONATE', 'I', 350, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19082, 671, 'CALCIUM CARBONATE', 'I', 200, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CALCIUM CARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47178, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43029, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.12, '%', '', '', 'N', '', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42237, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.003, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36750, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.75, '%', '', '', 'N', '', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36829, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.2, '%', '', '', 'N', '', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36792, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36797, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.2, '%', '', '', 'N', '', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36791, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22030, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20216, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.12, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15774, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2.3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE ((AS DIGLUCONATE)) MI IS CHLORHEXIDINE GLUCONATE 2.3% W/W AS P');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17006, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13003, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14489, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.015, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE GLUCONATE.W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14490, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13327, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13289, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13290, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 4, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12329, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.475, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12861, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10767, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 20, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10669, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10177, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1436, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 4, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE DIGLUCONATE W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60445, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60446, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60786, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.12, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62430, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63982, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.12, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64096, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.12, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64391, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63862, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.12, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65180, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.5, '%', '', '', 'N', '', '0.5% W/V, 0.5G/100ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65268, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.12, '%', '', '', 'N', '', '0.12%W/W; 0.12G/100G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66040, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.12, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64982, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64983, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64984, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67988, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69089, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70226, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 4, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70264, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71841, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71113, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71177, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71947, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69848, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76467, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73892, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.003, '%', '', '', 'N', '', '0.003% (=0.176MG/G).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75254, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74413, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73640, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78057, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78106, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.05, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78101, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78102, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77786, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77815, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 4, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78280, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2.0, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80225, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.12, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62989, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66399, 265, 'MENTHOL', 'I', 20, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77576, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78032, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.05, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79892, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50653, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.01, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83045, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82418, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.01, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34222, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', 'W/V', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16498, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 20, '%', '', '', 'N', 'W/V', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63898, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2.0, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77225, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.5, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30398, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27903, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.05, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28206, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 4, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19810, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 4, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19626, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16494, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14568, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11826, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12713, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 4, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10668, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 4, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9824, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 20, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63965, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62715, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 4, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64263, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66842, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66843, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66260, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 2, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63199, 470, 'GABAPENTIN', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19506, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 0.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14496, 626, 'CHLORHEXIDINE GLUCONATE', 'I', 40, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: CHLORHEXIDINE GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73040, 13090, 'GEFITINIB', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14767, 13098, 'PERICIAZINE', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PERICYAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12425, 13098, 'PERICIAZINE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PERICYAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12653, 13098, 'PERICIAZINE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PERICYAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13159, 13098, 'PERICIAZINE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PERICYAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75736, 13104, 'INSULIN DETEMIR', 'I', 100, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73940, 13106, 'LARONIDASE', 'I', 0.58, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71262, 13107, 'LEVETIRACETAM', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71263, 13107, 'LEVETIRACETAM', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71264, 13107, 'LEVETIRACETAM', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75964, 13107, 'LEVETIRACETAM', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75965, 13107, 'LEVETIRACETAM', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75966, 13107, 'LEVETIRACETAM', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78145, 13107, 'LEVETIRACETAM', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78146, 13107, 'LEVETIRACETAM', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78147, 13107, 'LEVETIRACETAM', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77141, 13107, 'LEVETIRACETAM', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77142, 13107, 'LEVETIRACETAM', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77143, 13107, 'LEVETIRACETAM', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78274, 13107, 'LEVETIRACETAM', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78272, 13107, 'LEVETIRACETAM', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78273, 13107, 'LEVETIRACETAM', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78275, 13107, 'LEVETIRACETAM', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78276, 13107, 'LEVETIRACETAM', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78277, 13107, 'LEVETIRACETAM', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79696, 13107, 'LEVETIRACETAM', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79697, 13107, 'LEVETIRACETAM', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83854, 13107, 'LEVETIRACETAM', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83855, 13107, 'LEVETIRACETAM', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83856, 13107, 'LEVETIRACETAM', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37137, 13119, 'GLUTARAL', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: GLUTARALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37109, 13119, 'GLUTARAL', 'I', 2.1, '%', '', '', 'N', '', 'Historic Freeform Text: GLUTARALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34111, 13119, 'GLUTARAL', 'I', 3.4, '%', '', '', 'N', '', 'Historic Freeform Text: GLUTARALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34112, 13119, 'GLUTARAL', 'I', 2.4, '%', '', '', 'N', '', 'Historic Freeform Text: GLUTARALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26018, 13119, 'GLUTARAL', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: GLUTARALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17211, 13119, 'GLUTARAL', 'I', 0.15, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GLUTARALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14692, 13119, 'GLUTARAL', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: GLUTARALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14177, 13119, 'GLUTARAL', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: GLUTARALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13891, 13119, 'GLUTARAL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: GLUTARALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11833, 13119, 'GLUTARAL', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GLUTARALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11834, 13119, 'GLUTARAL', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: GLUTARALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12768, 13119, 'GLUTARAL', 'I', 2.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GLUTARALDEHYDE DIN ORIGINALLY ASSGD FOR 2%, CTRL #063558 INVOLVED CHG TO DEC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12770, 13119, 'GLUTARAL', 'I', 3.4, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GLUTARALDEHYDE ORIGINALLY ASSGD FOR 3.2%, CTRL #063558 INVOLVES CHG TO DECLA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12767, 13119, 'GLUTARAL', 'I', 2.6, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GLUTARALDEHYDE CTRL #063558 INVOLVED CHG TO DECLARATION OF STRENGTH FROM MIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50234, 13119, 'GLUTARAL', 'I', 20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63207, 13119, 'GLUTARAL', 'I', 10.725, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67955, 13119, 'GLUTARAL', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: GLUTARALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71031, 13119, 'GLUTARAL', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: GLUTARALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70486, 13119, 'GLUTARAL', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76498, 13119, 'GLUTARAL', 'I', 12.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76631, 13119, 'GLUTARAL', 'I', 12.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75223, 13119, 'GLUTARAL', 'I', 12.75, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72991, 13119, 'GLUTARAL', 'I', 12.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74558, 13119, 'GLUTARAL', 'I', 7.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77951, 13119, 'GLUTARAL', 'I', 2.65, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78037, 13119, 'GLUTARAL', 'I', 24, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80388, 13119, 'GLUTARAL', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47571, 13119, 'GLUTARAL', 'I', 10, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43840, 13121, 'CISPLATIN', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71404, 13123, 'ROSUVASTATIN (ROSUVASTATIN CALCIUM)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71405, 13123, 'ROSUVASTATIN (ROSUVASTATIN CALCIUM)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71406, 13123, 'ROSUVASTATIN (ROSUVASTATIN CALCIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75100, 13123, 'ROSUVASTATIN (ROSUVASTATIN CALCIUM)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42376, 13124, 'MERADIMATE', 'I', 4.0, '%', '', '', 'N', '', 'Historic Freeform Text: MENTHYL ANTHRANILATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42377, 13124, 'MERADIMATE', 'I', 4.0, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MENTHYL ANTHRANILATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42310, 13124, 'MERADIMATE', 'I', 4.8, '%', '', '', 'N', '', 'Historic Freeform Text: MENTHYL ANTHRANILATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71534, 13124, 'MERADIMATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69886, 13124, 'MERADIMATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74630, 13124, 'MERADIMATE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79440, 13124, 'MERADIMATE', 'I', 4.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79647, 13124, 'MERADIMATE', 'I', 4.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42334, 13124, 'MERADIMATE', 'I', 2.5, '%', '', '', 'N', '%', 'Historic Freeform Text: METHYL ANTHRANILATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64736, 13124, 'MERADIMATE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64737, 13124, 'MERADIMATE', 'I', 4, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64740, 13124, 'MERADIMATE', 'I', 4, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71683, 13153, 'ERTAPENEM (ERTAPENEM SODIUM)', 'I', 1, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75672, 13175, 'CETUXIMAB', 'I', 2, 'MG', '', '', 'N', 'ML', 'HUMAN/MOUSE CHIMERIC ANTIBODY.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75446, 15875, 'LUTROPIN ALFA', 'I', 75, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43758, 637, 'FLUTICASONE PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60564, 637, 'FLUTICASONE PROPIONATE', 'I', 50, 'µG', '', '', 'N', 'BLISTER', 'PER BLISTER.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60565, 637, 'FLUTICASONE PROPIONATE', 'I', 100, 'µG', '', '', 'N', 'BLISTER', 'PER BLISTER.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60566, 637, 'FLUTICASONE PROPIONATE', 'I', 250, 'µG', '', '', 'N', 'BLISTER', 'PER BLISTER.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60567, 637, 'FLUTICASONE PROPIONATE', 'I', 500, 'µG', '', '', 'N', 'BLISTER', 'PER BLISTER.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43126, 637, 'FLUTICASONE PROPIONATE', 'I', 50, 'µG', '', '', 'N', 'ACT', 'Historic Freeform Text: FLUTICASONE PROPIONATE Qty Unit: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78009, 637, 'FLUTICASONE PROPIONATE', 'I', 50, 'µG', '', '', 'N', 'ACT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68258, 637, 'FLUTICASONE PROPIONATE', 'I', 50, 'µG', '', '', 'N', 'ACT', 'HISTORIC FREEFORM TEXT: FLUTICASONE PROPIONATE QTY UNIT: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68259, 637, 'FLUTICASONE PROPIONATE', 'I', 125, 'µG', '', '', 'N', 'ACT', 'HISTORIC FREEFORM TEXT: FLUTICASONE PROPIONATE QTY UNIT: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68260, 637, 'FLUTICASONE PROPIONATE', 'I', 250, 'µG', '', '', 'N', 'ACT', 'HISTORIC FREEFORM TEXT: FLUTICASONE PROPIONATE QTY UNIT: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78143, 637, 'FLUTICASONE PROPIONATE', 'I', 50, 'µG', '', '', 'N', 'ACT', 'Historic Freeform Text: FLUTICASONE PROPIONATE Qty Unit: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64426, 637, 'FLUTICASONE PROPIONATE', 'I', 100, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64427, 637, 'FLUTICASONE PROPIONATE', 'I', 250, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64428, 637, 'FLUTICASONE PROPIONATE', 'I', 500, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69136, 637, 'FLUTICASONE PROPIONATE', 'I', 125, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69137, 637, 'FLUTICASONE PROPIONATE', 'I', 250, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (457, 646, 'VITAMIN C', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 646, 'VITAMIN C (ASCORBIC ACID)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 646, 'VITAMIN C (CALCIUM ASCORBATE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70202, 646, 'VITAMIN C (ASCORBIC ACID)', 'I', 120, 'MG', '', '', 'N', '', 'PINK TABLET A.M.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76186, 646, 'VITAMIN C (ASCORBIC ACID)', 'I', 120, 'MG', '', '', 'N', '', 'PINK TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66277, 646, 'VITAMIN C (ASCORBIC ACID)', 'I', 80, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84451, 646, 'VITAMIN C', 'I', 4.700, 'G', '', '', 'N', 'PCK', 'SACHET B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26396, 646, 'VITAMIN C', 'I', 50, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26397, 646, 'VITAMIN C', 'I', 50, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21168, 646, 'VITAMIN C', 'I', 50, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2871, 646, 'VITAMIN C (VITAMIN C)', 'I', 1, 'G', '', '10', 'Y', 'ML', 'Historic Freeform Text: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16462, 646, 'VITAMIN C', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ASCORBIC ACID ((VIAL 1))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9992, 646, 'VITAMIN C (SODIUM ASCORBATE)', 'I', 250, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ASCORBIC ACID ((SOD ASCORBATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6072, 646, 'VITAMIN C', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5903, 646, 'VITAMIN C', 'I', 250, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5851, 646, 'VITAMIN C', 'I', 500, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5613, 646, 'VITAMIN C', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7309, 646, 'VITAMIN C', 'I', 500, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6693, 646, 'VITAMIN C', 'I', 250, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68684, 646, 'VITAMIN C', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69229, 646, 'VITAMIN C (ASCORBIC ACID)', 'I', 500, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62576, 646, 'VITAMIN C', 'I', 50, 'MG', '', '22', 'N', 'MG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33790, 646, 'VITAMIN C (ASCORBIC ACID)', 'I', 13, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31530, 646, 'VITAMIN C (ASCORBIC ACID)', 'I', 50, 'MG', '', '22', 'N', 'G', 'HISTORIC FREEFORM TEXT: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (32780, 646, 'VITAMIN C', 'I', 50, 'MG', '', '23', 'N', 'G', 'HISTORIC FREEFORM TEXT: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19088, 646, 'VITAMIN C', 'I', 50, 'MG', '', '23', 'N', 'G', 'Historic Freeform Text: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 646, 'VITAMIN C', 'I', 555, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14113, 646, 'VITAMIN C', 'I', 555, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15001, 646, 'VITAMIN C', 'I', 13, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10527, 646, 'VITAMIN C', 'I', 500, 'MG', '', '75', 'N', 'G', 'Historic Freeform Text: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5322, 646, 'VITAMIN C', 'I', 13.23, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: ASCORBIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62330, 646, 'VITAMIN C', 'I', 50, 'MG', '', '23', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66631, 646, 'VITAMIN C', 'I', 100, 'MG', '', '300', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66864, 646, 'VITAMIN C', 'I', 10, 'MG', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73067, 646, 'VITAMIN C (ASCORBIC ACID)', 'I', 50, 'MG', '', '22', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36399, 648, 'PROTEASE', 'I', 25000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: PROTEASE Qty Unit: ECC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36179, 648, 'PROTEASE', 'I', 37500, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: PROTEASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35065, 648, 'PROTEASE', 'I', 11000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: PROTEASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27084, 648, 'PROTEASE', 'I', 65000, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PROTEASE QTY UNIT: ECC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27081, 648, 'PROTEASE', 'I', 39000, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PROTEASE QTY UNIT: ECC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13302, 648, 'PROTEASE', 'I', 62500, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PROTEASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9892, 648, 'PROTEASE', 'I', 55000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: PROTEASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3189, 648, 'PROTEASE', 'I', 30000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: PROTEASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3891, 648, 'PROTEASE', 'I', 30000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: PROTEASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1649, 648, 'PROTEASE', 'I', 30000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: PROTEASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48551, 648, 'PROTEASE', 'I', 30000, 'UNIT', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60913, 648, 'PROTEASE', 'I', 104000, 'UNIT', '', '', 'N', '', 'PER TABLET: PROTEASE ACTIVITY  104000 FCC UNITS. FROM (650 MG) OF PORCINE PANCREATIN.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62457, 648, 'PROTEASE', 'I', 18750, 'UNIT', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62458, 648, 'PROTEASE', 'I', 75000, 'UNIT', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65603, 648, 'PROTEASE', 'I', 60000, 'UNIT', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12239, 648, 'PROTEASE', 'I', 280000, 'UNIT', '', '2.8', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62615, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36399, 649, 'LIPASE', 'I', 4500, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LIPASE QTY UNIT: ECC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36179, 649, 'LIPASE', 'I', 10000, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LIPASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35065, 649, 'LIPASE', 'I', 4000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: LIPASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27084, 649, 'LIPASE', 'I', 20000, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LIPOLYTIC ENZYME QTY UNIT: ECC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27081, 649, 'LIPASE', 'I', 12000, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LIPOLYTIC ENZYME QTY UNIT: ECC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13302, 649, 'LIPASE', 'I', 25000, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LIPOLYTIC ENZYME');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9892, 649, 'LIPASE', 'I', 20000, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LIPOLYTIC ENZYME');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3189, 649, 'LIPASE', 'I', 8000, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LIPOLYTIC ENZYME');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3891, 649, 'LIPASE', 'I', 8000, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LIPOLYTIC ENZYME');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1649, 649, 'LIPASE', 'I', 8000, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LIPOLYTIC ENZYME');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48551, 649, 'LIPASE', 'I', 8000, 'UNIT', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60913, 649, 'LIPASE', 'I', 16640, 'UNIT', '', '', 'N', '', 'PER TABLET: LIPASE ACTIVITY  16640 FCC UNITS. FROM (650 MG) OF PORCINE PANCREATIN.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62457, 649, 'LIPASE', 'I', 5000, 'UNIT', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62458, 649, 'LIPASE', 'I', 20000, 'UNIT', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65603, 649, 'LIPASE', 'I', 16000, 'UNIT', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12239, 649, 'LIPASE', 'I', 67200, 'UNIT', '', '2.8', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15483, 650, 'DORNASE ALFA', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DORNASE ALFA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53422, 657, 'DEA METHOXYCINNAMATE', 'I', 4, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53423, 657, 'DEA METHOXYCINNAMATE', 'I', 4, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3297, 591, 'ARNICA', 'I', 30, 'G', '', '237', 'N', 'ML', 'Historic Freeform Text: ARNICA ((TCT EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3314, 591, 'ARNICA', 'I', 10.5, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: ARNICA FLOWERS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61538, 602, 'LUFENURON', 'I', 460, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61539, 602, 'LUFENURON', 'I', 230, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61540, 602, 'LUFENURON', 'I', 115, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61541, 602, 'LUFENURON', 'I', 46, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62367, 602, 'LUFENURON', 'I', 204.9, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62368, 602, 'LUFENURON', 'I', 409.8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62370, 602, 'LUFENURON', 'I', 90, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42931, 602, 'LUFENURON', 'I', 266, 'MG', '', '', 'N', 'DOSE', 'Historic Freeform Text: LUFENURON');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15748, 602, 'LUFENURON', 'I', 133, 'MG', '', '', 'N', 'DOSE', 'HISTORIC FREEFORM TEXT: LUFENURON');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60851, 602, 'LUFENURON', 'I', 80, 'MG', '', '', 'N', 'SYR', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60852, 602, 'LUFENURON', 'I', 40, 'MG', '', '', 'N', 'SYR', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12688, 623, 'IVERMECTIN', 'I', 68, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IVERMECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12689, 623, 'IVERMECTIN', 'I', 136, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IVERMECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12690, 623, 'IVERMECTIN', 'I', 272, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IVERMECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8253, 623, 'IVERMECTIN', 'I', 68, 'µG', '', '', 'N', '', 'Historic Freeform Text: IVERMECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8254, 623, 'IVERMECTIN', 'I', 136, 'µG', '', '', 'N', '', 'Historic Freeform Text: IVERMECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8255, 623, 'IVERMECTIN', 'I', 272, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IVERMECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43421, 623, 'IVERMECTIN', 'I', 0.04, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IVERMECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76456, 623, 'IVERMECTIN', 'I', 1.87, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76227, 623, 'IVERMECTIN', 'I', 1.87, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77545, 623, 'IVERMECTIN', 'I', 1.55, '%', '', '', 'N', '', 'W/W. 114MG/SYR.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5556, 623, 'IVERMECTIN', 'I', 120, 'MG', '', '', 'N', 'SYR', 'HISTORIC FREEFORM TEXT: IVERMECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61226, 623, 'IVERMECTIN', 'I', 120, 'MG', '', '', 'N', 'SYR', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61227, 623, 'IVERMECTIN', 'I', 120, 'MG', '', '', 'N', 'SYR', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76096, 623, 'IVERMECTIN', 'I', 120, 'MG', '', '', 'N', 'SYR', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76077, 623, 'IVERMECTIN', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11026, 623, 'IVERMECTIN', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: IVERMECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77880, 623, 'IVERMECTIN', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9878, 623, 'IVERMECTIN', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: IVERMECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5974, 623, 'IVERMECTIN', 'I', 0.8, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: IVERMECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7268, 623, 'IVERMECTIN', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: IVERMECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67162, 623, 'IVERMECTIN', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67526, 623, 'IVERMECTIN', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71594, 623, 'IVERMECTIN', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72353, 623, 'IVERMECTIN', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72466, 623, 'IVERMECTIN', 'I', 0.8, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76875, 623, 'IVERMECTIN', 'I', 5.0, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79223, 623, 'IVERMECTIN', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: IVERMECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81610, 623, 'IVERMECTIN', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77464, 623, 'IVERMECTIN', 'I', 6, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: IVERMECTIN B1A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2981, 587, 'CYNARA SCOLYMUS', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: ARTICHOKE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15532, 570, 'VIGABATRIN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: VIGABATRIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43682, 570, 'VIGABATRIN', 'I', 500, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: VIGABATRIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19977, 520, 'TRENBOLONE ACETATE', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRENBOLONE ACETATE QTY UNIT: IMP  ONE IMPLANT (8 PELLETS) CONTAINS: 200MG TR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50587, 520, 'TRENBOLONE ACETATE', 'I', 140, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61191, 520, 'TRENBOLONE ACETATE', 'I', 120, 'MG', '', '', 'N', '', 'EACH IMPLANT (6 PELLETS) CONTAINS: 120MG TRENBOLONE ACETATE AND  24MG ESTRADIOL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71354, 520, 'TRENBOLONE ACETATE', 'I', 100, 'MG', '', '', 'N', '', '100MG/IMPLANT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70362, 520, 'TRENBOLONE ACETATE', 'I', 40, 'MG', '', '', 'N', '', '20 MG PER PELLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73894, 520, 'TRENBOLONE ACETATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80251, 520, 'TRENBOLONE ACETATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16884, 520, 'TRENBOLONE ACETATE', 'I', 120, 'MG', '', '', 'N', 'IMP', 'HISTORIC FREEFORM TEXT: TRENBOLONE ACETATE QTY UNIT: IMP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68718, 520, 'TRENBOLONE ACETATE', 'I', 140, 'MG', '', '', 'N', 'DOSE', 'EACH IMPLANT (6 PELLETS) CONTAINS: 120MG TRENBOLONE ACETATE AND  24MG ESTRADIOL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69765, 520, 'TRENBOLONE ACETATE', 'I', 140, 'MG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69852, 520, 'TRENBOLONE ACETATE', 'I', 120, 'MG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16106, 535, 'POLYALKYLENE GLYCOL ETHER IODOPHOR', 'I', 4.85, '%', '', '', 'N', '', 'W/W AVAILABLE IODINE 0.5%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8342, 535, 'POLYALKYLENE GLYCOL ETHER IODOPHOR', 'I', 8.5, '%', '', '', 'N', 'W/W', 'PROVIDING A MINIMUM OF 1% AVAILABLE IODINE. W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37952, 539, 'SODIUM HYPOCHLORITE', 'I', 2.4, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM HYPOCHLORITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26016, 539, 'SODIUM HYPOCHLORITE', 'I', 12, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM HYPOCHLORITE SOLUTION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18662, 539, 'SODIUM HYPOCHLORITE', 'I', 10.2, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM HYPOCHLORITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18901, 539, 'SODIUM HYPOCHLORITE', 'I', 10.4, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM HYPOCHLORITE SOLUTION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16020, 539, 'SODIUM HYPOCHLORITE', 'I', 1.15, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM HYPOCHLORITE SOLUTION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13342, 539, 'SODIUM HYPOCHLORITE', 'I', 3.5, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM HYPOCHLORITE SOLUTION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9158, 539, 'SODIUM HYPOCHLORITE', 'I', 12, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM HYPOCHLORITE SOLUTION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8161, 539, 'SODIUM HYPOCHLORITE', 'I', 10.8, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM HYPOCHLORITE SOLUTION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72400, 13246, 'PEGINTERFERON ALFA-2A', 'I', 180, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2747, 539, 'SODIUM HYPOCHLORITE', 'I', 12, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM HYPOCHLORITE SOLUTION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47240, 539, 'SODIUM HYPOCHLORITE', 'I', 10.8, '%', '', '', 'N', '', '12% AVAILABLE CHLORINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62524, 539, 'SODIUM HYPOCHLORITE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67815, 539, 'SODIUM HYPOCHLORITE', 'I', 10, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67818, 539, 'SODIUM HYPOCHLORITE', 'I', 10, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69617, 539, 'SODIUM HYPOCHLORITE', 'I', 0.057, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70367, 539, 'SODIUM HYPOCHLORITE', 'I', 10.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70368, 539, 'SODIUM HYPOCHLORITE', 'I', 10.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70535, 539, 'SODIUM HYPOCHLORITE', 'I', 1.84, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70551, 539, 'SODIUM HYPOCHLORITE', 'I', 2.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69903, 539, 'SODIUM HYPOCHLORITE', 'I', 0.114, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75117, 539, 'SODIUM HYPOCHLORITE', 'I', 10.8, '%', '', '', 'N', '', 'GUARANTEE: SODIUM HYPOCLORITE 10.8% WHEN PACKED (10.3% AVAILABLE CHLORINE).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72833, 539, 'SODIUM HYPOCHLORITE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76646, 539, 'SODIUM HYPOCHLORITE', 'I', 7.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75710, 539, 'SODIUM HYPOCHLORITE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72574, 539, 'SODIUM HYPOCHLORITE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72575, 539, 'SODIUM HYPOCHLORITE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76098, 539, 'SODIUM HYPOCHLORITE', 'I', 10.3, '%', '', '', 'N', '', 'GUARANTEE: SODIUM HYPOCHLORITE 10.8%  (10.3% AVAILABLE CHLORINE CONTENT)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73516, 539, 'SODIUM HYPOCHLORITE', 'I', 1.45, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78103, 539, 'SODIUM HYPOCHLORITE', 'I', 5.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78378, 539, 'SODIUM HYPOCHLORITE', 'I', 2.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76976, 539, 'SODIUM HYPOCHLORITE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77075, 539, 'SODIUM HYPOCHLORITE', 'I', 10.8, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79879, 539, 'SODIUM HYPOCHLORITE', 'I', 1.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80494, 539, 'SODIUM HYPOCHLORITE', 'I', 1.84, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82758, 539, 'SODIUM HYPOCHLORITE', 'I', 5.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82760, 539, 'SODIUM HYPOCHLORITE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80481, 539, 'SODIUM HYPOCHLORITE', 'I', 0.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80497, 539, 'SODIUM HYPOCHLORITE', 'I', 1.84, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81958, 539, 'SODIUM HYPOCHLORITE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80038, 539, 'SODIUM HYPOCHLORITE', 'I', 0.025, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80039, 539, 'SODIUM HYPOCHLORITE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80040, 539, 'SODIUM HYPOCHLORITE', 'I', 0.7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80041, 539, 'SODIUM HYPOCHLORITE', 'I', 0.75, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83458, 539, 'SODIUM HYPOCHLORITE', 'I', 0.55, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83676, 539, 'SODIUM HYPOCHLORITE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84125, 539, 'SODIUM HYPOCHLORITE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84126, 539, 'SODIUM HYPOCHLORITE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84545, 539, 'SODIUM HYPOCHLORITE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84546, 539, 'SODIUM HYPOCHLORITE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84547, 539, 'SODIUM HYPOCHLORITE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84548, 539, 'SODIUM HYPOCHLORITE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77566, 539, 'SODIUM HYPOCHLORITE', 'I', 2.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81865, 539, 'SODIUM HYPOCHLORITE', 'I', 6.15, '%', '', '', 'N', 'W/W', 'BY WEIGHT AS IN REVIEW DOCUMENT.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81120, 539, 'SODIUM HYPOCHLORITE', 'I', 2.73, '%', '', '', 'N', 'W/W', '2.73% WHEN PACKAGED.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81309, 539, 'SODIUM HYPOCHLORITE', 'I', 1.4, '%', '', '', 'N', 'W/W', '1.4% WHEN PACKED, AS PER LABEL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63200, 470, 'GABAPENTIN', 'I', 800, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81310, 539, 'SODIUM HYPOCHLORITE', 'I', 0.7, '%', '', '', 'N', 'W/W', '0.7% WHEN PACKED, AS PER LABEL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81311, 539, 'SODIUM HYPOCHLORITE', 'I', 0.75, '%', '', '', 'N', 'W/W', '0.75% WHEN PACKED, AS PER LABEL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81312, 539, 'SODIUM HYPOCHLORITE', 'I', 0.1, '%', '', '', 'N', 'W/W', '0.1% WHEN PACKED, AS PER LABEL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81313, 539, 'SODIUM HYPOCHLORITE', 'I', 0.025, '%', '', '', 'N', 'W/W', '0.025% WHEN PACKED, AS PER LABEL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84668, 539, 'SODIUM HYPOCHLORITE', 'I', 2.4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84317, 539, 'SODIUM HYPOCHLORITE', 'I', 6, '%', '', '', 'N', 'W/V', '6% AS PER APPROVED LABEL RECEIVED TODAY 2010.10.19./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7083, 539, 'SODIUM HYPOCHLORITE', 'I', 5, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM HYPOCHLORITE SOLUTION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71842, 13186, 'CALCITONIN (SALMON SYNTHETIC)', 'I', 200, 'UNIT', '', '', 'N', 'SPRAY', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74713, 13186, 'CALCITONIN (SALMON SYNTHETIC)', 'I', 200, 'UNIT', '', '', 'N', 'SPRAY', 'HISTORIC FREEFORM TEXT: CALCITONIN SALMON SYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64365, 13186, 'CALCITONIN (SALMON SYNTHETIC)', 'I', 200, 'UNIT', '', '', 'N', 'ACT', 'HISTORIC FREEFORM TEXT: CALCITONIN SALMON SYNTHETIC ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13975, 13186, 'CALCITONIN (SALMON SYNTHETIC)', 'I', 100, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: CALCITONIN SALMON SYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12837, 13186, 'CALCITONIN (SALMON SYNTHETIC)', 'I', 200, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CALCITONIN SALMON SYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70189, 13186, 'CALCITONIN (SALMON SYNTHETIC)', 'I', 200, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CALCITONIN SALMON SYNTHETIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10923, 13190, 'PORCINE PITUITARY LUTEINIZING HORMONE', 'I', 25, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: LUTEINIZING HORMONE ((PORCINE PITUITARY))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82491, 13190, 'PORCINE PITUITARY LUTEINIZING HORMONE', 'I', 25, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75292, 13190, 'PORCINE PITUITARY LUTEINIZING HORMONE', 'I', 1.25, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72046, 13214, 'ALLERGENIC EXTRACTS POLLENS', 'I', 40000, 'UNIT', '', '', 'N', 'ML', 'EXTRACT CONT.UP TO 40000PNU/ML OR 1:10W/V OR OTHER DIL. AS REQUESTED BY PHYSICIAN.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72045, 13214, 'ALLERGENIC EXTRACTS POLLENS', 'I', 40000, 'UNIT', '', '', 'N', 'ML', 'EXTRACT CONT.UP TO 40000PNU/ML OR 1:10W/V OR OTHER DIL. AS REQUESTED BY PHYSICIAN.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72047, 13214, 'ALLERGENIC EXTRACTS POLLENS', 'I', 40000, 'UNIT', '', '', 'N', 'ML', 'EXTRACT CONT.UP TO 40000PNU/ML OR 1:10W/V OR OTHER DIL. AS REQUESTED BY PHYSICIAN.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72048, 13215, 'ALLERGENIC EXTRACT NON-POLLEN', 'I', 40000, 'UNIT', '', '', 'N', 'ML', 'EXTRACT CONT.UP TO 40000PNU/ML OR 1:10W/V OR OTHER DIL. AS REQUESTED BY PHYSICIAN.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72049, 13215, 'ALLERGENIC EXTRACT NON-POLLEN', 'I', 40000, 'UNIT', '', '', 'N', 'ML', 'EXTRACT CONT.UP TO 40000PNU/ML OR 1:10W/V OR OTHER DIL. AS REQUESTED BY PHYSICIAN.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72050, 13215, 'ALLERGENIC EXTRACT NON-POLLEN', 'I', 40000, 'UNIT', '', '', 'N', 'ML', 'EXTRACT CONT.UP TO 40000PNU/ML OR 1:10W/V OR OTHER DIL. AS REQUESTED BY PHYSICIAN.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72060, 13224, 'CETRORELIX (CETRORELIX ACETATE)', 'I', 0.25, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72061, 13224, 'CETRORELIX (CETRORELIX ACETATE)', 'I', 3, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72117, 13233, 'ADEFOVIR DIPIVOXIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82511, 13238, 'EVEROLIMUS', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82512, 13238, 'EVEROLIMUS', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9929, 13244, 'BETAMETHASONE VALERATE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: BETAMETHASONE 17-VALERATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4521, 13244, 'BETAMETHASONE VALERATE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BETAMETHASONE 17-VALERATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4522, 13244, 'BETAMETHASONE VALERATE', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BETAMETHASONE 17-VALERATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9268, 13244, 'BETAMETHASONE VALERATE', 'I', 0.1, '%', '', '', 'N', '%', 'Historic Freeform Text: BETAMETHASONE 17-VALERATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9269, 13244, 'BETAMETHASONE VALERATE', 'I', 1.22, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: BETAMETHASONE VALERATE ((BASE 1MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8973, 13244, 'BETAMETHASONE VALERATE', 'I', 1, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: BETAMETHASONE 17-VALERATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72399, 13246, 'PEGINTERFERON ALFA-2A', 'I', 180, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73839, 13246, 'PEGINTERFERON ALFA-2A', 'I', 180, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73840, 13246, 'PEGINTERFERON ALFA-2A', 'I', 180, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72455, 13247, 'ALMOTRIPTAN (ALMOTRIPTAN MALATE)', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72456, 13247, 'ALMOTRIPTAN (ALMOTRIPTAN MALATE)', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72547, 13253, 'PIMOBENDAN', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72490, 13253, 'PIMOBENDAN', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72491, 13253, 'PIMOBENDAN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72766, 13268, 'RASBURICASE', 'I', 1.5, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84250, 13271, 'FEBUXOSTAT', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72981, 13276, 'FULVESTRANT', 'I', 50, 'MG', '', '', 'N', 'ML', '250MG/5ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 10239, 'LEUCINE', 'I', 930, 'MG', '', '', 'N', '', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43947, 10239, 'LEUCINE', 'I', 1.08, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44068, 10239, 'LEUCINE', 'I', 770, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15493, 10239, 'LEUCINE', 'I', 880, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11329, 10239, 'LEUCINE', 'I', 730, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 10239, 'LEUCINE', 'I', 5.4, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7163, 10239, 'LEUCINE', 'I', 726, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 10239, 'LEUCINE', 'I', 810, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 10239, 'LEUCINE', 'I', 2.5, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4661, 10239, 'LEUCINE', 'I', 620, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 10239, 'LEUCINE', 'I', 620, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 10239, 'LEUCINE', 'I', 4, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 10239, 'LEUCINE', 'I', 4, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 10239, 'LEUCINE', 'I', 102, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5698, 8603, 'STREPTOMYCIN (STREPTOMYCIN SULFATE)', 'I', 100, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: STREPTOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67590, 8603, 'STREPTOMYCIN (STREPTOMYCIN SULFATE)', 'I', 1, 'G', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22007, 8603, 'STREPTOMYCIN (STREPTOMYCIN SULFATE)', 'I', 15.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: STREPTOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9372, 8603, 'STREPTOMYCIN (STREPTOMYCIN SULFATE)', 'I', 15.5, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: STREPTOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12922, 8603, 'STREPTOMYCIN (STREPTOMYCIN SULFATE)', 'I', 72, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: STREPTOMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78527, 16030, 'NELARABINE', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1612, 510, 'CALCIUM PHOSPHATE (TRIBASIC)', 'I', 324, 'MG', '', '', 'N', '', 'Historic Freeform Text: CALCIUM PHOSPHATE (TRIBASIC)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2005, 510, 'CALCIUM PHOSPHATE (TRIBASIC)', 'I', 324, 'MG', '', '', 'N', '', 'Historic Freeform Text: CALCIUM PHOSPHATE (TRIBASIC)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64083, 510, 'CALCIUM PHOSPHATE (TRIBASIC)', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1993, 510, 'CALCIUM PHOSPHATE (TRIBASIC)', 'I', 21, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CALCIUM PHOSPHATE (TRIBASIC)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1766, 510, 'CALCIUM PHOSPHATE (TRIBASIC)', 'I', 21, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CALCIUM PHOSPHATE (TRIBASIC)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64039, 510, 'CALCIUM PHOSPHATE (TRIBASIC)', 'I', 52, 'G', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64903, 510, 'CALCIUM PHOSPHATE (TRIBASIC)', 'I', 38, 'G', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18786, 450, 'BUFFER SOLUTION', 'I', 10, 'ML', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: BUFFER SOLUTION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16210, 470, 'GABAPENTIN', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15944, 470, 'GABAPENTIN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15945, 470, 'GABAPENTIN', 'I', 300, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67356, 470, 'GABAPENTIN', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67357, 470, 'GABAPENTIN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67358, 470, 'GABAPENTIN', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68490, 470, 'GABAPENTIN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68491, 470, 'GABAPENTIN', 'I', 300, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68492, 470, 'GABAPENTIN', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67676, 470, 'GABAPENTIN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67677, 470, 'GABAPENTIN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67678, 470, 'GABAPENTIN', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68271, 470, 'GABAPENTIN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68273, 470, 'GABAPENTIN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68274, 470, 'GABAPENTIN', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71589, 470, 'GABAPENTIN', 'I', 800, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70477, 470, 'GABAPENTIN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70478, 470, 'GABAPENTIN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70479, 470, 'GABAPENTIN', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72809, 470, 'GABAPENTIN', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74111, 470, 'GABAPENTIN', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74112, 470, 'GABAPENTIN', 'I', 800, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74137, 470, 'GABAPENTIN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74138, 470, 'GABAPENTIN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74139, 470, 'GABAPENTIN', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74325, 470, 'GABAPENTIN', 'I', 800, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74324, 470, 'GABAPENTIN', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74506, 470, 'GABAPENTIN', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74507, 470, 'GABAPENTIN', 'I', 800, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72596, 470, 'GABAPENTIN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72597, 470, 'GABAPENTIN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72598, 470, 'GABAPENTIN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74631, 470, 'GABAPENTIN', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74632, 470, 'GABAPENTIN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74633, 470, 'GABAPENTIN', 'I', 400, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74634, 470, 'GABAPENTIN', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74635, 470, 'GABAPENTIN', 'I', 800, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73612, 470, 'GABAPENTIN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73613, 470, 'GABAPENTIN', 'I', 300, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73614, 470, 'GABAPENTIN', 'I', 400, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77130, 470, 'GABAPENTIN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77131, 470, 'GABAPENTIN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77132, 470, 'GABAPENTIN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77133, 470, 'GABAPENTIN', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77134, 470, 'GABAPENTIN', 'I', 800, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77872, 470, 'GABAPENTIN', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77873, 470, 'GABAPENTIN', 'I', 800, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79608, 470, 'GABAPENTIN', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79609, 470, 'GABAPENTIN', 'I', 300, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79610, 470, 'GABAPENTIN', 'I', 400, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79611, 470, 'GABAPENTIN', 'I', 600, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79612, 470, 'GABAPENTIN', 'I', 800, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79005, 470, 'GABAPENTIN', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79006, 470, 'GABAPENTIN', 'I', 300, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79007, 470, 'GABAPENTIN', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80454, 470, 'GABAPENTIN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80455, 470, 'GABAPENTIN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80456, 470, 'GABAPENTIN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80660, 470, 'GABAPENTIN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80661, 470, 'GABAPENTIN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80662, 470, 'GABAPENTIN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83846, 470, 'GABAPENTIN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83847, 470, 'GABAPENTIN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83848, 470, 'GABAPENTIN', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: GABAPENTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44188, 420, 'GADODIAMIDE', 'I', 287, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GADODIAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43063, 424, 'AZITHROMYCIN', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AZITHROMYCIN ((AZITHROMYCIN DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50450, 424, 'AZITHROMYCIN', 'I', 600, 'MG', '', '', 'Y', '', 'AZITHROMYCIN (AS DIHYDRATE).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71669, 424, 'AZITHROMYCIN (AZITHROMYCIN ISOPROPANOLATE MONOHYDRATE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76396, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE HEMIETHANOLATE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76408, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE HEMIETHANOLATE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76409, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE HEMIETHANOLATE)', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76416, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE HEMIETHANOLATE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75127, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE HEMIETHANOLATE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74052, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE)', 'I', 250, 'MG', '', '', 'N', '', 'AS AZITHROMYCIN MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75325, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE HEMIETHANOLATE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74132, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE)', 'I', 600, 'MG', '', '', 'N', '', 'AS AZITHROMYCIN MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74701, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE HEMIETHANOLATE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74702, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE HEMIETHANOLATE)', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76092, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE HEMIETHANOLATE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76094, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE)', 'I', 250, 'MG', '', '', 'N', '', 'AS AZITHROMYCIN MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76095, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE)', 'I', 600, 'MG', '', '', 'N', '', 'AS AZITHROMYCIN MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75998, 424, 'AZITHROMYCIN', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AZITHROMYCIN ((AZITHROMYCIN DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79623, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE HEMIETHANOLATE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81664, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81666, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE)', 'I', 600, 'MG', '', '', 'N', '', 'AS AZITHROMYCIN MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63455, 424, 'AZITHROMYCIN', 'I', 500, 'MG', '', '', 'N', 'VIAL', 'AZITHROMYCIN (DIHYDRATE).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78290, 424, 'AZITHROMYCIN (AZITHROMYCIN HYDROGEN CITRATE)', 'I', 500, 'MG', '', '', 'N', 'VIAL', '100MG/ML AZITHROMYCIN AFTER RECONSTITION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43386, 424, 'AZITHROMYCIN', 'I', 100, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: AZITHROMYCIN ((AS DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43387, 424, 'AZITHROMYCIN', 'I', 200, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: AZITHROMYCIN ((AS DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75984, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE HEMIETHANOLATE)', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75985, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE HEMIETHANOLATE)', 'I', 200, 'MG', '', '5', 'N', 'ML', 'THIS DIN COMES IN TWO SIZES: 600 MG AND 900 MG AZITHROMYCIN PER BOTTLE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76803, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE HEMIETHANOLATE)', 'I', 100, 'MG', '', '5', 'N', 'ML', 'AZITHROMYCIN ETHANOLATE: 116.67 MG/5 ML (TAKING INTO ACCOUNT THE EXCESS REQUIRED IN ORDER TO ENSURE ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76805, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE HEMIETHANOLATE)', 'I', 200, 'MG', '', '5', 'N', 'ML', 'THIS DIN COMES IN TWO SIZES: 600 MG AND 900 MG AZITHROMYCIN PER BOTTLE) AZITHROMYCIN ETHANOLATE: 233');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81805, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE)', 'I', 200, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81804, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE)', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80071, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE HEMIETHANOLATE)', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80072, 424, 'AZITHROMYCIN (AZITHROMYCIN MONOHYDRATE HEMIETHANOLATE)', 'I', 200, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83998, 424, 'AZITHROMYCIN (AZITHROMYCIN DIHYDRATE)', 'I', 2, 'G', '', '', 'N', 'BOTTLE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11341, 433, 'DIMETHICONE', 'I', 45, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIMETHICONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7455, 433, 'DIMETHICONE', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIMETHICONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42159, 433, 'DIMETHICONE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: SIMETHICONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11430, 433, 'DIMETHICONE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11936, 433, 'DIMETHICONE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60861, 433, 'DIMETHICONE', 'I', 5, '%', '', '', 'N', '', 'DIMETHICONE 225');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60901, 433, 'DIMETHICONE', 'I', 5, '%', '', '', 'N', '', 'DIMETHICONE 225');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69988, 433, 'DIMETHICONE', 'I', 3, '%', '', '', 'N', '', '676MG/CLOTH NOTIFICATION LABEL: 756MG/CLOTH./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74220, 433, 'DIMETHICONE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77695, 433, 'DIMETHICONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77697, 433, 'DIMETHICONE', 'I', 1.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77698, 433, 'DIMETHICONE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77895, 433, 'DIMETHICONE', 'I', 3.2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77896, 433, 'DIMETHICONE', 'I', 3.2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67909, 433, 'DIMETHICONE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73513, 433, 'DIMETHICONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77696, 433, 'DIMETHICONE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81251, 433, 'DIMETHICONE', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78703, 433, 'DIMETHICONE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79649, 433, 'DIMETHICONE', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80397, 433, 'DIMETHICONE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80131, 433, 'DIMETHICONE', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42310, 433, 'DIMETHICONE', 'I', 3, '%', '', '', 'N', '%', 'Historic Freeform Text: SIMETHICONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44552, 433, 'DIMETHICONE', 'I', 25, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIMETHICONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13074, 433, 'DIMETHICONE', 'I', 25, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DIMETHICONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9572, 433, 'DIMETHICONE', 'I', 25, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIMETHICONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10217, 433, 'DIMETHICONE', 'I', 25, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIMETHICONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73340, 13296, 'AGALSIDASE BETA', 'I', 5, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73341, 13296, 'AGALSIDASE BETA', 'I', 35, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73392, 13300, 'AGALSIDASE ALFA', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63131, 13301, 'EPTACOG ALFA (ACTIVATED)', 'I', 1.2, 'MG', '', '', 'N', 'VIAL', 'EPTACOG ALFA (ACTIVATED) AS PER INN CUMULATIVE LIST 12), SCANNED PM AND PRODUCT LABEL./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83442, 13366, 'MEMANTINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63132, 13301, 'EPTACOG ALFA (ACTIVATED)', 'I', 2.4, 'MG', '', '', 'N', 'VIAL', 'EPTACOG ALFA (ACTIVATED) AS PER INN CUMULATIVE LIST 12), SCANNED PM AND PRODUCT LABEL./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63133, 13301, 'EPTACOG ALFA (ACTIVATED)', 'I', 4.8, 'MG', '', '', 'N', 'VIAL', 'EPTACOG ALFA (ACTIVATED) AS PER INN CUMULATIVE LIST 12), SCANNED PM AND PRODUCT LABEL./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83251, 13301, 'EPTACOG ALFA (ACTIVATED)', 'I', 1, 'MG', '', '', 'N', 'VIAL', '2010.03.17. EPTACOG ALFA (ACTIVATED) AS PER INN CUMULATIVE LIST 12), PM AND PRODUCT LABEL. 50 KIU/VI');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83252, 13301, 'EPTACOG ALFA (ACTIVATED)', 'I', 2, 'MG', '', '', 'N', 'VIAL', '2010.03.17. EPTACOG ALFA (ACTIVATED) AS PER INN CUMULATIVE LIST 12), PM AND PRODUCT LABEL. 100 KIU/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83253, 13301, 'EPTACOG ALFA (ACTIVATED)', 'I', 5, 'MG', '', '', 'N', 'VIAL', '2010.03.17. EPTACOG ALFA (ACTIVATED) AS PER INN CUMULATIVE LIST 12), PM AND PRODUCT LABEL. 250 KIU/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73493, 13308, 'PONAZURIL', 'I', 150, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79274, 13310, 'AMBRISENTAN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79275, 13310, 'AMBRISENTAN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73526, 13311, 'VARDENAFIL (VARDENAFIL HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73527, 13311, 'VARDENAFIL (VARDENAFIL HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73528, 13311, 'VARDENAFIL (VARDENAFIL HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73533, 13313, 'MIGLUSTAT', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43389, 13315, 'QUINAGOLIDE (QUINAGOLIDE HYDROCHLORIDE)', 'I', 0.025, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: QUINAGOLIDE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43390, 13315, 'QUINAGOLIDE (QUINAGOLIDE HYDROCHLORIDE)', 'I', 0.05, 'MG', '', '', 'N', '', 'Historic Freeform Text: QUINAGOLIDE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43391, 13315, 'QUINAGOLIDE (QUINAGOLIDE HYDROCHLORIDE)', 'I', 0.075, 'MG', '', '', 'N', '', 'Historic Freeform Text: QUINAGOLIDE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43392, 13315, 'QUINAGOLIDE (QUINAGOLIDE HYDROCHLORIDE)', 'I', 0.15, 'MG', '', '', 'N', '', 'Historic Freeform Text: QUINAGOLIDE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73543, 13317, 'HYPROLOSE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73815, 13323, 'ETONOGESTREL', 'I', 11.4, 'MG', '', '', 'N', '', 'DELIVERS 120 MICROGRAM ETONOGESTREL PER DAY');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73841, 13326, 'PEMETREXED (PEMETREXED DISODIUM)', 'I', 500, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79204, 13326, 'PEMETREXED (PEMETREXED DISODIUM)', 'I', 100, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73983, 13330, 'TERIPARATIDE', 'I', 250, 'µG', '', '', 'N', 'ML', 'TERIPARATIDE(RECOMBINANT DNA ORIGIN)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73990, 13333, 'OXYBUTYNIN', 'I', 36, 'MG', '', '', 'N', '', 'EACH 39 CM SQUARE SYSTEM CONTAINS 36 MG OXYBUTYNIN- 3.9MG/DAY SYSTEM.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73995, 13334, 'SODIUM PICOSULFATE', 'I', 10, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78587, 13334, 'SODIUM PICOSULFATE', 'I', 10, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80347, 13334, 'SODIUM PICOSULFATE', 'I', 10, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84334, 13334, 'SODIUM PICOSULFATE', 'I', 10, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74000, 13336, 'SODIUM PERBORATE MONOHYDRATE', 'I', 29, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74152, 13346, 'ELETRIPTAN (ELETRIPTAN HYDROBROMIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74153, 13346, 'ELETRIPTAN (ELETRIPTAN HYDROBROMIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74170, 13348, 'VORICONAZOLE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74171, 13348, 'VORICONAZOLE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74172, 13348, 'VORICONAZOLE', 'I', 200, 'MG', '', '', 'N', 'VIAL', 'WHEN RECONSTITUTED EACH ML CONTAINS 10MG VORICONAZOLE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76561, 13348, 'VORICONAZOLE', 'I', 3, 'G', '', '', 'N', 'BOTTLE', '3000MG/BOTTLE 40MG/ML AFTER RECONSTITUTION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74230, 13350, 'FROVATRIPTAN (FROVATRIPTAN SUCCINATE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74235, 13352, 'CINACALCET (CINACALCET HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74236, 13352, 'CINACALCET (CINACALCET HYDROCHLORIDE)', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74237, 13352, 'CINACALCET (CINACALCET HYDROCHLORIDE)', 'I', 90, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19642, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 40, 'MG', '', '', 'Y', '', 'Historic Freeform Text: ALENDRONATE ((AS ALENDRONATE SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19643, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 10, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: ALENDRONATE ((AS ALENDRONATE SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69356, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 70, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: ALENDRONATE ((AS ALENDRONATE SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71618, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73095, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73096, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73098, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 70, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66249, 2414, 'NAPROXEN (NAPROXEN SODIUM)', 'I', 375, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74334, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM TRIHYDRATE)', 'I', 40, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: ALENDRONATE ((AS ALENDRONATE SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74335, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM TRIHYDRATE)', 'I', 70, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: ALENDRONATE ((AS ALENDRONATE SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75552, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM TRIHYDRATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75626, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM TRIHYDRATE)', 'I', 70, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: ALENDRONATE ((AS ALENDRONATE SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72588, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 5, 'MG', '', '', 'Y', '', 'ALENDRONATE AS ALENDRONATE SODIUM MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75867, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 70, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74709, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 70, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76091, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 70, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76210, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM TRIHYDRATE)', 'I', 70, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77179, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM TRIHYDRATE)', 'I', 70, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76840, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 70, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76841, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 70, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77346, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77347, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77349, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 70, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76957, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 70, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78733, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 70, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78840, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 70, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80047, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM TRIHYDRATE)', 'I', 70, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78508, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM)', 'I', 70, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83819, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM TRIHYDRATE)', 'I', 70, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: ALENDRONATE ((AS ALENDRONATE SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72982, 13353, 'ALENDRONIC ACID (ALENDRONATE SODIUM TRIHYDRATE)', 'I', 70, 'MG', '', '75', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74379, 13356, 'ADALIMUMAB', 'I', 40, 'MG', '', '0.8', 'N', 'ML', '0.8ML PER VIAL - 0.8ML PER SYRINGE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75157, 13359, 'DELTA-9-TETRAHYDROCANNABINOL (CANNABIS SATIVA EXTRACT)', 'I', 27, 'MG', '', '', 'N', 'ML', 'FROM TRADE NAME TETRANABINEX-CANNABIS SATIVA EXTRACT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74602, 13365, 'OMALIZUMAB', 'I', 150, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74607, 13366, 'MEMANTINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80955, 13366, 'MEMANTINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80632, 13366, 'MEMANTINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80653, 13366, 'MEMANTINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83026, 13366, 'MEMANTINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83428, 13366, 'MEMANTINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85130, 13366, 'MEMANTINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74660, 13370, 'DANOFLOXACIN (DANOFLOXACIN MESYLATE)', 'I', 180, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74661, 13371, 'VON WILLEBRAND FACTOR (HUMAN)', 'I', 840, 'UNIT', '', '5', 'N', 'ML', '(DRIED, PASTEURIZED) 500 - 800 IU RECONSTITUTED WITH 10ML DILUENT.  ANTIHEMOPHILIC FACTOR (HUMAN)/VO');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74662, 13371, 'VON WILLEBRAND FACTOR (HUMAN)', 'I', 1680, 'UNIT', '', '10', 'N', 'ML', '(DRIED, PASTEURIZED) 1000-1600 IU RECONSTITUTED WITH 20ML DILUENT  ANTIHEMOPHILIC FACTOR (HUMAN)/VON');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74663, 13371, 'VON WILLEBRAND FACTOR (HUMAN)', 'I', 3360, 'UNIT', '', '15', 'N', 'ML', '(DRIED, PASTEURIZED) 1800-3000 IU RECONSTITUTED WITH 30ML DILUENT  ANTIHEMOPHILIC FACTOR (HUMAN)/VON');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77219, 13371, 'VON WILLEBRAND FACTOR (HUMAN)', 'I', 500, 'UNIT', '', '5.0', 'N', 'ML', '(DRIED, PASTEURIZED) 500-800 IU RECONSTITUTED WITH 10ML DILUENT. ANTIHEMOPHILIC FACTOR (HUMAN)/VON W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77222, 13371, 'VON WILLEBRAND FACTOR (HUMAN)', 'I', 1000, 'UNIT', '', '10.0', 'N', 'ML', '(DRIED, PASTEURIZED) 500-800 IU RECONSTITUTED WITH 10ML DILUENT. ANTIHEMOPHILIC FACTOR (HUMAN)/VON W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51418, 11482, 'CYTOMEGALOVIRUS IMMUNE GLOBULIN (HUMAN)', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13990, 11385, 'TERBINAFINE (TERBINAFINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TERBINAFINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63385, 11385, 'TERBINAFINE (TERBINAFINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64398, 11385, 'TERBINAFINE (TERBINAFINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63887, 11385, 'TERBINAFINE (TERBINAFINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66543, 11385, 'TERBINAFINE (TERBINAFINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66246, 11385, 'TERBINAFINE (TERBINAFINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73989, 11385, 'TERBINAFINE (TERBINAFINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73216, 11385, 'TERBINAFINE (TERBINAFINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74755, 11385, 'TERBINAFINE (TERBINAFINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: TERBINAFINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74833, 11385, 'TERBINAFINE (TERBINAFINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78466, 11385, 'TERBINAFINE (TERBINAFINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78330, 11385, 'TERBINAFINE (TERBINAFINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77963, 11385, 'TERBINAFINE (TERBINAFINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80558, 11385, 'TERBINAFINE (TERBINAFINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83835, 11385, 'TERBINAFINE (TERBINAFINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84217, 11385, 'TERBINAFINE (TERBINAFINE HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15820, 11388, 'FLUVASTATIN (FLUVASTATIN SODIUM)', 'I', 20, 'MG', '', '', 'Y', '', 'Historic Freeform Text: FLUVASTATIN ((AS FLUVASTATIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15821, 11388, 'FLUVASTATIN (FLUVASTATIN SODIUM)', 'I', 40, 'MG', '', '', 'Y', '', 'Historic Freeform Text: FLUVASTATIN ((AS FLUVASTATIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73534, 11388, 'FLUVASTATIN (FLUVASTATIN SODIUM)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10382, 11346, 'CEFTIOFUR (CEFTIOFUR SODIUM)', 'I', 50, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CEFTIOFUR SODIUM ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62738, 11346, 'CEFTIOFUR (CEFTIOFUR HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78362, 11346, 'CEFTIOFUR (CEFTIOFUR HYDROCHLORIDE)', 'I', 125, 'MG', '', '10', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77751, 11346, 'CEFTIOFUR (CEFTIOFUR CRYSTALLINE FREE ACID)', 'I', 200, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79818, 11346, 'CEFTIOFUR (CEFTIOFUR HYDROCHLORIDE)', 'I', 500, 'MG', '', '10', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79102, 11346, 'CEFTIOFUR (CEFTIOFUR CRYSTALLINE FREE ACID)', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70384, 11349, 'FLUDARABINE PHOSPHATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77921, 11349, 'FLUDARABINE PHOSPHATE', 'I', 50, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76943, 11349, 'FLUDARABINE PHOSPHATE', 'I', 25, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83698, 11349, 'FLUDARABINE PHOSPHATE', 'I', 25, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63823, 11188, 'MIDAZOLAM', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63824, 11188, 'MIDAZOLAM', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67147, 11188, 'MIDAZOLAM (MIDAZOLAM HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67148, 11188, 'MIDAZOLAM (MIDAZOLAM HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66736, 11188, 'MIDAZOLAM', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66737, 11188, 'MIDAZOLAM', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67876, 11188, 'MIDAZOLAM (MIDAZOLAM HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67877, 11188, 'MIDAZOLAM (MIDAZOLAM HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75449, 11213, 'DORZOLAMIDE (DORZOLAMIDE HYDROCHLORIDE)', 'I', 2, '%', '', '', 'Y', '', 'DORZOLAMIDE 20MG/ML, DORZOLAMIDE HYDROCHLORIDE 22.3MG/ML. EW');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66250, 2414, 'NAPROXEN (NAPROXEN SODIUM)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67341, 2414, 'NAPROXEN', 'I', 375, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20083, 11213, 'DORZOLAMIDE (DORZOLAMIDE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: DORZOLAMIDE ((AS HYDROCHLORIDE SALT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63627, 11213, 'DORZOLAMIDE (DORZOLAMIDE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74388, 11213, 'DORZOLAMIDE (DORZOLAMIDE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78499, 11213, 'DORZOLAMIDE (DORZOLAMIDE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82984, 11213, 'DORZOLAMIDE (DORZOLAMIDE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', 'ML', '2% DORZOLAMIDE AS DORZOLAMIDE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80181, 11213, 'DORZOLAMIDE (DORZOLAMIDE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49403, 11220, 'BROMOCRIPTINE (BROMOCRIPTINE MESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51080, 11220, 'BROMOCRIPTINE (BROMOCRIPTINE MESYLATE)', 'I', 2.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62064, 11220, 'BROMOCRIPTINE (BROMOCRIPTINE MESYLATE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62065, 11220, 'BROMOCRIPTINE (BROMOCRIPTINE MESYLATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61585, 11220, 'BROMOCRIPTINE (BROMOCRIPTINE MESYLATE)', 'I', 2.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61586, 11220, 'BROMOCRIPTINE (BROMOCRIPTINE MESYLATE)', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60242, 11220, 'BROMOCRIPTINE (BROMOCRIPTINE MESYLATE)', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2536, 7072, 'TRIETHANOLAMINE STEARATE', 'I', 4, '%', '', '', 'N', '%', 'Historic Freeform Text: TRIETHANOLAMINE STEARATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75157, 14448, 'CANNABIDIOL (CANNABIS SATIVA EXTRACT)', 'I', 25, 'MG', '', '', 'N', 'ML', 'FROM TRADE NAME NABIDIOLEX CANNABIS SATIVA EXTRACT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78264, 14465, 'IMIDAPRIL HYDROCHLORIDE', 'I', 0.075, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78265, 14465, 'IMIDAPRIL HYDROCHLORIDE', 'I', 0.150, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78266, 14465, 'IMIDAPRIL HYDROCHLORIDE', 'I', 0.300, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82520, 2474, 'NALOXONE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82521, 2474, 'NALOXONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82522, 2474, 'NALOXONE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18024, 2474, 'NALOXONE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NALOXONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18025, 2474, 'NALOXONE HYDROCHLORIDE', 'I', 0.4, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NALOXONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74044, 2487, 'PARAFFIN', 'I', 89.6, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19533, 2442, 'CLOMIPRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18530, 2442, 'CLOMIPRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14535, 2442, 'CLOMIPRAMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14536, 2442, 'CLOMIPRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76604, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 3.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14537, 2442, 'CLOMIPRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4382, 2442, 'CLOMIPRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLOMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2164, 2442, 'CLOMIPRAMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2039, 2442, 'CLOMIPRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48987, 2442, 'CLOMIPRAMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51042, 2442, 'CLOMIPRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51044, 2442, 'CLOMIPRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62663, 2442, 'CLOMIPRAMINE HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62664, 2442, 'CLOMIPRAMINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62665, 2442, 'CLOMIPRAMINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68806, 2442, 'CLOMIPRAMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68807, 2442, 'CLOMIPRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68808, 2442, 'CLOMIPRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOMIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13390, 2446, 'DEFEROXAMINE MESYLATE', 'I', 2, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: DEFEROXAMINE MESYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67360, 2446, 'DEFEROXAMINE MESYLATE', 'I', 2, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: DEFEROXAMINE MESYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71256, 2446, 'DEFEROXAMINE MESYLATE', 'I', 2, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13546, 2446, 'DEFEROXAMINE MESYLATE', 'I', 500, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: DEFEROXAMINE MESYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65727, 2446, 'DEFEROXAMINE MESYLATE', 'I', 500, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: DEFEROXAMINE MESYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65257, 2446, 'DEFEROXAMINE MESYLATE', 'I', 500, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62433, 2418, 'CARMUSTINE', 'I', 7.7, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2153, 2418, 'CARMUSTINE', 'I', 100, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: CARMUSTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44068, 2385, 'THREONINE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: DL-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15493, 2385, 'THREONINE', 'I', 400, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: DL-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7163, 2385, 'THREONINE', 'I', 330, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: DL-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4661, 2385, 'THREONINE', 'I', 420, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: DL-THREONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 2385, 'THREONINE', 'I', 64.6, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (38260, 2395, 'LACTULOSE', 'I', 667, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LACTULOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12699, 2395, 'LACTULOSE', 'I', 667, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LACTULOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66642, 2395, 'LACTULOSE', 'I', 667, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71628, 2395, 'LACTULOSE', 'I', 667, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78124, 2395, 'LACTULOSE', 'I', 667, 'MG', '', '', 'N', 'ML', '(10G/15ML)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81724, 2395, 'LACTULOSE', 'I', 667, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14019, 2402, 'DANTROLENE SODIUM', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DANTROLENE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14018, 2402, 'DANTROLENE SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DANTROLENE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14017, 2402, 'DANTROLENE SODIUM', 'I', 20, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: DANTROLENE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2495, 2403, 'SODIUM LAURYL ETHER SULFATE', 'I', 6, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM LAURYL ETHER SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44216, 2414, 'NAPROXEN', 'I', 750, 'MG', '', '', 'N', '', ' QTY UNIT: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11184, 2414, 'NAPROXEN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11185, 2414, 'NAPROXEN', 'I', 375, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11186, 2414, 'NAPROXEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11187, 2414, 'NAPROXEN', 'I', 125, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6524, 2414, 'NAPROXEN', 'I', 375, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5860, 2414, 'NAPROXEN', 'I', 375, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6266, 2414, 'NAPROXEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5508, 2414, 'NAPROXEN', 'I', 375, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5222, 2414, 'NAPROXEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5183, 2414, 'NAPROXEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5175, 2414, 'NAPROXEN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5036, 2414, 'NAPROXEN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4980, 2414, 'NAPROXEN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4981, 2414, 'NAPROXEN', 'I', 125, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64377, 2414, 'NAPROXEN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64378, 2414, 'NAPROXEN', 'I', 375, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64379, 2414, 'NAPROXEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67215, 2414, 'NAPROXEN', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67216, 2414, 'NAPROXEN', 'I', 375, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67217, 2414, 'NAPROXEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67340, 2414, 'NAPROXEN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70894, 2414, 'NAPROXEN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70895, 2414, 'NAPROXEN', 'I', 375, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70896, 2414, 'NAPROXEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78006, 2414, 'NAPROXEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78005, 2414, 'NAPROXEN', 'I', 375, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79656, 2414, 'NAPROXEN', 'I', 375, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79657, 2414, 'NAPROXEN', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83596, 2414, 'NAPROXEN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83597, 2414, 'NAPROXEN', 'I', 375, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83598, 2414, 'NAPROXEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83599, 2414, 'NAPROXEN', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83600, 2414, 'NAPROXEN', 'I', 375, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83601, 2414, 'NAPROXEN', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84676, 2414, 'NAPROXEN', 'I', 375, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84677, 2414, 'NAPROXEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19314, 2414, 'NAPROXEN', 'I', 750, 'MG', '', '', 'N', 'SRT', 'Historic Freeform Text: NAPROXEN Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50634, 2414, 'NAPROXEN', 'I', 750, 'MG', '', '', 'N', 'SRT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19448, 2414, 'NAPROXEN', 'I', 250, 'MG', '', '', 'N', 'ECT', 'Historic Freeform Text: NAPROXEN Qty Unit: ECT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19315, 2414, 'NAPROXEN', 'I', 500, 'MG', '', '', 'N', 'ECT', 'Historic Freeform Text: NAPROXEN Qty Unit: ECT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19316, 2414, 'NAPROXEN', 'I', 375, 'MG', '', '', 'N', 'ECT', 'Historic Freeform Text: NAPROXEN Qty Unit: ECT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64618, 2414, 'NAPROXEN', 'I', 500, 'MG', '', '', 'N', 'ECT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14566, 2414, 'NAPROXEN', 'I', 500, 'MG', '', '', 'N', 'SUP', 'Historic Freeform Text: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19661, 2414, 'NAPROXEN', 'I', 25, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NAPROXEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64887, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70998, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70999, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70541, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76603, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 3.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75413, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75414, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74217, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75527, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75528, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74500, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75015, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73821, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 0.5, '%', '', '', 'N', '', '(I.E 9 GM OF AQUEOUS SOLUTION OF 33%)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77476, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78218, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 0.25, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78220, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78221, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78154, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78156, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 0.25, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78656, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78813, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78893, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78894, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78895, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78604, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79068, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 0.53, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79098, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76605, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 2.00, '%', '', '', 'N', 'W/W', '(MEXORYL SX)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82930, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82931, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80435, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80393, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82270, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80383, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79784, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84959, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 2.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84962, 390, 'TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID', 'I', 2.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20256, 348, 'HEPATITIS A VACCINE, INACTIVATED', 'I', 1440, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HEPATITIS A VACCINE ((INACTIVATED)). HM175 HEPATITIS A VIRUS STRAIN.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63411, 348, 'HEPATITIS A VACCINE, INACTIVATED', 'I', 500, 'UNIT', '', '0.5', 'N', 'ML', 'HEPATITIS A VACCINE, INACTIVATED, VIROSOME-FORMULATED. WITH AT LEAST 500RU OF HEPATITIS A ANTIGEN PE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47865, 348, 'HEPATITIS A VACCINE, INACTIVATED', 'I', 50, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49687, 348, 'HEPATITIS A VACCINE, INACTIVATED', 'I', 720, 'UNIT', '', '1.0', 'N', 'ML', '720 ELISA UNITS (EL.U.)/1.0ML AS INACTIVATED HEPATITIS A VIRAL ANTIGEN (HM 175 STRAIN).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50339, 348, 'HEPATITIS A VACCINE, INACTIVATED', 'I', 720, 'UNIT', '', '0.5', 'N', 'ML', 'HM175 HEPATITIS A VIRUS STRAIN.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61149, 348, 'HEPATITIS A VACCINE, INACTIVATED', 'I', 160, 'UNIT', '', '0.5', 'N', 'ML', 'UNIT IS ANTIGEN UNIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60885, 348, 'HEPATITIS A VACCINE, INACTIVATED', 'I', 360, 'UNIT', '', '0.5', 'N', 'ML', '360 ELISA UNITS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67674, 348, 'HEPATITIS A VACCINE, INACTIVATED', 'I', 80, 'UNIT', '', '0.5', 'N', 'ML', 'UNIT IS ANTIGEN UNIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72706, 348, 'HEPATITIS A VACCINE, INACTIVATED', 'I', 160, 'UNIT', '', '0.5', 'N', 'ML', 'SUSPENSION, 160 ANTIGEN UNITS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17797, 349, 'ROCURONIUM BROMIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ROCURONIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80390, 349, 'ROCURONIUM BROMIDE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80363, 349, 'ROCURONIUM BROMIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ROCURONIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36404, 298, 'MINERAL OIL LIGHT', 'I', 100, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MINERAL OIL LIGHT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2643, 298, 'MINERAL OIL LIGHT', 'I', 100, '%', '', '', 'N', '', 'V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49031, 298, 'MINERAL OIL LIGHT', 'I', 100, '%', '', '', 'N', '%', 'Historic Freeform Text: MINERAL OIL LIGHT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80731, 298, 'MINERAL OIL LIGHT', 'I', 34.0, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PEPTONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79248, 298, 'MINERAL OIL LIGHT', 'I', 34, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18517, 299, 'EPOETIN ALFA', 'I', 10000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: EPOETIN ALFA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18538, 299, 'EPOETIN ALFA', 'I', 2000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: EPOETIN ALFA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18529, 299, 'EPOETIN ALFA', 'I', 4000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: EPOETIN ALFA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50949, 299, 'EPOETIN ALFA', 'I', 1000, 'UNIT', '', '0.5', 'N', 'ML', 'CONC=1000IU/0.5ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50950, 299, 'EPOETIN ALFA', 'I', 2000, 'UNIT', '', '0.5', 'N', 'ML', 'CONC=2000IU/0.5ML PREFILLED SYRINGE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50951, 299, 'EPOETIN ALFA', 'I', 3000, 'UNIT', '', '0.3', 'N', 'ML', 'CONC=3000IU/0.3ML PREFILLED SYR.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50952, 299, 'EPOETIN ALFA', 'I', 4000, 'UNIT', '', '0.4', 'N', 'ML', 'CONC=4000IU/0.4ML PREFILLED SYRINGE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50953, 299, 'EPOETIN ALFA', 'I', 10000, 'UNIT', '', '', 'N', 'ML', 'CONC=10000IU/1.0ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64311, 299, 'EPOETIN ALFA', 'I', 40000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: EPOETIN ALFA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67133, 299, 'EPOETIN ALFA', 'I', 20000, 'UNIT', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67308, 299, 'EPOETIN ALFA', 'I', 5000, 'UNIT', '', '0.5', 'N', 'ML', 'CONC=10000IU/1.0ML . PRE-FILLED SYR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67309, 299, 'EPOETIN ALFA', 'I', 6000, 'UNIT', '', '0.6', 'N', 'ML', 'CONC=10000IU/1.0ML. PRE-FILLED SYR.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67311, 299, 'EPOETIN ALFA', 'I', 8000, 'UNIT', '', '0.8', 'N', 'ML', 'CONC=10000IU/1.0ML. PRE-FILLED SYR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77409, 299, 'EPOETIN ALFA', 'I', 30000, 'UNIT', '', '0.75', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75353, 306, 'UROFOLLITROPIN', 'I', 75, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16851, 308, 'ARTICAINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ARTICAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16850, 308, 'ARTICAINE HYDROCHLORIDE', 'I', 40.0, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ARTICAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16508, 308, 'ARTICAINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ARTICAINE ((HCL)) ------------------------------------------------------FOR ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16511, 308, 'ARTICAINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ARTICAINE ((HCL)) ------------------------------------------------------FOR ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72840, 308, 'ARTICAINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72841, 308, 'ARTICAINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74608, 308, 'ARTICAINE HYDROCHLORIDE', 'I', 40.0, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ARTICAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82513, 308, 'ARTICAINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82514, 308, 'ARTICAINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70202, 309, 'IRON (FERROUS FUMARATE)', 'I', 35, 'MG', '', '', 'N', '', 'PINK TABLET A.M.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76186, 309, 'IRON (FERROUS FUMARATE)', 'I', 35, 'MG', '', '', 'N', '', 'PINK TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5754, 265, 'MENTHOL', 'I', 40, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43298, 309, 'IRON (IRON DEXTRAN COMPLEX)', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: IRON ((AS IRON DEXTRAN COMPLEX))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43006, 309, 'IRON (IRON DEXTRAN COMPLEX)', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: IRON ((AS IRON DEXTRAN))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15622, 309, 'IRON (IRON DEXTRAN)', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: IRON ((FROM IRON DEXTRAN))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11872, 309, 'IRON (IRON DEXTRAN COMPLEX)', 'I', 200, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: IRON (AS IRON DEXTRAN COMPLEX)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12802, 309, 'IRON (IRON DEXTRAN COMPLEX)', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: IRON DEXTRAN ((FE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9554, 309, 'IRON (FERRIC HYDROXIDE SUCROSE COMPLEX)', 'I', 20, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: FERRIC HYDROXIDE SUCRE COMP ((IRON EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7145, 309, 'IRON (IRON DEXTRAN COMPLEX)', 'I', 100, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: IRON DEXTRAN COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5924, 309, 'IRON (IRON DEXTRAN COMPLEX)', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: IRON DEXTRAN ((IRON EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6367, 309, 'IRON (IRON DEXTRAN COMPLEX)', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: IRON DEXTRAN COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4396, 309, 'IRON (IRON DEXTRAN COMPLEX)', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: IRON DEXTRAN COMPLEX 2010.04.07. ACTIVE INGREDIENT REVISED FROM IRON DEXTRAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2010, 309, 'IRON (IRON DEXTRAN COMPLEX)', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: IRON DEXTRAN ((IRON EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67236, 309, 'IRON (SODIUM FERRIC GLUCONATE COMPLEX IN SUCROSE INJECTION)', 'I', 12.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67648, 309, 'IRON (IRON SUCROSE)', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70078, 309, 'IRON (GLEPTOFERRON)', 'I', 200, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73759, 309, 'IRON (FERRIC HYDROXIDE DEXTRAN COMPLEX)', 'I', 200, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 309, 'IRON (FERROUS SULFATE)', 'I', 3.746, 'G', '', '', 'Y', 'KG', 'HISTORIC FREEFORM TEXT: FERROUS SULFATE ((IRON EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36399, 253, 'AMYLASE', 'I', 20000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: AMYLASE Qty Unit: ECC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36179, 253, 'AMYLASE', 'I', 33200, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: AMYLASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35065, 253, 'AMYLASE', 'I', 11000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: AMYLASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27084, 253, 'AMYLASE', 'I', 65000, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALPHA-AMYLASE QTY UNIT: ECC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27081, 253, 'AMYLASE', 'I', 39000, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALPHA-AMYLASE QTY UNIT: ECC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13302, 253, 'AMYLASE', 'I', 74000, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALPHA-AMYLASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9892, 253, 'AMYLASE', 'I', 55000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: ALPHA-AMYLASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3189, 253, 'AMYLASE', 'I', 30000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: ALPHA-AMYLASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3891, 253, 'AMYLASE', 'I', 30000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: ALPHA-AMYLASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1649, 253, 'AMYLASE', 'I', 30000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: ALPHA-AMYLASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48551, 253, 'AMYLASE', 'I', 30000, 'UNIT', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60913, 253, 'AMYLASE', 'I', 140000, 'UNIT', '', '', 'N', '', 'PER TABLET: AMYLASE ACTIVITY  140000 FCC UNITS. FROM (650 MG) OF PORCINE PANCREATIN.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62457, 253, 'AMYLASE', 'I', 16600, 'UNIT', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62458, 253, 'AMYLASE', 'I', 66400, 'UNIT', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65603, 253, 'AMYLASE', 'I', 60000, 'UNIT', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12239, 253, 'AMYLASE', 'I', 280000, 'UNIT', '', '2.8', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43218, 256, 'STANDARDIZED CAT HAIR ACETONE PRECIPITATED', 'I', 10000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: STAN.CAT HAIR ACETONE PREC. 10000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43219, 257, 'STANDARDIZED CAT PELT ACETONE PRECIPITATED', 'I', 10000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: STAN.CAT PELT ACETONE PREC. ((10000BAU/ML))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61969, 265, 'MENTHOL', 'I', 8.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76114, 265, 'MENTHOL', 'I', 6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80640, 265, 'MENTHOL', 'I', 8.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42186, 265, 'MENTHOL', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42099, 265, 'MENTHOL', 'I', 1.5, '%', '', '', 'N', '', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42113, 265, 'MENTHOL', 'I', 1.25, '%', '', '', 'N', '', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42042, 265, 'MENTHOL', 'I', 1.5, '%', '', '', 'N', '', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42043, 265, 'MENTHOL', 'I', 1.5, '%', '', '', 'N', '', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41939, 265, 'MENTHOL', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42607, 265, 'MENTHOL', 'I', 0.6, '%', '', '', 'N', '', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15950, 265, 'MENTHOL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10999, 265, 'MENTHOL', 'I', 0.3, '%', '', '', 'N', '', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9335, 265, 'MENTHOL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3998, 265, 'MENTHOL', 'I', 2.0, '%', '', '', 'N', '', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2022, 265, 'MENTHOL', 'I', 2.0, '%', '', '', 'N', '', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60861, 265, 'MENTHOL', 'I', 0.15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60901, 265, 'MENTHOL', 'I', 0.50, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60289, 265, 'MENTHOL', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74263, 265, 'MENTHOL', 'I', 0.97, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74327, 265, 'MENTHOL', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77120, 265, 'MENTHOL', 'I', 1.5, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79467, 265, 'MENTHOL', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80107, 265, 'MENTHOL', 'I', 1.25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80397, 265, 'MENTHOL', 'I', 0.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10674, 265, 'MENTHOL', 'I', 1, '%', '', '', 'N', 'W/V', 'HISTORIC FREEFORM TEXT: MENTHOL. W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77121, 265, 'MENTHOL', 'I', 1.5, '%', '', '', 'N', 'W/V', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42334, 265, 'MENTHOL', 'I', 0.6, '%', '', '', 'N', '%', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22937, 265, 'MENTHOL', 'I', 3, '%', '', '', 'N', '%', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3665, 265, 'MENTHOL', 'I', 1.25, '%', '', '', 'N', '%', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3666, 265, 'MENTHOL', 'I', 0.75, '%', '', '', 'N', '%', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6564, 265, 'MENTHOL', 'I', 2, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6249, 265, 'MENTHOL', 'I', 5.124, 'G', '', '470', 'N', 'ML', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4553, 265, 'MENTHOL', 'I', 3.7, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3312, 265, 'MENTHOL', 'I', 6, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3313, 265, 'MENTHOL', 'I', 17.1, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3314, 265, 'MENTHOL', 'I', 5.1, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42528, 265, 'MENTHOL', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36844, 265, 'MENTHOL', 'I', 23.14, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4161, 265, 'MENTHOL', 'I', 7.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MENTHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50217, 265, 'MENTHOL', 'I', 22, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66168, 265, 'MENTHOL', 'I', 10.75, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4657, 265, 'MENTHOL', 'I', 4.40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2842, 265, 'MENTHOL', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75087, 265, 'MENTHOL', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75088, 265, 'MENTHOL', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75089, 265, 'MENTHOL', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76530, 265, 'MENTHOL', 'I', 20, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77454, 265, 'MENTHOL', 'I', 10, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80636, 265, 'MENTHOL', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80637, 265, 'MENTHOL', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83190, 265, 'MENTHOL', 'I', 10, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13570, 265, 'MENTHOL', 'I', 0.5, '%', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16939, 267, 'SODIUM LINEAR ALKYLATE SULFONATE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM LINEAR ALKYLATE SULFONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47167, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41753, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42569, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42382, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42082, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41830, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41831, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37037, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37150, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37097, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37099, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35047, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34150, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33272, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (32410, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31568, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33120, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31506, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33917, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27225, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26144, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25897, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25898, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22846, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22847, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22143, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22086, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19429, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19418, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19419, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20255, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19624, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19935, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17887, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17880, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19249, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19250, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19248, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19103, 270, 'ACETAMINOPHEN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19084, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17235, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16752, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15805, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15202, 270, 'ACETAMINOPHEN', 'I', 120, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15204, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15205, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17113, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15706, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15580, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15581, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15579, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15578, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15514, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16437, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13120, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14130, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14131, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13607, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12942, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14084, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14595, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14596, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14509, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14475, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14449, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14450, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14383, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13865, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13316, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13312, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14316, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13804, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13259, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13765, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13761, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14206, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11794, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11753, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11741, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12461, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11140, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11141, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11646, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11041, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12154, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12565, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11427, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11921, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11339, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8387, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9626, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9627, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9628, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8250, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8251, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8252, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8247, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8249, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10205, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8597, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5476, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7081, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5372, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5345, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6516, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5876, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5778, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5780, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6893, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6894, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6346, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7434, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6824, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7363, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7364, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7352, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6763, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6764, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5584, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5570, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5571, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7288, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4883, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4884, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4733, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4734, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5255, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5184, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5254, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5035, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2178, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2179, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2180, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2727, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2728, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2064, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2065, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49590, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47718, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48231, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49357, 270, 'ACETAMINOPHEN', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49359, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49360, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48431, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50062, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52221, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50212, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50292, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50484, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50547, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51867, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51868, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51869, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62483, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62514, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62597, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62610, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62614, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61372, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60748, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60749, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60750, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60817, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62325, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', '', 'FORM = BI-LAYER CAPLET. FIRST LAYER DISSOLVES IMMEDIATELY TO PROVIDE PROMPT RELIEF WHILE THE SECOND ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60162, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60900, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60916, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60917, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61697, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63299, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64652, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64134, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64135, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63901, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63224, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65178, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65249, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65250, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65859, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64806, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64807, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66799, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66193, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66847, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66910, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66916, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66917, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64993, 270, 'ACETAMINOPHEN', 'I', 160.00, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66950, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66958, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65665, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67104, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67870, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69009, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69017, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69018, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68103, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68104, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68664, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68230, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68231, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68299, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72216, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72217, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70191, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', '', 'FORM = BI-LAYER CAPLET. FIRST LAYER DISSOLVES IMMEDIATELY TO PROVIDE PROMPT RELIEF WHILE THE SECOND ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70220, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70222, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70284, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70285, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70286, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69738, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70399, 270, 'ACETAMINOPHEN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71047, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71094, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70470, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69866, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76431, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73918, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73920, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75158, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73935, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72935, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74005, 270, 'ACETAMINOPHEN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74007, 270, 'ACETAMINOPHEN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74016, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74017, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74040, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75299, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76681, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73003, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74181, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75371, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73064, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75452, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75534, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74414, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74415, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75800, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73187, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74549, 270, 'ACETAMINOPHEN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74550, 270, 'ACETAMINOPHEN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75828, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75829, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75894, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75895, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75896, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75929, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75930, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75939, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73359, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76086, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76087, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76130, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76137, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76138, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76167, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76168, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76170, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76171, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76172, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73537, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76178, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76185, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76188, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76190, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76189, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76192, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76236, 270, 'ACETAMINOPHEN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73592, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73655, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73656, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73677, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73678, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74921, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74922, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76238, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73681, 270, 'ACETAMINOPHEN', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73702, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73703, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73704, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73705, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73774, 270, 'ACETAMINOPHEN', 'I', 325.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73775, 270, 'ACETAMINOPHEN', 'I', 500.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75035, 270, 'ACETAMINOPHEN', 'I', 325.00, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75038, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78062, 270, 'ACETAMINOPHEN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77584, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77593, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77210, 270, 'ACETAMINOPHEN', 'I', 650.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77128, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77631, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77849, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77891, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77892, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77787, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77806, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77807, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77847, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76904, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', '', 'BI-LAYER TABLET MADE UP OF AN IMMEDIATE RELEASE COMPONENT OF 325MG ACETAMINOPHEN AND AN EXTENDED REL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77185, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78348, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81657, 270, 'ACETAMINOPHEN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82152, 270, 'ACETAMINOPHEN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81882, 270, 'ACETAMINOPHEN', 'I', 650.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78657, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', '', 'BI-LAYER TABLET MADE UP OF AN IMMEDIATE RELEASE COMPONENT OF 325MG ACETAMINOPHEN AND AN EXTENDED REL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79084, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79088, 270, 'ACETAMINOPHEN', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79269, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78913, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79863, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79679, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79195, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79278, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81249, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80540, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80829, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79146, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79356, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82241, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81005, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79071, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82884, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82084, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83056, 270, 'ACETAMINOPHEN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83258, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83303, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83304, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83316, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83344, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83343, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84247, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84644, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19271, 270, 'ACETAMINOPHEN', 'I', 120, 'MG', '', '', 'N', 'SUP', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19272, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', 'SUP', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14591, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '', 'N', 'SUP', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14592, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', 'SUP', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14593, 270, 'ACETAMINOPHEN', 'I', 120, 'MG', '', '', 'N', 'SUP', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14594, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', 'SUP', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49361, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', 'SUP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37051, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35886, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37105, 270, 'ACETAMINOPHEN', 'I', 1000, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26397, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26396, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77936, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21168, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10188, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65873, 270, 'ACETAMINOPHEN', 'I', 1000, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65633, 270, 'ACETAMINOPHEN', 'I', 1000, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70790, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76387, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: PHENIRAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75146, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76511, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80466, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83004, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37183, 270, 'ACETAMINOPHEN', 'I', 1, 'G', '', '30', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42388, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42341, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '1', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42135, 270, 'ACETAMINOPHEN', 'I', 32, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42136, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42066, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41867, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41869, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33482, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33483, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30945, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26863, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21989, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18015, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19244, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16988, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13960, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11795, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11796, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10450, 270, 'ACETAMINOPHEN', 'I', 32, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10451, 270, 'ACETAMINOPHEN', 'I', 16, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12412, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11063, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12722, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '20', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12159, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11384, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6112, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47448, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50056, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60014, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60714, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64653, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64394, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63140, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66840, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66983, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72095, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69814, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76432, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76469, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76530, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26864, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76233, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75558, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75858, 270, 'ACETAMINOPHEN', 'I', 1000, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74683, 270, 'ACETAMINOPHEN', 'I', 1000, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74797, 270, 'ACETAMINOPHEN', 'I', 1000, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76164, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76166, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74919, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74920, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74923, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76254, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73724, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77475, 270, 'ACETAMINOPHEN', 'I', 1000, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77628, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77585, 270, 'ACETAMINOPHEN', 'I', 1000, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77674, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77675, 270, 'ACETAMINOPHEN', 'I', 1000, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77749, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78697, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79105, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78620, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79002, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79122, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81650, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78973, 270, 'ACETAMINOPHEN', 'I', 1000, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79762, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79763, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79547, 270, 'ACETAMINOPHEN', 'I', 80, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79548, 270, 'ACETAMINOPHEN', 'I', 160, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80682, 270, 'ACETAMINOPHEN', 'I', 500, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62576, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '22', 'N', 'MG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31530, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '22', 'N', 'G', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (32780, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '23', 'N', 'G', 'HISTORIC FREEFORM TEXT: ACETAMINOPHEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62330, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '23', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71050, 270, 'ACETAMINOPHEN', 'I', 650, 'MG', '', '24', 'N', 'G', 'STRENGTH VALUE PER DOSAGE UNIT CHANGED TO 24G FROM 23 G AS PER CONTROL NO. 119452.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73067, 270, 'ACETAMINOPHEN', 'I', 325, 'MG', '', '22', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17800, 271, 'MEGLUMINE IOXITALAMATE', 'I', 513, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MEGLUMINE IOXITALAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75617, 277, 'AZELAIC ACID', 'I', 15, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18314, 278, 'ALDESLEUKIN', 'I', 22000000, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: ALDESLEUKIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18868, 285, 'DANAPAROID SODIUM', 'I', 750, 'UNIT', '', '0.6', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DANAPAROID SODIUM ((1250ANTI-XA UNITS/ML))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20020, 217, 'BACILLUS CALMETTE-GUERIN (BCG) SUBSTRAIN CONNAUGHT', 'I', 81, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: BACILLUS CALMETTE-GUERIN (BCG) SUBSTRAIN CONNAUGHT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (673, 217, 'BACILLUS CALMETTE-GUERIN (BCG) SUBSTRAIN CONNAUGHT', 'I', 0.1, 'MG', '', '0.1', 'N', 'ML', 'HISTORIC FREEFORM TEXT: B.C.G. VACCINE  ACTIVE INGREDIENT CHANGED FROM B.C.G. VACCINE TO BACILLUS CA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42480, 219, 'SODIUM FLUORIDE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM FLUORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42483, 219, 'SODIUM FLUORIDE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM FLUORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14444, 219, 'SODIUM FLUORIDE', 'I', 0.243, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM FLUORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71650, 2280, 'OCTOCRYLENE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77106, 219, 'SODIUM FLUORIDE', 'I', 0.243, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM FLUORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84966, 219, 'SODIUM FLUORIDE', 'I', 0.243, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20107, 224, 'ADAPALENE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: ADAPALENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50959, 224, 'ADAPALENE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75946, 224, 'ADAPALENE', 'I', 0.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85075, 224, 'ADAPALENE', 'I', 0.1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69474, 225, 'MOXIDECTIN', 'I', 10, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43488, 225, 'MOXIDECTIN', 'I', 5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MOXIDECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43168, 225, 'MOXIDECTIN', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MOXIDECTIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51036, 225, 'MOXIDECTIN', 'I', 20, 'MG', '', '', 'N', 'ML', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74889, 225, 'MOXIDECTIN', 'I', 4, 'MG', '', '0.4', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74890, 225, 'MOXIDECTIN', 'I', 8, 'MG', '', '0.8', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74891, 225, 'MOXIDECTIN', 'I', 62.5, 'MG', '', '2.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74892, 225, 'MOXIDECTIN', 'I', 25, 'MG', '', '1.0', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74893, 225, 'MOXIDECTIN', 'I', 10, 'MG', '', '0.4', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74894, 225, 'MOXIDECTIN', 'I', 100, 'MG', '', '4.0', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76244, 225, 'MOXIDECTIN', 'I', 20, 'MG', '', '', 'N', 'ML', '2%W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1086, 10209, 'PHENYTOIN', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENYLHYDANTOIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (613, 10209, 'PHENYTOIN', 'I', 125, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIPHENYLHYDANTOIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (769, 10209, 'PHENYTOIN', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIPHENYLHYDANTOIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73583, 10209, 'PHENYTOIN', 'I', 125, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIPHENYLHYDANTOIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15805, 10224, 'DOXYLAMINE SUCCINATE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: DOXYLAMINE SUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12744, 10224, 'DOXYLAMINE SUCCINATE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DOXYLAMINE SUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5509, 10224, 'DOXYLAMINE SUCCINATE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DOXYLAMINE SUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69017, 10224, 'DOXYLAMINE SUCCINATE', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71047, 10224, 'DOXYLAMINE SUCCINATE', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74007, 10224, 'DOXYLAMINE SUCCINATE', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74016, 10224, 'DOXYLAMINE SUCCINATE', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74415, 10224, 'DOXYLAMINE SUCCINATE', 'I', 6.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DOXYLAMINE SUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74550, 10224, 'DOXYLAMINE SUCCINATE', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75829, 10224, 'DOXYLAMINE SUCCINATE', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75929, 10224, 'DOXYLAMINE SUCCINATE', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79269, 10224, 'DOXYLAMINE SUCCINATE', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82084, 10224, 'DOXYLAMINE SUCCINATE', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37183, 10224, 'DOXYLAMINE SUCCINATE', 'I', 12.5, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: DOXYLAMINE SUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13960, 10224, 'DOXYLAMINE SUCCINATE', 'I', 7.5, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: DOXYLAMINE SUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5475, 10224, 'DOXYLAMINE SUCCINATE', 'I', 1.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DOXYLAMINE SUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4615, 10224, 'DOXYLAMINE SUCCINATE', 'I', 1.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DOXYLAMINE SUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50030, 10224, 'DOXYLAMINE SUCCINATE', 'I', 1.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DOXYLAMINE SUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68650, 10224, 'DOXYLAMINE SUCCINATE', 'I', 6.25, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75858, 10224, 'DOXYLAMINE SUCCINATE', 'I', 12.5, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76254, 10224, 'DOXYLAMINE SUCCINATE', 'I', 12.5, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77585, 10224, 'DOXYLAMINE SUCCINATE', 'I', 12.5, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: DOXYLAMINE SUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78973, 10224, 'DOXYLAMINE SUCCINATE', 'I', 12.5, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (677, 10070, 'PIPERAZINE HYDROCHLORIDE', 'I', 53, '%', '', '', 'N', '', 'Historic Freeform Text: PIPERAZINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (678, 10070, 'PIPERAZINE HYDROCHLORIDE', 'I', 34, '%', '', '', 'N', '', 'Historic Freeform Text: PIPERAZINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (126, 10070, 'PIPERAZINE HYDROCHLORIDE', 'I', 12.4, '%', '', '', 'N', '', 'Historic Freeform Text: PIPERAZINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60664, 9745, 'DIMETHYL SULFOXIDE', 'I', 60, '%', '', '', 'N', '', 'V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52516, 9745, 'DIMETHYL SULFOXIDE', 'I', 90, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52518, 9745, 'DIMETHYL SULFOXIDE', 'I', 90, '%', '', '', 'N', 'V/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3769, 9745, 'DIMETHYL SULFOXIDE', 'I', 500, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: DIMETHYLSULFOXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67117, 9745, 'DIMETHYL SULFOXIDE', 'I', 500, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: DIMETHYLSULFOXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3620, 9570, 'WHITE CEDAR OIL', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: WHITE CEDAR OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82160, 9570, 'WHITE CEDAR OIL', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 9397, 'L-ASPARTIC ACID', 'I', 1.3, 'G', '', '', 'N', '', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19306, 9397, 'L-ASPARTIC ACID', 'I', 1.05, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 9397, 'L-ASPARTIC ACID', 'I', 298, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43947, 9397, 'L-ASPARTIC ACID', 'I', 600, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 9397, 'L-ASPARTIC ACID', 'I', 298, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 9397, 'L-ASPARTIC ACID', 'I', 298, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 9397, 'L-ASPARTIC ACID', 'I', 245, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 9397, 'L-ASPARTIC ACID', 'I', 298, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 9397, 'L-ASPARTIC ACID', 'I', 298, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 9397, 'L-ASPARTIC ACID', 'I', 245, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 9397, 'L-ASPARTIC ACID', 'I', 330, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 9397, 'L-ASPARTIC ACID', 'I', 245, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 9397, 'L-ASPARTIC ACID', 'I', 298, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 9397, 'L-ASPARTIC ACID', 'I', 245, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 9397, 'L-ASPARTIC ACID', 'I', 370, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18644, 9397, 'L-ASPARTIC ACID', 'I', 700, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 9397, 'L-ASPARTIC ACID', 'I', 700, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18608, 9397, 'L-ASPARTIC ACID', 'I', 490, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 9397, 'L-ASPARTIC ACID', 'I', 527, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18607, 9397, 'L-ASPARTIC ACID', 'I', 595, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 9397, 'L-ASPARTIC ACID', 'I', 4.7, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 9397, 'L-ASPARTIC ACID', 'I', 2, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-ASPARTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 9397, 'L-ASPARTIC ACID', 'I', 600, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 9397, 'L-ASPARTIC ACID', 'I', 0.73, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 9397, 'L-ASPARTIC ACID', 'I', 1.28, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 9397, 'L-ASPARTIC ACID', 'I', 1.65, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 9397, 'L-ASPARTIC ACID', 'I', 1.65, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4657, 9402, 'POTASSIUM BICARBONATE', 'I', 52.7, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12923, 9402, 'POTASSIUM BICARBONATE', 'I', 206, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: POTASSIUM BICARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2481, 9008, 'HYOSCINE BUTYLBROMIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: SCOPOLAMINE N-BUTYLBROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2483, 9008, 'HYOSCINE BUTYLBROMIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SCOPOLAMINE N-BUTYLBROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48226, 9008, 'HYOSCINE BUTYLBROMIDE', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76773, 9008, 'HYOSCINE BUTYLBROMIDE', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41695, 8712, 'JUNIPER TAR', 'I', 0.166, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: JUNIPERTAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5557, 8712, 'JUNIPER TAR', 'I', 0.33, '%', '', '', 'N', '', 'Historic Freeform Text: JUNIPERTAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2984, 8712, 'JUNIPER TAR', 'I', 0.09, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: JUNIPERTAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1495, 8712, 'JUNIPER TAR', 'I', 0.16, '%', '', '', 'N', '', 'Historic Freeform Text: JUNIPERTAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64533, 8712, 'JUNIPER TAR', 'I', 0.33, '%', '', '', 'N', '', 'Historic Freeform Text: JUNIPERTAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (134, 8712, 'JUNIPER TAR', 'I', 60, 'G', '', '11.35', 'N', 'KG', 'Historic Freeform Text: JUNIPERTAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2181, 7148, 'BORIC ACID', 'I', 15, '%', '', '', 'N', '', 'Historic Freeform Text: BORIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74675, 7148, 'BORIC ACID', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1139, 7148, 'BORIC ACID', 'I', 1.9, '%', '', '', 'N', '%', 'Historic Freeform Text: BORIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3888, 7148, 'BORIC ACID', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: BORIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48860, 7148, 'BORIC ACID', 'I', 3.6, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48974, 7148, 'BORIC ACID', 'I', 6.7, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10226, 6681, 'YOHIMBINE', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: YOHIMBINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13850, 5560, 'POTASSIUM HYDROXIDE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: POTASSIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 9735, 'SODIUM', 'I', 30, 'MEQ', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 9735, 'SODIUM', 'I', 30, 'MEQ', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6404, 9735, 'SODIUM (SODIUM CHLORIDE)', 'I', 132, 'MEQ', '', '', 'N', 'L', 'Historic Freeform Text: SOD CHLORIDE ((SOD EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17209, 8285, 'DRONABINOL', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: TETRAHYDRO CANNABINOLS ((AS DELTA-9))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17207, 8285, 'DRONABINOL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: TETRAHYDRO CANNABINOLS ((AS DELTA-9))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27350, 6950, 'BENZOIN', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZOIN ((TINCTURE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13247, 6950, 'BENZOIN', 'I', 1.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZOIN ((TINCTURE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34874, 6950, 'BENZOIN', 'I', 25, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: BENZOIN ((TINCTURE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41578, 6950, 'BENZOIN', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: BENZOIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (818, 6950, 'BENZOIN', 'I', 20.46, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11254, 5019, 'NICOTINIC ACID', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: NICOTINIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1142, 5019, 'NICOTINIC ACID', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: NICOTINIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 5019, 'NICOTINIC ACID', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75581, 5019, 'NICOTINIC ACID', 'I', 500, 'MG', '', '', 'N', '', 'TABLET (EXTENDED-RELEASE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75582, 5019, 'NICOTINIC ACID', 'I', 1000, 'MG', '', '', 'N', '', 'TABLET (EXTENDED-RELEASE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74771, 5019, 'NICOTINIC ACID', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74772, 5019, 'NICOTINIC ACID', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74773, 5019, 'NICOTINIC ACID', 'I', 1000, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79485, 5019, 'NICOTINIC ACID', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79486, 5019, 'NICOTINIC ACID', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79488, 5019, 'NICOTINIC ACID', 'I', 1000, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22007, 5019, 'NICOTINIC ACID', 'I', 1.47, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NICOTINIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9372, 5019, 'NICOTINIC ACID', 'I', 1.47, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NICOTINIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3499, 5019, 'NICOTINIC ACID', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: NICOTINIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3965, 5019, 'NICOTINIC ACID', 'I', 800, 'MG', '', '1.25', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NICOTINIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 5019, 'NICOTINIC ACID', 'I', 4.73, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: NICOTINIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 5019, 'NICOTINIC ACID', 'I', 1.74, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: NICOTINIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 5019, 'NICOTINIC ACID', 'I', 17.60, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: NICOTINIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24471, 5019, 'NICOTINIC ACID', 'I', 4.488, 'G', '', '170', 'N', 'G', 'Historic Freeform Text: NICOTINIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12922, 5019, 'NICOTINIC ACID', 'I', 14.84, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: NICOTINIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8101, 5019, 'NICOTINIC ACID', 'I', 3, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: NICOTINIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 3844, 'QUATERNIUM-15', 'I', 0.081, 'MG', '', '', 'N', 'PATCH', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 9927, 'SERINE', 'I', 525, 'MG', '', '', 'N', '', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43947, 9927, 'SERINE', 'I', 1.02, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 9927, 'SERINE', 'I', 225, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44068, 9927, 'SERINE', 'I', 500, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20278, 9927, 'SERINE', 'I', 250, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 9927, 'SERINE', 'I', 212.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19306, 9927, 'SERINE', 'I', 795, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20302, 9927, 'SERINE', 'I', 250, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20303, 9927, 'SERINE', 'I', 212.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 9927, 'SERINE', 'I', 212.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 9927, 'SERINE', 'I', 250, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 9927, 'SERINE', 'I', 250, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20289, 9927, 'SERINE', 'I', 212.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 9927, 'SERINE', 'I', 125, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 9927, 'SERINE', 'I', 250, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 9927, 'SERINE', 'I', 250, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20279, 9927, 'SERINE', 'I', 250, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 9927, 'SERINE', 'I', 225, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 9927, 'SERINE', 'I', 225, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 9927, 'SERINE', 'I', 185, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 9927, 'SERINE', 'I', 225, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 9927, 'SERINE', 'I', 225, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 9927, 'SERINE', 'I', 185, 'MG', '', '100', 'N', 'ML', 'L-SERINE IS 185.5 MG BY CALCULATION, 185 MG ON LABEL /KM HISTORIC FREEFORM TEXT: L-SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 9927, 'SERINE', 'I', 265, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 9927, 'SERINE', 'I', 186, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 9927, 'SERINE', 'I', 225, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 9927, 'SERINE', 'I', 347, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 9927, 'SERINE', 'I', 185, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18644, 9927, 'SERINE', 'I', 530, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 9927, 'SERINE', 'I', 530, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18608, 9927, 'SERINE', 'I', 371, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18607, 9927, 'SERINE', 'I', 450, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 9927, 'SERINE', 'I', 495, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11329, 9927, 'SERINE', 'I', 500, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 9927, 'SERINE', 'I', 3.6, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5890, 9927, 'SERINE', 'I', 370, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 9927, 'SERINE', 'I', 370, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 9927, 'SERINE', 'I', 1.6, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3468, 9927, 'SERINE', 'I', 420, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4560, 9927, 'SERINE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2776, 9927, 'SERINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SERINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 9927, 'SERINE', 'I', 51, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 9927, 'SERINE', 'I', 400, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 9927, 'SERINE', 'I', 1.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 9927, 'SERINE', 'I', 1.75, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 9927, 'SERINE', 'I', 2.25, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 9927, 'SERINE', 'I', 2.25, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43920, 2361, 'ZERANOL', 'I', 36, 'MG', '', '', 'N', 'DOSE', '12 MG PER IMPLANT PELLET, 3 PELLETS/DOSE. EW. 16.3.98 ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2837, 2371, 'MORANTEL TARTRATE', 'I', 200, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: MORANTEL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19677, 2373, 'MICONAZOLE NITRATE', 'I', 400, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MICONAZOLE NITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16612, 2373, 'MICONAZOLE NITRATE', 'I', 400, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MICONAZOLE NITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63071, 2373, 'MICONAZOLE NITRATE', 'I', 1200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17832, 2373, 'MICONAZOLE NITRATE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: MICONAZOLE NITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16608, 2373, 'MICONAZOLE NITRATE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: MICONAZOLE NITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16609, 2373, 'MICONAZOLE NITRATE', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MICONAZOLE NITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16610, 2373, 'MICONAZOLE NITRATE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: MICONAZOLE NITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16611, 2373, 'MICONAZOLE NITRATE', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MICONAZOLE NITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49064, 2373, 'MICONAZOLE NITRATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50390, 2373, 'MICONAZOLE NITRATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67948, 2373, 'MICONAZOLE NITRATE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69637, 2373, 'MICONAZOLE NITRATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16610, 2373, 'MICONAZOLE NITRATE', 'I', 400, 'MG', '', '', 'N', 'SUP', 'HISTORIC FREEFORM TEXT: MICONAZOLE NITRATE ((3 OVULES 400MG EACH))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16611, 2373, 'MICONAZOLE NITRATE', 'I', 100, 'MG', '', '', 'N', 'SUP', 'HISTORIC FREEFORM TEXT: MICONAZOLE NITRATE ((7 SUP 100MG EACH/KIT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50876, 2373, 'MICONAZOLE NITRATE', 'I', 2, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63070, 2373, 'MICONAZOLE NITRATE', 'I', 1200, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63070, 2373, 'MICONAZOLE NITRATE', 'I', 2, '%', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10300, 2373, 'MICONAZOLE NITRATE', 'I', 23, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MICONAZOLE NITRATE ((BASE 20MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10481, 2373, 'MICONAZOLE NITRATE', 'I', 20, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: MICONAZOLE NITRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19479, 2375, 'CLOTRIMAZOLE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOTRIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19480, 2375, 'CLOTRIMAZOLE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOTRIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44016, 2375, 'CLOTRIMAZOLE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: CLOTRIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19483, 2375, 'CLOTRIMAZOLE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: CLOTRIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19484, 2375, 'CLOTRIMAZOLE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: CLOTRIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10748, 2375, 'CLOTRIMAZOLE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLOTRIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49563, 2375, 'CLOTRIMAZOLE', 'I', 1, '%', '', '', 'N', '', '1% TOPICAL CREAM - 1 10G TUBE PER KIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49563, 2375, 'CLOTRIMAZOLE', 'I', 10, '%', '', '', 'N', '', '10% VAGINAL CREAM - 1 5G APPLICATOR PER KIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62905, 2375, 'CLOTRIMAZOLE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: CLOTRIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74951, 2375, 'CLOTRIMAZOLE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLOTRIMAZOLE (1% CREAM, 1X10G TUBE PER KIT)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74952, 2375, 'CLOTRIMAZOLE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLOTRIMAZOLE ((1% CREAM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79727, 2375, 'CLOTRIMAZOLE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79728, 2375, 'CLOTRIMAZOLE', 'I', 1, '%', '', '', 'N', '', 'CANESTEN EXTERNAL CREAM DIN 02311720 /JJ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74951, 2375, 'CLOTRIMAZOLE', 'I', 200, 'MG', '', '', 'N', 'VTAB', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74952, 2375, 'CLOTRIMAZOLE', 'I', 500, 'MG', '', '', 'N', 'VTAB', 'HISTORIC FREEFORM TEXT: CLOTRIMAZOLE ((KIT WITH 1-500MG SUP))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47180, 2375, 'CLOTRIMAZOLE', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: CLOTRIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47181, 2375, 'CLOTRIMAZOLE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: CLOTRIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19487, 2375, 'CLOTRIMAZOLE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: CLOTRIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11893, 2375, 'CLOTRIMAZOLE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: CLOTRIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9926, 2375, 'CLOTRIMAZOLE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: CLOTRIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9927, 2375, 'CLOTRIMAZOLE', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: CLOTRIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83919, 2375, 'CLOTRIMAZOLE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10777, 2375, 'CLOTRIMAZOLE', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: CLOTRIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83017, 2375, 'CLOTRIMAZOLE', 'I', 10, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19340, 2327, 'KETOPROFEN', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: KETOPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19507, 2327, 'KETOPROFEN', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: KETOPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18302, 2327, 'KETOPROFEN', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: KETOPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18301, 2327, 'KETOPROFEN', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: KETOPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19115, 2327, 'KETOPROFEN', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: KETOPROFEN Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16039, 2327, 'KETOPROFEN', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: KETOPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14025, 2327, 'KETOPROFEN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: KETOPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10134, 2327, 'KETOPROFEN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: KETOPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10135, 2327, 'KETOPROFEN', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: KETOPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10136, 2327, 'KETOPROFEN', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: KETOPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60312, 2327, 'KETOPROFEN', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70092, 2327, 'KETOPROFEN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70093, 2327, 'KETOPROFEN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19338, 2327, 'KETOPROFEN', 'I', 100, 'MG', '', '', 'N', 'ECT', 'Historic Freeform Text: KETOPROFEN Qty Unit: ECT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19339, 2327, 'KETOPROFEN', 'I', 50, 'MG', '', '', 'N', 'ECT', 'Historic Freeform Text: KETOPROFEN Qty Unit: ECT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16042, 2327, 'KETOPROFEN', 'I', 50, 'MG', '', '', 'N', 'ECT', 'Historic Freeform Text: KETOPROFEN Qty Unit: ECT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16038, 2327, 'KETOPROFEN', 'I', 100, 'MG', '', '', 'N', 'ECT', 'Historic Freeform Text: KETOPROFEN Qty Unit: ECT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18303, 2327, 'KETOPROFEN', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: KETOPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13635, 2327, 'KETOPROFEN', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: KETOPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13895, 2328, 'AIR', 'I', 99.7, '%', '', '', 'N', '', 'Historic Freeform Text: COMPRESSED AIR ((99.995-99.7%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13896, 2328, 'AIR', 'I', 85, '%', '', '', 'N', '', 'Historic Freeform Text: COMPRESSED AIR ((99-85%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13897, 2328, 'AIR', 'I', 50, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COMPRESSED AIR ((69.9-50%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13892, 2328, 'AIR', 'I', 70, '%', '', '', 'N', '', 'Historic Freeform Text: COMPRESSED AIR ((84.9-70%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5684, 2328, 'AIR', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: AIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18513, 2329, 'NITROUS OXIDE', 'I', 50, '%', '', '', 'N', '', 'Historic Freeform Text: NITROUS OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19262, 2329, 'NITROUS OXIDE', 'I', 99, '%', '', '', 'N', '', 'Historic Freeform Text: NITROUS OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19102, 2329, 'NITROUS OXIDE', 'I', 50, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NITROUS OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13887, 2329, 'NITROUS OXIDE', 'I', 99, '%', '', '', 'N', '', 'Historic Freeform Text: NITROUS OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6850, 2329, 'NITROUS OXIDE', 'I', 50, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NITROUS OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5685, 2329, 'NITROUS OXIDE', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: NITROUS OXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19100, 2331, 'NEON', 'I', 0.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NEON');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8185, 2331, 'NEON', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: NEON');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (45814, 2333, 'OXYGEN', 'I', 99.9, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37030, 2333, 'OXYGEN', 'I', 100, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70253, 2280, 'OCTOCRYLENE', 'I', 1.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27306, 2333, 'OXYGEN', 'I', 99.5, '%', '', '', 'N', '', 'Historic Freeform Text: OXYGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19290, 2333, 'OXYGEN', 'I', 50, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN ((20% TO 50%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19291, 2333, 'OXYGEN', 'I', 23.5, '%', '', '', 'N', '', 'ACTIVE INGREDIENT STRENGTH CHANGED FROM 21% TO 23.5 AND 79% TO 76.5% FOR OXGEN AND NITROGEN RESPECTI');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19293, 2333, 'OXYGEN', 'I', 50, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN ((BALANCE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19299, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20047, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20349, 2333, 'OXYGEN', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: OXYGEN ((USP))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18513, 2333, 'OXYGEN', 'I', 50, '%', '', '', 'N', '', 'Historic Freeform Text: OXYGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19100, 2333, 'OXYGEN', 'I', 21.0, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19101, 2333, 'OXYGEN', 'I', 21.0, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN ((19.5% TO 21%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19102, 2333, 'OXYGEN', 'I', 50, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18663, 2333, 'OXYGEN', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: OXYGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15005, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', 'Historic Freeform Text: OXYGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13920, 2333, 'OXYGEN', 'I', 21.5, '%', '', '', 'N', '', 'Historic Freeform Text: OXYGEN ((20.5-21.5%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13910, 2333, 'OXYGEN', 'I', 93, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN ((99-93%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13885, 2333, 'OXYGEN', 'I', 19.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN ((19.5-23.5%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13886, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13890, 2333, 'OXYGEN', 'I', 24, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN ((18-24%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13894, 2333, 'OXYGEN', 'I', 50, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN ((23.5-50%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11059, 2333, 'OXYGEN', 'I', 77, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN ((77-87.9%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8185, 2333, 'OXYGEN', 'I', 21, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6850, 2333, 'OXYGEN', 'I', 50, '%', '', '', 'N', '', 'Historic Freeform Text: OXYGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5689, 2333, 'OXYGEN', 'I', 20, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6826, 2333, 'OXYGEN', 'I', 99.0, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN  JUNE 27/01 - UPDATED STRENGTH OF OXYGEN FROM 99.5% TO 99.0% AS PER U');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5682, 2333, 'OXYGEN', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: OXYGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5686, 2333, 'OXYGEN', 'I', 95, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5545, 2333, 'OXYGEN', 'I', 99.5, '%', '', '', 'N', '', 'Historic Freeform Text: OXYGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50235, 2333, 'OXYGEN', 'I', 99.99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61847, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', 'USP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61206, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62190, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64194, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64346, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64373, 2333, 'OXYGEN', 'I', 100, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66253, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66280, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66284, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66939, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72159, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73046, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73094, 2333, 'OXYGEN', 'I', 99.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72531, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77527, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79765, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80944, 2333, 'OXYGEN', 'I', 99, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46353, 2333, 'OXYGEN', 'I', 50, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: OXYGEN ((23 TO 50%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44612, 2333, 'OXYGEN', 'I', 21, '%', '', '', 'N', '%', 'Historic Freeform Text: OXYGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11058, 2333, 'OXYGEN', 'I', 88, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: OXYGEN ((88-92.9%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11060, 2333, 'OXYGEN', 'I', 50, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: OXYGEN ((50-76.9%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19290, 2334, 'HELIUM', 'I', 50, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HELIUM ((BALANCE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19294, 2334, 'HELIUM', 'I', 99, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HELIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19101, 2334, 'HELIUM', 'I', 10.0, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HELIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13920, 2334, 'HELIUM', 'I', 10.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HELIUM ((9.5-10.5%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13883, 2334, 'HELIUM', 'I', 99, '%', '', '', 'N', '', 'Historic Freeform Text: HELIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13890, 2334, 'HELIUM', 'I', 76, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HELIUM ((82-76%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5689, 2334, 'HELIUM', 'I', 80, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HELIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5688, 2334, 'HELIUM', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: HELIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46353, 2334, 'HELIUM', 'I', 50, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: HELIUM ((50 TO 77%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44612, 2334, 'HELIUM', 'I', 10, '%', '', '', 'N', '%', 'Historic Freeform Text: HELIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19293, 2335, 'CARBON DIOXIDE', 'I', 50, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBON DIOXIDE ((0.5-50%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19263, 2335, 'CARBON DIOXIDE', 'I', 99, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBON DIOXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13910, 2335, 'CARBON DIOXIDE', 'I', 7, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBON DIOXIDE ((1-7%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13896, 2335, 'CARBON DIOXIDE', 'I', 15, '%', '', '', 'N', '', 'Historic Freeform Text: CARBON DIOXIDE ((1-15%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13897, 2335, 'CARBON DIOXIDE', 'I', 50, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBON DIOXIDE ((30.1-50%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13884, 2335, 'CARBON DIOXIDE', 'I', 99, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBON DIOXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13892, 2335, 'CARBON DIOXIDE', 'I', 30, '%', '', '', 'N', '', 'Historic Freeform Text: CARBON DIOXIDE ((15.1-30%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11059, 2335, 'CARBON DIOXIDE', 'I', 23, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBON DIOXIDE ((12.1-23%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5686, 2335, 'CARBON DIOXIDE', 'I', 5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBON DIOXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5687, 2335, 'CARBON DIOXIDE', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: CARBON DIOXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11058, 2335, 'CARBON DIOXIDE', 'I', 12, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: CARBON DIOXIDE ((7.1-12%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11060, 2335, 'CARBON DIOXIDE', 'I', 50, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: CARBON DIOXIDE ((23.1-50%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10665, 2345, 'TERBUTALINE SULFATE', 'I', 0.5, 'MG', '', '', 'N', 'ACT', 'Historic Freeform Text: TERBUTALINE SULFATE Qty Unit: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30927, 2280, 'OCTOCRYLENE', 'I', 9, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OCTOCRYLENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79216, 2280, 'OCTOCRYLENE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19037, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OCTOCRYLENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75823, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50939, 2280, 'OCTOCRYLENE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67232, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65424, 2280, 'OCTOCRYLENE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65426, 2280, 'OCTOCRYLENE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64887, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66892, 2280, 'OCTOCRYLENE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68325, 2280, 'OCTOCRYLENE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68818, 2280, 'OCTOCRYLENE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68355, 2280, 'OCTOCRYLENE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69420, 2280, 'OCTOCRYLENE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68574, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72192, 2280, 'OCTOCRYLENE', 'I', 8, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72275, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71649, 2280, 'OCTOCRYLENE', 'I', 8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69552, 2280, 'OCTOCRYLENE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70998, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70999, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69834, 2280, 'OCTOCRYLENE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70541, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72053, 2280, 'OCTOCRYLENE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76449, 2280, 'OCTOCRYLENE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76450, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75161, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76518, 2280, 'OCTOCRYLENE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76600, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76603, 2280, 'OCTOCRYLENE', 'I', 10.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76604, 2280, 'OCTOCRYLENE', 'I', 10.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75392, 2280, 'OCTOCRYLENE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75409, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75413, 2280, 'OCTOCRYLENE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75414, 2280, 'OCTOCRYLENE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74215, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73106, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75527, 2280, 'OCTOCRYLENE', 'I', 7, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75528, 2280, 'OCTOCRYLENE', 'I', 7, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75557, 2280, 'OCTOCRYLENE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75565, 2280, 'OCTOCRYLENE', 'I', 8, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75594, 2280, 'OCTOCRYLENE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72392, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75709, 2280, 'OCTOCRYLENE', 'I', 8.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73166, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74500, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74554, 2280, 'OCTOCRYLENE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75847, 2280, 'OCTOCRYLENE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75868, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75869, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74651, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74654, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74655, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75907, 2280, 'OCTOCRYLENE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74749, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73436, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76179, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76213, 2280, 'OCTOCRYLENE', 'I', 2.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76214, 2280, 'OCTOCRYLENE', 'I', 2.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76327, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76328, 2280, 'OCTOCRYLENE', 'I', 2.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72761, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72762, 2280, 'OCTOCRYLENE', 'I', 2.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73821, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77484, 2280, 'OCTOCRYLENE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77485, 2280, 'OCTOCRYLENE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77488, 2280, 'OCTOCRYLENE', 'I', 8.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78156, 2280, 'OCTOCRYLENE', 'I', 9, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77531, 2280, 'OCTOCRYLENE', 'I', 7, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77533, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77461, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77476, 2280, 'OCTOCRYLENE', 'I', 8, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77577, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77578, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77605, 2280, 'OCTOCRYLENE', 'I', 9.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77606, 2280, 'OCTOCRYLENE', 'I', 9.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78218, 2280, 'OCTOCRYLENE', 'I', 9, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78220, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78221, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77122, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77123, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76898, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77048, 2280, 'OCTOCRYLENE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77517, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77614, 2280, 'OCTOCRYLENE', 'I', 2.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77629, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77608, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78154, 2280, 'OCTOCRYLENE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77383, 2280, 'OCTOCRYLENE', 'I', 10.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78240, 2280, 'OCTOCRYLENE', 'I', 9.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77299, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78310, 2280, 'OCTOCRYLENE', 'I', 1.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78311, 2280, 'OCTOCRYLENE', 'I', 1.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76910, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78023, 2280, 'OCTOCRYLENE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78024, 2280, 'OCTOCRYLENE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76934, 2280, 'OCTOCRYLENE', 'I', 1.7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77324, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77326, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78020, 2280, 'OCTOCRYLENE', 'I', 1.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79960, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79018, 2280, 'OCTOCRYLENE', 'I', 2.8, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78656, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78690, 2280, 'OCTOCRYLENE', 'I', 2.35, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78689, 2280, 'OCTOCRYLENE', 'I', 2.35, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79181, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79182, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80443, 2280, 'OCTOCRYLENE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78700, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78701, 2280, 'OCTOCRYLENE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79265, 2280, 'OCTOCRYLENE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78989, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79294, 2280, 'OCTOCRYLENE', 'I', 2.35, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78813, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79295, 2280, 'OCTOCRYLENE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79719, 2280, 'OCTOCRYLENE', 'I', 2.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80173, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78621, 2280, 'OCTOCRYLENE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78893, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78894, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78895, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79252, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79253, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79255, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79257, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78604, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78605, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78929, 2280, 'OCTOCRYLENE', 'I', 2.79, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78930, 2280, 'OCTOCRYLENE', 'I', 2.79, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79533, 2280, 'OCTOCRYLENE', 'I', 9.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80565, 2280, 'OCTOCRYLENE', 'I', 1.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79238, 2280, 'OCTOCRYLENE', 'I', 2.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79320, 2280, 'OCTOCRYLENE', 'I', 2.35, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79197, 2280, 'OCTOCRYLENE', 'I', 3.55, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78635, 2280, 'OCTOCRYLENE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79067, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79226, 2280, 'OCTOCRYLENE', 'I', 1.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80227, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80110, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80111, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80641, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80828, 2280, 'OCTOCRYLENE', 'I', 6.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78647, 2280, 'OCTOCRYLENE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82839, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82383, 2280, 'OCTOCRYLENE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79098, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79184, 2280, 'OCTOCRYLENE', 'I', 7, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82622, 2280, 'OCTOCRYLENE', 'I', 2.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80820, 2280, 'OCTOCRYLENE', 'I', 2.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80821, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82313, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82530, 2280, 'OCTOCRYLENE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84131, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84132, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84342, 2280, 'OCTOCRYLENE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84348, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84353, 2280, 'OCTOCRYLENE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84541, 2280, 'OCTOCRYLENE', 'I', 2.7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85091, 2280, 'OCTOCRYLENE', 'I', 2.75, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48991, 2280, 'OCTOCRYLENE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76605, 2280, 'OCTOCRYLENE', 'I', 10.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72549, 2280, 'OCTOCRYLENE', 'I', 2.25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72583, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75934, 2280, 'OCTOCRYLENE', 'I', 8.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74885, 2280, 'OCTOCRYLENE', 'I', 8.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76200, 2280, 'OCTOCRYLENE', 'I', 2.35, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76215, 2280, 'OCTOCRYLENE', 'I', 2.4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74967, 2280, 'OCTOCRYLENE', 'I', 12.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74968, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74969, 2280, 'OCTOCRYLENE', 'I', 12.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74970, 2280, 'OCTOCRYLENE', 'I', 12.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74999, 2280, 'OCTOCRYLENE', 'I', 8.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76204, 2280, 'OCTOCRYLENE', 'I', 2.8, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72764, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77368, 2280, 'OCTOCRYLENE', 'I', 8.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77389, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77391, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78219, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76938, 2280, 'OCTOCRYLENE', 'I', 2.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76863, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77721, 2280, 'OCTOCRYLENE', 'I', 2.35, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76941, 2280, 'OCTOCRYLENE', 'I', 2.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78222, 2280, 'OCTOCRYLENE', 'I', 2.4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80859, 2280, 'OCTOCRYLENE', 'I', 9.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81654, 2280, 'OCTOCRYLENE', 'I', 4.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81144, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81175, 2280, 'OCTOCRYLENE', 'I', 2.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79851, 2280, 'OCTOCRYLENE', 'I', 2.35, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80135, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82780, 2280, 'OCTOCRYLENE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82843, 2280, 'OCTOCRYLENE', 'I', 7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80128, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80480, 2280, 'OCTOCRYLENE', 'I', 2.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80566, 2280, 'OCTOCRYLENE', 'I', 2.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82206, 2280, 'OCTOCRYLENE', 'I', 2.75, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82242, 2280, 'OCTOCRYLENE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82930, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82931, 2280, 'OCTOCRYLENE', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82964, 2280, 'OCTOCRYLENE', 'I', 1.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79731, 2280, 'OCTOCRYLENE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78685, 2280, 'OCTOCRYLENE', 'I', 2.35, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78686, 2280, 'OCTOCRYLENE', 'I', 2.35, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79183, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80487, 2280, 'OCTOCRYLENE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80488, 2280, 'OCTOCRYLENE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80350, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79766, 2280, 'OCTOCRYLENE', 'I', 4.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80723, 2280, 'OCTOCRYLENE', 'I', 2.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82834, 2280, 'OCTOCRYLENE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80748, 2280, 'OCTOCRYLENE', 'I', 2.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80791, 2280, 'OCTOCRYLENE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81406, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82015, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82018, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82161, 2280, 'OCTOCRYLENE', 'I', 2.35, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81716, 2280, 'OCTOCRYLENE', 'I', 2.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80088, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79605, 2280, 'OCTOCRYLENE', 'I', 2.25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80025, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80026, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80027, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80174, 2280, 'OCTOCRYLENE', 'I', 2.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80175, 2280, 'OCTOCRYLENE', 'I', 2.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80176, 2280, 'OCTOCRYLENE', 'I', 2.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80435, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80436, 2280, 'OCTOCRYLENE', 'I', 1.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80398, 2280, 'OCTOCRYLENE', 'I', 1.25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80400, 2280, 'OCTOCRYLENE', 'I', 1.25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81451, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81454, 2280, 'OCTOCRYLENE', 'I', 8.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81366, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81367, 2280, 'OCTOCRYLENE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81371, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81370, 2280, 'OCTOCRYLENE', 'I', 7.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81372, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81017, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81337, 2280, 'OCTOCRYLENE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80050, 2280, 'OCTOCRYLENE', 'I', 0.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80051, 2280, 'OCTOCRYLENE', 'I', 0.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80052, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80055, 2280, 'OCTOCRYLENE', 'I', 1.25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80056, 2280, 'OCTOCRYLENE', 'I', 0.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80960, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82493, 2280, 'OCTOCRYLENE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82494, 2280, 'OCTOCRYLENE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80198, 2280, 'OCTOCRYLENE', 'I', 2.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80199, 2280, 'OCTOCRYLENE', 'I', 2.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80200, 2280, 'OCTOCRYLENE', 'I', 2.7, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81604, 2280, 'OCTOCRYLENE', 'I', 8.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81708, 2280, 'OCTOCRYLENE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81709, 2280, 'OCTOCRYLENE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77392, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77390, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81779, 2280, 'OCTOCRYLENE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81842, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82013, 2280, 'OCTOCRYLENE', 'I', 2.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82014, 2280, 'OCTOCRYLENE', 'I', 2.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82508, 2280, 'OCTOCRYLENE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80327, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80453, 2280, 'OCTOCRYLENE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80328, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80478, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80568, 2280, 'OCTOCRYLENE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79983, 2280, 'OCTOCRYLENE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80631, 2280, 'OCTOCRYLENE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80810, 2280, 'OCTOCRYLENE', 'I', 2.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80024, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80022, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80023, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80411, 2280, 'OCTOCRYLENE', 'I', 2.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81076, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79524, 2280, 'OCTOCRYLENE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79595, 2280, 'OCTOCRYLENE', 'I', 2.25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80113, 2280, 'OCTOCRYLENE', 'I', 2.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80577, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81413, 2280, 'OCTOCRYLENE', 'I', 7.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81415, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81660, 2280, 'OCTOCRYLENE', 'I', 4.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79618, 2280, 'OCTOCRYLENE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80460, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80069, 2280, 'OCTOCRYLENE', 'I', 2.35, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80696, 2280, 'OCTOCRYLENE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81266, 2280, 'OCTOCRYLENE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82515, 2280, 'OCTOCRYLENE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80393, 2280, 'OCTOCRYLENE', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81293, 2280, 'OCTOCRYLENE', 'I', 8.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81892, 2280, 'OCTOCRYLENE', 'I', 8.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81893, 2280, 'OCTOCRYLENE', 'I', 8.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81894, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82380, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82381, 2280, 'OCTOCRYLENE', 'I', 2.75, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82415, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80362, 2280, 'OCTOCRYLENE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79484, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80383, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80425, 2280, 'OCTOCRYLENE', 'I', 1.25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81911, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80061, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80516, 2280, 'OCTOCRYLENE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80517, 2280, 'OCTOCRYLENE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81043, 2280, 'OCTOCRYLENE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81044, 2280, 'OCTOCRYLENE', 'I', 2.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82367, 2280, 'OCTOCRYLENE', 'I', 2.75, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82017, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82019, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82020, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80669, 2280, 'OCTOCRYLENE', 'I', 1.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80670, 2280, 'OCTOCRYLENE', 'I', 1.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81913, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81914, 2280, 'OCTOCRYLENE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81915, 2280, 'OCTOCRYLENE', 'I', 5.25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81916, 2280, 'OCTOCRYLENE', 'I', 8.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81921, 2280, 'OCTOCRYLENE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82373, 2280, 'OCTOCRYLENE', 'I', 2.75, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82462, 2280, 'OCTOCRYLENE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80254, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80256, 2280, 'OCTOCRYLENE', 'I', 1.25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80537, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80539, 2280, 'OCTOCRYLENE', 'I', 7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82060, 2280, 'OCTOCRYLENE', 'I', 2.4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82067, 2280, 'OCTOCRYLENE', 'I', 2.4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80034, 2280, 'OCTOCRYLENE', 'I', 2.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80035, 2280, 'OCTOCRYLENE', 'I', 2.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80177, 2280, 'OCTOCRYLENE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80178, 2280, 'OCTOCRYLENE', 'I', 1.25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81069, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80302, 2280, 'OCTOCRYLENE', 'I', 1.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82543, 2280, 'OCTOCRYLENE', 'I', 2.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78779, 2280, 'OCTOCRYLENE', 'I', 1.7, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80864, 2280, 'OCTOCRYLENE', 'I', 2.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79868, 2280, 'OCTOCRYLENE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80380, 2280, 'OCTOCRYLENE', 'I', 1.9, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80567, 2280, 'OCTOCRYLENE', 'I', 7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80595, 2280, 'OCTOCRYLENE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79784, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81488, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81490, 2280, 'OCTOCRYLENE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81491, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83072, 2280, 'OCTOCRYLENE', 'I', 1.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83098, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83101, 2280, 'OCTOCRYLENE', 'I', 2.35, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83168, 2280, 'OCTOCRYLENE', 'I', 8.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83388, 2280, 'OCTOCRYLENE', 'I', 1.25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83389, 2280, 'OCTOCRYLENE', 'I', 1.25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83391, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83403, 2280, 'OCTOCRYLENE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83420, 2280, 'OCTOCRYLENE', 'I', 2.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83564, 2280, 'OCTOCRYLENE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83580, 2280, 'OCTOCRYLENE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83581, 2280, 'OCTOCRYLENE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83677, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83772, 2280, 'OCTOCRYLENE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83773, 2280, 'OCTOCRYLENE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83775, 2280, 'OCTOCRYLENE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83859, 2280, 'OCTOCRYLENE', 'I', 4.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83866, 2280, 'OCTOCRYLENE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83869, 2280, 'OCTOCRYLENE', 'I', 2.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83877, 2280, 'OCTOCRYLENE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83881, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83983, 2280, 'OCTOCRYLENE', 'I', 9.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83984, 2280, 'OCTOCRYLENE', 'I', 9.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84003, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84004, 2280, 'OCTOCRYLENE', 'I', 8.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84006, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84032, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84033, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84034, 2280, 'OCTOCRYLENE', 'I', 2.80, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84035, 2280, 'OCTOCRYLENE', 'I', 2.50, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84036, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84041, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84039, 2280, 'OCTOCRYLENE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84042, 2280, 'OCTOCRYLENE', 'I', 2.56, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84061, 2280, 'OCTOCRYLENE', 'I', 1.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84076, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84092, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84118, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84119, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84207, 2280, 'OCTOCRYLENE', 'I', 2.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84257, 2280, 'OCTOCRYLENE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84262, 2280, 'OCTOCRYLENE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84291, 2280, 'OCTOCRYLENE', 'I', 2.75, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84292, 2280, 'OCTOCRYLENE', 'I', 10.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84403, 2280, 'OCTOCRYLENE', 'I', 2.75, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84415, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84423, 2280, 'OCTOCRYLENE', 'I', 2.75, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84424, 2280, 'OCTOCRYLENE', 'I', 2.75, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84431, 2280, 'OCTOCRYLENE', 'I', 2.75, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84472, 2280, 'OCTOCRYLENE', 'I', 2.75, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84640, 2280, 'OCTOCRYLENE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84706, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84707, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84715, 2280, 'OCTOCRYLENE', 'I', 7.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84959, 2280, 'OCTOCRYLENE', 'I', 5.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84962, 2280, 'OCTOCRYLENE', 'I', 5.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84975, 2280, 'OCTOCRYLENE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85096, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85097, 2280, 'OCTOCRYLENE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85098, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85099, 2280, 'OCTOCRYLENE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53419, 2280, 'OCTOCRYLENE', 'I', 2, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53422, 2280, 'OCTOCRYLENE', 'I', 3.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53423, 2280, 'OCTOCRYLENE', 'I', 3.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53424, 2280, 'OCTOCRYLENE', 'I', 4, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53425, 2280, 'OCTOCRYLENE', 'I', 4, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53426, 2280, 'OCTOCRYLENE', 'I', 9, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61380, 2280, 'OCTOCRYLENE', 'I', 7, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64737, 2280, 'OCTOCRYLENE', 'I', 7, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64740, 2280, 'OCTOCRYLENE', 'I', 7, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81034, 2280, 'OCTOCRYLENE', 'I', 5.0, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83672, 2280, 'OCTOCRYLENE', 'I', 2.7, '%', '', '50', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62467, 2280, 'OCTOCRYLENE', 'I', 10, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15897, 2282, 'DANAZOL', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DANAZOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15163, 2282, 'DANAZOL', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DANAZOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14747, 2282, 'DANAZOL', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: DANAZOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60895, 2289, 'DODECYL DIMETHYL BENZYL AMMONIUM CHLORIDE', 'I', 1.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13021, 2292, 'TIMOLOL MALEATE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: TIMOLOL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14928, 2292, 'TIMOLOL MALEATE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: TIMOLOL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14929, 2292, 'TIMOLOL MALEATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: TIMOLOL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14930, 2292, 'TIMOLOL MALEATE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: TIMOLOL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12879, 2292, 'TIMOLOL MALEATE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: TIMOLOL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12880, 2292, 'TIMOLOL MALEATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: TIMOLOL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8589, 2292, 'TIMOLOL MALEATE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: TIMOLOL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8590, 2292, 'TIMOLOL MALEATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: TIMOLOL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8591, 2292, 'TIMOLOL MALEATE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: TIMOLOL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17212, 2292, 'TIMOLOL MALEATE', 'I', 0.25, '%', '', '', 'N', '', 'Historic Freeform Text: TIMOLOL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17214, 2292, 'TIMOLOL MALEATE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: TIMOLOL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42943, 2298, 'DOXORUBICIN HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: DOXORUBICIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42944, 2298, 'DOXORUBICIN HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: DOXORUBICIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42945, 2298, 'DOXORUBICIN HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: DOXORUBICIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18674, 2298, 'DOXORUBICIN HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DOXORUBICIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48640, 2298, 'DOXORUBICIN HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61804, 2298, 'DOXORUBICIN HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69014, 2298, 'DOXORUBICIN HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17817, 2300, 'LORAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LORAZEPAM QTY UNIT: SLT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16118, 2300, 'LORAZEPAM', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LORAZEPAM QTY UNIT: SLT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16586, 2300, 'LORAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM Qty Unit: SLT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16587, 2300, 'LORAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16588, 2300, 'LORAZEPAM', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16589, 2300, 'LORAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11191, 2300, 'LORAZEPAM', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11192, 2300, 'LORAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11195, 2300, 'LORAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9423, 2300, 'LORAZEPAM', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9424, 2300, 'LORAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9349, 2300, 'LORAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6656, 2300, 'LORAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6657, 2300, 'LORAZEPAM', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6658, 2300, 'LORAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6295, 2300, 'LORAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6296, 2300, 'LORAZEPAM', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6297, 2300, 'LORAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7314, 2300, 'LORAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6135, 2300, 'LORAZEPAM', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6136, 2300, 'LORAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69897, 2300, 'LORAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69898, 2300, 'LORAZEPAM', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69899, 2300, 'LORAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78350, 2300, 'LORAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78351, 2300, 'LORAZEPAM', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78352, 2300, 'LORAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83628, 2300, 'LORAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83629, 2300, 'LORAZEPAM', 'I', 1.0, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83630, 2300, 'LORAZEPAM', 'I', 2.0, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67176, 2300, 'LORAZEPAM', 'I', 4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LORAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2193, 2311, 'ALUMINUM SODIUM SULFATE', 'I', 520, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALUMINUM SODIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2182, 2311, 'ALUMINUM SODIUM SULFATE', 'I', 520, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALUMINUM SODIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18210, 2252, 'FENOTEROL HYDROBROMIDE', 'I', 0.3125, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: FENOTEROL HYDROBROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16195, 2256, 'BROMOCRIPTINE MESYLATE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: BROMOCRIPTINE MESYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65081, 2264, 'DACARBAZINE', 'I', 600, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18485, 2274, 'MAPROTILINE HYDROCHLORIDE', 'I', 75, 'MG', '', '', 'N', '', 'Historic Freeform Text: MAPROTILINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18486, 2274, 'MAPROTILINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: MAPROTILINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18489, 2274, 'MAPROTILINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: MAPROTILINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2529, 2275, 'LOMUSTINE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOMUSTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2530, 2275, 'LOMUSTINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOMUSTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2531, 2275, 'LOMUSTINE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOMUSTINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66752, 2219, 'TRIS HYDROXYMETHYL NITROMETHANE', 'I', 19.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69733, 2219, 'TRIS HYDROXYMETHYL NITROMETHANE', 'I', 19.56, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8198, 228, 'EGG PHOSPHOLIPIDS', 'I', 0.9, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: EGG PHOSPHATIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8197, 228, 'EGG PHOSPHOLIPIDS', 'I', 1.2, '%', '', '', 'N', '', 'Historic Freeform Text: EGG PHOSPHATIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43172, 228, 'EGG PHOSPHOLIPIDS', 'I', 1.2, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: EGG PHOSPHOLIPIDS ((PURIFIED))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19284, 228, 'EGG PHOSPHOLIPIDS', 'I', 1.2, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: EGG PHOSPHATIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19285, 228, 'EGG PHOSPHOLIPIDS', 'I', 1.2, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: EGG PHOSPHATIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18484, 228, 'EGG PHOSPHOLIPIDS', 'I', 1.2, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: EGG PHOSPHATIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18647, 228, 'EGG PHOSPHOLIPIDS', 'I', 1.2, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: EGG PHOSPHATIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47094, 228, 'EGG PHOSPHOLIPIDS', 'I', 700, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: EGG PHOSPHATIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16103, 231, 'THEOPHYLLINE', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: THEOPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16482, 231, 'THEOPHYLLINE', 'I', 600, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: THEOPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14032, 231, 'THEOPHYLLINE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: THEOPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14033, 231, 'THEOPHYLLINE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: THEOPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14031, 231, 'THEOPHYLLINE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: THEOPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48617, 231, 'THEOPHYLLINE', 'I', 100, 'MG', '', '', 'N', '', 'THEOPHYLLINE, ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48618, 231, 'THEOPHYLLINE', 'I', 200, 'MG', '', '', 'N', '', 'THEOPHYLLINE, ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48619, 231, 'THEOPHYLLINE', 'I', 300, 'MG', '', '', 'N', '', 'THEOPHYLLINE, ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84507, 231, 'THEOPHYLLINE', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84508, 231, 'THEOPHYLLINE', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13450, 231, 'THEOPHYLLINE', 'I', 80, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: THEOPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6170, 231, 'THEOPHYLLINE', 'I', 80, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: THEOPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3455, 231, 'THEOPHYLLINE', 'I', 80, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: THEOPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5078, 231, 'THEOPHYLLINE', 'I', 80, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: THEOPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1980, 231, 'THEOPHYLLINE', 'I', 7, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THEOPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16879, 232, 'PERINDOPRIL ERBUMINE', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: PERINDOPRIL ERBUMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16880, 232, 'PERINDOPRIL ERBUMINE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: PERINDOPRIL ERBUMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70751, 232, 'PERINDOPRIL ERBUMINE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70752, 232, 'PERINDOPRIL ERBUMINE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70814, 232, 'PERINDOPRIL ERBUMINE', 'I', 8, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PERINDOPRIL ERBUMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77467, 232, 'PERINDOPRIL ERBUMINE', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80705, 232, 'PERINDOPRIL ERBUMINE', 'I', 8.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18931, 233, 'LEVOCARNITINE', 'I', 330, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LEVOCARNITINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19094, 233, 'LEVOCARNITINE', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LEVOCARNITINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18903, 233, 'LEVOCARNITINE', 'I', 200, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LEVOCARNITINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73019, 234, 'POLYETHYLENE GLYCOL 400', 'I', 1.0, '%', '', '', 'N', '', 'V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73342, 234, 'POLYETHYLENE GLYCOL 400', 'I', 0.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82979, 234, 'POLYETHYLENE GLYCOL 400', 'I', 1.0, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81391, 234, 'POLYETHYLENE GLYCOL 400', 'I', 1.0, '%', '', '', 'N', 'V/V', 'V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17201, 238, 'LAMOTRIGINE', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LAMOTRIGINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17203, 238, 'LAMOTRIGINE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LAMOTRIGINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17160, 238, 'LAMOTRIGINE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: LAMOTRIGINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63629, 238, 'LAMOTRIGINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67259, 238, 'LAMOTRIGINE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: LAMOTRIGINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67260, 238, 'LAMOTRIGINE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: LAMOTRIGINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69223, 238, 'LAMOTRIGINE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: LAMOTRIGINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69224, 238, 'LAMOTRIGINE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: LAMOTRIGINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69225, 238, 'LAMOTRIGINE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: LAMOTRIGINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67741, 238, 'LAMOTRIGINE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LAMOTRIGINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71124, 238, 'LAMOTRIGINE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: LAMOTRIGINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71125, 238, 'LAMOTRIGINE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: LAMOTRIGINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71126, 238, 'LAMOTRIGINE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: LAMOTRIGINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71190, 238, 'LAMOTRIGINE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75095, 238, 'LAMOTRIGINE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: LAMOTRIGINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75096, 238, 'LAMOTRIGINE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: LAMOTRIGINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75097, 238, 'LAMOTRIGINE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: LAMOTRIGINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72568, 238, 'LAMOTRIGINE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72569, 238, 'LAMOTRIGINE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72570, 238, 'LAMOTRIGINE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82850, 238, 'LAMOTRIGINE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82851, 238, 'LAMOTRIGINE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82852, 238, 'LAMOTRIGINE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78831, 238, 'LAMOTRIGINE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78826, 238, 'LAMOTRIGINE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78830, 238, 'LAMOTRIGINE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 246, 'FERROUS GLUCONATE', 'I', 2, 'G', '', '', 'N', '', 'Historic Freeform Text: FERROUS GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43923, 249, 'CLOPROSTENOL (CLOPROSTENOL SODIUM)', 'I', 175, 'µG', '', '2', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CLOPROSTENOL175MCG/2ML SUPPLIED  AS CLOPROSTENOL SODIUM 184 MCG/2ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43924, 249, 'CLOPROSTENOL (CLOPROSTENOL SODIUM)', 'I', 250, 'µG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78370, 249, 'CLOPROSTENOL (CLOPROSTENOL SODIUM)', 'I', 250, 'µG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19228, 188, 'CEFPROZIL', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CEFPROZIL ((ANHYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19229, 188, 'CEFPROZIL', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEFPROZIL ((ANHYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77837, 188, 'CEFPROZIL (CEFPROZIL MONOHYDRATE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77836, 188, 'CEFPROZIL (CEFPROZIL MONOHYDRATE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77887, 188, 'CEFPROZIL (CEFPROZIL MONOHYDRATE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77888, 188, 'CEFPROZIL (CEFPROZIL MONOHYDRATE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80966, 188, 'CEFPROZIL (CEFPROZIL MONOHYDRATE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78751, 188, 'CEFPROZIL', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78752, 188, 'CEFPROZIL', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80284, 188, 'CEFPROZIL (CEFPROZIL MONOHYDRATE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80285, 188, 'CEFPROZIL (CEFPROZIL MONOHYDRATE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19226, 188, 'CEFPROZIL', 'I', 250, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CEFPROZIL ((ANHYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19227, 188, 'CEFPROZIL', 'I', 125, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CEFPROZIL ((ANHYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77893, 188, 'CEFPROZIL (CEFPROZIL MONOHYDRATE)', 'I', 250, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77932, 188, 'CEFPROZIL', 'I', 125, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CEFPROZIL ((ANHYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77933, 188, 'CEFPROZIL', 'I', 250, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CEFPROZIL ((ANHYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78873, 188, 'CEFPROZIL (CEFPROZIL MONOHYDRATE)', 'I', 125, 'MG', '', '5', 'N', 'ML', 'AFTER RECONSTITUTION.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78874, 188, 'CEFPROZIL (CEFPROZIL MONOHYDRATE)', 'I', 250, 'MG', '', '5', 'N', 'ML', 'AFTER RECONSTITUTION.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81489, 188, 'CEFPROZIL (CEFPROZIL MONOHYDRATE)', 'I', 125, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49245, 190, 'ZUCLOPENTHIXOL DECANOATE', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ZUCLOPENTHIXOL DECAN. ((ZU.EQ.144.4MG/ML))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49244, 191, 'ZUCLOPENTHIXOL ACETATE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19306, 193, 'L-LYSINE (LYSINE ACETATE)', 'I', 1.575, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-LYSINE ((AS ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18644, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 1.05, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 1.05, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 193, 'L-LYSINE', 'I', 1.1, 'G', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 193, 'L-LYSINE (L-LYSINE HYDROCHLORIDE)', 'I', 145, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 446, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-LYSINE ACETATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 446, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 368, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 446, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-LYSINE ACETATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 193, 'L-LYSINE (LYSINE ACETATE)', 'I', 446, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-LYSINE ACETATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19143, 193, 'L-LYSINE (L-LYSINE HYDROCHLORIDE)', 'I', 290, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-LYSINE ((AS HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 368, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-LYSINE ACETATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 525, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 368, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 446, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-LYSINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 475, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 368, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18608, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 735, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18607, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 893, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 677, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11329, 193, 'L-LYSINE (L-LYSINE HYDROCHLORIDE)', 'I', 580, 'MG', '', '100', 'Y', 'ML', 'Historic Freeform Text: LYSINE HCL ((LYSINE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5890, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 624, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LYSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3468, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 720, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-LYSINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4560, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 510, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-LYSINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 193, 'L-LYSINE (L-LYSINE HYDROCHLORIDE)', 'I', 580, 'MG', '', '100', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: L-LYSINE HCL ((L-LYSINE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2776, 193, 'L-LYSINE (L-LYSINE ACETATE)', 'I', 360, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-LYSINE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46352, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44478, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (45490, 197, 'BENZALKONIUM CHLORIDE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41219, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41220, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41221, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41889, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37743, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37819, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.52, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37812, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34234, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.09, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34215, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.89, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34190, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34197, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33839, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.14, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30372, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (29437, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (29438, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (29436, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28516, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.68, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28306, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.4, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27723, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.14, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27724, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.34, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27725, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.68, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26014, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25675, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21969, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.34, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21701, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19411, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19421, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20265, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.36, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20266, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.14, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20267, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.92, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20268, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.96, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19346, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20223, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.2, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20091, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.34, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20068, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.72, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20341, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19504, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19488, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18892, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18514, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18016, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.06, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17969, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.15, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18815, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18799, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18782, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18770, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18771, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18733, 197, 'BENZALKONIUM CHLORIDE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18329, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.09, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18304, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18713, 197, 'BENZALKONIUM CHLORIDE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18714, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.34, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17768, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.69, '%', '', '', 'N', '', 'INCREASED FROM 1.54% TO 1.69% APPROVED BY DU/BGIVD');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19113, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18934, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.68, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18626, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18900, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17242, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17243, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17241, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15899, 197, 'BENZALKONIUM CHLORIDE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15873, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16773, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16774, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.07, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15830, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16719, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16720, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16238, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.125, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16183, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16184, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.09, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15690, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16053, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15557, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15507, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15508, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.43, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16875, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.68, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15973, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.64, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15972, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.72, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15954, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.2, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15947, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.54, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14705, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13705, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.115, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13683, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.07, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13687, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.54, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13656, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.115, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68184, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14632, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14617, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13553, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13394, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13373, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13352, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14412, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.14, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13891, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13341, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13868, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14321, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13249, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.76, '%', '', '', 'N', '', 'STRENGTH OF ACTIVE CHANGED FROM 6.14 TO 6.76% AS PER DISINFECTANT REVIEW AREA - SHANNON C. WRIGHT. P');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13233, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.38, '%', '', '', 'N', '', 'STRENGTH OF ACTIVE CHANGED FROM 3.07 TO 3.37% AS PER DISINFECTANT REVIEW AREA - SHANNON C. WRIGHT. P');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14255, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.34, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13788, 197, 'BENZALKONIUM CHLORIDE', 'I', 9.4, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13767, 197, 'BENZALKONIUM CHLORIDE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14211, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14213, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18480, 215, 'DEXRAZOXANE', 'I', 250, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14215, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11314, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11296, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10490, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10491, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10471, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10425, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10429, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12403, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.07, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12404, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.14, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12405, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.54, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12406, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.54, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12407, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.54, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12408, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11066, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12289, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.125, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12255, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.125, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12210, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.07, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11453, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12556, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11431, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11922, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.52, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10686, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9822, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.00, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8461, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8428, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8429, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8435, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9221, 197, 'BENZALKONIUM CHLORIDE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9223, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9224, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.08, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8354, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.28, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9621, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.80, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8606, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10010, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8044, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8045, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8046, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9323, 197, 'BENZALKONIUM CHLORIDE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8478, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7139, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5377, 197, 'BENZALKONIUM CHLORIDE', 'I', 20, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7079, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7071, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7041, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6535, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6523, 197, 'BENZALKONIUM CHLORIDE', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67608, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.680, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7632, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7022, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6469, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6466, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6464, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6465, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6450, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7457, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5699, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.35, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6268, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6263, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6203, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7322, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.29, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7320, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5578, 197, 'BENZALKONIUM CHLORIDE', 'I', 14.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5579, 197, 'BENZALKONIUM CHLORIDE', 'I', 9, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6666, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6667, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5544, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.89, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3836, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.3, '%', '', '', 'N', '', 'W/W. HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4938, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.44, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18481, 215, 'DEXRAZOXANE', 'I', 500, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3824, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3826, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3828, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4889, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3766, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.12, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3732, 197, 'BENZALKONIUM CHLORIDE', 'I', 7.5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4218, 197, 'BENZALKONIUM CHLORIDE', 'I', 14.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4200, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.35, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5289, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4199, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.75, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4190, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3619, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3594, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.85, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3592, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5240, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3470, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3471, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5132, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.9, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5120, 197, 'BENZALKONIUM CHLORIDE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4612, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5088, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3924, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4494, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3884, 197, 'BENZALKONIUM CHLORIDE', 'I', 7.4, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3307, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1984, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2589, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2545, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.75, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2486, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2487, 197, 'BENZALKONIUM CHLORIDE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2430, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3039, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.625, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3040, 197, 'BENZALKONIUM CHLORIDE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3026, 197, 'BENZALKONIUM CHLORIDE', 'I', 9, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3015, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.55, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2404, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.2, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2406, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2389, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2901, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.89, '%', '', '', 'N', '', 'W/W. HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2305, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2298, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2932, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.12, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2265, 197, 'BENZALKONIUM CHLORIDE', 'I', 3, '%', '', '', 'N', '', 'SODIUM EDETATE 0.05% TAKEN OUT AS A SECOND ACTIVE ON 12.03.2001 AS PER BPA AS THIS AI IS NO LONGER C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2868, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2196, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (869, 197, 'BENZALKONIUM CHLORIDE', 'I', 13, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2679, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48111, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49187, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (234, 197, 'BENZALKONIUM CHLORIDE', 'I', 11.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49430, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50059, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50061, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50153, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.01, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50154, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.01, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50646, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.84, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50866, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'ALSO CALLED:  N-ALKYL DIMETHYL BENZYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50870, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.520, '%', '', '', 'N', '', 'ALSO CALLED:  N-ALKYL DIMETHYL BENZYL AMMONIUM CHLORIDE ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51889, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51894, 197, 'BENZALKONIUM CHLORIDE', 'I', 9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53825, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53831, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61859, 197, 'BENZALKONIUM CHLORIDE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60432, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.68, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61178, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62048, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.44, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61358, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61429, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.54, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61475, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60867, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60956, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61030, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62389, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62391, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62416, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.20, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62417, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.520, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63262, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63207, 197, 'BENZALKONIUM CHLORIDE', 'I', 17.06, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64646, 197, 'BENZALKONIUM CHLORIDE', 'I', 7.675, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64703, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62709, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62730, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63709, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64299, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64461, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67114, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67119, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.54, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67128, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67134, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.54, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65206, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.28, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65736, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65738, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65191, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.340, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65192, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.340, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67182, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65270, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.106, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65845, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.170, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65846, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66379, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.170, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66387, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.125, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66562, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64770, 197, 'BENZALKONIUM CHLORIDE', 'I', 7.95, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64771, 197, 'BENZALKONIUM CHLORIDE', 'I', 7.95, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65998, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.86, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66666, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66672, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66752, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.29, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64939, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66126, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66174, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66931, 197, 'BENZALKONIUM CHLORIDE', 'I', 7.68, '%', '', '', 'N', '', 'QUATS IN THE  FORMULATION ARE SUPPLIED IN AN 80% STRENGTH.  THEREFORE 6.14%  REFLECTS THE ACTUAL CON');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65628, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.106, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66940, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.17, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65636, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65637, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65645, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66995, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.034, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65142, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.190, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67048, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.339, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68306, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68309, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.170, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68862, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69419, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68930, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68931, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68933, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.28, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67324, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67373, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67389, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.125, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67406, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67435, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67464, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69060, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67512, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.34, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69105, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.339, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67586, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67597, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68144, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.170, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67640, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67651, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.170, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67652, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.680, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67609, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67773, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68288, 197, 'BENZALKONIUM CHLORIDE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72119, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.33, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72148, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.0532, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72152, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.339, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72153, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.680, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72154, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.170, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69931, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.170, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69936, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69957, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.034, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69970, 197, 'BENZALKONIUM CHLORIDE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71395, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71396, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71397, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70000, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70044, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70059, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.186, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70067, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70765, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70767, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.04, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71522, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.27, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71523, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.27, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72292, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72294, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72295, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72301, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.190, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70135, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70137, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70143, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70144, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70804, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70805, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70836, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71528, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71597, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71598, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70165, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.115, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70197, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70199, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70268, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.2520, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70274, 197, 'BENZALKONIUM CHLORIDE', 'I', 11.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71698, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71713, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.173, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69659, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.12, '%', '', '', 'N', '', 'DIN ORIGINALLY HAD BENZALKONIUM CHLORIDE 6.4% BUT AS PER REVIEWER IT IS AN 80% SOLUTION EQUIVALENT T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70365, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69698, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69699, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69733, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.09, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69735, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.680, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70392, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.145, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70410, 197, 'BENZALKONIUM CHLORIDE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70433, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.11, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70442, 197, 'BENZALKONIUM CHLORIDE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70460, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70469, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.08, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70469, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.02, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70471, 197, 'BENZALKONIUM CHLORIDE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70475, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.01, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70493, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.33, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70506, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.034, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71209, 197, 'BENZALKONIUM CHLORIDE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69840, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.12, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70546, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.08, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70546, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.02, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71966, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71992, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.64, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71987, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69914, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70599, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70601, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70605, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71318, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.07, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76438, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.35, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76443, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.085, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76444, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.032, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76446, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.032, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76452, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76453, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72889, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73896, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.0, '%', '', '', 'N', '', 'WT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75171, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.024, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76457, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76458, 197, 'BENZALKONIUM CHLORIDE', 'I', 9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76459, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76460, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76479, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.0240, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76537, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72773, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72793, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.54, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72815, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72822, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72823, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72834, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.11, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72860, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75206, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.173, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75223, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.24, '%', '', '', 'N', '', 'DISCREPANCY BETWEEN 3011 AND LABEL WHICH HAS PURE ACTIVE MOLECULE, 3011 HAS COMMERCIAL 12.47%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75225, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.96, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75223, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.74, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75231, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75242, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75243, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75251, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.54, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76592, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76631, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76639, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.170, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76640, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.04, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76650, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72930, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72931, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72932, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72933, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.680, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74028, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74065, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74069, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75267, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75290, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.384, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74145, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75402, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76765, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76777, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.034, '%', '', '', 'N', '', 'W/W ALKYL: 40%C12, 50%C14, AND 10%C16');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73025, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.76, '%', '', '', 'N', '', 'INCREASED FROM 6.14% TO 6.76% AS APPROVED BY DU.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73035, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.680, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73036, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.339, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73037, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.170, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72340, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.170, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72341, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72342, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72344, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.33, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74298, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74316, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74317, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74326, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.92, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74338, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74344, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75554, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75555, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75587, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75633, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.04, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75693, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.085, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75693, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.085, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78179, 167, 'TACROLIMUS', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72427, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.14, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72428, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72443, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.5, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74517, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75729, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75784, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72572, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74558, 197, 'BENZALKONIUM CHLORIDE', 'I', 26.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75848, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.20, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72493, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72494, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72496, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72497, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72498, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.54, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72499, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.14, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75948, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75959, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.14, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72614, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72615, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.11, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73296, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.68, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73297, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73298, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.17, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73357, 197, 'BENZALKONIUM CHLORIDE', 'I', 20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73358, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.175, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74691, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74753, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.09, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76012, 197, 'BENZALKONIUM CHLORIDE', 'I', 9.2160, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76050, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.48, '%', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76078, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73373, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.12, '%', '', '', 'N', '', 'W/W ACTIVE CHANGED FROM 0.122% TO 0.12% APPROVED BY MGR NDED.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73374, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.12, '%', '', '', 'N', '', 'W/W ACTIVE CHANGED FROM 0.122% TO  0.12% APPROVED BY MGR NDED.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73375, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.12, '%', '', '', 'N', '', 'W/W ACTIVE CHANGED FROM 0.122% TO 0.12% APPROVED BY MGR NDED.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73376, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.12, '%', '', '', 'N', '', 'W/W ACTIVE CHANGED FROM 0.122% TO 0.12% APPROVED BY MGR NDED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73405, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.200, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74808, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75783, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76109, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73470, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.04, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73518, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73631, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73675, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.125, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73676, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74943, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74946, 197, 'BENZALKONIUM CHLORIDE', 'I', 20, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76264, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76314, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.11, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76315, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.11, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72696, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73707, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73723, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73722, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73726, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72742, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.28, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72770, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.680, '%', '', '', 'N', '', 'C14: 50%; C12: 40%; C16: 10%.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72771, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.680, '%', '', '', 'N', '', 'C14: 50%; C12: 40%; C16: 10%.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73838, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73858, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78114, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.339, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77369, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77370, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78415, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.339, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78416, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78430, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78487, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76834, 197, 'BENZALKONIUM CHLORIDE', 'I', 20, '%', '', '', 'N', '', 'W/W N-ALKYL (C14 60% C12 25% C16 15%) DIMETHYL BENZYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77307, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77126, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77080, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.0, '%', '', '', 'N', '', '40%C12, 50%C14, 10%C10');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76873, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77627, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77546, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77547, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78044, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.0532, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78127, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.680, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77801, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77802, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77810, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77811, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77814, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77829, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77844, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.2, '%', '', '', 'N', '', 'CONCENTRATE PART A. W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77845, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77869, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77870, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77871, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77382, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78183, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78184, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78230, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.034, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78233, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.170, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78236, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78238, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.339, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77175, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77005, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.632, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77006, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.035, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78260, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78279, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76811, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77300, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.38, '%', '', '', 'N', '', 'ACTIVE CHANGED FROM 4.4% TO 4.38% TO MATCH APPROVED LABEL. EW');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77591, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77649, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.37, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77874, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.339, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78326, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77412, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.339, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76819, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76820, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.69, '%', '', '', 'N', '', 'DURING CONTROL NO. 140615 ACTIVES WERE CHANGED FROM DIDECYL DIMETHYL AMMONIUM CHLORIDE 2.31% TO 2.54');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77965, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1375, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77966, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1375, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78017, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81582, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79843, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.2, '%', '', '', 'N', '', 'CONCENTRATE PART A. W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79846, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.170, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82831, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82279, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78511, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78729, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78730, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78933, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.34, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79260, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78569, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.3, '%', '', '', 'N', '', 'W/W.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82833, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79876, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78783, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80991, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.115, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81854, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80095, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.1000, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80737, 197, 'BENZALKONIUM CHLORIDE', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80738, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.64, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83037, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83038, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.170, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83039, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.085, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78563, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.85, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79842, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79844, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80719, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79106, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.085, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78918, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.37, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78919, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79881, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.34, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79882, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.034, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80171, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80496, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82556, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82554, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.248, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80303, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80305, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80458, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80754, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.64, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79837, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.12, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79967, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.20, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79860, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81121, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.025, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81651, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.680, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81653, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80642, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.680, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80646, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.170, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79562, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.170, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81844, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81845, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.59, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80495, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.145, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80972, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.63, '%', '', '', 'N', '', 'ACTIVE WAS CHANGED TO 5.63% FROM 5.625% FOR DIN 00388246');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80374, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80388, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82428, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79858, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.248, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81305, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81992, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81995, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81996, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.170, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81997, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.248, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80336, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80216, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.16, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82417, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80541, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80464, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80630, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82544, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79832, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80379, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82114, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.04, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82115, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82120, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83084, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83214, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.69, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83511, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83525, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.34, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83623, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83682, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83946, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.125, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83950, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.034, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83957, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83962, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84010, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84056, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.170, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84220, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62673, 122, 'LAMIVUDINE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84223, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84357, 197, 'BENZALKONIUM CHLORIDE', 'I', 8.680, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84358, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84366, 197, 'BENZALKONIUM CHLORIDE', 'I', 7.95, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84367, 197, 'BENZALKONIUM CHLORIDE', 'I', 3.000, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84373, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84404, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.26, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84439, 197, 'BENZALKONIUM CHLORIDE', 'I', 20.32, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84440, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84554, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84566, 197, 'BENZALKONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84735, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.032, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84768, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85170, 197, 'BENZALKONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85405, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.339, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13294, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.69, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE  2009.06.04. ACTIVE INGREDIENT STRENGTH REVISED FROM 1');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14193, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82604, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.76, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50653, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.20, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71907, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.12, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75580, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77007, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.20, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77008, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.034, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81274, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81277, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81564, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82781, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82414, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82413, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80749, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80990, 197, 'BENZALKONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80681, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80403, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80420, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.125, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80521, 197, 'BENZALKONIUM CHLORIDE', 'I', 7.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80521, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81286, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79941, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79995, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.05320, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79988, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79976, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79977, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.339, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80116, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80645, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.339, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79901, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80857, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79811, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.11, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81013, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81014, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80476, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', 'W/W', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81303, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81994, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.05320, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79566, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83051, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82416, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.145, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82418, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.20, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80036, 197, 'BENZALKONIUM CHLORIDE', 'I', 6.76, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80037, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.69, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80465, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82548, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80569, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83237, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83493, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83633, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83718, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83994, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84145, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84419, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.072, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84422, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.072, '%', '', '', 'N', 'W/W', 'THE 0.72% LISTED IN THE NOTE TO SIPD SECTION OF THE REVIWE AREA WAS WRONG.  THE STRENGTH IS 0.072% A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84441, 197, 'BENZALKONIUM CHLORIDE', 'I', 1.32, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84999, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.115, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85333, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.339, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85423, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.339, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85444, 197, 'BENZALKONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80304, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', 'W/V', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83956, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', 'W/V', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84128, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.133, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18082, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9483, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', '%', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5046, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.4, '%', '', '', 'N', '%', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5010, 197, 'BENZALKONIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '%', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2171, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '%', 'Historic Freeform Text: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61938, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62787, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44888, 197, 'BENZALKONIUM CHLORIDE', 'I', 4, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61680, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.347, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80735, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80764, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80442, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62461, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, 'MG', '', '100', 'N', 'MG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64460, 197, 'BENZALKONIUM CHLORIDE', 'I', 0.13, 'MG', '', '100', 'N', 'MG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13766, 197, 'BENZALKONIUM CHLORIDE', 'I', 1, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: BENZALKONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8529, 200, 'ALUMINUM AMMONIUM SULFATE', 'I', 50, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: ALUMINUM AMMONIUM SULFATE DODECAHYDRATE ACTIVE CHANGED FROM ALUMINUM AMMONIU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19802, 214, 'BACILLUS CALMETTE-GUERIN (BCG) STRAIN TICE', 'I', 800000000, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: BACILLUS CALMETTE-GUERIN (BCG) STRAIN TICE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44541, 150, 'ACETYLSALICYLIC ACID', 'I', 15.5, 'G', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47383, 150, 'ACETYLSALICYLIC ACID', 'I', 15.6, 'G', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67736, 150, 'ACETYLSALICYLIC ACID', 'I', 15.5, 'G', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78977, 150, 'ACETYLSALICYLIC ACID', 'I', 15.6, 'G', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42161, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36346, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36347, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23669, 150, 'ACETYLSALICYLIC ACID', 'I', 330, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23671, 150, 'ACETYLSALICYLIC ACID', 'I', 330, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23672, 150, 'ACETYLSALICYLIC ACID', 'I', 330, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23354, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23355, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22274, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19434, 150, 'ACETYLSALICYLIC ACID', 'I', 650, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19790, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID Qty Unit: ECT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19489, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID Qty Unit: ECT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19474, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19475, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19477, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18349, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18909, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13699, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14683, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID QTY UNIT: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12946, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12943, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12944, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14508, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14369, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14370, 150, 'ACETYLSALICYLIC ACID', 'I', 650, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14311, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14312, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11798, 150, 'ACETYLSALICYLIC ACID', 'I', 650, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11158, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11065, 150, 'ACETYLSALICYLIC ACID', 'I', 375, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76928, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11025, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10711, 150, 'ACETYLSALICYLIC ACID', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10712, 150, 'ACETYLSALICYLIC ACID', 'I', 650, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10200, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5371, 150, 'ACETYLSALICYLIC ACID', 'I', 375, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6479, 150, 'ACETYLSALICYLIC ACID', 'I', 330, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6480, 150, 'ACETYLSALICYLIC ACID', 'I', 330, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6419, 150, 'ACETYLSALICYLIC ACID', 'I', 330, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5779, 150, 'ACETYLSALICYLIC ACID', 'I', 330, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5777, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7362, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4896, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4897, 150, 'ACETYLSALICYLIC ACID', 'I', 650, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3158, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4272, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3369, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1233, 150, 'ACETYLSALICYLIC ACID', 'I', 330, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2410, 150, 'ACETYLSALICYLIC ACID', 'I', 650, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1171, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2966, 150, 'ACETYLSALICYLIC ACID', 'I', 975, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2918, 150, 'ACETYLSALICYLIC ACID', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1025, 150, 'ACETYLSALICYLIC ACID', 'I', 375, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2811, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID PREVIOUSLY ASA 324 MG (ADAMS LABS LTD.)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (876, 150, 'ACETYLSALICYLIC ACID', 'I', 375, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (872, 150, 'ACETYLSALICYLIC ACID', 'I', 330, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (873, 150, 'ACETYLSALICYLIC ACID', 'I', 330, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (468, 150, 'ACETYLSALICYLIC ACID', 'I', 650, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47953, 150, 'ACETYLSALICYLIC ACID', 'I', 330, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47954, 150, 'ACETYLSALICYLIC ACID', 'I', 330, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47955, 150, 'ACETYLSALICYLIC ACID', 'I', 330, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47956, 150, 'ACETYLSALICYLIC ACID', 'I', 330, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (157, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48421, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48434, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50227, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (55849, 150, 'ACETYLSALICYLIC ACID', 'I', 375, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61971, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62074, 150, 'ACETYLSALICYLIC ACID', 'I', 375, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62075, 150, 'ACETYLSALICYLIC ACID', 'I', 350, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62101, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61576, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60919, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60918, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61080, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63223, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65795, 150, 'ACETYLSALICYLIC ACID', 'I', 25, 'MG', '', '', 'Y', '', 'CAPSULE, IMMEDIATE RELEASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65982, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66118, 150, 'ACETYLSALICYLIC ACID', 'I', 330, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66818, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66913, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66968, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67838, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69406, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69500, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67917, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68992, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67738, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67739, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67740, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68301, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70004, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71561, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71600, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70240, 150, 'ACETYLSALICYLIC ACID', 'I', 375, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71800, 150, 'ACETYLSALICYLIC ACID', 'I', 162, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69836, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76584, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75453, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75794, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', 'TAB DELAYED-RELEASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75795, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', 'TAB DELAYED-RELEASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75796, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', 'TAB DELAYED-RELEASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73562, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73680, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73709, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73710, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75019, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75021, 150, 'ACETYLSALICYLIC ACID', 'I', 650, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73778, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73779, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78087, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77528, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76924, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76925, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76929, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78136, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77808, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77088, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77009, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77010, 150, 'ACETYLSALICYLIC ACID', 'I', 650, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76948, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78862, 150, 'ACETYLSALICYLIC ACID', 'I', 375, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80715, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80717, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79706, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79707, 150, 'ACETYLSALICYLIC ACID', 'I', 80, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80238, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80239, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79926, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', 'DELAYED RELEASE TABLET./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79927, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', 'DELAYED RELEASE TABLET./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79928, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', 'DELAYED RELEASE TABLET.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81810, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81813, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78992, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83769, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83770, 150, 'ACETYLSALICYLIC ACID', 'I', 650, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84814, 150, 'ACETYLSALICYLIC ACID', 'I', 81, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74000, 150, 'ACETYLSALICYLIC ACID', 'I', 31, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48139, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', 'GUM', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48140, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', 'GUM', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42652, 150, 'ACETYLSALICYLIC ACID', 'I', 325, 'MG', '', '', 'N', 'EVT', 'Historic Freeform Text: ACETYLSALICYLIC ACID Qty Unit: EVT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77472, 150, 'ACETYLSALICYLIC ACID', 'I', 500, 'MG', '', '', 'N', 'PCK', 'SINGLE DOSE POUCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9727, 150, 'ACETYLSALICYLIC ACID', 'I', 14.5, 'G', '', '20', 'N', 'G', 'Historic Freeform Text: ACETYLSALICYLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43513, 156, 'FAMCICLOVIR', 'I', 125, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FAMCICLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43514, 156, 'FAMCICLOVIR', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: FAMCICLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18768, 156, 'FAMCICLOVIR', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: FAMCICLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76420, 156, 'FAMCICLOVIR', 'I', 125, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FAMCICLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76421, 156, 'FAMCICLOVIR', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: FAMCICLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76422, 156, 'FAMCICLOVIR', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: FAMCICLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76367, 156, 'FAMCICLOVIR', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76368, 156, 'FAMCICLOVIR', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76369, 156, 'FAMCICLOVIR', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77741, 156, 'FAMCICLOVIR', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77742, 156, 'FAMCICLOVIR', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77739, 156, 'FAMCICLOVIR', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79124, 156, 'FAMCICLOVIR', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79125, 156, 'FAMCICLOVIR', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79126, 156, 'FAMCICLOVIR', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81030, 156, 'FAMCICLOVIR', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81031, 156, 'FAMCICLOVIR', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81032, 156, 'FAMCICLOVIR', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18989, 157, 'DOCETAXEL', 'I', 20, 'MG', '', '0.5', 'N', 'ML', 'Historic Freeform Text: DOCETAXEL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18990, 157, 'DOCETAXEL', 'I', 80, 'MG', '', '2', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DOCETAXEL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84699, 157, 'DOCETAXEL', 'I', 10.0, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44210, 167, 'TACROLIMUS', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TACROLIMUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44211, 167, 'TACROLIMUS', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TACROLIMUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67015, 167, 'TACROLIMUS', 'I', 0.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TACROLIMUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78180, 167, 'TACROLIMUS', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TACROLIMUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78181, 167, 'TACROLIMUS', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TACROLIMUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81736, 167, 'TACROLIMUS', 'I', 3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68109, 167, 'TACROLIMUS', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68110, 167, 'TACROLIMUS', 'I', 0.03, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44212, 167, 'TACROLIMUS', 'I', 5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: TACROLIMUS ((ANHYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19497, 169, 'SEVOFLURANE', 'I', 99.97, '%', '', '', 'N', '', 'Historic Freeform Text: SEVOFLURANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75141, 169, 'SEVOFLURANE', 'I', 99.97, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79344, 169, 'SEVOFLURANE', 'I', 99.97, '%', '', '', 'N', '', 'W/W ANHYDROUS BASIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42237, 171, 'POLYAMINOPROPYL BIGUANIDE', 'I', 0.0005, '%', '', '', 'N', '', 'Historic Freeform Text: BIGUANIDE POLYAMINOPROPYL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41994, 171, 'POLYAMINOPROPYL BIGUANIDE', 'I', 0.00005, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BIGUANIDE POLYAMINOPROPYL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49610, 171, 'POLYAMINOPROPYL BIGUANIDE', 'I', 0.0001, '%', '', '', 'N', '', 'QTY. 0.0001%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73892, 171, 'POLYAMINOPROPYL BIGUANIDE', 'I', 0.0005, '%', '', '', 'N', '', '0.0005% (=0.03MG/G)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80971, 171, 'POLYAMINOPROPYL BIGUANIDE', 'I', 0.0001, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80854, 171, 'POLYAMINOPROPYL BIGUANIDE', 'I', 0.0001, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19241, 172, 'INTERFERON BETA-1B', 'I', 0.3, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: INTERFERON BETA-1B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82345, 172, 'INTERFERON BETA-1B', 'I', 0.3, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: INTERFERON BETA-1B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18515, 180, 'LANSOPRAZOLE', 'I', 15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LANSOPRAZOLE QTY UNIT: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18516, 180, 'LANSOPRAZOLE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: LANSOPRAZOLE Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76617, 180, 'LANSOPRAZOLE', 'I', 15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LANSOPRAZOLE QTY UNIT: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76618, 180, 'LANSOPRAZOLE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73429, 180, 'LANSOPRAZOLE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73430, 180, 'LANSOPRAZOLE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77919, 180, 'LANSOPRAZOLE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77920, 180, 'LANSOPRAZOLE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83904, 180, 'LANSOPRAZOLE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83905, 180, 'LANSOPRAZOLE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84278, 180, 'LANSOPRAZOLE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84279, 180, 'LANSOPRAZOLE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85113, 180, 'LANSOPRAZOLE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61948, 180, 'LANSOPRAZOLE', 'I', 30, 'MG', '', '', 'N', 'CAP', 'UNIT = SRC.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47167, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37037, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36824, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85056, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34825, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31477, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27547, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27528, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24750, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19429, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19820, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19951, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17794, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17781, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16067, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13447, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13277, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13782, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14223, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11762, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12725, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12743, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10874, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10875, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5363, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3266, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3775, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4253, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5187, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (696, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2552, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1694, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47391, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49235, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49476, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48412, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48413, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48414, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62481, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62482, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61145, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61146, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62594, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60487, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62073, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60817, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63024, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64879, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64880, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65665, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69432, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69018, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68166, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72217, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76427, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73932, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73933, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74181, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73064, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74279, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74280, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75939, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73592, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73828, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77809, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78348, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79084, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78953, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78954, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78913, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81456, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79190, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80667, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80881, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79786, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79541, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83395, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84104, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84371, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41558, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14257, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65100, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71812, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76655, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76653, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 2.0, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80466, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70891, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 1, 'G', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37198, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34247, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34604, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 6.25, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31478, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19023, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15880, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 6.25, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15516, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15917, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10486, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11772, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11229, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11223, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11650, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5430, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6844, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4469, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50217, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64773, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 6.25, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66839, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67953, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69689, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71163, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 6.25, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71272, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 6.25, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76469, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 6.25, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76376, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 6.25, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76164, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78380, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIPHENHYDRAMINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80619, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 12.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79122, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 6.25, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80939, 182, 'DIPHENHYDRAMINE HYDROCHLORIDE', 'I', 6.25, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19525, 118, 'MYCOPHENOLATE MOFETIL', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: MYCOPHENOLATE MOFETIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60818, 118, 'MYCOPHENOLATE MOFETIL', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63885, 118, 'MYCOPHENOLATE MOFETIL (MYCOPHENOLATE MOFETIL HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65823, 118, 'MYCOPHENOLATE MOFETIL', 'I', 200, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19421, 119, 'N-TETRADECYL-N,N-DIMETHYL-N-ETHYLBENZYL NH4CL', 'I', 1.625, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: N-TETRADECYL-N,N-DIMETHYL-N-ETHYLBENZYL NH4CL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19421, 120, 'N-DODECYL-N,N-DIMETHYL-N-ETHYL BENZYL NH4CL', 'I', 3.375, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: N-DODECYL-N,N-DIMETHYL-N-ETHYL BENZYL NH4CL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35667, 121, 'LARD', 'I', 15.46, '%', '', '', 'N', '%', 'Historic Freeform Text: LARD');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19614, 122, 'LAMIVUDINE', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62649, 122, 'LAMIVUDINE', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68746, 122, 'LAMIVUDINE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72120, 122, 'LAMIVUDINE', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75473, 122, 'LAMIVUDINE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19615, 122, 'LAMIVUDINE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LAMIVUDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62650, 122, 'LAMIVUDINE', 'I', 5, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50574, 127, 'INACTIVATED POLIOMYELITIS VACCINE (D.C.O.) TYPE 3 SAUKETT', 'I', 32, 'UNIT', '', '0.5', 'N', 'ML', 'UNIT IS DU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50651, 127, 'INACTIVATED POLIOMYELITIS VACCINE (D.C.O.) TYPE 3 SAUKETT', 'I', 32, 'UNIT', '', '0.5', 'N', 'ML', 'UNIT = DU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50224, 127, 'INACTIVATED POLIOMYELITIS VACCINE (D.C.O.) TYPE 3 SAUKETT', 'I', 32, 'UNIT', '', '0.5', 'N', 'ML', 'UNIT = DU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67042, 127, 'INACTIVATED POLIOMYELITIS VACCINE (D.C.O.) TYPE 3 SAUKETT', 'I', 32, 'UNIT', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5907, 127, 'INACTIVATED POLIOMYELITIS VACCINE (D.C.O.) TYPE 3 SAUKETT', 'I', 32, 'UNIT', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50574, 128, 'INACTIVATED POLIOMYELITIS VACCINE (D.C.O.) TYPE 2 M.E.F.1', 'I', 8, 'UNIT', '', '0.5', 'N', 'ML', 'UNIT IS DU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50651, 128, 'INACTIVATED POLIOMYELITIS VACCINE (D.C.O.) TYPE 2 M.E.F.1', 'I', 8, 'UNIT', '', '0.5', 'N', 'ML', 'UNIT = DU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50224, 128, 'INACTIVATED POLIOMYELITIS VACCINE (D.C.O.) TYPE 2 M.E.F.1', 'I', 8, 'UNIT', '', '0.5', 'N', 'ML', 'UNIT = DU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67042, 128, 'INACTIVATED POLIOMYELITIS VACCINE (D.C.O.) TYPE 2 M.E.F.1', 'I', 8, 'UNIT', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5907, 128, 'INACTIVATED POLIOMYELITIS VACCINE (D.C.O.) TYPE 2 M.E.F.1', 'I', 8, 'UNIT', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83726, 128, 'INACTIVATED POLIOMYELITIS VACCINE (D.C.O.) TYPE 2 M.E.F.1', 'I', 8, 'UNIT', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50574, 129, 'INACTIVATED POLIOMYELITIS VACCINE (D.C.O.) TYPE 1 MAHONEY', 'I', 40, 'UNIT', '', '0.5', 'N', 'ML', 'UNIT IS DU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50651, 129, 'INACTIVATED POLIOMYELITIS VACCINE (D.C.O.) TYPE 1 MAHONEY', 'I', 40, 'UNIT', '', '0.5', 'N', 'ML', 'UNIT - DU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50224, 129, 'INACTIVATED POLIOMYELITIS VACCINE (D.C.O.) TYPE 1 MAHONEY', 'I', 40, 'UNIT', '', '0.5', 'N', 'ML', 'UNIT - DU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67042, 129, 'INACTIVATED POLIOMYELITIS VACCINE (D.C.O.) TYPE 1 MAHONEY', 'I', 40, 'UNIT', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5907, 129, 'INACTIVATED POLIOMYELITIS VACCINE (D.C.O.) TYPE 1 MAHONEY', 'I', 40, 'UNIT', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20020, 130, 'PHOSPHATE-BUFFERED SALINE (DILUENT)', 'I', 3, 'ML', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: PHOSPHATE-BUFFERED SALINE (DILUENT)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62300, 9653, 'KAOLIN', 'I', 167, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83012, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19553, 135, 'GANCICLOVIR (GANCICLOVIR SODIUM)', 'I', 500, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: GANCICLOVIR ((AS GANCICLOVIR SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44255, 144, 'LOSARTAN POTASSIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOSARTAN POTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19167, 144, 'LOSARTAN POTASSIUM', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOSARTAN POTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19168, 144, 'LOSARTAN POTASSIUM', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LOSARTAN POTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48580, 144, 'LOSARTAN POTASSIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64599, 144, 'LOSARTAN POTASSIUM', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78318, 144, 'LOSARTAN POTASSIUM', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37311, 5279, 'COPPER NAPHTHENATE', 'I', 37.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: COPPER NAPHTHENATE COPPER NAPHTHENATE 40% SOLUTION IN MINERAL SPRIT: 937.6 M');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82612, 5279, 'COPPER NAPHTHENATE', 'I', 37.5, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: COPPER NAPHTHENATE COPPER NAPHTHENATE 40% SOLUTION IN MINERAL SPRIT: 937.6 M');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12920, 5279, 'COPPER NAPHTHENATE', 'I', 37.5, '%', '', '', 'N', '%', 'Historic Freeform Text: COPPER NAPHTHENATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9363, 5279, 'COPPER NAPHTHENATE', 'I', 37.5, '%', '', '', 'N', '%', 'Historic Freeform Text: COPPER NAPHTHENATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5922, 5279, 'COPPER NAPHTHENATE', 'I', 37.5, '%', '', '', 'N', '%', 'Historic Freeform Text: COPPER NAPHTHENATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5165, 5279, 'COPPER NAPHTHENATE', 'I', 37.5, '%', '', '', 'N', '%', 'Historic Freeform Text: COPPER NAPHTHENATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6457, 5279, 'COPPER NAPHTHENATE', 'I', 37.5, 'G', '', '100', 'N', 'G', '37.5%W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 4785, 'CALCIUM PHOSPHATE (DIBASIC)', 'I', 2, 'G', '', '', 'N', '', 'Historic Freeform Text: CALCIUM PHOSPHATE (DIBASIC)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7144, 4785, 'CALCIUM PHOSPHATE (DIBASIC)', 'I', 6000, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4986, 4785, 'CALCIUM PHOSPHATE (DIBASIC)', 'I', 12, '%', '', '', 'N', '', 'Historic Freeform Text: CALCIUM PHOSPHATE (DIBASIC)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 4785, 'CALCIUM PHOSPHATE (DIBASIC)', 'I', 90, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: CALCIUM PHOSPHATE (DIBASIC)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18635, 4785, 'CALCIUM PHOSPHATE (DIBASIC)', 'I', 6, 'G', '', '19', 'N', 'G', 'Historic Freeform Text: CALCIUM PHOSPHATE (DIBASIC)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66864, 4785, 'CALCIUM PHOSPHATE (DIBASIC)', 'I', 177.5, 'G', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66865, 4785, 'CALCIUM PHOSPHATE (DIBASIC)', 'I', 177.5, 'G', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35469, 4785, 'CALCIUM PHOSPHATE (DIBASIC)', 'I', 974, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: CALCIUM PHOSPHATE (DIBASIC)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6566, 4785, 'CALCIUM PHOSPHATE (DIBASIC)', 'I', 11, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: CALCIUM PHOSPHATE (DIBASIC)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2119, 4785, 'CALCIUM PHOSPHATE (DIBASIC)', 'I', 300, 'MG', '', '30', 'N', 'G', 'Historic Freeform Text: CALCIUM PHOSPHATE (DIBASIC)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66452, 4334, 'BERMUDA GRASS', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '(CYNODON DACTYLON). 10000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 3842, 'P-TERT-BUTYLPHENOL FORMALDEHYDE RESIN', 'I', 0.041, 'MG', '', '', 'N', 'PATCH', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31093, 3566, 'PETROLATUM', 'I', 85, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PETROLATUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28169, 3566, 'PETROLATUM', 'I', 94, '%', '', '', 'N', '', 'Historic Freeform Text: PETROLATUM ((WHITE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17759, 3566, 'PETROLATUM', 'I', 55, '%', '', '', 'N', '', 'Historic Freeform Text: PETROLATUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18099, 3566, 'PETROLATUM', 'I', 55, '%', '', '', 'N', '', 'Historic Freeform Text: PETROLATUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16777, 3566, 'PETROLATUM', 'I', 80, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PETROLATUM ((WHITE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13538, 3566, 'PETROLATUM', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: PETROLATUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11430, 3566, 'PETROLATUM', 'I', 6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11936, 3566, 'PETROLATUM', 'I', 30, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10314, 3566, 'PETROLATUM', 'I', 100, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PETROLATUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7127, 3566, 'PETROLATUM', 'I', 67, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PETROLATUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2259, 3566, 'PETROLATUM', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: PETROLATUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60869, 3566, 'PETROLATUM', 'I', 50, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63342, 3566, 'PETROLATUM', 'I', 43, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76643, 3566, 'PETROLATUM', 'I', 45.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76644, 3566, 'PETROLATUM', 'I', 45.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72397, 3566, 'PETROLATUM', 'I', 55, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76990, 3566, 'PETROLATUM', 'I', 9.88, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59943, 3566, 'PETROLATUM', 'I', 53.4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81094, 3566, 'PETROLATUM', 'I', 98.79, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72398, 3566, 'PETROLATUM', 'I', 49.5, '%', '', '', 'N', 'W/W', '2010.07.30. ADDITION OF PETROLATUM AS PER SUBMISSION 139515 APPROVED BY TAIWO WOMILOJU./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84162, 3566, 'PETROLATUM', 'I', 60.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41756, 3566, 'PETROLATUM', 'I', 100, '%', '', '', 'N', '%', 'Historic Freeform Text: PETROLATUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37581, 3566, 'PETROLATUM', 'I', 22, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: PETROLATUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11785, 3566, 'PETROLATUM', 'I', 21.4, '%', '', '', 'N', '%', 'Historic Freeform Text: PETROLATUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9587, 3566, 'PETROLATUM', 'I', 100, '%', '', '', 'N', '%', 'Historic Freeform Text: PETROLATUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2163, 3566, 'PETROLATUM', 'I', 100, '%', '', '', 'N', '%', 'Historic Freeform Text: PETROLATUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64111, 3566, 'PETROLATUM', 'I', 10.00, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63854, 3566, 'PETROLATUM', 'I', 100, '%', '', '', 'N', '%', 'Historic Freeform Text: PETROLATUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63100, 3566, 'PETROLATUM', 'I', 95.96, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75291, 3566, 'PETROLATUM', 'I', 30.75, 'MG', '', '400', 'N', 'MG', '400MG PIECE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62542, 3566, 'PETROLATUM', 'I', 1000, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3630, 3566, 'PETROLATUM', 'I', 15.17, 'G', '', '70.87', 'N', 'G', 'Historic Freeform Text: PETROLATUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6502, 3566, 'PETROLATUM', 'I', 214, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PETROLATUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49921, 3566, 'PETROLATUM', 'I', 214, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80280, 3566, 'PETROLATUM', 'I', 214.02, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15242, 3438, 'ALCOHOL DENATURED', 'I', 71, '%', '', '', 'N', '', 'Historic Freeform Text: ALCOHOL DENATURED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61020, 3438, 'ALCOHOL DENATURED', 'I', 71.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81365, 3438, 'ALCOHOL DENATURED', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63492, 3438, 'ALCOHOL DENATURED', 'I', 10, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79691, 3438, 'ALCOHOL DENATURED', 'I', 10.00, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74692, 13372, 'FOSAMPRENAVIR (FOSAMPRENAVIR CALCIUM)', 'I', 700, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74693, 13372, 'FOSAMPRENAVIR (FOSAMPRENAVIR CALCIUM)', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75422, 13375, 'DROSPIRENONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74710, 13375, 'DROSPIRENONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74711, 13375, 'DROSPIRENONE', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80656, 13375, 'DROSPIRENONE', 'I', 3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 13384, 'METHYLPARABEN', 'I', 0.16, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS PARABEN MIX 0.80MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 9393, 'ETHYL PARABEN', 'I', 0.16, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS PARABEN MIX 0.80MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18636, 9653, 'KAOLIN', 'I', 302, 'MG', '', '', 'N', '', 'Historic Freeform Text: KAOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4088, 9653, 'KAOLIN', 'I', 972, 'MG', '', '', 'N', '', 'Historic Freeform Text: KAOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2005, 9653, 'KAOLIN', 'I', 975, 'MG', '', '', 'N', '', 'Historic Freeform Text: KAOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2587, 9653, 'KAOLIN', 'I', 195, 'MG', '', '', 'N', '', 'Historic Freeform Text: KAOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1612, 9653, 'KAOLIN', 'I', 975, 'MG', '', '', 'N', '', 'Historic Freeform Text: KAOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (753, 9653, 'KAOLIN', 'I', 390, 'MG', '', '', 'N', '', 'Historic Freeform Text: KAOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49958, 9653, 'KAOLIN', 'I', 16, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76196, 9653, 'KAOLIN', 'I', 16, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1993, 9653, 'KAOLIN', 'I', 175, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: KAOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1766, 9653, 'KAOLIN', 'I', 175, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: KAOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78861, 9653, 'KAOLIN', 'I', 196.1, 'MG', '', '', 'N', 'ML', '17.45% W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18637, 9653, 'KAOLIN', 'I', 12.37, 'G', '', '28.35', 'N', 'G', 'Historic Freeform Text: KAOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48860, 9653, 'KAOLIN', 'I', 474.9, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (231, 9653, 'KAOLIN', 'I', 146.25, 'MG', '', '2.9', 'N', 'G', 'Historic Freeform Text: KAOLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48974, 9653, 'KAOLIN', 'I', 481.3, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2479, 8750, 'MAGNESIUM SULFATE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: MAGNESIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2191, 8750, 'MAGNESIUM SULFATE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: MAGNESIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64083, 8750, 'MAGNESIUM SULFATE', 'I', 54, '%', '', '', 'N', 'W/W', 'MAGNESIUM SULFATE HEPTAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3567, 8750, 'MAGNESIUM SULFATE', 'I', 83.96, '%', '', '', 'N', '%', 'Historic Freeform Text: MAGNESIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36412, 8750, 'MAGNESIUM SULFATE', 'I', 20, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MAGNESIUM SULFATE ((HEPTAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 8750, 'MAGNESIUM SULFATE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19701, 8750, 'MAGNESIUM SULFATE', 'I', 500, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MAGNESIUM SULFATE ((HEPTAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10939, 8750, 'MAGNESIUM SULFATE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 8750, 'MAGNESIUM SULFATE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5614, 8750, 'MAGNESIUM SULFATE', 'I', 500, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 8750, 'MAGNESIUM SULFATE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'MAGNESIUM SULFATE TRIHYDRATE(AS MAGNESIUM SULFATE HEPTAHYDRATE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3922, 8750, 'MAGNESIUM SULFATE', 'I', 500, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MAGNESIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 8750, 'MAGNESIUM SULFATE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 8750, 'MAGNESIUM SULFATE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3088, 8750, 'MAGNESIUM SULFATE', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2334, 8750, 'MAGNESIUM SULFATE', 'I', 500, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MAGNESIUM SULFATE HEPTAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 8750, 'MAGNESIUM SULFATE', 'I', 1.08, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: MAGNESIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10527, 8750, 'MAGNESIUM SULFATE', 'I', 1.5, 'G', '', '75', 'N', 'G', 'Historic Freeform Text: MAGNESIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8523, 8750, 'MAGNESIUM SULFATE', 'I', 16.52, 'G', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66865, 8750, 'MAGNESIUM SULFATE', 'I', 20, 'G', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14165, 8750, 'MAGNESIUM SULFATE', 'I', 200, 'MG', '', '450', 'N', 'G', 'Historic Freeform Text: MAGNESIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8101, 8750, 'MAGNESIUM SULFATE', 'I', 175, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: MAGNESIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3926, 8750, 'MAGNESIUM SULFATE', 'I', 200, 'MG', '', '450', 'N', 'G', 'Historic Freeform Text: MAGNESIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9, 14593, 'THIAMAZOLE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METHIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74416, 14593, 'THIAMAZOLE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78139, 14593, 'THIAMAZOLE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81832, 14593, 'THIAMAZOLE', 'I', 2.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METHIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81833, 14593, 'THIAMAZOLE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METHIMAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3629, 2221, 'DISODIUM DODECYL DIPHENYLOXIDE DISULFONATE', 'I', 1.342, '%', '', '', 'N', '', 'Historic Freeform Text: DISODIUM DODECYL DIPHENYLOXIDE DISULFONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37819, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.456, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28516, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.604, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27724, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.3, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27725, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.6, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26014, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.05, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21969, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.302, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20223, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.66, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20091, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.302, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20068, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.216, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18016, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.1475, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18733, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18713, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18714, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.302, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18934, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.604, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16875, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.604, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15973, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.24, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15972, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.27, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15954, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.3, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14255, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.302, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13211, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11922, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.456, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9822, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.125, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8461, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.875, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8435, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.875, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9621, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.05, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9323, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.125, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7079, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.84, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6784, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.0, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50870, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.456, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61859, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60432, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.604, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61178, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.66, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60895, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 8.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60956, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.90, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62416, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.66, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62417, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.456, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64299, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65191, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.302, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65192, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.302, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65845, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66379, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66174, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.66, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66940, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66995, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.01, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67048, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68309, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67512, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69105, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68144, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67651, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67652, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67608, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67773, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.84, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68288, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72148, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.01995, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72152, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72153, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72154, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69931, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69957, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.01, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70000, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.90, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70767, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.015, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71522, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.06, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71523, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.06, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70268, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.0945, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71698, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.66, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71713, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.815, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70365, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.66, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69735, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70471, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.90, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70506, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.010, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71209, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76443, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.407, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73896, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.90, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75206, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.815, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75242, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76631, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76639, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76640, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.012, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76650, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.66, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72933, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76765, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.66, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76777, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.010, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73035, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73036, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73037, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72340, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75586, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.026, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75633, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.012, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73296, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.604, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73298, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76012, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.7648, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76078, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.66, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73405, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.825, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73470, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.015, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74943, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.06, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72770, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.604, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72771, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.604, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73858, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.37, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78114, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78400, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.96, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78415, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76873, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.90, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78044, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.01995, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78127, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78230, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.013, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78233, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78236, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78238, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77005, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.690, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77006, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.01, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77874, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77412, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78017, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.125, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79846, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78933, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.302, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79260, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.90, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78783, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.660, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80095, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.5375, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80737, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80738, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.19, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83038, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83039, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.407, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79106, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.407, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79881, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.302, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79882, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.013, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80754, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.19, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81651, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80642, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80646, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79562, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80976, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80388, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81996, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80216, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.06, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80532, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82114, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.012, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83379, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83525, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.63, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83950, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.013, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84056, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84357, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84367, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.125, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84439, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 7.62, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84650, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85405, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77007, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.660, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: DIOCTYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77008, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.010, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80866, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.01125, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79995, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.01995, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79977, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80645, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81994, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.01995, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85333, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85423, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.628, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61680, 2232, 'DIOCTYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.156, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37819, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.14, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28516, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.51, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27724, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27725, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.51, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26014, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.1, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21969, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20223, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.65, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20091, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20068, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.54, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18016, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.295, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18733, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18713, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18714, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18934, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.51, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16875, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.51, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15973, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.48, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15972, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.54, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15954, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 4.6, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14255, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13211, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.8, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11922, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.14, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9822, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8461, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.75, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8435, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.75, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9621, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9323, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7079, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6784, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50870, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.140, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61859, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60432, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.51, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61178, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.65, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60956, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62416, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.65, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62417, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.140, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64299, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 4.9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65191, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65192, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65845, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66379, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66174, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.65, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66940, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66995, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.025, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67048, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68309, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67512, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.254, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69105, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68144, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67651, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67652, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.510, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67608, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.510, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67773, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 4.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68288, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72148, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.0399, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72152, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72153, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.510, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72154, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69931, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69957, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.025, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70000, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70767, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.03, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71522, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.64, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71523, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.64, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70268, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.1890, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71698, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.65, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71713, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.63, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70365, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.65, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69735, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.510, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70471, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70506, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.025, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71209, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76443, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73896, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75206, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.63, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75242, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.75, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76631, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76639, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76640, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.03, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76650, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.65, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72933, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.510, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76765, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.65, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76777, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.025, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73035, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.510, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73036, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73037, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72340, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75586, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.054, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75633, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.03, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73296, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.51, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73298, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76012, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.9120, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76078, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.65, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73405, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.650, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73470, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.03, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74943, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72770, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.510, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72771, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.510, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73858, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.93, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78114, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78400, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.40, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78415, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76873, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50229, 2192, 'CLONAZEPAM', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78044, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.0399, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78127, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.510, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78230, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.026, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78233, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78236, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.75, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78238, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77005, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 4.224, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77006, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.005, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77874, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77412, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78017, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79846, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78933, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79260, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78783, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.650, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80095, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.0750, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80737, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80738, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.48, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83038, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83039, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79106, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.814, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79881, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79882, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.026, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80754, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.48, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81651, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.510, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80642, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.510, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80646, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79562, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80976, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80388, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81996, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80216, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.12, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80532, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82114, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.03, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83379, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83525, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83950, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.026, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84056, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.627, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84357, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 6.510, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84367, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.250, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84439, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 15.24, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84650, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 2.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85405, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77007, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 1.650, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77008, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.025, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80866, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.0225, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79995, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.03990, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79977, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80645, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81994, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.03990, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85333, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85423, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 3.255, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61680, 2218, 'OCTYL DECYL DIMETHYL AMMONIUM CHLORIDE', 'I', 0.260, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34574, 2184, 'RIBAVIRIN', 'I', 6, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: RIBAVIRIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73839, 2184, 'RIBAVIRIN', 'I', 200, 'MG', '', '', 'N', 'TAB', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73840, 2184, 'RIBAVIRIN', 'I', 200, 'MG', '', '', 'N', 'TAB', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70155, 2184, 'RIBAVIRIN', 'I', 200, 'MG', '', '', 'N', 'CAP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70156, 2184, 'RIBAVIRIN', 'I', 200, 'MG', '', '', 'N', 'CAP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70157, 2184, 'RIBAVIRIN', 'I', 200, 'MG', '', '', 'N', 'CAP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70158, 2184, 'RIBAVIRIN', 'I', 200, 'MG', '', '', 'N', 'CAP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70159, 2184, 'RIBAVIRIN', 'I', 200, 'MG', '', '', 'N', 'CAP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73948, 2184, 'RIBAVIRIN', 'I', 200, 'MG', '', '', 'N', 'CAP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73950, 2184, 'RIBAVIRIN', 'I', 200, 'MG', '', '', 'N', 'CAP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73951, 2184, 'RIBAVIRIN', 'I', 200, 'MG', '', '', 'N', 'CAP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73952, 2184, 'RIBAVIRIN', 'I', 200, 'MG', '', '', 'N', 'CAP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85660, 2184, 'RIBAVIRIN', 'I', 200, 'MG', '', '', 'N', 'CAP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85661, 2184, 'RIBAVIRIN', 'I', 200, 'MG', '', '', 'N', 'CAP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85662, 2184, 'RIBAVIRIN', 'I', 200, 'MG', '', '', 'N', 'CAP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85663, 2184, 'RIBAVIRIN', 'I', 200, 'MG', '', '', 'N', 'CAP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43383, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43969, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43970, 2192, 'CLONAZEPAM', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43971, 2192, 'CLONAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43888, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19628, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18849, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18850, 2192, 'CLONAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18366, 2192, 'CLONAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19221, 2192, 'CLONAZEPAM', 'I', 0.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19063, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19048, 2192, 'CLONAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17142, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17145, 2192, 'CLONAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14587, 2192, 'CLONAZEPAM', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14588, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14589, 2192, 'CLONAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2568, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2569, 2192, 'CLONAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49164, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49167, 2192, 'CLONAZEPAM', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49166, 2192, 'CLONAZEPAM', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50228, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53892, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (54229, 2192, 'CLONAZEPAM', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (54230, 2192, 'CLONAZEPAM', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60241, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62476, 2192, 'CLONAZEPAM', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62475, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65752, 2192, 'CLONAZEPAM', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65751, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75602, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75603, 2192, 'CLONAZEPAM', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75604, 2192, 'CLONAZEPAM', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79715, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79716, 2192, 'CLONAZEPAM', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79718, 2192, 'CLONAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83010, 2192, 'CLONAZEPAM', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83011, 2192, 'CLONAZEPAM', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78865, 2192, 'CLONAZEPAM', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78866, 2192, 'CLONAZEPAM', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLONAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83110, 2192, 'CLONAZEPAM', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12451, 2193, 'PRAZOSIN HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: PRAZOSIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12452, 2193, 'PRAZOSIN HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: PRAZOSIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12453, 2193, 'PRAZOSIN HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PRAZOSIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12694, 2193, 'PRAZOSIN HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: PRAZOSIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12695, 2193, 'PRAZOSIN HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: PRAZOSIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12696, 2193, 'PRAZOSIN HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PRAZOSIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49399, 2195, 'MITOMYCIN', 'I', 5, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49400, 2195, 'MITOMYCIN', 'I', 20, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49991, 2195, 'MITOMYCIN', 'I', 20, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61099, 2195, 'MITOMYCIN', 'I', 5, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37362, 2198, 'PROTIRELIN', 'I', 200, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: PROTIRELIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14489, 2199, 'CETRIMIDE', 'I', 0.15, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CETRIMIDE.W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78162, 2199, 'CETRIMIDE', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16100, 2199, 'CETRIMIDE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: CETRIMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37164, 2199, 'CETRIMIDE', 'I', 150, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: CETRIMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18687, 2203, 'PERACETIC ACID', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: PERACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13689, 2203, 'PERACETIC ACID', 'I', 0.06, '%', '', '', 'N', '', 'Historic Freeform Text: PERACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12252, 2203, 'PERACETIC ACID', 'I', 35, '%', '', '', 'N', '', 'Historic Freeform Text: PERACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48981, 2203, 'PERACETIC ACID', 'I', 0.08, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63904, 2203, 'PERACETIC ACID', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78600, 2203, 'PERACETIC ACID', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70105, 2203, 'PERACETIC ACID', 'I', 5.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76311, 2203, 'PERACETIC ACID', 'I', 4.50, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80386, 2203, 'PERACETIC ACID', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82224, 2203, 'PERACETIC ACID', 'I', 0.23, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80714, 2203, 'PERACETIC ACID', 'I', 0.08, '%', '', '', 'N', '', 'Historic Freeform Text: PERACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83744, 2203, 'PERACETIC ACID', 'I', 0.06, '%', '', '', 'N', '', 'Historic Freeform Text: PERACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81863, 2203, 'PERACETIC ACID', 'I', 5.1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80441, 2203, 'PERACETIC ACID', 'I', 0.050, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83975, 2203, 'PERACETIC ACID', 'I', 5.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84438, 2203, 'PERACETIC ACID', 'I', 6.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63214, 2208, 'ORTHO-PHTHALALDEHYDE', 'I', 0.55, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76392, 2208, 'ORTHO-PHTHALALDEHYDE', 'I', 5.75, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16678, 2150, 'COLLAGENASE', 'I', 250, 'UNIT', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: COLLAGENASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19436, 2155, 'DESMOPRESSIN ACETATE', 'I', 0.1, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESMOPRESSIN ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19441, 2155, 'DESMOPRESSIN ACETATE', 'I', 0.2, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESMOPRESSIN ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70677, 2155, 'DESMOPRESSIN ACETATE', 'I', 0.1, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESMOPRESSIN ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74293, 2155, 'DESMOPRESSIN ACETATE', 'I', 0.1, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESMOPRESSIN ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74294, 2155, 'DESMOPRESSIN ACETATE', 'I', 0.2, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESMOPRESSIN ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77313, 2155, 'DESMOPRESSIN ACETATE', 'I', 0.1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77314, 2155, 'DESMOPRESSIN ACETATE', 'I', 0.2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76960, 2155, 'DESMOPRESSIN ACETATE', 'I', 0.1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76961, 2155, 'DESMOPRESSIN ACETATE', 'I', 0.2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66190, 2155, 'DESMOPRESSIN ACETATE', 'I', 10, 'µG', '', '', 'N', 'SPRAY', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9861, 2155, 'DESMOPRESSIN ACETATE', 'I', 10, 'µG', '', '', 'N', 'ACT', 'HISTORIC FREEFORM TEXT: DESMOPRESSIN ACETATE QTY UNIT: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61220, 2155, 'DESMOPRESSIN ACETATE', 'I', 150, 'µG', '', '', 'N', 'ACT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18289, 2155, 'DESMOPRESSIN ACETATE', 'I', 15, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: DESMOPRESSIN ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13867, 2155, 'DESMOPRESSIN ACETATE', 'I', 4, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: DESMOPRESSIN ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14413, 2155, 'DESMOPRESSIN ACETATE', 'I', 0.1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DESMOPRESSIN ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43457, 2165, 'CIMETIDINE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43458, 2165, 'CIMETIDINE', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43459, 2165, 'CIMETIDINE', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43460, 2165, 'CIMETIDINE', 'I', 800, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11958, 2165, 'CIMETIDINE', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11959, 2165, 'CIMETIDINE', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11960, 2165, 'CIMETIDINE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11961, 2165, 'CIMETIDINE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8588, 2165, 'CIMETIDINE', 'I', 800, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5434, 2165, 'CIMETIDINE', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5435, 2165, 'CIMETIDINE', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5361, 2165, 'CIMETIDINE', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5362, 2165, 'CIMETIDINE', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6265, 2165, 'CIMETIDINE', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7312, 2165, 'CIMETIDINE', 'I', 800, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5195, 2165, 'CIMETIDINE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5196, 2165, 'CIMETIDINE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5151, 2165, 'CIMETIDINE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5152, 2165, 'CIMETIDINE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: CIMETIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47892, 2165, 'CIMETIDINE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47893, 2165, 'CIMETIDINE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47894, 2165, 'CIMETIDINE', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47895, 2165, 'CIMETIDINE', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47896, 2165, 'CIMETIDINE', 'I', 800, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50597, 2165, 'CIMETIDINE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50598, 2165, 'CIMETIDINE', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50600, 2165, 'CIMETIDINE', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66952, 2165, 'CIMETIDINE (CIMETIDINE HYDROCHLORIDE)', 'I', 300, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20187, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20188, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20310, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20311, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17831, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17833, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11188, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11189, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8602, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8603, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9887, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9886, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6611, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6612, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6512, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6513, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5818, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5819, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6311, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5091, 2167, 'METOPROLOL TARTRATE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2738, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2739, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50067, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50068, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50428, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50429, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72183, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72185, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70136, 2167, 'METOPROLOL TARTRATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73226, 2167, 'METOPROLOL TARTRATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73713, 2167, 'METOPROLOL TARTRATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73847, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73846, 2167, 'METOPROLOL TARTRATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73848, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77067, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77068, 2167, 'METOPROLOL TARTRATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78208, 2167, 'METOPROLOL TARTRATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78738, 2167, 'METOPROLOL TARTRATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80085, 2167, 'METOPROLOL TARTRATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80086, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80087, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78871, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78872, 2167, 'METOPROLOL TARTRATE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80066, 2167, 'METOPROLOL TARTRATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80067, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80068, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83560, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83561, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83667, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83668, 2167, 'METOPROLOL TARTRATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83938, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83939, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84194, 2167, 'METOPROLOL TARTRATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84195, 2167, 'METOPROLOL TARTRATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84196, 2167, 'METOPROLOL TARTRATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7357, 2167, 'METOPROLOL TARTRATE', 'I', 1, 'MG', '', '1', 'N', 'ML', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7325, 2167, 'METOPROLOL TARTRATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75326, 2167, 'METOPROLOL TARTRATE', 'I', 1, 'MG', '', '1', 'N', 'ML', 'Historic Freeform Text: METOPROLOL TARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10675, 2173, 'DEXTROMETHORPHAN (DEXTROMETHORPHAN HYDROBROMIDE)', 'I', 7.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15823, 2113, 'DIFLUNISAL', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIFLUNISAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15826, 2113, 'DIFLUNISAL', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIFLUNISAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14751, 2113, 'DIFLUNISAL', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIFLUNISAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14752, 2113, 'DIFLUNISAL', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIFLUNISAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14553, 2113, 'DIFLUNISAL', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIFLUNISAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14554, 2113, 'DIFLUNISAL', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIFLUNISAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12660, 2114, 'MECLOFENAMIC ACID', 'I', 50, 'MG', '', '', 'N', 'G', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43234, 2115, 'VALPROIC ACID', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: VALPROIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43211, 2115, 'VALPROIC ACID', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: VALPROIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19664, 2115, 'VALPROIC ACID', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: VALPROIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18804, 2115, 'VALPROIC ACID', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: VALPROIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18998, 2115, 'VALPROIC ACID', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: VALPROIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5676, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 125, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIVALPROEX SOD ((VALPORIC ACID EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5677, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIVALPROEX SOD ((VALPORIC ACID EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5678, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIVALPROEX SOD ((VALPORIC ACID EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3112, 2115, 'VALPROIC ACID', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: VALPROIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47553, 2115, 'VALPROIC ACID', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50820, 2115, 'VALPROIC ACID', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50311, 2115, 'VALPROIC ACID', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50312, 2115, 'VALPROIC ACID', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50031, 2115, 'VALPROIC ACID', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61189, 2115, 'VALPROIC ACID', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61972, 2115, 'VALPROIC ACID', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61432, 2115, 'VALPROIC ACID', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63179, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 125, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63182, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 125, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63183, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 250, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63184, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 500, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63196, 2115, 'VALPROIC ACID', 'I', 250, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63881, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63882, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63883, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68099, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68100, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68101, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69859, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69860, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69861, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74609, 2115, 'VALPROIC ACID', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74610, 2115, 'VALPROIC ACID', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75063, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75064, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75065, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77946, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77947, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77948, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63180, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 250, 'MG', '', '', 'Y', 'ECT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63181, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 500, 'MG', '', '', 'Y', 'ECT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62993, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 125, 'MG', '', '', 'N', 'ECT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62994, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 250, 'MG', '', '', 'N', 'ECT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62995, 2115, 'VALPROIC ACID (DIVALPROEX SODIUM)', 'I', 500, 'MG', '', '', 'N', 'ECT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43944, 2115, 'VALPROIC ACID (SODIUM VALPROATE)', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VALPROIC ACID ((AS THE SODIUM SALT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3156, 2115, 'VALPROIC ACID (SODIUM VALPROATE)', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VALPROATE SODIUM ((VALPROIC ACID EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60096, 2115, 'VALPROIC ACID (SODIUM VALPROATE)', 'I', 250, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62254, 2115, 'VALPROIC ACID (SODIUM VALPROATE)', 'I', 250, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61603, 2115, 'VALPROIC ACID (SODIUM VALPROATE)', 'I', 250, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61782, 2115, 'VALPROIC ACID (SODIUM VALPROATE)', 'I', 50, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9574, 2117, 'TRIAZOLAM', 'I', 0.125, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIAZOLAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9575, 2117, 'TRIAZOLAM', 'I', 0.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIAZOLAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18627, 2118, 'COLESTIPOL HYDROCHLORIDE', 'I', 1, 'G', '', '', 'N', '', 'Historic Freeform Text: COLESTIPOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18552, 2118, 'COLESTIPOL HYDROCHLORIDE', 'I', 5, 'G', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: COLESTIPOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7199, 2118, 'COLESTIPOL HYDROCHLORIDE', 'I', 5, 'G', '', '', 'N', 'PCK', 'Historic Freeform Text: COLESTIPOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16293, 2126, 'SULINDAC', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULINDAC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16294, 2126, 'SULINDAC', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULINDAC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9238, 2126, 'SULINDAC', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULINDAC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9239, 2126, 'SULINDAC', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULINDAC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8592, 2126, 'SULINDAC', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULINDAC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8593, 2126, 'SULINDAC', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULINDAC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42159, 2129, 'PADIMATE O', 'I', 6.6, '%', '', '', 'N', '', 'Historic Freeform Text: PADIMATE O');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16272, 2129, 'PADIMATE O', 'I', 3.3, '%', '', '', 'N', '', 'Historic Freeform Text: PADIMATE O');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61544, 2129, 'PADIMATE O', 'I', 3.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60920, 2129, 'PADIMATE O', 'I', 8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68743, 2129, 'PADIMATE O', 'I', 8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69834, 2129, 'PADIMATE O', 'I', 8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74215, 2129, 'PADIMATE O', 'I', 8.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73489, 2129, 'PADIMATE O', 'I', 8, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78311, 2129, 'PADIMATE O', 'I', 8.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78019, 2129, 'PADIMATE O', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78020, 2129, 'PADIMATE O', 'I', 7.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66357, 2129, 'PADIMATE O', 'I', 1.4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79439, 2129, 'PADIMATE O', 'I', 6.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81016, 2129, 'PADIMATE O', 'I', 6.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80453, 2129, 'PADIMATE O', 'I', 8.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79646, 2129, 'PADIMATE O', 'I', 6.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83906, 2129, 'PADIMATE O', 'I', 6.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42334, 2129, 'PADIMATE O', 'I', 6.6, '%', '', '', 'N', '%', 'Historic Freeform Text: PADIMATE O');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16893, 2129, 'PADIMATE O', 'I', 7, '%', '', '', 'N', '%', 'Historic Freeform Text: PADIMATE O');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16896, 2129, 'PADIMATE O', 'I', 8, '%', '', '', 'N', '%', 'Historic Freeform Text: PADIMATE O');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19650, 2133, 'FLUNISOLIDE', 'I', 25, 'µG', '', '', 'N', 'ACT', 'Historic Freeform Text: FLUNISOLIDE Qty Unit: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62753, 2133, 'FLUNISOLIDE', 'I', 0.25, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75000, 2139, 'MYCOPHENOLIC ACID (MYCOPHENOLATE SODIUM)', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75001, 2139, 'MYCOPHENOLIC ACID (MYCOPHENOLATE SODIUM)', 'I', 360, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3486, 2140, 'PATENT BLUE SODIUM', 'I', 50, 'MG', '', '2', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PATENT BLUE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22917, 78, 'CHARCOAL ACTIVATED', 'I', 260, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHARCOAL ACTIVATED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11341, 78, 'CHARCOAL ACTIVATED', 'I', 140, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHARCOAL ACTIVATED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59931, 78, 'CHARCOAL ACTIVATED', 'I', 225, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80809, 78, 'CHARCOAL ACTIVATED', 'I', 170, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79065, 78, 'CHARCOAL ACTIVATED', 'I', 260, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (622, 78, 'CHARCOAL ACTIVATED', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: CARBON AMORPHOUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67893, 78, 'CHARCOAL ACTIVATED', 'I', 100, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6317, 78, 'CHARCOAL ACTIVATED', 'I', 50, 'G', '', '225', 'N', 'ML', 'Historic Freeform Text: CHARCOAL ACTIVATED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7267, 78, 'CHARCOAL ACTIVATED', 'I', 50, 'G', '', '250', 'N', 'ML', 'Historic Freeform Text: CHARCOAL ACTIVATED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (29506, 78, 'CHARCOAL ACTIVATED', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHARCOAL ACTIVATED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (29507, 78, 'CHARCOAL ACTIVATED', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHARCOAL ACTIVATED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17399, 78, 'CHARCOAL ACTIVATED', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHARCOAL ACTIVATED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16533, 78, 'CHARCOAL ACTIVATED', 'I', 222, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHARCOAL ACTIVATED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6393, 78, 'CHARCOAL ACTIVATED', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHARCOAL ACTIVATED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (231, 78, 'CHARCOAL ACTIVATED', 'I', 1.04, 'G', '', '2.9', 'N', 'G', 'Historic Freeform Text: CARBON AMORPHOUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62983, 78, 'CHARCOAL ACTIVATED', 'I', 1, 'G', '', '1', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35469, 78, 'CHARCOAL ACTIVATED', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: CHARCOAL ACTIVATED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84428, 90, 'COAGULATION FACTOR IX (HUMAN)', 'I', 620, 'UNIT', '', '', 'N', '', '400-620IU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78001, 90, 'COAGULATION FACTOR IX (HUMAN)', 'I', 620, 'UNIT', '', '', 'N', 'VIAL', '400-620 INTER. UNIT; AFTER RECONSTITUTION: 20-31 IU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43011, 90, 'COAGULATION FACTOR IX (HUMAN)', 'I', 720, 'UNIT', '', '5', 'N', 'ML', '480 - 720 IU/5ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44074, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CIPROFLOXACIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44075, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CIPROFLOXACIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44076, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 750, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CIPROFLOXACIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76241, 1, 'OLANZAPINE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44057, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'Y', '', 'Historic Freeform Text: CIPROFLOXACIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44058, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'Y', '', 'Historic Freeform Text: CIPROFLOXACIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44059, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 750, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: CIPROFLOXACIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47426, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47427, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47428, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72225, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE, CIPROFLOXACIN)', 'I', 500, 'MG', '', '', 'N', '', 'THIS IS A COATED BI-LAYER TABLET CONSISTING OF AN IMMEDIATE-RELEASE LAYER AND AN EROSION-MATRIX TYPE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71582, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71583, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71584, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71025, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71026, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71027, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69747, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69748, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69749, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72788, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CIPROFLOXACIN ((AS HCL MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72789, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CIPROFLOXACIN ((AS HCL MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72790, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 750, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CIPROFLOXACIN ((AS HCL MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75238, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'Y', '', 'Historic Freeform Text: CIPROFLOXACIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75239, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73124, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73125, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73126, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73618, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73619, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73620, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73622, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73623, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73624, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73626, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73627, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73628, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73669, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE, CIPROFLOXACIN)', 'I', 1000, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80332, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80333, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78902, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78903, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78904, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80295, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80296, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80297, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83851, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83852, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83853, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 750, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12953, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 0.3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CIPROFLOXACIN HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73887, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74854, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 0.3, '%', '', '', 'N', '', 'W/V.EACH ML CONTAINS CIPROFLOXACIN HYDROCHLORIDE MONOHYDRATE 3.5MG EQUIV. TO 3MG BASE. EW.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73758, 93, 'CIPROFLOXACIN (CIPROFLOXACIN HYDROCHLORIDE)', 'I', 0.3, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78663, 93, 'CIPROFLOXACIN (CIPROFLOXACIN LACTATE)', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60849, 93, 'CIPROFLOXACIN', 'I', 10, 'G', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75287, 93, 'CIPROFLOXACIN', 'I', 2.0, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74200, 93, 'CIPROFLOXACIN', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78723, 93, 'CIPROFLOXACIN', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78981, 93, 'CIPROFLOXACIN', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79003, 93, 'CIPROFLOXACIN', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42981, 96, 'ANTI-INHIBITOR COAGULANT COMPLEX', 'I', 1200, 'UNIT', '', '', 'N', 'VIAL', '400-1200IU/VIAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83912, 96, 'ANTI-INHIBITOR COAGULANT COMPLEX', 'I', 3250, 'UNIT', '', '', 'N', 'VIAL', '2010.06.18. STRENGTH RANGE IS: 1750-3250 IU/VIAL./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65120, 4, 'RITONAVIR', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77104, 4, 'RITONAVIR', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79781, 4, 'RITONAVIR', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84270, 4, 'RITONAVIR', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43516, 4, 'RITONAVIR', 'I', 80, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: RITONAVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67570, 4, 'RITONAVIR', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43455, 8, 'DESFLURANE', 'I', 1, 'ML', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DESFLURANE. 961127:  PETER CHAN REQUESTED THAT CONCENTRATION BE CHANGED TO 1');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43530, 1, 'OLANZAPINE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: OLANZAPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43531, 1, 'OLANZAPINE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: OLANZAPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43532, 1, 'OLANZAPINE', 'I', 7.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OLANZAPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43533, 1, 'OLANZAPINE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: OLANZAPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62290, 1, 'OLANZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62291, 1, 'OLANZAPINE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66953, 1, 'OLANZAPINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66954, 1, 'OLANZAPINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66955, 1, 'OLANZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66956, 1, 'OLANZAPINE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76745, 1, 'OLANZAPINE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76746, 1, 'OLANZAPINE', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76747, 1, 'OLANZAPINE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76748, 1, 'OLANZAPINE', 'I', 10.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76749, 1, 'OLANZAPINE', 'I', 15.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76242, 1, 'OLANZAPINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76243, 1, 'OLANZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76239, 1, 'OLANZAPINE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76240, 1, 'OLANZAPINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82351, 1, 'OLANZAPINE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82352, 1, 'OLANZAPINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82353, 1, 'OLANZAPINE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82354, 1, 'OLANZAPINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82355, 1, 'OLANZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82356, 1, 'OLANZAPINE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81866, 1, 'OLANZAPINE', 'I', 20.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79749, 1, 'OLANZAPINE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79750, 1, 'OLANZAPINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79751, 1, 'OLANZAPINE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79752, 1, 'OLANZAPINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79753, 1, 'OLANZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81102, 1, 'OLANZAPINE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81103, 1, 'OLANZAPINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81104, 1, 'OLANZAPINE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81105, 1, 'OLANZAPINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81106, 1, 'OLANZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81107, 1, 'OLANZAPINE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79599, 1, 'OLANZAPINE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79600, 1, 'OLANZAPINE', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79601, 1, 'OLANZAPINE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79602, 1, 'OLANZAPINE', 'I', 10.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79603, 1, 'OLANZAPINE', 'I', 15.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80674, 1, 'OLANZAPINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80675, 1, 'OLANZAPINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80676, 1, 'OLANZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80677, 1, 'OLANZAPINE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78844, 1, 'OLANZAPINE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78848, 1, 'OLANZAPINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78849, 1, 'OLANZAPINE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78850, 1, 'OLANZAPINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78851, 1, 'OLANZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78852, 1, 'OLANZAPINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78853, 1, 'OLANZAPINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78854, 1, 'OLANZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79308, 1, 'OLANZAPINE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79309, 1, 'OLANZAPINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79310, 1, 'OLANZAPINE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79311, 1, 'OLANZAPINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79312, 1, 'OLANZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79313, 1, 'OLANZAPINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79314, 1, 'OLANZAPINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79315, 1, 'OLANZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81288, 1, 'OLANZAPINE', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81289, 1, 'OLANZAPINE', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81290, 1, 'OLANZAPINE', 'I', 15, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81291, 1, 'OLANZAPINE', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81318, 1, 'OLANZAPINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81319, 1, 'OLANZAPINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81320, 1, 'OLANZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81321, 1, 'OLANZAPINE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82273, 1, 'OLANZAPINE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82274, 1, 'OLANZAPINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82275, 1, 'OLANZAPINE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82276, 1, 'OLANZAPINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82277, 1, 'OLANZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82431, 1, 'OLANZAPINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82432, 1, 'OLANZAPINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82433, 1, 'OLANZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82535, 1, 'OLANZAPINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82540, 1, 'OLANZAPINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82541, 1, 'OLANZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84470, 1, 'OLANZAPINE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71336, 1, 'OLANZAPINE (OLANZAPINE TARTRATE)', 'I', 10, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43396, 17, 'PERTACTIN', 'I', 3, 'µG', '', '0.5', 'N', 'ML', 'Historic Freeform Text: PERTACTIN ((69 KDA MEMBRANE PROTEIN))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50651, 17, 'PERTACTIN', 'I', 3, 'µG', '', '0.5', 'N', 'ML', 'PERTACTIN (69 KDA MEMBRANE PROTEIN).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50224, 17, 'PERTACTIN', 'I', 3, 'µG', '', '0.5', 'N', 'ML', 'PERTACTIN (69 KDA MEMBRANE PROTEIN).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63789, 17, 'PERTACTIN', 'I', 3, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67042, 17, 'PERTACTIN', 'I', 3, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71860, 17, 'PERTACTIN', 'I', 2.5, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73878, 17, 'PERTACTIN', 'I', 8, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83726, 17, 'PERTACTIN', 'I', 3, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43396, 18, 'FIMBRIAE', 'I', 5, 'µG', '', '0.5', 'N', 'ML', 'Historic Freeform Text: FIMBRIAE ((AGGLUTINOGENS 2+3))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50651, 18, 'FIMBRIAE', 'I', 5, 'µG', '', '0.5', 'N', 'ML', 'FIMBRIAE (AGGLUTINOGEN 2 + 3).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50224, 18, 'FIMBRIAE', 'I', 5, 'µG', '', '0.5', 'N', 'ML', 'FIMBRIAE (AGGLUTINOGEN 2 + 3).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67042, 18, 'FIMBRIAE', 'I', 5, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43396, 19, 'FILAMENTOUS HAEMAGGLUTININ', 'I', 20, 'µG', '', '0.5', 'N', 'ML', 'Historic Freeform Text: FILAMENTOUS HAEMAGGLUTININ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50651, 19, 'FILAMENTOUS HAEMAGGLUTININ', 'I', 20, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50224, 19, 'FILAMENTOUS HAEMAGGLUTININ', 'I', 20, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63789, 19, 'FILAMENTOUS HAEMAGGLUTININ', 'I', 5, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67042, 19, 'FILAMENTOUS HAEMAGGLUTININ', 'I', 20, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71860, 19, 'FILAMENTOUS HAEMAGGLUTININ', 'I', 8, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73878, 19, 'FILAMENTOUS HAEMAGGLUTININ', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83726, 19, 'FILAMENTOUS HAEMAGGLUTININ', 'I', 5, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43396, 20, 'PERTUSSIS TOXOID', 'I', 20, 'µG', '', '0.5', 'N', 'ML', 'Historic Freeform Text: PERTUSSIS TOXOID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50651, 20, 'PERTUSSIS TOXOID', 'I', 20, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50224, 20, 'PERTUSSIS TOXOID', 'I', 20, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63789, 20, 'PERTUSSIS TOXOID', 'I', 2.5, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67042, 20, 'PERTUSSIS TOXOID', 'I', 20, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71860, 20, 'PERTUSSIS TOXOID', 'I', 8, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73878, 20, 'PERTUSSIS TOXOID', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83726, 20, 'PERTUSSIS TOXOID', 'I', 2.5, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43395, 27, 'ANASTROZOLE', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ANASTROZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10426, 28, 'TIAMULIN (TIAMULIN HYDROGEN FUMARATE)', 'I', 23.59, 'G', '', '', 'Y', 'PCK', 'AS TIAMULIN HYDROGEN FUMARATE (29G).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43399, 28, 'TIAMULIN (TIAMULIN HYDROGEN FUMARATE)', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: TIAMULIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12200, 28, 'TIAMULIN (TIAMULIN HYDROGEN FUMARATE)', 'I', 17.8, 'G', '', '', 'Y', 'KG', 'HISTORIC FREEFORM TEXT: TIAMULIN HYDROGEN FUMARATE 22GM/KG ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66162, 28, 'TIAMULIN (TIAMULIN FUMARATE)', 'I', 17.8, 'G', '', '', 'Y', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80986, 28, 'TIAMULIN (TIAMULIN FUMARATE)', 'I', 365.2, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42310, 33, 'OXYBENZONE', 'I', 5.2, '%', '', '', 'N', '', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42159, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', '', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79255, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41955, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41956, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41957, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41935, 33, 'OXYBENZONE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42607, 33, 'OXYBENZONE', 'I', 4.5, '%', '', '', 'N', '', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37913, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (32792, 33, 'OXYBENZONE', 'I', 3.5, '%', '', '', 'N', '', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33490, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30927, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19330, 33, 'OXYBENZONE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18691, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15869, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16272, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', '', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47540, 33, 'OXYBENZONE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48123, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50605, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50939, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', 'ALSO CALLED BENZOPHENONE-3 ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53823, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60497, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61295, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61296, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61544, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60890, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60920, 33, 'OXYBENZONE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60325, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62463, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63261, 33, 'OXYBENZONE', 'I', 4.7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63263, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63264, 33, 'OXYBENZONE', 'I', 5.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64081, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63342, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63348, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63350, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64701, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64702, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64150, 33, 'OXYBENZONE', 'I', 5.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64225, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64289, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63102, 33, 'OXYBENZONE', 'I', 5.9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65907, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65423, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65427, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66706, 33, 'OXYBENZONE', 'I', 4.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66828, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66892, 33, 'OXYBENZONE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66974, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68325, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68818, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68850, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69344, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68355, 33, 'OXYBENZONE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69420, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67949, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67987, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68570, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68574, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68594, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68186, 33, 'OXYBENZONE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68743, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67743, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71383, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71382, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71384, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71386, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72192, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72270, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72271, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72275, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70085, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70087, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70111, 33, 'OXYBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71534, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70856, 33, 'OXYBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71649, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70878, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70879, 33, 'OXYBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70880, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70881, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70903, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70904, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71650, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70261, 33, 'OXYBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69791, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69834, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69886, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71277, 33, 'OXYBENZONE', 'I', 1.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72068, 33, 'OXYBENZONE', 'I', 0.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76449, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76450, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76470, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73900, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75172, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76518, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75229, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76634, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74004, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75350, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76383, 33, 'OXYBENZONE', 'I', 5.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76711, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74176, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75392, 33, 'OXYBENZONE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75409, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75413, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75414, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75425, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75777, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76744, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73042, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73044, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74215, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74229, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74244, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75450, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75512, 33, 'OXYBENZONE', 'I', 4.25, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72336, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72339, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73106, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74271, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74321, 33, 'OXYBENZONE', 'I', 2.7, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75531, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75596, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72406, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75641, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75676, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75677, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75697, 33, 'OXYBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73166, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74441, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75752, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75755, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75756, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75768, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72581, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72582, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74564, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75847, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74630, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74651, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74654, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74655, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75989, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73308, 33, 'OXYBENZONE', 'I', 4.50, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73323, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74735, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73436, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76146, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73488, 33, 'OXYBENZONE', 'I', 5.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73489, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74916, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76213, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76214, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73607, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73657, 33, 'OXYBENZONE', 'I', 5.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74918, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73755, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73756, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74998, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76206, 33, 'OXYBENZONE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76325, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76328, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76349, 33, 'OXYBENZONE', 'I', 1.75, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72761, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72762, 33, 'OXYBENZONE', 'I', 0.9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78108, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78385, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78402, 33, 'OXYBENZONE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77441, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77461, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77512, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77550, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77551, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77577, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77578, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77612, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77613, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77374, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77083, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77439, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77517, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77611, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77614, 33, 'OXYBENZONE', 'I', 2.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77630, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77608, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76890, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77681, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77682, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77883, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78157, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77299, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78301, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78304, 33, 'OXYBENZONE', 'I', 5.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78317, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77927, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77928, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77581, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78023, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78024, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76934, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77321, 33, 'OXYBENZONE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77322, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77323, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77324, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77325, 33, 'OXYBENZONE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77326, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78047, 33, 'OXYBENZONE', 'I', 2.10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77513, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77515, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77617, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77618, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79423, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79215, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82245, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79960, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79018, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78689, 33, 'OXYBENZONE', 'I', 5.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78690, 33, 'OXYBENZONE', 'I', 6.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79082, 33, 'OXYBENZONE', 'I', 5.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79181, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79182, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80443, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78611, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78700, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78701, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79256, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79262, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79263, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79420, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78709, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79271, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79294, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79798, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79415, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79416, 33, 'OXYBENZONE', 'I', 4.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79417, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79719, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79407, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81450, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79252, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79253, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79257, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78929, 33, 'OXYBENZONE', 'I', 6.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78930, 33, 'OXYBENZONE', 'I', 6.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80565, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79238, 33, 'OXYBENZONE', 'I', 2.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79319, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79320, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79321, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79322, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79931, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79197, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78629, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78635, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79982, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79226, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79228, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79232, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79233, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79992, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80227, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80110, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80111, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79026, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79168, 33, 'OXYBENZONE', 'I', 5.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82839, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82382, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79421, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79090, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79092, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79185, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79086, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78589, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79251, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82461, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80800, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80457, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82313, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82530, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83915, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83916, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84120, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84130, 33, 'OXYBENZONE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84131, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84133, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84342, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84347, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84348, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84353, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84379, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84553, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84603, 33, 'OXYBENZONE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84818, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84903, 33, 'OXYBENZONE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85091, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16229, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15968, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48991, 33, 'OXYBENZONE', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50232, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60006, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65475, 33, 'OXYBENZONE', 'I', 6.00, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65639, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67685, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70086, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70588, 33, 'OXYBENZONE', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75370, 33, 'OXYBENZONE', 'I', 4.25, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75634, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72583, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75934, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74849, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74883, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74884, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74885, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76200, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76215, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74967, 33, 'OXYBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74968, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74969, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74970, 33, 'OXYBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74999, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76204, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76351, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77368, 33, 'OXYBENZONE', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78398, 33, 'OXYBENZONE', 'I', 2.00, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78399, 33, 'OXYBENZONE', 'I', 2.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77463, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77389, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77390, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77391, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77392, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77473, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78219, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77288, 33, 'OXYBENZONE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76938, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76894, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76863, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77470, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76891, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76892, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77633, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77721, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76941, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78297, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77340, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77341, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79439, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79440, 33, 'OXYBENZONE', 'I', 5.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80859, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81656, 33, 'OXYBENZONE', 'I', 3.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81144, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81175, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81252, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82350, 33, 'OXYBENZONE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79851, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80135, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81909, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79849, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79850, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81268, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82780, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82843, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79579, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79748, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80566, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82206, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82210, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80985, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82242, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79731, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78685, 33, 'OXYBENZONE', 'I', 5.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78686, 33, 'OXYBENZONE', 'I', 6.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79183, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80487, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80488, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80350, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79766, 33, 'OXYBENZONE', 'I', 5.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80527, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80531, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82834, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81406, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82015, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82016, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82018, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82161, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82592, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81707, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81716, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79460, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80088, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82602, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80025, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80026, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80027, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80175, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80176, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80436, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81454, 33, 'OXYBENZONE', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81366, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81367, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81371, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81370, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81372, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81016, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81017, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81337, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80049, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80050, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80051, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80052, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80055, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80056, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80960, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82493, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82494, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80198, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80199, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81604, 33, 'OXYBENZONE', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81605, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'Y', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81708, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81709, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81557, 33, 'OXYBENZONE', 'I', 2.4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81842, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82013, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82508, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82617, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80327, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80453, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80328, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80478, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80568, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79983, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80631, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80810, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80023, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80024, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80022, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81076, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79645, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79646, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79647, 33, 'OXYBENZONE', 'I', 5.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79648, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79989, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80228, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80580, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81301, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81413, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81415, 33, 'OXYBENZONE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79618, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79620, 33, 'OXYBENZONE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80460, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80069, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81266, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79169, 33, 'OXYBENZONE', 'I', 5.4, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82515, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81635, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81926, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', 'SEE PRODUCT NOTE FIELD.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81928, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81929, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', 'SEE PRODUCT NOTE FIELD.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81930, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', 'SEE PRODUCT NOTE FIELD.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81892, 33, 'OXYBENZONE', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81893, 33, 'OXYBENZONE', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81894, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82380, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82381, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80362, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79484, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80392, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81911, 33, 'OXYBENZONE', 'I', 4.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80061, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80515, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80516, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80517, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80525, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80524, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80526, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81043, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81044, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82368, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82372, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79871, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82017, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82019, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82020, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80671, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81912, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81913, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81914, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81915, 33, 'OXYBENZONE', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81916, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81919, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81920, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81921, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82621, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80504, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80503, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83050, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79249, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80707, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82373, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82462, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80254, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80256, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80537, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80539, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81639, 33, 'OXYBENZONE', 'I', 2.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82063, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82065, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81069, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80099, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80302, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78779, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80864, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80865, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80879, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82484, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83001, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79868, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80380, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80595, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81287, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82779, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79540, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81488, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81490, 33, 'OXYBENZONE', 'I', 0.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81491, 33, 'OXYBENZONE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83072, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83101, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83278, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83388, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83389, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83391, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83403, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83420, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83564, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83580, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83581, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83772, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83773, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83775, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83859, 33, 'OXYBENZONE', 'I', 6.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83866, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83869, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83903, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83906, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83908, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83964, 33, 'OXYBENZONE', 'I', 1.40, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83983, 33, 'OXYBENZONE', 'I', 5.4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83984, 33, 'OXYBENZONE', 'I', 5.4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84003, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84004, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84006, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84034, 33, 'OXYBENZONE', 'I', 6.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84035, 33, 'OXYBENZONE', 'I', 4.75, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84039, 33, 'OXYBENZONE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84041, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84042, 33, 'OXYBENZONE', 'I', 4.75, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84055, 33, 'OXYBENZONE', 'I', 1.40, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84061, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84076, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84092, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84209, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84257, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84262, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84291, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84292, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84399, 33, 'OXYBENZONE', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84403, 33, 'OXYBENZONE', 'I', 4.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84415, 33, 'OXYBENZONE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84424, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84431, 33, 'OXYBENZONE', 'I', 2.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84465, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84503, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84574, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84576, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84579, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84580, 33, 'OXYBENZONE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84664, 33, 'OXYBENZONE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84706, 33, 'OXYBENZONE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84886, 33, 'OXYBENZONE', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84959, 33, 'OXYBENZONE', 'I', 6.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84962, 33, 'OXYBENZONE', 'I', 6.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42332, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '%', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42329, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '%', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18554, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '%', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16893, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '%', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16896, 33, 'OXYBENZONE', 'I', 4.5, '%', '', '', 'N', '%', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50132, 33, 'OXYBENZONE', 'I', 4.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53416, 33, 'OXYBENZONE', 'I', 1.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53417, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53421, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53422, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53423, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53424, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53425, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53426, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61886, 33, 'OXYBENZONE', 'I', 3, '%', '', '', 'N', '%', 'Historic Freeform Text: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61896, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60506, 33, 'OXYBENZONE', 'I', 1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60302, 33, 'OXYBENZONE', 'I', 4.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60326, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60327, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60328, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63346, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63347, 33, 'OXYBENZONE', 'I', 4, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63349, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63351, 33, 'OXYBENZONE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64334, 33, 'OXYBENZONE', 'I', 2, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64738, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64739, 33, 'OXYBENZONE', 'I', 6, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65601, 33, 'OXYBENZONE', 'I', 2.5, '%', '', '', 'N', '%', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15518, 33, 'OXYBENZONE', 'I', 4, 'G', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: OXYBENZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61299, 33, 'OXYBENZONE', 'I', 2, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71227, 33, 'OXYBENZONE', 'I', 3, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43254, 41, 'MEROPENEM', 'I', 1, 'G', '', '', 'N', 'VIAL', 'Historic Freeform Text: MEROPENEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43253, 41, 'MEROPENEM', 'I', 500, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: MEROPENEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 42, 'DEXTROSE', 'I', 2.5, 'G', '', '', 'N', '', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21687, 42, 'DEXTROSE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17398, 42, 'DEXTROSE', 'I', 50, '%', '', '', 'N', '', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13009, 42, 'DEXTROSE', 'I', 15, '%', '', '', 'N', '', 'Historic Freeform Text: DEXTROSE ((MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12930, 42, 'DEXTROSE', 'I', 14.5, '%', '', '', 'N', '', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5664, 42, 'DEXTROSE', 'I', 50, '%', '', '', 'N', '', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4913, 42, 'DEXTROSE', 'I', 0.092, '%', '', '', 'N', '', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3326, 42, 'DEXTROSE', 'I', 25, '%', '', '', 'N', '', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4986, 42, 'DEXTROSE', 'I', 61, '%', '', '', 'N', '', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12924, 42, 'DEXTROSE (DEXTROSE MONOHYDRATE)', 'I', 15, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77615, 42, 'DEXTROSE', 'I', 50, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3406, 42, 'DEXTROSE', 'I', 50, '%', '', '', 'N', 'W/V', 'DEXTROSE MONOHYDRATE USP 50% W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81241, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35667, 42, 'DEXTROSE', 'I', 16.75, '%', '', '', 'N', '%', 'Historic Freeform Text: DEXTROSE ((MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22423, 42, 'DEXTROSE', 'I', 40, '%', '', '', 'N', '%', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21688, 42, 'DEXTROSE', 'I', 5, '%', '', '', 'N', '%', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12794, 42, 'DEXTROSE', 'I', 50, '%', '', '', 'N', '%', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7388, 42, 'DEXTROSE', 'I', 56.6, '%', '', '', 'N', '%', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31465, 42, 'DEXTROSE', 'I', 43.208, 'G', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18319, 42, 'DEXTROSE', 'I', 222.7, 'G', '', '', 'N', 'PCK', 'Historic Freeform Text: DEXTROSE ((HYDROUS USP))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 42, 'DEXTROSE', 'I', 20, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36695, 42, 'DEXTROSE', 'I', 15, 'G', '', '30', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36794, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36795, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23039, 42, 'DEXTROSE', 'I', 2, 'G', '', '63', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23494, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'HYDROUS DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21767, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'HYDROUS DEXTROSE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21764, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'HYDROUS DEXTROSE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21753, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'HYDROUS DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21754, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'HYDROUS DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21755, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21756, 42, 'DEXTROSE', 'I', 2.5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21752, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21713, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21715, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21998, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20279, 42, 'DEXTROSE', 'I', 20, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20278, 42, 'DEXTROSE', 'I', 16.6, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 42, 'DEXTROSE', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19610, 42, 'DEXTROSE', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20303, 42, 'DEXTROSE', 'I', 25, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20302, 42, 'DEXTROSE', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 42, 'DEXTROSE', 'I', 25, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 42, 'DEXTROSE', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20289, 42, 'DEXTROSE', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 42, 'DEXTROSE', 'I', 16.6, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 42, 'DEXTROSE', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 42, 'DEXTROSE', 'I', 25, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 42, 'DEXTROSE', 'I', 20, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18823, 42, 'DEXTROSE', 'I', 40, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18824, 42, 'DEXTROSE', 'I', 50, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18825, 42, 'DEXTROSE', 'I', 33.3, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18826, 42, 'DEXTROSE', 'I', 13.3, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18827, 42, 'DEXTROSE', 'I', 20, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 42, 'DEXTROSE', 'I', 20, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 42, 'DEXTROSE', 'I', 25, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 42, 'DEXTROSE', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 42, 'DEXTROSE', 'I', 25, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19143, 42, 'DEXTROSE', 'I', 16.6, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 42, 'DEXTROSE', 'I', 25, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 42, 'DEXTROSE', 'I', 25, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 42, 'DEXTROSE', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18686, 42, 'DEXTROSE', 'I', 70, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18991, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 42, 'DEXTROSE', 'I', 25, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18085, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18086, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18087, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18550, 42, 'DEXTROSE', 'I', 20, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 42, 'DEXTROSE', 'I', 20, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16794, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15772, 42, 'DEXTROSE', 'I', 4.25, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15778, 42, 'DEXTROSE', 'I', 1.5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15768, 42, 'DEXTROSE', 'I', 1.5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15769, 42, 'DEXTROSE', 'I', 2.5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15763, 42, 'DEXTROSE', 'I', 2.5, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15764, 42, 'DEXTROSE', 'I', 4.25, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13033, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13034, 42, 'DEXTROSE', 'I', 3.3, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14077, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 42, 'DEXTROSE', 'I', 16.6, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 42, 'DEXTROSE', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14073, 42, 'DEXTROSE', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 42, 'DEXTROSE', 'I', 25, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14071, 42, 'DEXTROSE', 'I', 25, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 42, 'DEXTROSE', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 42, 'DEXTROSE', 'I', 25, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14067, 42, 'DEXTROSE', 'I', 25, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14578, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6769, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 42, 'DEXTROSE', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14250, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10515, 42, 'DEXTROSE', 'I', 3.3, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10511, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10438, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10439, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10440, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10441, 42, 'DEXTROSE', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11038, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12711, 42, 'DEXTROSE', 'I', 3.3, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10937, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10938, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10930, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10931, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10932, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10933, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12787, 42, 'DEXTROSE', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10934, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10935, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10936, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10924, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10925, 42, 'DEXTROSE', 'I', 2.5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10926, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10927, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10928, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10929, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10866, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10867, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10863, 42, 'DEXTROSE', 'I', 1.5, 'G', '', '100', 'N', 'ML', 'DEXTROSE HYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10864, 42, 'DEXTROSE', 'I', 2.5, 'G', '', '100', 'N', 'ML', 'DEXTROSE HYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10865, 42, 'DEXTROSE', 'I', 4.25, 'G', '', '100', 'N', 'ML', 'DEXTROSE HYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10861, 42, 'DEXTROSE', 'I', 2.5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11376, 42, 'DEXTROSE', 'I', 2.45, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE (MONOHYDRATE)./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11354, 42, 'DEXTROSE', 'I', 1.47, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE (MONOHYDRATE)/KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10143, 42, 'DEXTROSE', 'I', 4.25, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE (HEMODIALYSIS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10144, 42, 'DEXTROSE', 'I', 1.5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE (HEMODIALYSIS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9526, 42, 'DEXTROSE', 'I', 75, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10009, 42, 'DEXTROSE', 'I', 2.5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE (HEMODIALYSIS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10041, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10042, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10043, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10044, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10045, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7141, 42, 'DEXTROSE', 'I', 50, 'G', '', '1000', 'N', 'ML', 'DEXTROSE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'AS DEXTROSE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3820, 42, 'DEXTROSE', 'I', 50, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3132, 42, 'DEXTROSE', 'I', 3.3, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3133, 42, 'DEXTROSE', 'I', 3.3, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3407, 42, 'DEXTROSE', 'I', 27, 'G', '', '60', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2002, 42, 'DEXTROSE', 'I', 250, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2003, 42, 'DEXTROSE', 'I', 75, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1673, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1623, 42, 'DEXTROSE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1614, 42, 'DEXTROSE', 'I', 75, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1615, 42, 'DEXTROSE', 'I', 250, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59976, 42, 'DEXTROSE', 'I', 10, 'G', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78452, 42, 'DEXTROSE', 'I', 5.0, 'G', '', '100', 'N', 'ML', 'DEXTROSE HYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78453, 42, 'DEXTROSE', 'I', 5.0, 'G', '', '100', 'N', 'ML', 'DEXTROSE HYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36412, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21689, 42, 'DEXTROSE', 'I', 700, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS USP))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15538, 42, 'DEXTROSE', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS USP))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15539, 42, 'DEXTROSE', 'I', 500, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS USP))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13714, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE ((HYDROUS USP))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13288, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14251, 42, 'DEXTROSE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14183, 42, 'DEXTROSE', 'I', 250, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10518, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10519, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10520, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10512, 42, 'DEXTROSE', 'I', 500, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: DEXTROSE (HEMODIALYSIS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11624, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11625, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12256, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12171, 42, 'DEXTROSE', 'I', 200, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12681, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11905, 42, 'DEXTROSE', 'I', 10.80, 'MG', '', '', 'N', 'ML', 'DEXTROSE MONHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5373, 42, 'DEXTROSE', 'I', 25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6400, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE (MONOHYDRATE).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6260, 42, 'DEXTROSE', 'I', 250, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6768, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6228, 42, 'DEXTROSE', 'I', 50.0, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3819, 42, 'DEXTROSE', 'I', 400, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE (MONOHYDRATE).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3747, 42, 'DEXTROSE', 'I', 200, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE (MONOHYDRATE).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5339, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5340, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3585, 42, 'DEXTROSE', 'I', 700, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE (MONOHYDRATE).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3534, 42, 'DEXTROSE', 'I', 50.0, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3535, 42, 'DEXTROSE', 'I', 50.0, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE (MONOHYDRATE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3536, 42, 'DEXTROSE', 'I', 50.0, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3537, 42, 'DEXTROSE', 'I', 33.3, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3538, 42, 'DEXTROSE', 'I', 33.3, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2575, 42, 'DEXTROSE', 'I', 33.3, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1750, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE (MONOHYDRATE).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1751, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE (MONOHYDRATE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1739, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1744, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1746, 42, 'DEXTROSE', 'I', 500, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE (MONOHYDRATE).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1747, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE (MONOHYDRATE).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1748, 42, 'DEXTROSE', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE (MONOHYDRATE).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1749, 42, 'DEXTROSE', 'I', 50.0, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE (MONOHYDRATE).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1732, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1737, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2902, 42, 'DEXTROSE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE (MONOHYDRATE).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1548, 42, 'DEXTROSE', 'I', 25, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13000, 42, 'DEXTROSE', 'I', 150, 'MG', '', '', 'N', 'ML', 'DEXTROSE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36836, 42, 'DEXTROSE', 'I', 89.99, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36814, 42, 'DEXTROSE', 'I', 112.53, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34881, 42, 'DEXTROSE', 'I', 90, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34878, 42, 'DEXTROSE', 'I', 45, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34879, 42, 'DEXTROSE', 'I', 45, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19744, 42, 'DEXTROSE', 'I', 90, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19735, 42, 'DEXTROSE', 'I', 89.99, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20121, 42, 'DEXTROSE', 'I', 90, 'G', '', '', 'N', 'L', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20115, 42, 'DEXTROSE', 'I', 67.5, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20116, 42, 'DEXTROSE', 'I', 45, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20118, 42, 'DEXTROSE', 'I', 67.5, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20119, 42, 'DEXTROSE', 'I', 45, 'G', '', '', 'N', 'L', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20111, 42, 'DEXTROSE', 'I', 45, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20114, 42, 'DEXTROSE', 'I', 45, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19739, 42, 'DEXTROSE', 'I', 90, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20076, 42, 'DEXTROSE', 'I', 90, 'G', '', '', 'N', 'L', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20044, 42, 'DEXTROSE', 'I', 45, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20046, 42, 'DEXTROSE', 'I', 45, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20040, 42, 'DEXTROSE', 'I', 67.5, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20041, 42, 'DEXTROSE', 'I', 90, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76953, 11980, 'LEFLUNOMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18268, 42, 'DEXTROSE', 'I', 90, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE (HEMODIALYSIS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18206, 42, 'DEXTROSE', 'I', 45, 'G', '', '', 'N', 'L', 'HISTORIC FREEFORM TEXT: DEXTROSE (HEMODIALYSIS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18202, 42, 'DEXTROSE', 'I', 90, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE (HEMODIALYSIS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18199, 42, 'DEXTROSE', 'I', 45, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE (HEMODIALYSIS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18200, 42, 'DEXTROSE', 'I', 45, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE (HEMODIALYSIS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18167, 42, 'DEXTROSE', 'I', 45, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10820, 42, 'DEXTROSE', 'I', 45, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE (HEMODIALYSIS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9854, 42, 'DEXTROSE', 'I', 67.5, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE (HEMODIALYSIS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9852, 42, 'DEXTROSE', 'I', 45.0, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE (HEMODIALYSIS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9848, 42, 'DEXTROSE', 'I', 45, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE (HEMODIALYSIS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9845, 42, 'DEXTROSE', 'I', 67.5, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE (HEMODIALYSIS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9131, 42, 'DEXTROSE', 'I', 89.99, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9130, 42, 'DEXTROSE', 'I', 89.99, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9129, 42, 'DEXTROSE', 'I', 89.99, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10114, 42, 'DEXTROSE', 'I', 67.54, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE (HEMODIALYSIS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10115, 42, 'DEXTROSE', 'I', 67.54, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE (HEMODIALYSIS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8585, 42, 'DEXTROSE', 'I', 67.54, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8586, 42, 'DEXTROSE', 'I', 67.5, 'G', '', '', 'N', 'L', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62960, 42, 'DEXTROSE', 'I', 90, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62965, 42, 'DEXTROSE', 'I', 90, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66299, 42, 'DEXTROSE', 'I', 90.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71993, 42, 'DEXTROSE', 'I', 37.5, 'G', '', '', 'N', 'L', 'ANHYDROUS GLUCOSE, AS GLUCOSE MONOHYDRATE 41.25G/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71997, 42, 'DEXTROSE', 'I', 62.6, 'G', '', '', 'N', 'L', 'GLUCOSE ANHYDROUS GLUCOSE MONOHYDRATE 68.85G/L. BAG A.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71998, 42, 'DEXTROSE', 'I', 105.5, 'G', '', '', 'N', 'L', 'GLUCOSE ANHYDROUS GLUCOSE MONOHYDRATE 117.14G/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73901, 42, 'DEXTROSE', 'I', 74.25, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73902, 42, 'DEXTROSE', 'I', 99.0, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73903, 42, 'DEXTROSE', 'I', 99.0, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73904, 42, 'DEXTROSE', 'I', 99.0, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73905, 42, 'DEXTROSE', 'I', 99.0, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73915, 42, 'DEXTROSE', 'I', 99.0, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73916, 42, 'DEXTROSE', 'I', 49.5, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73917, 42, 'DEXTROSE', 'I', 49.5, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73919, 42, 'DEXTROSE', 'I', 49.5, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73921, 42, 'DEXTROSE', 'I', 49.5, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73922, 42, 'DEXTROSE', 'I', 49.5, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73923, 42, 'DEXTROSE', 'I', 49.5, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73924, 42, 'DEXTROSE', 'I', 49.5, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73925, 42, 'DEXTROSE', 'I', 99.0, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73927, 42, 'DEXTROSE', 'I', 99.0, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81283, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73929, 42, 'DEXTROSE', 'I', 74.25, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75411, 42, 'DEXTROSE', 'I', 49.5, 'G', '', '', 'N', 'L', '(MONOHYDRATE). BEFORE DILUTION;EQUIVALENT TO 250MML/L. AFTER DILUTION: GLUCOSE: 5.55MMOL/L.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75804, 42, 'DEXTROSE', 'I', 49.5, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75805, 42, 'DEXTROSE', 'I', 49.5, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75811, 42, 'DEXTROSE', 'I', 49.5, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75812, 42, 'DEXTROSE', 'I', 49.5, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73193, 42, 'DEXTROSE', 'I', 99, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74647, 42, 'DEXTROSE', 'I', 16.5, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74648, 42, 'DEXTROSE', 'I', 46.75, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74649, 42, 'DEXTROSE', 'I', 25.0, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74785, 42, 'DEXTROSE', 'I', 99.0, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74787, 42, 'DEXTROSE', 'I', 49.5, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74790, 42, 'DEXTROSE', 'I', 99.0, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74791, 42, 'DEXTROSE', 'I', 74.25, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74792, 42, 'DEXTROSE', 'I', 74.25, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74793, 42, 'DEXTROSE', 'I', 74.25, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81573, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'DEXTROSE MONOHYDRATE. APPROVED BY BPS. 2009.07.13/KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81574, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'DEXTROSE MONOHYDRATE. APPROVED BY BPS. 2009.07.13/KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81576, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'DEXTROSE MONOHYDRATE. APPROVED BY BPS. 2009.07.13/KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81578, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'DEXTROSE MONOHYDRATE. APPROVED BY BPS. 2009.07.13/KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81236, 42, 'DEXTROSE', 'I', 74.28, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81237, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'DEXTROSE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81238, 42, 'DEXTROSE', 'I', 98.99, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81262, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'AS MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81265, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'AS MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81270, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'AS MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81271, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'AS MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81272, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'AS MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81577, 42, 'DEXTROSE', 'I', 74.28, 'G', '', '', 'N', 'L', 'AS DEXTROSE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81579, 42, 'DEXTROSE', 'I', 74.28, 'G', '', '', 'N', 'L', 'AS DEXTROSE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81580, 42, 'DEXTROSE', 'I', 74.28, 'G', '', '', 'N', 'L', 'AS DEXTROSE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81227, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'DEXTROSE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81224, 42, 'DEXTROSE', 'I', 74.28, 'G', '', '', 'N', 'L', 'DEXTROSE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81225, 42, 'DEXTROSE', 'I', 98.99, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81226, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'DEXTROSE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81280, 42, 'DEXTROSE', 'I', 98.99, 'G', '', '', 'N', 'L', 'AS MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81282, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'AS MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81592, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81593, 42, 'DEXTROSE', 'I', 98.99, 'G', '', '', 'N', 'L', 'DEXTROSE MONOHYDRATE AS PER REVIEW AREA./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81594, 42, 'DEXTROSE', 'I', 98.99, 'G', '', '', 'N', 'L', 'DEXTROSE MONOHYDRATE. APPROVED BY BPS. 2009.07.15/KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81595, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'DEXTROSE MONOHYDRATE. APPROVED BY BPS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81596, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81598, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81601, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81602, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81279, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'AS MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81281, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'AS MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81283, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'AS MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81284, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'AS MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81239, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'DEXTROSE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81240, 42, 'DEXTROSE', 'I', 98.99, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81241, 42, 'DEXTROSE', 'I', 74.28, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81242, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81275, 42, 'DEXTROSE', 'I', 49.49, 'G', '', '', 'N', 'L', 'AS MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80217, 42, 'DEXTROSE', 'I', 49.05, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80218, 42, 'DEXTROSE', 'I', 98.99, 'G', '', '', 'N', 'L', 'MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 42, 'DEXTROSE', 'I', 82.50, 'G', '', '', 'N', 'L', 'EQUIVALENT TO GLUCOSE ANHYDROUS 75.0 G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 42, 'DEXTROSE', 'I', 154, 'G', '', '', 'N', 'L', 'EQUIVALENT TO GLUCOSE ANHYDROUS 140 G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 42, 'DEXTROSE', 'I', 121, 'G', '', '', 'N', 'L', 'EQUIVALENT TO GLUCOSE ANHYDROUS 110 G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 42, 'DEXTROSE', 'I', 121, 'G', '', '', 'N', 'L', 'EQUIVALENT TO GLUCOSE ANHYDROUS 110 G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85140, 42, 'DEXTROSE', 'I', 49.5, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE. CONTENT BEFORE DILUTION. EQUIVALENT TO 249.7 MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85141, 42, 'DEXTROSE', 'I', 49.5, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE. CONTENT BEFORE DILUTION. EQUIVALENT TO 249.7 MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85142, 42, 'DEXTROSE', 'I', 49.5, 'G', '', '', 'N', 'L', 'GLUCOSE MONOHYDRATE. CONTENT BEFORE DILUTION. EQUIVALENT TO 249.7 MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15158, 42, 'DEXTROSE', 'I', 47.562, 'G', '', '80', 'N', 'G', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10527, 42, 'DEXTROSE', 'I', 31, 'G', '', '75', 'N', 'G', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12827, 42, 'DEXTROSE', 'I', 149.924, 'G', '', '184', 'N', 'G', 'HISTORIC FREEFORM TEXT: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10794, 42, 'DEXTROSE', 'I', 43.238, 'G', '', '73', 'N', 'G', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11333, 42, 'DEXTROSE', 'I', 152, 'G', '', '184', 'N', 'G', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65789, 42, 'DEXTROSE', 'I', 41.734, 'G', '', '76', 'N', 'G', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65790, 42, 'DEXTROSE', 'I', 149.04, 'G', '', '185', 'N', 'G', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76260, 42, 'DEXTROSE', 'I', 152.00, 'G', '', '184', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2043, 42, 'DEXTROSE', 'I', 660, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: DEXTROSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9588, 53, 'POTASSIUM CHLORIDE', 'I', 1.5, 'G', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE. 20MMOL(MEQ)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2479, 53, 'POTASSIUM CHLORIDE', 'I', 1.98, 'G', '', '', 'N', '', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2191, 53, 'POTASSIUM CHLORIDE', 'I', 1.98, 'G', '', '', 'N', '', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 53, 'POTASSIUM CHLORIDE', 'I', 1, 'G', '', '', 'N', '', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5975, 53, 'POTASSIUM CHLORIDE', 'I', 600, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4739, 53, 'POTASSIUM CHLORIDE', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (889, 53, 'POTASSIUM CHLORIDE', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15177, 53, 'POTASSIUM CHLORIDE', 'I', 0.075, '%', '', '', 'N', '', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7474, 53, 'POTASSIUM CHLORIDE', 'I', 0.075, '%', '', '', 'N', '', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6366, 53, 'POTASSIUM CHLORIDE', 'I', 0.075, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4913, 53, 'POTASSIUM CHLORIDE', 'I', 0.038, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3326, 53, 'POTASSIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', '', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4986, 53, 'POTASSIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2009, 53, 'POTASSIUM CHLORIDE', 'I', 84.46, '%', '', '', 'N', '%', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1979, 53, 'POTASSIUM CHLORIDE', 'I', 84.46, '%', '', '', 'N', '%', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33649, 53, 'POTASSIUM CHLORIDE', 'I', 0.74, 'G', '', '', 'N', 'PCK', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81284, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31465, 53, 'POTASSIUM CHLORIDE', 'I', 1.94, 'G', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9351, 53, 'POTASSIUM CHLORIDE', 'I', 3.05, 'G', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81164, 53, 'POTASSIUM CHLORIDE', 'I', 0.76, 'G', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84451, 53, 'POTASSIUM CHLORIDE', 'I', 1.015, 'G', '', '', 'N', 'PCK', 'SACHET A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23184, 53, 'POTASSIUM CHLORIDE', 'I', 2.46, 'G', '', '25', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78450, 53, 'POTASSIUM CHLORIDE', 'I', 0.15, 'G', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9833, 53, 'POTASSIUM CHLORIDE', 'I', 7.46, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76308, 53, 'POTASSIUM CHLORIDE', 'I', 0.157, 'G', '', '1000', 'N', 'ML', 'SOLUTION B (BUFFER).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76310, 53, 'POTASSIUM CHLORIDE', 'I', 0.314, 'G', '', '1000', 'N', 'ML', 'SOLUTION B (BUFFER).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78451, 53, 'POTASSIUM CHLORIDE', 'I', 0.3, 'G', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78452, 53, 'POTASSIUM CHLORIDE', 'I', 0.15, 'G', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78453, 53, 'POTASSIUM CHLORIDE', 'I', 0.3, 'G', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3394, 53, 'POTASSIUM CHLORIDE', 'I', 20, 'MEQ', '', '10', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 53, 'POTASSIUM CHLORIDE', 'I', 22, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 53, 'POTASSIUM CHLORIDE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23494, 53, 'POTASSIUM CHLORIDE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21767, 53, 'POTASSIUM CHLORIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21764, 53, 'POTASSIUM CHLORIDE', 'I', 120, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21753, 53, 'POTASSIUM CHLORIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21754, 53, 'POTASSIUM CHLORIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21755, 53, 'POTASSIUM CHLORIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21756, 53, 'POTASSIUM CHLORIDE', 'I', 15, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21757, 53, 'POTASSIUM CHLORIDE', 'I', 37, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21752, 53, 'POTASSIUM CHLORIDE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21713, 53, 'POTASSIUM CHLORIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21999, 53, 'POTASSIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21998, 53, 'POTASSIUM CHLORIDE', 'I', 37, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 53, 'POTASSIUM CHLORIDE', 'I', 22, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 53, 'POTASSIUM CHLORIDE', 'I', 22, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 53, 'POTASSIUM CHLORIDE', 'I', 97, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 53, 'POTASSIUM CHLORIDE', 'I', 97, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18991, 53, 'POTASSIUM CHLORIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 53, 'POTASSIUM CHLORIDE', 'I', 45, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18029, 53, 'POTASSIUM CHLORIDE', 'I', 0.75, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15227, 53, 'POTASSIUM CHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13034, 53, 'POTASSIUM CHLORIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14578, 53, 'POTASSIUM CHLORIDE', 'I', 97, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14250, 53, 'POTASSIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11330, 53, 'POTASSIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11197, 53, 'POTASSIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10936, 53, 'POTASSIUM CHLORIDE', 'I', 179, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10937, 53, 'POTASSIUM CHLORIDE', 'I', 328, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10938, 53, 'POTASSIUM CHLORIDE', 'I', 75, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10939, 53, 'POTASSIUM CHLORIDE', 'I', 40, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10929, 53, 'POTASSIUM CHLORIDE', 'I', 75, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10930, 53, 'POTASSIUM CHLORIDE', 'I', 224, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10931, 53, 'POTASSIUM CHLORIDE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10932, 53, 'POTASSIUM CHLORIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10933, 53, 'POTASSIUM CHLORIDE', 'I', 224, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12741, 53, 'POTASSIUM CHLORIDE', 'I', 37, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12186, 53, 'POTASSIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10934, 53, 'POTASSIUM CHLORIDE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10935, 53, 'POTASSIUM CHLORIDE', 'I', 224, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10927, 53, 'POTASSIUM CHLORIDE', 'I', 75, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10928, 53, 'POTASSIUM CHLORIDE', 'I', 224, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10866, 53, 'POTASSIUM CHLORIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10867, 53, 'POTASSIUM CHLORIDE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10862, 53, 'POTASSIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11905, 53, 'POTASSIUM CHLORIDE', 'I', 0.45, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9830, 53, 'POTASSIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9826, 53, 'POTASSIUM CHLORIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9827, 53, 'POTASSIUM CHLORIDE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8169, 53, 'POTASSIUM CHLORIDE', 'I', 0.75, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8601, 53, 'POTASSIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10041, 53, 'POTASSIUM CHLORIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10042, 53, 'POTASSIUM CHLORIDE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10043, 53, 'POTASSIUM CHLORIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10044, 53, 'POTASSIUM CHLORIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10045, 53, 'POTASSIUM CHLORIDE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 53, 'POTASSIUM CHLORIDE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5373, 53, 'POTASSIUM CHLORIDE', 'I', 0.747, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81239, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5950, 53, 'POTASSIUM CHLORIDE', 'I', 1.193, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6400, 53, 'POTASSIUM CHLORIDE', 'I', 3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6360, 53, 'POTASSIUM CHLORIDE', 'I', 0.75, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6228, 53, 'POTASSIUM CHLORIDE', 'I', 3.0, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5535, 53, 'POTASSIUM CHLORIDE', 'I', 74.55, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 53, 'POTASSIUM CHLORIDE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3820, 53, 'POTASSIUM CHLORIDE', 'I', 239, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3132, 53, 'POTASSIUM CHLORIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3133, 53, 'POTASSIUM CHLORIDE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3534, 53, 'POTASSIUM CHLORIDE', 'I', 1.49, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3535, 53, 'POTASSIUM CHLORIDE', 'I', 1.49, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3536, 53, 'POTASSIUM CHLORIDE', 'I', 1.49, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3537, 53, 'POTASSIUM CHLORIDE', 'I', 2.98, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3538, 53, 'POTASSIUM CHLORIDE', 'I', 1.49, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 53, 'POTASSIUM CHLORIDE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 53, 'POTASSIUM CHLORIDE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2527, 53, 'POTASSIUM CHLORIDE', 'I', 149, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1749, 53, 'POTASSIUM CHLORIDE', 'I', 0.3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1738, 53, 'POTASSIUM CHLORIDE', 'I', 0.37, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1745, 53, 'POTASSIUM CHLORIDE', 'I', 0.3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1737, 53, 'POTASSIUM CHLORIDE', 'I', 0.37, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1673, 53, 'POTASSIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1623, 53, 'POTASSIUM CHLORIDE', 'I', 37, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1628, 53, 'POTASSIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1622, 53, 'POTASSIUM CHLORIDE', 'I', 37, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (745, 53, 'POTASSIUM CHLORIDE', 'I', 0.3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65337, 53, 'POTASSIUM CHLORIDE', 'I', 14.9, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65339, 53, 'POTASSIUM CHLORIDE', 'I', 29.8, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65336, 53, 'POTASSIUM CHLORIDE', 'I', 7.46, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67329, 53, 'POTASSIUM CHLORIDE', 'I', 179, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70277, 53, 'POTASSIUM CHLORIDE', 'I', 328, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75479, 53, 'POTASSIUM CHLORIDE', 'I', 150, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82495, 53, 'POTASSIUM CHLORIDE', 'I', 37, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36836, 53, 'POTASSIUM CHLORIDE', 'I', 10.06, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36814, 53, 'POTASSIUM CHLORIDE', 'I', 8.39, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34878, 53, 'POTASSIUM CHLORIDE', 'I', 6.7, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34881, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19744, 53, 'POTASSIUM CHLORIDE', 'I', 5.02, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20121, 53, 'POTASSIUM CHLORIDE', 'I', 6.7, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20116, 53, 'POTASSIUM CHLORIDE', 'I', 6.7, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20118, 53, 'POTASSIUM CHLORIDE', 'I', 6.7, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20119, 53, 'POTASSIUM CHLORIDE', 'I', 6.7, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20111, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20114, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20115, 53, 'POTASSIUM CHLORIDE', 'I', 5.02, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19739, 53, 'POTASSIUM CHLORIDE', 'I', 10.06, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19735, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20044, 53, 'POTASSIUM CHLORIDE', 'I', 10, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20045, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20046, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20040, 53, 'POTASSIUM CHLORIDE', 'I', 6.7, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20041, 53, 'POTASSIUM CHLORIDE', 'I', 10, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18268, 53, 'POTASSIUM CHLORIDE', 'I', 6.7, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18206, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18202, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18199, 53, 'POTASSIUM CHLORIDE', 'I', 5.02, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18200, 53, 'POTASSIUM CHLORIDE', 'I', 5.02, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13833, 53, 'POTASSIUM CHLORIDE', 'I', 251.6, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10820, 53, 'POTASSIUM CHLORIDE', 'I', 10.05, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9854, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9852, 53, 'POTASSIUM CHLORIDE', 'I', 10.1, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9131, 53, 'POTASSIUM CHLORIDE', 'I', 10.06, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9129, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9130, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10115, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8586, 53, 'POTASSIUM CHLORIDE', 'I', 10.06, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8585, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6370, 53, 'POTASSIUM CHLORIDE', 'I', 2.97, 'G', '', '4', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49559, 53, 'POTASSIUM CHLORIDE', 'I', 0.298, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49560, 53, 'POTASSIUM CHLORIDE', 'I', 0.149, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62960, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62964, 53, 'POTASSIUM CHLORIDE', 'I', 10.1, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62965, 53, 'POTASSIUM CHLORIDE', 'I', 10.1, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63009, 53, 'POTASSIUM CHLORIDE', 'I', 0.3, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66299, 53, 'POTASSIUM CHLORIDE', 'I', 13.42, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73902, 53, 'POTASSIUM CHLORIDE', 'I', 10.1, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73903, 53, 'POTASSIUM CHLORIDE', 'I', 5.02, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73904, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73905, 53, 'POTASSIUM CHLORIDE', 'I', 5.02, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73915, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73916, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73917, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73919, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73921, 53, 'POTASSIUM CHLORIDE', 'I', 10.1, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73922, 53, 'POTASSIUM CHLORIDE', 'I', 10.1, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73923, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73924, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73925, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73927, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73929, 53, 'POTASSIUM CHLORIDE', 'I', 5.02, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75411, 53, 'POTASSIUM CHLORIDE', 'I', 13.47, 'G', '', '', 'N', 'L', 'BEFORE DILUTION; EQUIVALENT TO 180MMOL/L. AFTER DILUTION: POTASSIUM: 4MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75811, 53, 'POTASSIUM CHLORIDE', 'I', 6.70, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75812, 53, 'POTASSIUM CHLORIDE', 'I', 6.70, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73193, 53, 'POTASSIUM CHLORIDE', 'I', 10.1, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74785, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74787, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74790, 53, 'POTASSIUM CHLORIDE', 'I', 10.1, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74791, 53, 'POTASSIUM CHLORIDE', 'I', 10.1, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74792, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74793, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78012, 53, 'POTASSIUM CHLORIDE', 'I', 0.398, 'G', '', '', 'N', 'L', 'LARGE COMPARTMENT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81573, 53, 'POTASSIUM CHLORIDE', 'I', 3.36, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81574, 53, 'POTASSIUM CHLORIDE', 'I', 5.03, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81578, 53, 'POTASSIUM CHLORIDE', 'I', 3.36, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81236, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81237, 53, 'POTASSIUM CHLORIDE', 'I', 5.03, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81238, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81262, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81265, 53, 'POTASSIUM CHLORIDE', 'I', 10.06, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81270, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81271, 53, 'POTASSIUM CHLORIDE', 'I', 3.355, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81272, 53, 'POTASSIUM CHLORIDE', 'I', 8.39, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81577, 53, 'POTASSIUM CHLORIDE', 'I', 10.06, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81579, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81580, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81227, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81225, 53, 'POTASSIUM CHLORIDE', 'I', 10.06, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81280, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81282, 53, 'POTASSIUM CHLORIDE', 'I', 10.06, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81592, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81593, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81594, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81595, 53, 'POTASSIUM CHLORIDE', 'I', 10.06, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81596, 53, 'POTASSIUM CHLORIDE', 'I', 3.36, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81598, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81600, 53, 'POTASSIUM CHLORIDE', 'I', 5.03, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81601, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81602, 53, 'POTASSIUM CHLORIDE', 'I', 3.36, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81279, 53, 'POTASSIUM CHLORIDE', 'I', 3.36, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81281, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81283, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81284, 53, 'POTASSIUM CHLORIDE', 'I', 10.06, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81240, 53, 'POTASSIUM CHLORIDE', 'I', 10.06, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81241, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81275, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80217, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80218, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81222, 53, 'POTASSIUM CHLORIDE', 'I', 8.39, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 53, 'POTASSIUM CHLORIDE', 'I', 1.19, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 53, 'POTASSIUM CHLORIDE', 'I', 2.24, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 53, 'POTASSIUM CHLORIDE', 'I', 2.24, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85140, 53, 'POTASSIUM CHLORIDE', 'I', 3.35, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85141, 53, 'POTASSIUM CHLORIDE', 'I', 6.71, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85142, 53, 'POTASSIUM CHLORIDE', 'I', 10.1, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9631, 53, 'POTASSIUM CHLORIDE', 'I', 760, 'MG', '', '', 'N', 'L', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7143, 53, 'POTASSIUM CHLORIDE', 'I', 300, 'MG', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5663, 53, 'POTASSIUM CHLORIDE', 'I', 300, 'MG', '', '', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 53, 'POTASSIUM CHLORIDE', 'I', 1.15, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36843, 53, 'POTASSIUM CHLORIDE', 'I', 14.28, 'G', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: POTASSIUM CHLORIDE ((POTASSIUM EQ.7.48G))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17818, 53, 'POTASSIUM CHLORIDE', 'I', 14.28, 'G', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: K ((AS CHLORIDE 14.28GM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 53, 'POTASSIUM CHLORIDE', 'I', 12.49, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14119, 53, 'POTASSIUM CHLORIDE', 'I', 5.4, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14113, 53, 'POTASSIUM CHLORIDE', 'I', 4.25, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15158, 53, 'POTASSIUM CHLORIDE', 'I', 1.491, 'G', '', '80', 'N', 'G', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14253, 53, 'POTASSIUM CHLORIDE', 'I', 8.47, 'G', '', '200', 'N', 'G', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10527, 53, 'POTASSIUM CHLORIDE', 'I', 4, 'G', '', '75', 'N', 'G', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12827, 53, 'POTASSIUM CHLORIDE', 'I', 1.491, 'G', '', '184', 'N', 'G', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10794, 53, 'POTASSIUM CHLORIDE', 'I', 1.491, 'G', '', '73', 'N', 'G', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11333, 53, 'POTASSIUM CHLORIDE', 'I', 1.491, 'G', '', '184', 'N', 'G', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8523, 53, 'POTASSIUM CHLORIDE', 'I', 30.76, 'G', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64039, 53, 'POTASSIUM CHLORIDE', 'I', 2.7, 'G', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65789, 53, 'POTASSIUM CHLORIDE', 'I', 1.940, 'G', '', '76', 'N', 'G', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65790, 53, 'POTASSIUM CHLORIDE', 'I', 1.940, 'G', '', '185', 'N', 'G', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66865, 53, 'POTASSIUM CHLORIDE', 'I', 38, 'G', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76260, 53, 'POTASSIUM CHLORIDE', 'I', 1.491, 'G', '', '184', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33790, 53, 'POTASSIUM CHLORIDE', 'I', 38.46, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: POTASSIUM CHLORIDE ((POTASSIUM EQ. 20 MG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14165, 53, 'POTASSIUM CHLORIDE', 'I', 250, 'MG', '', '450', 'N', 'G', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15001, 53, 'POTASSIUM CHLORIDE', 'I', 38.46, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: KCL ((K EQ. 20MG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8101, 53, 'POTASSIUM CHLORIDE', 'I', 220, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6616, 53, 'POTASSIUM CHLORIDE', 'I', 10.65, 'MG', '', '', 'N', 'G', 'LABEL HAS 2.98G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5322, 53, 'POTASSIUM CHLORIDE', 'I', 0.5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3926, 53, 'POTASSIUM CHLORIDE', 'I', 250, 'MG', '', '450', 'N', 'G', 'Historic Freeform Text: POTASSIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47888, 53, 'POTASSIUM CHLORIDE', 'I', 114, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24471, 53, 'POTASSIUM CHLORIDE', 'I', 2.5, '%', '', '170', 'N', 'G', 'Historic Freeform Text: POTASSIUM CHLORIDE ((K EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2479, 55, 'SODIUM CHLORIDE', 'I', 2.5872, 'G', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2191, 55, 'SODIUM CHLORIDE', 'I', 2.5872, 'G', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 55, 'SODIUM CHLORIDE', 'I', 2, 'G', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15809, 55, 'SODIUM CHLORIDE', 'I', 209, 'MG', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15808, 55, 'SODIUM CHLORIDE', 'I', 209, 'MG', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5698, 55, 'SODIUM CHLORIDE', 'I', 345, 'MG', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6202, 55, 'SODIUM CHLORIDE', 'I', 209, 'MG', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50130, 55, 'SODIUM CHLORIDE', 'I', 73.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66863, 55, 'SODIUM CHLORIDE', 'I', 209, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16264, 55, 'SODIUM CHLORIDE', 'I', 115, 'ML', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21686, 55, 'SODIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18738, 55, 'SODIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18743, 55, 'SODIUM CHLORIDE', 'I', 0.45, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17778, 55, 'SODIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15177, 55, 'SODIUM CHLORIDE', 'I', 0.64, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16829, 55, 'SODIUM CHLORIDE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16830, 55, 'SODIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13286, 55, 'SODIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14249, 55, 'SODIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11116, 55, 'SODIUM CHLORIDE', 'I', 0.44, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12185, 55, 'SODIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7474, 55, 'SODIUM CHLORIDE', 'I', 0.64, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6366, 55, 'SODIUM CHLORIDE', 'I', 0.64, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4913, 55, 'SODIUM CHLORIDE', 'I', 0.714, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4986, 55, 'SODIUM CHLORIDE', 'I', 9, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1385, 55, 'SODIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1911, 55, 'SODIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1912, 55, 'SODIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1743, 55, 'SODIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75292, 55, 'SODIUM CHLORIDE (DILUENT)', 'I', 0.9, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83557, 55, 'SODIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79733, 55, 'SODIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', 'W/V', '900MG/100ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10923, 55, 'SODIUM CHLORIDE', 'I', 5, 'ML', '', '', 'N', 'VIAL', 'DILUENT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19030, 55, 'SODIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', 'VIAL', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16878, 55, 'SODIUM CHLORIDE', 'I', 0.9, '%', '', '', 'N', 'VIAL', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7388, 55, 'SODIUM CHLORIDE', 'I', 10, '%', '', '', 'N', '%', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33649, 55, 'SODIUM CHLORIDE', 'I', 1.46, 'G', '', '', 'N', 'PCK', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31465, 55, 'SODIUM CHLORIDE', 'I', 3.507, 'G', '', '', 'N', 'PCK', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9351, 55, 'SODIUM CHLORIDE', 'I', 5.85, 'G', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81164, 55, 'SODIUM CHLORIDE', 'I', 1.46, 'G', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84451, 55, 'SODIUM CHLORIDE', 'I', 2.691, 'G', '', '', 'N', 'PCK', 'SACHET A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36695, 55, 'SODIUM CHLORIDE', 'I', 2.75, 'G', '', '30', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78450, 55, 'SODIUM CHLORIDE', 'I', 0.9, 'G', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21691, 55, 'SODIUM CHLORIDE', 'I', 1.17, 'G', '', '20', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15492, 55, 'SODIUM CHLORIDE', 'I', 5, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11039, 55, 'SODIUM CHLORIDE', 'I', 3, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11040, 55, 'SODIUM CHLORIDE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12168, 55, 'SODIUM CHLORIDE', 'I', 12, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12169, 55, 'SODIUM CHLORIDE', 'I', 1.6, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9833, 55, 'SODIUM CHLORIDE', 'I', 7.31, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7141, 55, 'SODIUM CHLORIDE', 'I', 5.5, 'G', '', '1000', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7142, 55, 'SODIUM CHLORIDE', 'I', 4.5, 'G', '', '500', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6565, 55, 'SODIUM CHLORIDE', 'I', 4.5, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3407, 55, 'SODIUM CHLORIDE', 'I', 5.9, 'G', '', '60', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2002, 55, 'SODIUM CHLORIDE', 'I', 4.59, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1615, 55, 'SODIUM CHLORIDE', 'I', 4.59, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70916, 55, 'SODIUM CHLORIDE', 'I', 5.38, 'G', '', '1000', 'N', 'ML', 'COMPARTMENT A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70916, 55, 'SODIUM CHLORIDE', 'I', 5.38, 'G', '', '1000', 'N', 'ML', 'COMPARTMENT B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70916, 55, 'SODIUM CHLORIDE', 'I', 5.38, 'G', '', '1000', 'N', 'ML', 'COMPARTMENT C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70917, 55, 'SODIUM CHLORIDE', 'I', 5.38, 'G', '', '1000', 'N', 'ML', 'COMPARTMENT A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70917, 55, 'SODIUM CHLORIDE', 'I', 5.38, 'G', '', '1000', 'N', 'ML', 'COMPARTMENT B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70917, 55, 'SODIUM CHLORIDE', 'I', 5.38, 'G', '', '1000', 'N', 'ML', 'COMPARTMENT C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76040, 55, 'SODIUM CHLORIDE', 'I', 6.449, 'G', '', '1000', 'N', 'ML', 'COMPARTMENT B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76308, 55, 'SODIUM CHLORIDE', 'I', 6.450, 'G', '', '1000', 'N', 'ML', 'SOLUTION B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76310, 55, 'SODIUM CHLORIDE', 'I', 6.450, 'G', '', '1000', 'N', 'ML', 'SOLUTION B (BUFFER).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78451, 55, 'SODIUM CHLORIDE', 'I', 0.9, 'G', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78452, 55, 'SODIUM CHLORIDE', 'I', 0.9, 'G', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78453, 55, 'SODIUM CHLORIDE', 'I', 0.9, 'G', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66962, 55, 'SODIUM CHLORIDE', 'I', 6.45, 'G', '', '1000', 'N', 'ML', 'COMPARTMENT B ACTIVE CHANGED FROM 6.14G TO 6.45G APPROVED BY BPS CONTROL NO. 117439. EW');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 55, 'SODIUM CHLORIDE', 'I', 205, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21767, 55, 'SODIUM CHLORIDE', 'I', 91, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21764, 55, 'SODIUM CHLORIDE', 'I', 88, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21753, 55, 'SODIUM CHLORIDE', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21754, 55, 'SODIUM CHLORIDE', 'I', 330, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21755, 55, 'SODIUM CHLORIDE', 'I', 900, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21756, 55, 'SODIUM CHLORIDE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21757, 55, 'SODIUM CHLORIDE', 'I', 530, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21752, 55, 'SODIUM CHLORIDE', 'I', 450, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21715, 55, 'SODIUM CHLORIDE', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21999, 55, 'SODIUM CHLORIDE', 'I', 860, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21993, 55, 'SODIUM CHLORIDE', 'I', 900, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21998, 55, 'SODIUM CHLORIDE', 'I', 530, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 55, 'SODIUM CHLORIDE', 'I', 77, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 55, 'SODIUM CHLORIDE', 'I', 77, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 55, 'SODIUM CHLORIDE', 'I', 58.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 55, 'SODIUM CHLORIDE', 'I', 58.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 55, 'SODIUM CHLORIDE', 'I', 29.3, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 55, 'SODIUM CHLORIDE', 'I', 58.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 55, 'SODIUM CHLORIDE', 'I', 58.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 55, 'SODIUM CHLORIDE', 'I', 205, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 55, 'SODIUM CHLORIDE', 'I', 205, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 55, 'SODIUM CHLORIDE', 'I', 120, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 55, 'SODIUM CHLORIDE', 'I', 120, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18991, 55, 'SODIUM CHLORIDE', 'I', 450, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18937, 55, 'SODIUM CHLORIDE', 'I', 234, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 55, 'SODIUM CHLORIDE', 'I', 410, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18136, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18029, 55, 'SODIUM CHLORIDE', 'I', 6.4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17227, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 55, 'SODIUM CHLORIDE', 'I', 58.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15772, 55, 'SODIUM CHLORIDE', 'I', 538, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15778, 55, 'SODIUM CHLORIDE', 'I', 567, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15769, 55, 'SODIUM CHLORIDE', 'I', 538, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15768, 55, 'SODIUM CHLORIDE', 'I', 538, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15763, 55, 'SODIUM CHLORIDE', 'I', 567, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15764, 55, 'SODIUM CHLORIDE', 'I', 567, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13033, 55, 'SODIUM CHLORIDE', 'I', 450, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13034, 55, 'SODIUM CHLORIDE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 55, 'SODIUM CHLORIDE', 'I', 58.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 55, 'SODIUM CHLORIDE', 'I', 58.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 55, 'SODIUM CHLORIDE', 'I', 77, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 55, 'SODIUM CHLORIDE', 'I', 29.3, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 55, 'SODIUM CHLORIDE', 'I', 58.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 55, 'SODIUM CHLORIDE', 'I', 77, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14578, 55, 'SODIUM CHLORIDE', 'I', 140, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14579, 55, 'SODIUM CHLORIDE', 'I', 4.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13288, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14250, 55, 'SODIUM CHLORIDE', 'I', 600, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14183, 55, 'SODIUM CHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10521, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10515, 55, 'SODIUM CHLORIDE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10512, 55, 'SODIUM CHLORIDE', 'I', 567, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11232, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11197, 55, 'SODIUM CHLORIDE', 'I', 600, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10438, 55, 'SODIUM CHLORIDE', 'I', 200, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10439, 55, 'SODIUM CHLORIDE', 'I', 450, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10440, 55, 'SODIUM CHLORIDE', 'I', 900, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10441, 55, 'SODIUM CHLORIDE', 'I', 900, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10442, 55, 'SODIUM CHLORIDE', 'I', 450, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11038, 55, 'SODIUM CHLORIDE', 'I', 234, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12711, 55, 'SODIUM CHLORIDE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10936, 55, 'SODIUM CHLORIDE', 'I', 600, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10937, 55, 'SODIUM CHLORIDE', 'I', 600, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10938, 55, 'SODIUM CHLORIDE', 'I', 450, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10939, 55, 'SODIUM CHLORIDE', 'I', 800, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10929, 55, 'SODIUM CHLORIDE', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10930, 55, 'SODIUM CHLORIDE', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10931, 55, 'SODIUM CHLORIDE', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10932, 55, 'SODIUM CHLORIDE', 'I', 330, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10933, 55, 'SODIUM CHLORIDE', 'I', 330, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12787, 55, 'SODIUM CHLORIDE', 'I', 900, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12741, 55, 'SODIUM CHLORIDE', 'I', 530, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12186, 55, 'SODIUM CHLORIDE', 'I', 600, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12171, 55, 'SODIUM CHLORIDE', 'I', 900, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10934, 55, 'SODIUM CHLORIDE', 'I', 330, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10935, 55, 'SODIUM CHLORIDE', 'I', 450, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10925, 55, 'SODIUM CHLORIDE', 'I', 450, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10926, 55, 'SODIUM CHLORIDE', 'I', 330, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12674, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12675, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10866, 55, 'SODIUM CHLORIDE', 'I', 900, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10867, 55, 'SODIUM CHLORIDE', 'I', 900, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10861, 55, 'SODIUM CHLORIDE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10862, 55, 'SODIUM CHLORIDE', 'I', 860, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10863, 55, 'SODIUM CHLORIDE', 'I', 538, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10864, 55, 'SODIUM CHLORIDE', 'I', 538, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10865, 55, 'SODIUM CHLORIDE', 'I', 538, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11905, 55, 'SODIUM CHLORIDE', 'I', 3.51, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9830, 55, 'SODIUM CHLORIDE', 'I', 600, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9825, 55, 'SODIUM CHLORIDE', 'I', 900, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9826, 55, 'SODIUM CHLORIDE', 'I', 900, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9827, 55, 'SODIUM CHLORIDE', 'I', 900, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8276, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10143, 55, 'SODIUM CHLORIDE', 'I', 567, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10144, 55, 'SODIUM CHLORIDE', 'I', 567, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8169, 55, 'SODIUM CHLORIDE', 'I', 6.4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8601, 55, 'SODIUM CHLORIDE', 'I', 600, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10009, 55, 'SODIUM CHLORIDE', 'I', 567, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10040, 55, 'SODIUM CHLORIDE', 'I', 900, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10043, 55, 'SODIUM CHLORIDE', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10044, 55, 'SODIUM CHLORIDE', 'I', 450, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81595, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10045, 55, 'SODIUM CHLORIDE', 'I', 450, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5984, 55, 'SODIUM CHLORIDE', 'I', 4.4, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5373, 55, 'SODIUM CHLORIDE', 'I', 4.853, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5950, 55, 'SODIUM CHLORIDE', 'I', 6.43, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 55, 'SODIUM CHLORIDE', 'I', 410, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6360, 55, 'SODIUM CHLORIDE', 'I', 6.4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6228, 55, 'SODIUM CHLORIDE', 'I', 4.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78963, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', '0.3MOSM/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5535, 55, 'SODIUM CHLORIDE', 'I', 16.05, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3820, 55, 'SODIUM CHLORIDE', 'I', 374, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3132, 55, 'SODIUM CHLORIDE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3133, 55, 'SODIUM CHLORIDE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4792, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: WATER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4092, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3534, 55, 'SODIUM CHLORIDE', 'I', 4.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3535, 55, 'SODIUM CHLORIDE', 'I', 2.25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3537, 55, 'SODIUM CHLORIDE', 'I', 3.00, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3538, 55, 'SODIUM CHLORIDE', 'I', 3.0, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3395, 55, 'SODIUM CHLORIDE', 'I', 234, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3396, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2575, 55, 'SODIUM CHLORIDE', 'I', 3.0, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 55, 'SODIUM CHLORIDE', 'I', 117, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1848, 55, 'SODIUM CHLORIDE', 'I', 146, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1239, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1750, 55, 'SODIUM CHLORIDE', 'I', 4.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1751, 55, 'SODIUM CHLORIDE', 'I', 2.25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1739, 55, 'SODIUM CHLORIDE', 'I', 2.34, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1745, 55, 'SODIUM CHLORIDE', 'I', 6, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1747, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1749, 55, 'SODIUM CHLORIDE', 'I', 6.0, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1733, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1735, 55, 'SODIUM CHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1736, 55, 'SODIUM CHLORIDE', 'I', 4.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1737, 55, 'SODIUM CHLORIDE', 'I', 5.26, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1738, 55, 'SODIUM CHLORIDE', 'I', 5.26, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3009, 55, 'SODIUM CHLORIDE', 'I', 234, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1673, 55, 'SODIUM CHLORIDE', 'I', 600, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1628, 55, 'SODIUM CHLORIDE', 'I', 600, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1622, 55, 'SODIUM CHLORIDE', 'I', 526, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1623, 55, 'SODIUM CHLORIDE', 'I', 526, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1548, 55, 'SODIUM CHLORIDE', 'I', 3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (817, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (745, 55, 'SODIUM CHLORIDE', 'I', 8.6, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (228, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (115, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 55, 'SODIUM CHLORIDE', 'I', 538, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67329, 55, 'SODIUM CHLORIDE', 'I', 600, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70277, 55, 'SODIUM CHLORIDE', 'I', 600, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76534, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75293, 55, 'SODIUM CHLORIDE (DILUENT)', 'I', 9, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75479, 55, 'SODIUM CHLORIDE', 'I', 450, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82495, 55, 'SODIUM CHLORIDE', 'I', 526, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78504, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'ML', '(USP)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11439, 55, 'SODIUM CHLORIDE (DILUENT)', 'I', 9, 'MG', '', '', 'N', 'ML', '20 ML OF BACTEROISTATIC SODIUM CHLORIDE FOR INJECTION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36836, 55, 'SODIUM CHLORIDE', 'I', 262.98, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81240, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36814, 55, 'SODIUM CHLORIDE', 'I', 262.98, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34878, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34879, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34881, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19744, 55, 'SODIUM CHLORIDE', 'I', 275, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20121, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20116, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20118, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20119, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20111, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20114, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20115, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19739, 55, 'SODIUM CHLORIDE', 'I', 275, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19735, 55, 'SODIUM CHLORIDE', 'I', 268.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20076, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20044, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20045, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20046, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20040, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20041, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18268, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18206, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18202, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18199, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18200, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18167, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10820, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9854, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9852, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9848, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9845, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9131, 55, 'SODIUM CHLORIDE', 'I', 268.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9129, 55, 'SODIUM CHLORIDE', 'I', 268.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9130, 55, 'SODIUM CHLORIDE', 'I', 268.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9631, 55, 'SODIUM CHLORIDE', 'I', 1.46, 'G', '', '', 'N', 'L', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10115, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10114, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8586, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8585, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7143, 55, 'SODIUM CHLORIDE', 'I', 6, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6370, 55, 'SODIUM CHLORIDE', 'I', 5.86, 'G', '', '4', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5663, 55, 'SODIUM CHLORIDE', 'I', 6, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (129, 55, 'SODIUM CHLORIDE', 'I', 908, 'G', '', '81.6', 'N', 'L', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49558, 55, 'SODIUM CHLORIDE', 'I', 5.844, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49559, 55, 'SODIUM CHLORIDE', 'I', 5.844, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49560, 55, 'SODIUM CHLORIDE', 'I', 5.961, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64397, 55, 'SODIUM CHLORIDE', 'I', 5.4, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62960, 55, 'SODIUM CHLORIDE', 'I', 268, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62964, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62965, 55, 'SODIUM CHLORIDE', 'I', 268, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63009, 55, 'SODIUM CHLORIDE', 'I', 6.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66299, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67542, 55, 'SODIUM CHLORIDE', 'I', 82.84, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71993, 55, 'SODIUM CHLORIDE', 'I', 8.43, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71997, 55, 'SODIUM CHLORIDE', 'I', 8.43, 'G', '', '', 'N', 'L', 'BAG B.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71998, 55, 'SODIUM CHLORIDE', 'I', 8.43, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73901, 55, 'SODIUM CHLORIDE', 'I', 275.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73902, 55, 'SODIUM CHLORIDE', 'I', 268.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73903, 55, 'SODIUM CHLORIDE', 'I', 275.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73904, 55, 'SODIUM CHLORIDE', 'I', 275.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73905, 55, 'SODIUM CHLORIDE', 'I', 275.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73915, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73916, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73917, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73919, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73921, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73922, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73923, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73924, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73925, 55, 'SODIUM CHLORIDE', 'I', 268.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73927, 55, 'SODIUM CHLORIDE', 'I', 268.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73929, 55, 'SODIUM CHLORIDE', 'I', 275.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75411, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', 'BEFORE DILUTION; EQUIVALENT TO 4500MMOL/L. AFTER DILUTION: SODIUM: 100MMOL/L TOTAL CHLORIDE AFTER DI');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75804, 55, 'SODIUM CHLORIDE', 'I', 289.3, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75805, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75811, 55, 'SODIUM CHLORIDE', 'I', 289.3, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75812, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73193, 55, 'SODIUM CHLORIDE', 'I', 275, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74647, 55, 'SODIUM CHLORIDE', 'I', 5.640, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74648, 55, 'SODIUM CHLORIDE', 'I', 5.640, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74649, 55, 'SODIUM CHLORIDE', 'I', 5.640, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74785, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74787, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74790, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74791, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74792, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74793, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76226, 55, 'SODIUM CHLORIDE', 'I', 90.73, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78010, 55, 'SODIUM CHLORIDE', 'I', 7.66, 'G', '', '', 'N', 'L', 'LARGE COMPARTMENT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78012, 55, 'SODIUM CHLORIDE', 'I', 7.66, 'G', '', '', 'N', 'L', 'LARGE COMPARTMENT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81573, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81574, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81576, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81578, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81236, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81237, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81238, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81262, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81265, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81270, 55, 'SODIUM CHLORIDE', 'I', 289.3, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81271, 55, 'SODIUM CHLORIDE', 'I', 262.99, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81272, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81577, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81579, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81580, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81227, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81224, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81225, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81226, 55, 'SODIUM CHLORIDE', 'I', 289.3, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81280, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81282, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81592, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81593, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81594, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81596, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81598, 55, 'SODIUM CHLORIDE', 'I', 289.3, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81600, 55, 'SODIUM CHLORIDE', 'I', 276.1, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81601, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81602, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81279, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81281, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81283, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81284, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81239, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81240, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81241, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81242, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81275, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80217, 55, 'SODIUM CHLORIDE', 'I', 263.0, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80218, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81222, 55, 'SODIUM CHLORIDE', 'I', 273.5, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85140, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'CONTENT BEFORE DILUTION. EQUIVALENT TO 4500.3MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85141, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'CONTENT BEFORE DILUTION. EQUIVALENT TO 4500.3MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85142, 55, 'SODIUM CHLORIDE', 'I', 263, 'G', '', '', 'N', 'L', 'CONTENT BEFORE DILUTION. EQUIVALENT TO 4500.3MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43833, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'KIT', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43151, 55, 'SODIUM CHLORIDE', 'I', 5, 'ML', '', '', 'N', 'KIT', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE ((BACTERIOS.INJ,10ML/VIAL))  CORRECTION TO THE VOLUME OF DIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 55, 'SODIUM CHLORIDE', 'I', 17.77, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36843, 55, 'SODIUM CHLORIDE', 'I', 277.71, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17818, 55, 'SODIUM CHLORIDE', 'I', 277.71, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17121, 55, 'SODIUM CHLORIDE', 'I', 277.71, 'G', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 55, 'SODIUM CHLORIDE', 'I', 49.3, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14165, 55, 'SODIUM CHLORIDE', 'I', 3.15, 'G', '', '450', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14119, 55, 'SODIUM CHLORIDE', 'I', 39.4, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14113, 55, 'SODIUM CHLORIDE', 'I', 1.7, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15158, 55, 'SODIUM CHLORIDE', 'I', 4.675, 'G', '', '80', 'N', 'G', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14253, 55, 'SODIUM CHLORIDE', 'I', 41.52, 'G', '', '200', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10527, 55, 'SODIUM CHLORIDE', 'I', 9, 'G', '', '75', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12827, 55, 'SODIUM CHLORIDE', 'I', 4.675, 'G', '', '184', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10794, 55, 'SODIUM CHLORIDE', 'I', 4.675, 'G', '', '73', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11333, 55, 'SODIUM CHLORIDE', 'I', 4.675, 'G', '', '184', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8101, 55, 'SODIUM CHLORIDE', 'I', 2.8, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8523, 55, 'SODIUM CHLORIDE', 'I', 218.44, 'G', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3926, 55, 'SODIUM CHLORIDE', 'I', 3.15, 'G', '', '450', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65789, 55, 'SODIUM CHLORIDE', 'I', 3.507, 'G', '', '76', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65790, 55, 'SODIUM CHLORIDE', 'I', 3.507, 'G', '', '185', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76260, 55, 'SODIUM CHLORIDE', 'I', 4.675, 'G', '', '184', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33790, 55, 'SODIUM CHLORIDE', 'I', 711, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12923, 55, 'SODIUM CHLORIDE', 'I', 42.6, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15001, 55, 'SODIUM CHLORIDE', 'I', 710.4, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: NACL ((NA EQ. TO 283.25MG)). NACL STRENGTH REVISED ASPER VDD REQUEST (FROM 7');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10299, 55, 'SODIUM CHLORIDE', 'I', 9, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6616, 55, 'SODIUM CHLORIDE', 'I', 20.87, 'MG', '', '', 'N', 'G', 'LABEL HAS 5.84G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5322, 55, 'SODIUM CHLORIDE', 'I', 0.66, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47888, 55, 'SODIUM CHLORIDE', 'I', 320, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24471, 55, 'SODIUM CHLORIDE', 'I', 1, '%', '', '170', 'N', 'G', 'Historic Freeform Text: SODIUM CHLORIDE ((NA EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43196, 61, 'ABCIXIMAB', 'I', 2, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ABCIXIMAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43184, 63, 'FLORFENICOL', 'I', 300, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: FLORFENICOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77319, 63, 'FLORFENICOL', 'I', 23, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81673, 63, 'FLORFENICOL', 'I', 300, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51121, 63, 'FLORFENICOL', 'I', 500, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20322, 66, 'STAVUDINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: STAVUDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20323, 66, 'STAVUDINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: STAVUDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20324, 66, 'STAVUDINE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: STAVUDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20325, 66, 'STAVUDINE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: STAVUDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43165, 67, 'VIRGINIAMYCIN', 'I', 44, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11543, 67, 'VIRGINIAMYCIN', 'I', 500, 'G', '', '', 'N', 'KG', '2005.02.23 - MEDICINAL INGREDIENT CHANGED FROM VIRGINIAMYCIN M TO VIRGINIAMYCIN AS PER LABEL AND CON');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11533, 67, 'VIRGINIAMYCIN', 'I', 44, 'G', '', '', 'N', 'KG', '2005.02.23 - MEDICINAL INGREDIENT CHANGED FROM VIRGINIAMYCIN M TO VIRGINIAMYCIN AS PER LABEL AND CON');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11525, 67, 'VIRGINIAMYCIN', 'I', 22, 'G', '', '', 'N', 'KG', '2005.02.23 - MEDICINAL INGREDIENT CHANGED FROM VIRGINIAMYCIN M TO VIRGINIAMYCIN AS PER LABEL AND CON');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13226, 68, 'DAUNORUBICIN (DAUNORUBICIN HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', 'VIAL', 'Historic Freeform Text: DAUNORUBICIN HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50738, 68, 'DAUNORUBICIN (DAUNORUBICIN HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37254, 74, 'SULFUR', 'I', 5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13031, 74, 'SULFUR', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13014, 74, 'SULFUR', 'I', 2.0, '%', '', '', 'N', '', 'Historic Freeform Text: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13585, 74, 'SULFUR', 'I', 3.5, '%', '', '', 'N', '', 'W/V. HISTORIC FREEFORM TEXT: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13542, 74, 'SULFUR', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13858, 74, 'SULFUR', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5634, 74, 'SULFUR', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5635, 74, 'SULFUR', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3347, 74, 'SULFUR', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3320, 74, 'SULFUR', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1938, 74, 'SULFUR', 'I', 0.3, '%', '', '', 'N', '', 'Historic Freeform Text: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (622, 74, 'SULFUR', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1686, 74, 'SULFUR', 'I', 0.3, '%', '', '', 'N', '', 'Historic Freeform Text: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1687, 74, 'SULFUR', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47375, 74, 'SULFUR', 'I', 2, '%', '', '', 'N', '', 'SOLUBILIZED SULFUR EQUIVALENT TO 2% ELEMENTAL SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74174, 11980, 'LEFLUNOMIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (233, 74, 'SULFUR', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64695, 74, 'SULFUR (SODIUM THIOSULPHATE)', 'I', 2, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80278, 74, 'SULFUR', 'I', 2, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81731, 74, 'SULFUR (SODIUM THIOSULFATE)', 'I', 2, '%', '', '', 'N', 'W/V', 'SULFUR PRECIPITATED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13246, 74, 'SULFUR', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3567, 74, 'SULFUR', 'I', 2.92, '%', '', '', 'N', '%', 'Historic Freeform Text: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1394, 74, 'SULFUR', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1527, 74, 'SULFUR', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1218, 74, 'SULFUR', 'I', 30, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SULFUR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64684, 11922, 'GADOBUTROL', 'I', 604.72, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64696, 11923, 'TEMOZOLOMIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64697, 11923, 'TEMOZOLOMIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64698, 11923, 'TEMOZOLOMIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64699, 11923, 'TEMOZOLOMIDE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79831, 11923, 'TEMOZOLOMIDE', 'I', 140, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80666, 11923, 'TEMOZOLOMIDE', 'I', 100, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64716, 11925, 'ROSIGLITAZONE (ROSIGLITAZONE MALEATE)', 'I', 2, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64717, 11925, 'ROSIGLITAZONE (ROSIGLITAZONE MALEATE)', 'I', 4, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64718, 11925, 'ROSIGLITAZONE (ROSIGLITAZONE MALEATE)', 'I', 8, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71322, 11925, 'ROSIGLITAZONE (ROSIGLITAZONE MALEATE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71323, 11925, 'ROSIGLITAZONE (ROSIGLITAZONE MALEATE)', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71324, 11925, 'ROSIGLITAZONE (ROSIGLITAZONE MALEATE)', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72791, 11925, 'ROSIGLITAZONE (ROSIGLITAZONE MALEATE)', 'I', 2.00, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72792, 11925, 'ROSIGLITAZONE (ROSIGLITAZONE MALEATE)', 'I', 4.00, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73878, 11933, 'INACTIVATED POLIOVIRUS TYPE I', 'I', 40, 'UNIT', '', '0.5', 'N', 'ML', '40 D UNITS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79806, 11933, 'INACTIVATED POLIOVIRUS TYPE I', 'I', 40, 'D', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73878, 11934, 'INACTIVATED POLIOVIRUS TYPE II', 'I', 8, 'UNIT', '', '0.5', 'N', 'ML', '8 D UNITS ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79806, 11934, 'INACTIVATED POLIOVIRUS TYPE II', 'I', 8, 'D', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73878, 11935, 'INACTIVATED POLIOVIRUS TYPE III', 'I', 32, 'UNIT', '', '0.5', 'N', 'ML', '32 D UNITS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79806, 11935, 'INACTIVATED POLIOVIRUS TYPE III', 'I', 32, 'D', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 13390, 'PROPYLPARABEN', 'I', 0.16, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS PARABEN MIX 0.80MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37547, 8881, 'ISOPROPYL ALCOHOL', 'I', 17.20, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ISOPROPYL ALCOHOL STRENGTH AT INITIAL DIN ISSUANCE WAS 15.3%, THIS IS MINIMU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19302, 8881, 'ISOPROPYL ALCOHOL', 'I', 15, '%', '', '', 'N', '', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20013, 8881, 'ISOPROPYL ALCOHOL', 'I', 17.20, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ISOPROPYL ALCOHOL STRENGTH WAS 15.3% AT INITIAL DIN ISSUANCE AS MINIMUM GUAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15830, 8881, 'ISOPROPYL ALCOHOL', 'I', 8, '%', '', '', 'N', '', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16133, 8881, 'ISOPROPYL ALCOHOL', 'I', 1.18, '%', '', '', 'N', '', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13289, 8881, 'ISOPROPYL ALCOHOL', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13290, 8881, 'ISOPROPYL ALCOHOL', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12861, 8881, 'ISOPROPYL ALCOHOL', 'I', 70, '%', '', '', 'N', '', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8048, 8881, 'ISOPROPYL ALCOHOL', 'I', 40, '%', '', '', 'N', '', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5347, 8881, 'ISOPROPYL ALCOHOL', 'I', 65, '%', '', '', 'N', '', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3829, 8881, 'ISOPROPYL ALCOHOL', 'I', 5.54, '%', '', '', 'N', '', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3797, 8881, 'ISOPROPYL ALCOHOL', 'I', 53.41, '%', '', '', 'N', '', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (620, 8881, 'ISOPROPYL ALCOHOL', 'I', 30, '%', '', '', 'N', '', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2819, 8881, 'ISOPROPYL ALCOHOL', 'I', 30, '%', '', '', 'N', '', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67128, 8881, 'ISOPROPYL ALCOHOL', 'I', 21.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65180, 8881, 'ISOPROPYL ALCOHOL', 'I', 70, '%', '', '', 'N', '', '70% W/V, 70.0G/100ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66387, 8881, 'ISOPROPYL ALCOHOL', 'I', 14.85, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65889, 8881, 'ISOPROPYL ALCOHOL', 'I', 17.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65545, 8881, 'ISOPROPYL ALCOHOL', 'I', 15.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67366, 8881, 'ISOPROPYL ALCOHOL', 'I', 70, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67367, 8881, 'ISOPROPYL ALCOHOL', 'I', 70, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67389, 8881, 'ISOPROPYL ALCOHOL', 'I', 14.85, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67640, 8881, 'ISOPROPYL ALCOHOL', 'I', 21.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70138, 8881, 'ISOPROPYL ALCOHOL', 'I', 17.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70460, 8881, 'ISOPROPYL ALCOHOL', 'I', 8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71177, 8881, 'ISOPROPYL ALCOHOL', 'I', 4, '%', '', '', 'N', '', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71947, 8881, 'ISOPROPYL ALCOHOL', 'I', 70, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76460, 8881, 'ISOPROPYL ALCOHOL', 'I', 8.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75711, 8881, 'ISOPROPYL ALCOHOL', 'I', 20.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75722, 8881, 'ISOPROPYL ALCOHOL', 'I', 20.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73640, 8881, 'ISOPROPYL ALCOHOL', 'I', 70, '%', '', '', 'N', '', 'V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73675, 8881, 'ISOPROPYL ALCOHOL', 'I', 14.85, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76263, 8881, 'ISOPROPYL ALCOHOL', 'I', 70, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77442, 8881, 'ISOPROPYL ALCOHOL', 'I', 70.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77124, 8881, 'ISOPROPYL ALCOHOL', 'I', 45.60, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77845, 8881, 'ISOPROPYL ALCOHOL', 'I', 21.0, '%', '', '', 'N', '', 'W/V. ISOPROPYL ALCOHOL 99%.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78280, 8881, 'ISOPROPYL ALCOHOL', 'I', 70, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80305, 8881, 'ISOPROPYL ALCOHOL', 'I', 8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80458, 8881, 'ISOPROPYL ALCOHOL', 'I', 21.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80336, 8881, 'ISOPROPYL ALCOHOL', 'I', 21.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83957, 8881, 'ISOPROPYL ALCOHOL', 'I', 21.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84554, 8881, 'ISOPROPYL ALCOHOL', 'I', 21.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16228, 8881, 'ISOPROPYL ALCOHOL', 'I', 5.0, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5740, 8881, 'ISOPROPYL ALCOHOL', 'I', 5.0, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83578, 8881, 'ISOPROPYL ALCOHOL', 'I', 5.0, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80304, 8881, 'ISOPROPYL ALCOHOL', 'I', 21.0, '%', '', '', 'N', 'W/V', 'W/V. ISOPROPYL ALCOHOL 99%.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83956, 8881, 'ISOPROPYL ALCOHOL', 'I', 21.0, '%', '', '', 'N', 'W/V', 'W/V.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63898, 8881, 'ISOPROPYL ALCOHOL', 'I', 70, '%', '', '', 'N', 'V/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34222, 8881, 'ISOPROPYL ALCOHOL', 'I', 70, '%', '', '', 'N', 'V/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30398, 8881, 'ISOPROPYL ALCOHOL', 'I', 70, '%', '', '', 'N', '%', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19626, 8881, 'ISOPROPYL ALCOHOL', 'I', 70, '%', '', '', 'N', '%', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16494, 8881, 'ISOPROPYL ALCOHOL', 'I', 70, '%', '', '', 'N', '%', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9551, 8881, 'ISOPROPYL ALCOHOL', 'I', 2, '%', '', '', 'N', '%', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4815, 8881, 'ISOPROPYL ALCOHOL', 'I', 70, '%', '', '', 'N', '%', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1500, 8881, 'ISOPROPYL ALCOHOL', 'I', 30, '%', '', '', 'N', '%', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64263, 8881, 'ISOPROPYL ALCOHOL', 'I', 70.0, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66842, 8881, 'ISOPROPYL ALCOHOL', 'I', 70, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66843, 8881, 'ISOPROPYL ALCOHOL', 'I', 70, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3312, 8881, 'ISOPROPYL ALCOHOL', 'I', 150, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4553, 8881, 'ISOPROPYL ALCOHOL', 'I', 60, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3314, 8881, 'ISOPROPYL ALCOHOL', 'I', 12, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70822, 8881, 'ISOPROPYL ALCOHOL', 'I', 56.5, 'G', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6694, 8881, 'ISOPROPYL ALCOHOL', 'I', 0.6, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (818, 8881, 'ISOPROPYL ALCOHOL', 'I', 564.40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4771, 8881, 'ISOPROPYL ALCOHOL', 'I', 15, '%', '', '221.8', 'N', 'ML', 'Historic Freeform Text: ISOPROPYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (623, 6429, 'METHYL VIOLET', 'I', 0.51, '%', '', '', 'N', '', 'Historic Freeform Text: METHYL VIOLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1593, 6429, 'METHYL VIOLET', 'I', 0.85, '%', '', '', 'N', '', 'Historic Freeform Text: METHYL VIOLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3466, 6429, 'METHYL VIOLET', 'I', 71, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: METHYL VIOLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 5911, 'BUTYLPARABEN', 'I', 0.16, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS PARABEN MIX 0.80MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 6880, 'MAGNESIUM CARBONATE', 'I', 750, 'MG', '', '', 'N', '', 'Historic Freeform Text: MAGNESIUM CARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48421, 6880, 'MAGNESIUM CARBONATE', 'I', 52.3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48434, 6880, 'MAGNESIUM CARBONATE', 'I', 34, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64083, 6880, 'MAGNESIUM CARBONATE', 'I', 5.25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41536, 7140, 'MINERAL OIL', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31093, 7140, 'MINERAL OIL', 'I', 15, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28169, 7140, 'MINERAL OIL', 'I', 3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20312, 7140, 'MINERAL OIL', 'I', 78, '%', '', '', 'N', '', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17759, 7140, 'MINERAL OIL', 'I', 42.5, '%', '', '', 'N', '', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18099, 7140, 'MINERAL OIL', 'I', 42.5, '%', '', '', 'N', '', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16777, 7140, 'MINERAL OIL', 'I', 20, '%', '', '', 'N', '', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9820, 7140, 'MINERAL OIL', 'I', 42.5, '%', '', '', 'N', '', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5792, 7140, 'MINERAL OIL', 'I', 78, '%', '', '', 'N', '', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5569, 7140, 'MINERAL OIL', 'I', 64.5, '%', '', '', 'N', '', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3758, 7140, 'MINERAL OIL', 'I', 91, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2256, 7140, 'MINERAL OIL', 'I', 80, '%', '', '', 'N', '', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (721, 7140, 'MINERAL OIL', 'I', 100, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (57, 7140, 'MINERAL OIL', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62999, 7140, 'MINERAL OIL', 'I', 44.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41698, 7140, 'MINERAL OIL', 'I', 100, '%', '', '', 'N', '%', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37581, 7140, 'MINERAL OIL', 'I', 20, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24470, 7140, 'MINERAL OIL', 'I', 98, '%', '', '', 'N', '%', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16438, 7140, 'MINERAL OIL', 'I', 63.4, '%', '', '', 'N', '%', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12947, 7140, 'MINERAL OIL', 'I', 91.7, '%', '', '', 'N', '%', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14042, 7140, 'MINERAL OIL', 'I', 100, '%', '', '', 'N', '%', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11785, 7140, 'MINERAL OIL', 'I', 3.4, '%', '', '', 'N', '%', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11629, 7140, 'MINERAL OIL', 'I', 100, '%', '', '', 'N', '%', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2536, 7140, 'MINERAL OIL', 'I', 12, '%', '', '', 'N', '%', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64111, 7140, 'MINERAL OIL', 'I', 7.00, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (679, 7140, 'MINERAL OIL', 'I', 0, 'NIL', '', '', 'N', 'NIL', 'HISTORIC FREEFORM TEXT: PETROLATUM LIQUID  CONTACTED THE COMPANY SEVERAL TIMES TO UPDATE THE CONCENT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2045, 7140, 'MINERAL OIL', 'I', 0, 'NIL', '', '', 'N', 'NIL', 'HISTORIC FREEFORM TEXT: PETROLATUM LIQUID  CONTACTED THE COMPANY SEVERAL TIMES TO UPDATE THE CONCENT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1281, 7140, 'MINERAL OIL', 'I', 0.25, 'ML', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60965, 7140, 'MINERAL OIL', 'I', 1.6, 'ML', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65266, 7140, 'MINERAL OIL', 'I', 0.13, 'G', '', '1.04', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6502, 7140, 'MINERAL OIL', 'I', 34, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49921, 7140, 'MINERAL OIL', 'I', 34, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80280, 7140, 'MINERAL OIL', 'I', 39.77, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3630, 7140, 'MINERAL OIL', 'I', 2.816, 'ML', '', '70.87', 'N', 'G', 'Historic Freeform Text: PETROLATUM LIQUID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19291, 2332, 'NITROGEN', 'I', 76.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NITROGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19292, 2332, 'NITROGEN', 'I', 99, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NITROGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19100, 2332, 'NITROGEN', 'I', 78.2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NITROGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19101, 2332, 'NITROGEN', 'I', 68.7, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NITROGEN ((BALANCE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13920, 2332, 'NITROGEN', 'I', 67.7, '%', '', '', 'N', '', 'Historic Freeform Text: NITROGEN ((69.8-67.7%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13894, 2332, 'NITROGEN', 'I', 50, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NITROGEN ((76.5-50%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13882, 2332, 'NITROGEN', 'I', 99, '%', '', '', 'N', '', 'Historic Freeform Text: NITROGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13885, 2332, 'NITROGEN', 'I', 80.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NITROGEN ((80.5-76.5%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8185, 2332, 'NITROGEN', 'I', 78.2, '%', '', '', 'N', '', 'Historic Freeform Text: NITROGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5683, 2332, 'NITROGEN', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: NITROGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5221, 2332, 'NITROGEN', 'I', 99.0, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NITROGEN  JUNE 27/01 - UPDATED STRENGTH OF NITROGEN FROM 99.9% TO 99.0% AS P');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72506, 2332, 'NITROGEN', 'I', 99.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78261, 2332, 'NITROGEN', 'I', 100, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44612, 2332, 'NITROGEN', 'I', 68.9, '%', '', '', 'N', '%', 'Historic Freeform Text: NITROGEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19633, 47, 'ACETIC ACID', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: ACETIC ACID ((GLACIAL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62057, 47, 'ACETIC ACID', 'I', 0.74, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74675, 47, 'ACETIC ACID', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80386, 47, 'ACETIC ACID', 'I', 9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82224, 47, 'ACETIC ACID', 'I', 4.9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36836, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36814, 47, 'ACETIC ACID', 'I', 5.4, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34881, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34878, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34879, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19744, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19735, 47, 'ACETIC ACID', 'I', 8.11, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20121, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20115, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20116, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20118, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20119, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20111, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20114, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19739, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20076, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20044, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20045, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20046, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20040, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20041, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18268, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18206, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18202, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18199, 47, 'ACETIC ACID', 'I', 8.11, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18200, 47, 'ACETIC ACID', 'I', 5.41, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18167, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10820, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9854, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9852, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9848, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9845, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9131, 47, 'ACETIC ACID', 'I', 8.11, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9129, 47, 'ACETIC ACID', 'I', 8.11, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9130, 47, 'ACETIC ACID', 'I', 8.11, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10114, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10115, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8585, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8586, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: ACETIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62960, 47, 'ACETIC ACID', 'I', 8.11, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62964, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62965, 47, 'ACETIC ACID', 'I', 8.11, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66299, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73901, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73902, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73903, 47, 'ACETIC ACID', 'I', 8.11, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73904, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73905, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73915, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73916, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73917, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73919, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73921, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73922, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73923, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73924, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73925, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73927, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73929, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75411, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', 'BEFORE DILUTION; EQUIVALENT TO 180MML/L. AFTER DILUTION: ACETIC ACID: 4MMOL/L.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75804, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75805, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75811, 47, 'ACETIC ACID', 'I', 8.11, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75812, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73193, 47, 'ACETIC ACID', 'I', 8.11, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74785, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74787, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74790, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74791, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74792, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74793, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81573, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81574, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81576, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81578, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81236, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81237, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81238, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81262, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81265, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81270, 47, 'ACETIC ACID', 'I', 8.1, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81271, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81272, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81577, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81579, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81580, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81227, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81224, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81225, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81226, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81280, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81282, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81592, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81593, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81594, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81595, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81596, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81598, 47, 'ACETIC ACID', 'I', 8.1, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81600, 47, 'ACETIC ACID', 'I', 8.1, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81601, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81602, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81279, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81281, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81242, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81275, 47, 'ACETIC ACID', 'I', 10.8, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80217, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80218, 47, 'ACETIC ACID', 'I', 10.81, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81222, 47, 'ACETIC ACID', 'I', 8.1, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2443, 47, 'ACETIC ACID', 'I', 1.44, 'KG', '', '4.8', 'N', 'KG', 'Historic Freeform Text: ACETIC ACID ((DILUTE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61969, 7097, 'DICHLOROBENZYL ALCOHOL', 'I', 1.2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59951, 7097, 'DICHLOROBENZYL ALCOHOL', 'I', 1.2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81250, 7097, 'DICHLOROBENZYL ALCOHOL', 'I', 1.2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80640, 7097, 'DICHLOROBENZYL ALCOHOL', 'I', 1.2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (622, 7034, 'ALUMINUM POTASSIUM SULFATE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: ALUMINUM POTASSIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (129, 7034, 'ALUMINUM POTASSIUM SULFATE', 'I', 908, 'G', '', '81.6', 'N', 'L', 'Historic Freeform Text: ALUMINUM POTASSIUM SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15177, 10290, 'SODIUM CITRATE', 'I', 0.17, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM CITRATE ((DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23039, 10290, 'SODIUM CITRATE', 'I', 1.66, 'G', '', '63', 'N', 'ML', 'Historic Freeform Text: SODIUM CITRATE ((DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10497, 10290, 'SODIUM CITRATE', 'I', 4, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11376, 10290, 'SODIUM CITRATE', 'I', 2.2, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CITRATE (DIHYDRATE)./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11354, 10290, 'SODIUM CITRATE', 'I', 1.32, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CITRATE (DIHYDRATE)./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7141, 10290, 'SODIUM CITRATE', 'I', 0.7, 'G', '', '1000', 'N', 'ML', 'SODIUM CITRATE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18290, 10290, 'SODIUM CITRATE', 'I', 90, 'MG', '', '', 'N', 'ML', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18029, 10290, 'SODIUM CITRATE', 'I', 1.7, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8169, 10290, 'SODIUM CITRATE', 'I', 1.49, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM CITRATE ((DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5475, 10290, 'SODIUM CITRATE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6360, 10290, 'SODIUM CITRATE', 'I', 1.7, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4615, 10290, 'SODIUM CITRATE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50030, 10290, 'SODIUM CITRATE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14119, 10290, 'SODIUM CITRATE', 'I', 33.2, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: SODIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8198, 3289, 'SOYBEAN OIL', 'I', 5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SOYBEAN OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8197, 3289, 'SOYBEAN OIL', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: SOYBEAN OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3758, 3289, 'SOYBEAN OIL', 'I', 6.25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SOYBEAN OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47094, 3289, 'SOYBEAN OIL', 'I', 5.0, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SOYBEAN OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43172, 3289, 'SOYBEAN OIL', 'I', 30, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SOYBEAN OIL ((PURIFIED))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19284, 3289, 'SOYBEAN OIL', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SOYBEAN OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19285, 3289, 'SOYBEAN OIL', 'I', 20, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SOYBEAN OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18484, 3289, 'SOYBEAN OIL', 'I', 10, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SOYBEAN OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18647, 3289, 'SOYBEAN OIL', 'I', 20, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SOYBEAN OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 3289, 'SOYBEAN OIL', 'I', 6, 'G', '', '', 'N', 'L', 'REFINED OLIVE OIL (APPROXIMATELY 80%) + REFINED SOYBEAN OIL  (APPROXIMATELY 20%) = 30G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 3289, 'SOYBEAN OIL', 'I', 8, 'G', '', '', 'N', 'L', 'REFINED OLIVE OIL (APPROXIMATELY 80%) + REFINED SOYBEAN OIL  (APPROXIMATELY 20%) = 40G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 3289, 'SOYBEAN OIL', 'I', 8, 'G', '', '', 'N', 'L', 'REFINED OLIVE OIL (APPROXIMATELY 80%) + REFINED SOYBEAN OIL  (APPROXIMATELY 20%) = 40G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 3289, 'SOYBEAN OIL', 'I', 8, 'G', '', '', 'N', 'L', 'REFINED OLIVE OIL (APPROXIMATELY 80%) + REFINED SOYBEAN OIL  (APPROXIMATELY 20%) = 40G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5348, 628, 'METHYL SALICYLATE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: METHYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3998, 628, 'METHYL SALICYLATE', 'I', 2.0, '%', '', '', 'N', '', 'Historic Freeform Text: METHYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2022, 628, 'METHYL SALICYLATE', 'I', 2.0, '%', '', '', 'N', '', 'Historic Freeform Text: METHYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (233, 628, 'METHYL SALICYLATE', 'I', 3.6, '%', '', '', 'N', '', 'Historic Freeform Text: METHYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66170, 628, 'METHYL SALICYLATE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3669, 628, 'METHYL SALICYLATE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: METHYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3621, 628, 'METHYL SALICYLATE', 'I', 0.3, '%', '', '', 'N', '%', 'Historic Freeform Text: METHYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6564, 628, 'METHYL SALICYLATE', 'I', 2, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: METHYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3313, 628, 'METHYL SALICYLATE', 'I', 11.4, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: METHYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3314, 628, 'METHYL SALICYLATE', 'I', 41.7, 'G', '', '473', 'N', 'ML', 'Historic Freeform Text: METHYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66168, 628, 'METHYL SALICYLATE', 'I', 2.90, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (818, 628, 'METHYL SALICYLATE', 'I', 84.63, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2842, 628, 'METHYL SALICYLATE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1291, 628, 'METHYL SALICYLATE', 'I', 2.5, 'ML', '', '100', 'N', 'ML', 'Historic Freeform Text: METHYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2443, 628, 'METHYL SALICYLATE', 'I', 30, 'G', '', '4.8', 'N', 'KG', 'Historic Freeform Text: METHYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12801, 628, 'METHYL SALICYLATE', 'I', 48, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: METHYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5754, 628, 'METHYL SALICYLATE', 'I', 75, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: METHYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5076, 628, 'METHYL SALICYLATE', 'I', 48, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: METHYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3889, 628, 'METHYL SALICYLATE', 'I', 20, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: METHYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48860, 628, 'METHYL SALICYLATE', 'I', 0.10, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66399, 628, 'METHYL SALICYLATE', 'I', 3, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50130, 9505, 'SODIUM HYDROXIDE', 'I', 0, 'MG', '', '', 'N', '', 'NAOH = PH ADJUSTER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81278, 9505, 'SODIUM HYDROXIDE', 'I', 0.34, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82116, 9505, 'SODIUM HYDROXIDE', 'I', 0.34, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1894, 9505, 'SODIUM HYDROXIDE', 'I', 27.2, '%', '', '', 'N', '%', 'Historic Freeform Text: SODIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9342, 9505, 'SODIUM HYDROXIDE', 'I', 46, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: SODIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46885, 7132, 'POTASSIUM CITRATE', 'I', 540, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: POTASSIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83921, 7132, 'POTASSIUM CITRATE', 'I', 1080, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: POTASSIUM CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37543, 10212, 'POVIDONE', 'I', 0.6, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: POLYVINYL PYRROLIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47557, 10212, 'POVIDONE', 'I', 0.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73019, 10212, 'POVIDONE', 'I', 1.0, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78699, 10212, 'POVIDONE', 'I', 0.6, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81391, 10212, 'POVIDONE', 'I', 1.0, '%', '', '', 'N', 'W/V', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82979, 10212, 'POVIDONE', 'I', 1.0, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71788, 10212, 'POVIDONE', 'I', 6, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POLYVINYL PYRROLIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1394, 6984, 'ALUMINUM CHLOROHYDRATE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ALUMINUM CHLORHYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1527, 6984, 'ALUMINUM CHLOROHYDRATE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ALUMINUM CHLORHYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 8865, 'GLYCINE', 'I', 435, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50130, 8865, 'GLYCINE', 'I', 94, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15540, 8865, 'GLYCINE', 'I', 1.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31465, 8865, 'GLYCINE', 'I', 6.756, 'G', '', '', 'N', 'PCK', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44068, 8865, 'GLYCINE', 'I', 1.19, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76987, 11984, 'OXCARBAZEPINE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43947, 8865, 'GLYCINE', 'I', 2.06, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19610, 8865, 'GLYCINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18550, 8865, 'GLYCINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 8865, 'GLYCINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14077, 8865, 'GLYCINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 8865, 'GLYCINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 8865, 'GLYCINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14067, 8865, 'GLYCINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 8865, 'GLYCINE', 'I', 1.04, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11329, 8865, 'GLYCINE', 'I', 1.03, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9828, 8865, 'GLYCINE', 'I', 1.5, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 8865, 'GLYCINE', 'I', 1.1, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5890, 8865, 'GLYCINE', 'I', 1.1, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4661, 8865, 'GLYCINE', 'I', 2.08, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3468, 8865, 'GLYCINE', 'I', 1.28, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 8865, 'GLYCINE', 'I', 2.08, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 8865, 'GLYCINE', 'I', 212, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20278, 8865, 'GLYCINE', 'I', 515, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 8865, 'GLYCINE', 'I', 438, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19306, 8865, 'GLYCINE', 'I', 750, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20302, 8865, 'GLYCINE', 'I', 515, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20303, 8865, 'GLYCINE', 'I', 438, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 8865, 'GLYCINE', 'I', 438, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 8865, 'GLYCINE', 'I', 515, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 8865, 'GLYCINE', 'I', 515, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20289, 8865, 'GLYCINE', 'I', 438, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 8865, 'GLYCINE', 'I', 260, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 8865, 'GLYCINE', 'I', 515, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 8865, 'GLYCINE', 'I', 515, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20279, 8865, 'GLYCINE', 'I', 515, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 8865, 'GLYCINE', 'I', 212, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 8865, 'GLYCINE', 'I', 212, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 8865, 'GLYCINE', 'I', 175, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 8865, 'GLYCINE', 'I', 212, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19143, 8865, 'GLYCINE', 'I', 1040, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 8865, 'GLYCINE', 'I', 212, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 8865, 'GLYCINE', 'I', 175, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 8865, 'GLYCINE', 'I', 250, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 8865, 'GLYCINE', 'I', 175, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 8865, 'GLYCINE', 'I', 212, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 8865, 'GLYCINE', 'I', 270, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 8865, 'GLYCINE', 'I', 175, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18644, 8865, 'GLYCINE', 'I', 500, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 8865, 'GLYCINE', 'I', 500, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18607, 8865, 'GLYCINE', 'I', 425, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18608, 8865, 'GLYCINE', 'I', 350, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 8865, 'GLYCINE', 'I', 385, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14073, 8865, 'GLYCINE', 'I', 880, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 8865, 'GLYCINE', 'I', 880, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14071, 8865, 'GLYCINE', 'I', 880, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 8865, 'GLYCINE', 'I', 520, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 8865, 'GLYCINE', 'I', 880, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10470, 8865, 'GLYCINE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12562, 8865, 'GLYCINE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 8865, 'GLYCINE', 'I', 1.2, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6071, 8865, 'GLYCINE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3865, 8865, 'GLYCINE', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4560, 8865, 'GLYCINE', 'I', 900, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 8865, 'GLYCINE', 'I', 0.6, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2776, 8865, 'GLYCINE', 'I', 640, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 8865, 'GLYCINE', 'I', 51, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 8865, 'GLYCINE', 'I', 400, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78915, 8865, 'GLYCINE', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 8865, 'GLYCINE', 'I', 1.76, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 8865, 'GLYCINE', 'I', 3.07, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 8865, 'GLYCINE', 'I', 3.95, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 8865, 'GLYCINE', 'I', 3.95, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15158, 8865, 'GLYCINE', 'I', 6.006, 'G', '', '80', 'N', 'G', 'HISTORIC FREEFORM TEXT: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10527, 8865, 'GLYCINE', 'I', 12, 'G', '', '75', 'N', 'G', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12827, 8865, 'GLYCINE', 'I', 6.006, 'G', '', '184', 'N', 'G', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10794, 8865, 'GLYCINE', 'I', 6.006, 'G', '', '73', 'N', 'G', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11333, 8865, 'GLYCINE', 'I', 6.006, 'G', '', '184', 'N', 'G', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65789, 8865, 'GLYCINE', 'I', 6.756, 'G', '', '76', 'N', 'G', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65790, 8865, 'GLYCINE', 'I', 6.756, 'G', '', '185', 'N', 'G', 'Historic Freeform Text: GLYCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76260, 8865, 'GLYCINE', 'I', 6.006, 'G', '', '184', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2819, 10102, 'AMMONIA', 'I', 6.1, '%', '', '', 'N', '', 'Historic Freeform Text: AMMONIA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60869, 7238, 'STARCH', 'I', 49.95, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4913, 4759, 'SODIUM PHOSPHATE DIBASIC', 'I', 0.042, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31465, 4759, 'SODIUM PHOSPHATE DIBASIC', 'I', 0.600, 'G', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: SODIUM PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21757, 4759, 'SODIUM PHOSPHATE DIBASIC', 'I', 12, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21993, 4759, 'SODIUM PHOSPHATE DIBASIC', 'I', 430, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 4759, 'SODIUM PHOSPHATE DIBASIC', 'I', 49, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM PHOSPHATE ((DIBASIC))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 4759, 'SODIUM PHOSPHATE DIBASIC', 'I', 49, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM PHOSPHATE ((DIBASIC))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16794, 4759, 'SODIUM PHOSPHATE DIBASIC', 'I', 410, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11258, 4759, 'SODIUM PHOSPHATE DIBASIC', 'I', 268, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74665, 11980, 'LEFLUNOMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18607, 10237, 'HISTIDINE', 'I', 255, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10939, 4759, 'SODIUM PHOSPHATE DIBASIC', 'I', 8.75, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11330, 4759, 'SODIUM PHOSPHATE DIBASIC', 'I', 124.2, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5984, 4759, 'SODIUM PHOSPHATE DIBASIC', 'I', 7.58, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1958, 4759, 'SODIUM PHOSPHATE DIBASIC', 'I', 35.69575, 'KG', '', '576', 'N', 'L', 'Historic Freeform Text: SODIUM PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10527, 4759, 'SODIUM PHOSPHATE DIBASIC', 'I', 2.61, 'G', '', '75', 'N', 'G', 'Historic Freeform Text: SODIUM PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65790, 4759, 'SODIUM PHOSPHATE DIBASIC', 'I', 0.600, 'G', '', '185', 'N', 'G', 'Historic Freeform Text: SODIUM PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23039, 4753, 'SODIUM PHOSPHATE MONOBASIC', 'I', 140, 'MG', '', '63', 'N', 'ML', 'Historic Freeform Text: MONOBASIC SODIUMPHOSPHATE ((MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11330, 4753, 'SODIUM PHOSPHATE MONOBASIC', 'I', 51.7, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM ACID PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11258, 4753, 'SODIUM PHOSPHATE MONOBASIC', 'I', 276, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM ACID PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5984, 4753, 'SODIUM PHOSPHATE MONOBASIC', 'I', 1.81, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM ACID PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65789, 4753, 'SODIUM PHOSPHATE MONOBASIC', 'I', 0.600, 'G', '', '76', 'N', 'G', 'Historic Freeform Text: SODIUM ACID PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10527, 4753, 'SODIUM PHOSPHATE MONOBASIC', 'I', 950, 'MG', '', '75', 'N', 'G', 'Historic Freeform Text: SODIUM ACID PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84451, 4937, 'SODIUM ASCORBATE', 'I', 5.900, 'G', '', '', 'N', 'PCK', 'SACHET B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5969, 4937, 'SODIUM ASCORBATE', 'I', 250, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM ASCORBATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5901, 4937, 'SODIUM ASCORBATE', 'I', 250, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM ASCORBATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4133, 4937, 'SODIUM ASCORBATE', 'I', 250, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM ASCORBATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2043, 4937, 'SODIUM ASCORBATE', 'I', 25, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SODIUM ASCORBATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37542, 6033, 'POLYVINYL ALCOHOL', 'I', 1.4, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: POLYVINYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37543, 6033, 'POLYVINYL ALCOHOL', 'I', 1.4, '%', '', '', 'N', '', 'Historic Freeform Text: POLYVINYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19791, 6033, 'POLYVINYL ALCOHOL', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: POLYVINYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18791, 6033, 'POLYVINYL ALCOHOL', 'I', 1.4, '%', '', '', 'N', '', 'Historic Freeform Text: POLYVINYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17733, 6033, 'POLYVINYL ALCOHOL', 'I', 1.4, '%', '', '', 'N', '', 'Historic Freeform Text: POLYVINYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16655, 6033, 'POLYVINYL ALCOHOL', 'I', 1.4, '%', '', '', 'N', '', 'Historic Freeform Text: POLYVINYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5121, 6033, 'POLYVINYL ALCOHOL', 'I', 1.4, '%', '', '', 'N', '', 'Historic Freeform Text: POLYVINYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47493, 6033, 'POLYVINYL ALCOHOL', 'I', 1.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47557, 6033, 'POLYVINYL ALCOHOL', 'I', 1.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78699, 6033, 'POLYVINYL ALCOHOL', 'I', 0.5, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71788, 6033, 'POLYVINYL ALCOHOL', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POLYVINYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4088, 721, 'ALUMINUM HYDROXIDE', 'I', 324, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALUMINUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2587, 721, 'ALUMINUM HYDROXIDE', 'I', 65, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALUMINUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (753, 721, 'ALUMINUM HYDROXIDE', 'I', 130, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALUMINUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (457, 721, 'ALUMINUM HYDROXIDE', 'I', 35, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALUMINUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44552, 721, 'ALUMINUM HYDROXIDE', 'I', 200, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ALUMINUM HYDROXIDE ((DRIED GEL EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26833, 721, 'ALUMINUM HYDROXIDE', 'I', 228, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ALUMINUM HYDROXIDE ((EQ TO DRIED GEL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18186, 721, 'ALUMINUM HYDROXIDE', 'I', 300, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ALUMINUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13074, 721, 'ALUMINUM HYDROXIDE', 'I', 200, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ALUMINUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10217, 721, 'ALUMINUM HYDROXIDE', 'I', 200, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ALUMINUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (187, 721, 'ALUMINUM HYDROXIDE (DRIED ALUMINUM HYDROXIDE GEL)', 'I', 165, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ALUMINUM HYDROXIDE AL(OH)3 WAS 200MG BEFORE, IT HAS BEEN CORRECTED ACCORDING');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68677, 721, 'ALUMINUM HYDROXIDE', 'I', 200, 'MG', '', '5', 'N', 'ML', 'ALUMINUM HYDROXIDE ( DRIED GEL)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68678, 721, 'ALUMINUM HYDROXIDE', 'I', 400, 'MG', '', '5', 'N', 'ML', 'ALUMINUM HYDROXIDE (DRIED GEL)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74304, 721, 'ALUMINUM HYDROXIDE', 'I', 400, 'MG', '', '5', 'N', 'ML', 'DRIED GEL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74696, 721, 'ALUMINUM HYDROXIDE', 'I', 200, 'MG', '', '5', 'N', 'ML', '(ALUMINUM HYDROXIDE DRIED GEL 200MG, EQUIVALENT TO 306MG ALUMINUM HYDROXIDE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 10237, 'HISTIDINE', 'I', 270, 'MG', '', '', 'N', '', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43947, 10237, 'HISTIDINE', 'I', 1.18, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 10237, 'HISTIDINE', 'I', 128, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44068, 10237, 'HISTIDINE', 'I', 240, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20278, 10237, 'HISTIDINE', 'I', 240, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20279, 10237, 'HISTIDINE', 'I', 240, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 10237, 'HISTIDINE', 'I', 204, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19306, 10237, 'HISTIDINE', 'I', 450, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19610, 10237, 'HISTIDINE', 'I', 220, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20303, 10237, 'HISTIDINE', 'I', 204, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20302, 10237, 'HISTIDINE', 'I', 240, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 10237, 'HISTIDINE', 'I', 204, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 10237, 'HISTIDINE', 'I', 240, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 10237, 'HISTIDINE', 'I', 240, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20289, 10237, 'HISTIDINE', 'I', 204, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 10237, 'HISTIDINE', 'I', 120, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 10237, 'HISTIDINE', 'I', 240, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 10237, 'HISTIDINE', 'I', 240, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 10237, 'HISTIDINE', 'I', 128, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 10237, 'HISTIDINE', 'I', 128, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 10237, 'HISTIDINE', 'I', 128, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 10237, 'HISTIDINE', 'I', 105, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19143, 10237, 'HISTIDINE', 'I', 220, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 10237, 'HISTIDINE', 'I', 128, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 10237, 'HISTIDINE', 'I', 105, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 10237, 'HISTIDINE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 10237, 'HISTIDINE', 'I', 105, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 10237, 'HISTIDINE', 'I', 128, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 10237, 'HISTIDINE', 'I', 220, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 10237, 'HISTIDINE', 'I', 105, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18644, 10237, 'HISTIDINE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 10237, 'HISTIDINE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18608, 10237, 'HISTIDINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 10237, 'HISTIDINE', 'I', 312, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18550, 10237, 'HISTIDINE', 'I', 220, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 10237, 'HISTIDINE', 'I', 220, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15493, 10237, 'HISTIDINE', 'I', 250, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14077, 10237, 'HISTIDINE', 'I', 220, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 10237, 'HISTIDINE', 'I', 220, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 10237, 'HISTIDINE', 'I', 220, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14073, 10237, 'HISTIDINE', 'I', 186, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 10237, 'HISTIDINE', 'I', 186, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14071, 10237, 'HISTIDINE', 'I', 186, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 10237, 'HISTIDINE', 'I', 110, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14067, 10237, 'HISTIDINE', 'I', 220, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 10237, 'HISTIDINE', 'I', 220, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 10237, 'HISTIDINE', 'I', 186, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11329, 10237, 'HISTIDINE', 'I', 480, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 10237, 'HISTIDINE', 'I', 1.7, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7163, 10237, 'HISTIDINE', 'I', 429, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 10237, 'HISTIDINE', 'I', 260, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5890, 10237, 'HISTIDINE', 'I', 260, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 10237, 'HISTIDINE', 'I', 0.9, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4661, 10237, 'HISTIDINE', 'I', 440, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3468, 10237, 'HISTIDINE', 'I', 300, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4560, 10237, 'HISTIDINE', 'I', 210, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 10237, 'HISTIDINE', 'I', 440, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2776, 10237, 'HISTIDINE', 'I', 150, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 10237, 'HISTIDINE', 'I', 1.4, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 10237, 'HISTIDINE', 'I', 1.4, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: HISTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 10237, 'HISTIDINE', 'I', 71.4, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 10237, 'HISTIDINE', 'I', 380, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 10237, 'HISTIDINE', 'I', 1.51, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 10237, 'HISTIDINE', 'I', 2.64, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 10237, 'HISTIDINE', 'I', 3.40, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 10237, 'HISTIDINE', 'I', 3.40, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18072, 1988, 'TRANEXAMIC ACID', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRANEXAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18371, 1988, 'TRANEXAMIC ACID', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TRANEXAMIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70531, 1988, 'TRANEXAMIC ACID', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43305, 1995, 'CLOBAZAM', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLOBAZAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61740, 1995, 'CLOBAZAM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68447, 1995, 'CLOBAZAM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68625, 1995, 'CLOBAZAM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71472, 1995, 'CLOBAZAM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72805, 1995, 'CLOBAZAM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5963, 1998, 'ETOPOSIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETOPOSIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16507, 1998, 'ETOPOSIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ETOPOSIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64788, 1998, 'ETOPOSIDE', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 2001, 'CHROMIUM (CHROMIUM HVP CHELATE)', 'I', 20, 'µG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20314, 2001, 'CHROMIUM (CHROMIC CHLORIDE)', 'I', 4, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CR ((AS CHROMIC CHLORIDE.6H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19923, 2001, 'CHROMIUM (CHROMIC CHLORIDE)', 'I', 4, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CR ((AS CHROMIC CHLORIDE.6H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16225, 2001, 'CHROMIUM (CHROMIC CHLORIDE)', 'I', 10, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CR ((AS CHROMIC CHLORIDE.6H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16226, 2001, 'CHROMIUM (CHROMIC CHLORIDE)', 'I', 4, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CR ((AS CHROMIC CHLORIDE.6H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16227, 2001, 'CHROMIUM (CHROMIC CHLORIDE)', 'I', 10, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CR ((AS CHROMIC CHLORIDE.6H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16224, 2001, 'CHROMIUM (CHROMIC CHLORIDE)', 'I', 10, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CR ((AS CHROMIC CHLORIDE.6H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13523, 2001, 'CHROMIUM (CHROMIC CHLORIDE)', 'I', 4, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CHROMIC CHLORIDE ((CHROMIUM EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11357, 1935, 'TIAMULIN FUMARATE', 'I', 12.5, '%', '', '', 'N', 'W/V', 'AS TIAMULIN HYDROGEN FUMARATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20306, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL ((AS TRAZODONE EQ.TO 91MG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20307, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL ((AS TRAZODONE EQ.TO45.5MG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19936, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19937, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19938, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18853, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18854, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18855, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18189, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18190, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18191, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18046, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18045, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRAZODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18040, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13780, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4241, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49041, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49042, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49043, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51060, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51061, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51062, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60234, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60235, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76298, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76299, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76300, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRAZODONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81051, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRAZODONE HCL, EQUIVALENT TO 45.5 MG TRAZODONE BASE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81052, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRAZODONE HCL.EQUIVALENT TO 91MG TRAZODONE BASE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83411, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83412, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83413, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84690, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84691, 1939, 'TRAZODONE HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14687, 1942, 'IVERMECTIN B1A', 'I', 6, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: IVERMECTIN B1A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11544, 1943, 'OXIBENDAZOLE', 'I', 5.45, 'G', '', '', 'N', 'SYR', 'Historic Freeform Text: OXIBENDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43304, 1944, 'KETOTIFEN FUMARATE', 'I', 1, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: KETOTIFEN ((AS KETOTIFEN FUMARATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43232, 1944, 'KETOTIFEN FUMARATE', 'I', 1, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: KETOTIFEN FUMARATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43176, 1945, 'IPRATROPIUM BROMIDE', 'I', 0.025, '%', '', '', 'N', '', 'Historic Freeform Text: IPRATR.BR ((VIALS OF 250MCG/ML&500MCG/2ML))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70218, 1945, 'IPRATROPIUM BROMIDE', 'I', 0.03, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70219, 1945, 'IPRATROPIUM BROMIDE', 'I', 0.06, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19651, 1945, 'IPRATROPIUM BROMIDE', 'I', 42, 'µG', '', '', 'N', 'ACT', 'Historic Freeform Text: IPRATROPIUM BROMIDE Qty Unit: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19245, 1945, 'IPRATROPIUM BROMIDE', 'I', 21, 'µG', '', '', 'N', 'ACT', 'HISTORIC FREEFORM TEXT: IPRATROPIUM BROMIDE QTY UNIT: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71950, 1945, 'IPRATROPIUM BROMIDE', 'I', 20, 'µG', '', '', 'N', 'ACT', 'HISTORIC FREEFORM TEXT: IPRATROPIUM BROMIDE QTY UNIT: AEM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50824, 1945, 'IPRATROPIUM BROMIDE', 'I', 0.025, '%', '', '', 'N', '%', '500MCG/2ML.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43798, 1945, 'IPRATROPIUM BROMIDE', 'I', 125, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: IPRATROPIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19798, 1945, 'IPRATROPIUM BROMIDE', 'I', 250, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: IPRATROPIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16947, 1945, 'IPRATROPIUM BROMIDE', 'I', 250, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: IPRATROPIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50551, 1945, 'IPRATROPIUM BROMIDE', 'I', 250, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50552, 1945, 'IPRATROPIUM BROMIDE', 'I', 250, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51217, 1945, 'IPRATROPIUM BROMIDE', 'I', 250, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50442, 1945, 'IPRATROPIUM BROMIDE', 'I', 125, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50443, 1945, 'IPRATROPIUM BROMIDE', 'I', 250, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60449, 1945, 'IPRATROPIUM BROMIDE', 'I', 250, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60450, 1945, 'IPRATROPIUM BROMIDE', 'I', 250, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60227, 1945, 'IPRATROPIUM BROMIDE', 'I', 125, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67766, 1945, 'IPRATROPIUM BROMIDE', 'I', 125, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20153, 1945, 'IPRATROPIUM BROMIDE', 'I', 0.25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: IPRATROPIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18210, 1945, 'IPRATROPIUM BROMIDE', 'I', 0.125, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: IPRATROPIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51050, 1945, 'IPRATROPIUM BROMIDE (IPRATROPIUM BROMIDE MONOHYDRATE)', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'AS MONOHYDRATE.  0.5MG/2.5ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62586, 1945, 'IPRATROPIUM BROMIDE', 'I', 0.25, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64077, 1945, 'IPRATROPIUM BROMIDE', 'I', 0.3, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63098, 1945, 'IPRATROPIUM BROMIDE', 'I', 0.30, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67727, 1945, 'IPRATROPIUM BROMIDE', 'I', 0.5, 'MG', '', '2.5', 'N', 'ML', 'ANHYDROUS AS MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75181, 1945, 'IPRATROPIUM BROMIDE (IPRATROPIUM BROMIDE MONOHYDRATE)', 'I', 0.5, 'MG', '', '2.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75820, 1945, 'IPRATROPIUM BROMIDE', 'I', 0.5, 'MG', '', '2.5', 'N', 'ML', 'IPRATROPIUM BROMIDE ANHYDROUS [AS MONOHYDRATE]');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4913, 1951, 'GLUTATHIONE DISULFIDE', 'I', 0.0184, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: GLUTATHIONE DISULFIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43774, 1954, 'HYALURONATE SODIUM', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM HYALURONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20231, 1954, 'HYALURONATE SODIUM', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM HYALURONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8228, 1954, 'HYALURONATE SODIUM (HYALURONIC ACID, SODIUM SALT)', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM HYALURONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61993, 1954, 'HYALURONATE SODIUM', 'I', 17, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73895, 1954, 'HYALURONATE SODIUM', 'I', 10, 'MG', '', '', 'N', 'ML', '2009.04.01. HYALURONIC ACID, SODIUM SALT DELETED FROM SUPPLIED AS FIELD SINCE IT''S A SYNONYM TO HYAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43448, 1960, 'INDAPAMIDE', 'I', 1.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDAPAMIDE ((HEMIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43381, 1960, 'INDAPAMIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDAPAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43374, 1960, 'INDAPAMIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDAPAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19089, 1960, 'INDAPAMIDE', 'I', 1.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDAPAMIDE HEMIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19009, 1960, 'INDAPAMIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDAPAMIDE HEMIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18065, 1960, 'INDAPAMIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDAPAMIDE HEMIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63413, 1960, 'INDAPAMIDE', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63417, 1960, 'INDAPAMIDE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4857, 1960, 'INDAPAMIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDAPAMIDE HEMIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50491, 1960, 'INDAPAMIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'INDAPAMIDE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63577, 1960, 'INDAPAMIDE', 'I', 1.25, 'MG', '', '', 'N', '', 'INDAPAMIDE HEMIHYDRATE 1.25MG/TAB.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63891, 1960, 'INDAPAMIDE', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63893, 1960, 'INDAPAMIDE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63090, 1960, 'INDAPAMIDE', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63091, 1960, 'INDAPAMIDE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65803, 1960, 'INDAPAMIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'INDAPAMIDE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69270, 1960, 'INDAPAMIDE', 'I', 1.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: INDAPAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70751, 1960, 'INDAPAMIDE', 'I', 0.625, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70752, 1960, 'INDAPAMIDE', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71487, 1960, 'INDAPAMIDE', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80705, 1960, 'INDAPAMIDE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79803, 1960, 'INDAPAMIDE', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79804, 1960, 'INDAPAMIDE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43071, 1966, 'NIFEDIPINE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: NIFEDIPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42967, 1966, 'NIFEDIPINE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: NIFEDIPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19557, 1966, 'NIFEDIPINE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: NIFEDIPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19232, 1966, 'NIFEDIPINE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: NIFEDIPINE Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19098, 1966, 'NIFEDIPINE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: NIFEDIPINE Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19099, 1966, 'NIFEDIPINE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: NIFEDIPINE Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11183, 1966, 'NIFEDIPINE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: NIFEDIPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74666, 11980, 'LEFLUNOMIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8376, 1966, 'NIFEDIPINE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NIFEDIPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9938, 1966, 'NIFEDIPINE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: NIFEDIPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59718, 1966, 'NIFEDIPINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59719, 1966, 'NIFEDIPINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60957, 1966, 'NIFEDIPINE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80655, 1966, 'NIFEDIPINE', 'I', 60, 'MG', '', '', 'N', '', 'MICRONIZED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79926, 1966, 'NIFEDIPINE', 'I', 20, 'MG', '', '', 'N', '', 'EXTENDED RELEASE TABLET.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79927, 1966, 'NIFEDIPINE', 'I', 30, 'MG', '', '', 'N', '', 'EXTENDED RELEASE TABLET.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79928, 1966, 'NIFEDIPINE', 'I', 60, 'MG', '', '', 'N', '', 'EXTENDED RELEASE TABLET.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83448, 1966, 'NIFEDIPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49155, 1901, 'MEXILETINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49157, 1901, 'MEXILETINE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42867, 1904, 'GEMFIBROZIL', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: GEMFIBROZIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19191, 1904, 'GEMFIBROZIL', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: GEMFIBROZIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17230, 1904, 'GEMFIBROZIL', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: GEMFIBROZIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15824, 1904, 'GEMFIBROZIL', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: GEMFIBROZIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15825, 1904, 'GEMFIBROZIL', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: GEMFIBROZIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13840, 1904, 'GEMFIBROZIL', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: GEMFIBROZIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13841, 1904, 'GEMFIBROZIL', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: GEMFIBROZIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9259, 1904, 'GEMFIBROZIL', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: GEMFIBROZIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5759, 1904, 'GEMFIBROZIL', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: GEMFIBROZIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48859, 1904, 'GEMFIBROZIL', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49439, 1904, 'GEMFIBROZIL', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49689, 1904, 'GEMFIBROZIL', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63454, 1904, 'GEMFIBROZIL', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65804, 1904, 'GEMFIBROZIL', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: GEMFIBROZIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65265, 1904, 'GEMFIBROZIL', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65364, 1904, 'GEMFIBROZIL', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74001, 1904, 'GEMFIBROZIL', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74002, 1904, 'GEMFIBROZIL', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66760, 1906, 'LASALOCID SODIUM', 'I', 150, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66882, 1906, 'LASALOCID SODIUM', 'I', 150, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80733, 1906, 'LASALOCID SODIUM', 'I', 200, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80734, 1906, 'LASALOCID SODIUM', 'I', 200, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81127, 1910, 'NIMODIPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43307, 1913, 'CICLOPIROX OLAMINE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: CICLOPIROX OLAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71470, 1913, 'CICLOPIROX OLAMINE', 'I', 1.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43306, 1913, 'CICLOPIROX OLAMINE', 'I', 10, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: CICLOPIROX OLAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19720, 1921, 'TIAPROFENIC ACID', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TIAPROFENIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19722, 1921, 'TIAPROFENIC ACID', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: TIAPROFENIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18761, 1921, 'TIAPROFENIC ACID', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: TIAPROFENIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18762, 1921, 'TIAPROFENIC ACID', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: TIAPROFENIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17118, 1921, 'TIAPROFENIC ACID', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: TIAPROFENIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17119, 1921, 'TIAPROFENIC ACID', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: TIAPROFENIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50097, 1921, 'TIAPROFENIC ACID', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50098, 1921, 'TIAPROFENIC ACID', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50342, 1921, 'TIAPROFENIC ACID', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5995, 1924, 'TENIPOSIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TENIPOSIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43330, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43331, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 90, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43332, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17253, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17254, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DILTIAZEM HCL QTY UNIT: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17125, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17102, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11161, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11162, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9172, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9173, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10394, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10395, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9902, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9903, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47431, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48067, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48071, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48076, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48077, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50278, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50279, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50280, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50796, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50798, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50799, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50333, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50334, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50335, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50338, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50458, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50459, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50460, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50461, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50462, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 360, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67243, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67244, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67245, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67246, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66289, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66290, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66291, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66292, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70038, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70039, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70040, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70041, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70042, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 360, 'MG', '', '', 'N', '', 'Historic Freeform Text: DILTIAZEM HCL Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74195, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74196, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74197, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74198, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74199, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 360, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75715, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75716, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75717, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75718, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75719, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 360, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77643, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77644, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77645, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77646, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77647, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 360, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81070, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81071, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81072, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81073, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81074, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 360, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84095, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84096, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 180, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84097, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84098, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49026, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64862, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68717, 1926, 'DILTIAZEM HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43321, 1929, 'PENTOXIFYLLINE', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: PENTOXIFYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48622, 1929, 'PENTOXIFYLLINE', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49240, 1929, 'PENTOXIFYLLINE', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44254, 1929, 'PENTOXIFYLLINE', 'I', 2, 'G', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: PENTOXIFYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5262, 1930, 'AMSACRINE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: AMSACRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13636, 1859, 'MISOPROSTOL', 'I', 200, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MISOPROSTOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48191, 1859, 'MISOPROSTOL', 'I', 200, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64343, 1859, 'MISOPROSTOL', 'I', 100, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64344, 1859, 'MISOPROSTOL', 'I', 200, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67965, 1859, 'MISOPROSTOL', 'I', 100, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67966, 1859, 'MISOPROSTOL', 'I', 200, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68082, 1859, 'MISOPROSTOL', 'I', 0.1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68083, 1859, 'MISOPROSTOL', 'I', 0.2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43573, 1863, 'OXAPROZIN', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAPROZIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67591, 1863, 'OXAPROZIN', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAPROZIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13514, 1864, 'FLECAINIDE ACETATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLECAINIDE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13513, 1864, 'FLECAINIDE ACETATE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLECAINIDE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76117, 1864, 'FLECAINIDE ACETATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76118, 1864, 'FLECAINIDE ACETATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8407, 1867, 'NITROSCANATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: NITROSCANATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8408, 1867, 'NITROSCANATE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: NITROSCANATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11451, 1892, 'SALINOMYCIN SODIUM', 'I', 60, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: SALINOMYCIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10838, 1892, 'SALINOMYCIN SODIUM', 'I', 60, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: SALINOMYCIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49562, 1892, 'SALINOMYCIN SODIUM', 'I', 120, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60763, 1892, 'SALINOMYCIN SODIUM', 'I', 60, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60973, 1892, 'SALINOMYCIN SODIUM', 'I', 120, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70887, 1892, 'SALINOMYCIN SODIUM', 'I', 120, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75212, 1892, 'SALINOMYCIN SODIUM', 'I', 120, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8464, 1893, 'PROPAFENONE HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PROPAFENONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8465, 1893, 'PROPAFENONE HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROPAFENONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67227, 1893, 'PROPAFENONE HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67228, 1893, 'PROPAFENONE HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69411, 1893, 'PROPAFENONE HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69412, 1893, 'PROPAFENONE HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67659, 1893, 'PROPAFENONE HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PROPAFENONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67660, 1893, 'PROPAFENONE HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PROPAFENONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67721, 1893, 'PROPAFENONE HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67722, 1893, 'PROPAFENONE HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77991, 1893, 'PROPAFENONE HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77992, 1893, 'PROPAFENONE HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82854, 1893, 'PROPAFENONE HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82855, 1893, 'PROPAFENONE HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65048, 11951, 'MARBOFLOXACIN', 'I', 200, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65049, 11951, 'MARBOFLOXACIN', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65050, 11951, 'MARBOFLOXACIN', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65051, 11951, 'MARBOFLOXACIN', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83919, 11951, 'MARBOFLOXACIN', 'I', 3, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65111, 11956, 'OSELTAMIVIR (OSELTAMIVIR PHOSPHATE)', 'I', 75, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79011, 11956, 'OSELTAMIVIR (OSELTAMIVIR PHOSPHATE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79012, 11956, 'OSELTAMIVIR (OSELTAMIVIR PHOSPHATE)', 'I', 45, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69640, 11956, 'OSELTAMIVIR (OSELTAMIVIR PHOSPHATE)', 'I', 12, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65112, 11957, 'DACLIZUMAB', 'I', 5, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6366, 11969, 'SODIUM CITRATE DIHYDRATE', 'I', 0.17, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM CITRATE  2008.11.28. DIHYDRATE ADDED TO A. I. SODIUM CITRATE AS REQUE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8523, 11969, 'SODIUM CITRATE DIHYDRATE', 'I', 67.52, 'G', '', '400', 'N', 'G', 'AT VET DRUGS'' REQUEST (K. LANTHIER), SODIUM CITRATE WAS CHANGED TO SODIUM CITRATE DIHYDRATE. 2004.08');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65558, 11980, 'LEFLUNOMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65559, 11980, 'LEFLUNOMIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65560, 11980, 'LEFLUNOMIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74173, 11980, 'LEFLUNOMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76954, 11980, 'LEFLUNOMIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77371, 11980, 'LEFLUNOMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77372, 11980, 'LEFLUNOMIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79493, 11980, 'LEFLUNOMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79494, 11980, 'LEFLUNOMIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80469, 11980, 'LEFLUNOMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80470, 11980, 'LEFLUNOMIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83692, 11980, 'LEFLUNOMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83693, 11980, 'LEFLUNOMIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65597, 11982, 'RITUXIMAB', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65716, 11983, 'SELAMECTIN', 'I', 240, 'MG', '', '2', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65719, 11983, 'SELAMECTIN', 'I', 30, 'MG', '', '0.25', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65720, 11983, 'SELAMECTIN', 'I', 45, 'MG', '', '0.75', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65718, 11983, 'SELAMECTIN', 'I', 120, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65721, 11983, 'SELAMECTIN', 'I', 60, 'MG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65722, 11983, 'SELAMECTIN', 'I', 15, 'MG', '', '0.25', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76490, 11983, 'SELAMECTIN', 'I', 120, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65740, 11984, 'OXCARBAZEPINE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65741, 11984, 'OXCARBAZEPINE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65742, 11984, 'OXCARBAZEPINE', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76988, 11984, 'OXCARBAZEPINE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76989, 11984, 'OXCARBAZEPINE', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68661, 11984, 'OXCARBAZEPINE', 'I', 60, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65746, 11985, 'MELARSOMINE DIHYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65791, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 1.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65792, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 3, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65793, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 4.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65794, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 6, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79154, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 1.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79155, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79156, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 4.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79157, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81846, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 1.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81847, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81848, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 4.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81849, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79159, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 1.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79160, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 3.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79161, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 4.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79162, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 6.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81001, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 1.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81002, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 3, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81003, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 4.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81004, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 6, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79687, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 1.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79688, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79689, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 4.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79690, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82234, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 1.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82235, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 3, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82236, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 4.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82237, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 6, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78816, 11987, 'RIVASTIGMINE', 'I', 9, 'MG', '', '5', 'Y', 'SQ CM', 'IN VIVO RELEASE RATE OF 4.6MG/24H.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78817, 11987, 'RIVASTIGMINE', 'I', 18, 'MG', '', '10', 'Y', 'SQ CM', 'IN VIVO RELEASE RATE OF 9.5MG/24H.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69257, 11987, 'RIVASTIGMINE (RIVASTIGMINE HYDROGEN TARTRATE)', 'I', 2, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66078, 11996, 'VERTEPORFIN', 'I', 15, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7439, 11998, 'EMBUTRAMIDE', 'I', 200, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: N(2-(M-METHOXY PHENYL)-2-ETHYLBUTYL-(1))HYDROXY BUTYRAMID ------------------');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66192, 12003, 'KETANSERIN (KETANSERIN TARTRATE)', 'I', 2.5, 'MG', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66196, 12005, 'IBUTILIDE FUMARATE', 'I', 0.1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66198, 12006, 'CABERGOLINE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78674, 12006, 'CABERGOLINE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66262, 12009, 'DIFLOXACIN (DIFLOXACIN HYDROCHLORIDE)', 'I', 45.4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66263, 12009, 'DIFLOXACIN (DIFLOXACIN HYDROCHLORIDE)', 'I', 136, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66264, 12009, 'DIFLOXACIN (DIFLOXACIN HYDROCHLORIDE)', 'I', 11.4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66344, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66345, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66346, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 45, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76044, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76045, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76046, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 45, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78323, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78324, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78325, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 45, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78357, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78358, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78359, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 45, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81184, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81185, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81186, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 45, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79757, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79758, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79759, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 45, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78676, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78677, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78678, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 45, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79332, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79333, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79334, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 45, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79335, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47227, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79336, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79341, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 45, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78824, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78825, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78827, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 45, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78845, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78846, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78847, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 45, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78875, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78876, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78877, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 45, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78819, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78818, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78820, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 45, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82518, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82519, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 45, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80616, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80617, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80618, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 45, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83078, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83079, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83080, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 45, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85042, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85043, 12012, 'PIOGLITAZONE (PIOGLITAZONE HYDROCHLORIDE)', 'I', 45, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66455, 12013, 'KENTUCKY BLUE/JUNE', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '(POA PRATENSIS). 100000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66502, 12019, 'EXEMESTANE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66518, 12020, 'ALLERGEN EXTRACT - ALUM PRECIPITATED', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '10000 PNU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66520, 12020, 'ALLERGEN EXTRACT - ALUM PRECIPITATED', 'I', 1000, 'UNIT', '', '', 'N', 'ML', '1000 PNU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66521, 12020, 'ALLERGEN EXTRACT - ALUM PRECIPITATED', 'I', 100, 'UNIT', '', '', 'N', 'ML', '100 PNU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66522, 12022, 'ALLERGEN EXTRACT - DIAGNOSTIC', 'I', 0, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75458, 12024, 'ZOLEDRONIC ACID', 'I', 5, 'MG', '', '100', 'N', 'ML', 'CONTAINS 5.330 MG ZOLEDRONIC ACID MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72636, 12024, 'ZOLEDRONIC ACID', 'I', 4, 'MG', '', '5', 'N', 'ML', 'CORRESPONDS TO 4.264 MG ZOLEDRONIC ACID MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66576, 12026, 'RILUZOLE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66643, 12027, 'BASILIXIMAB', 'I', 20, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63832, 12028, 'INSULIN LISPRO PROTAMINE SUSPENSION', 'I', 75, 'UNIT', '', '', 'N', 'ML', '100 UNITS/ML: 25% INSULIN LISPRO INJECTION, 75% INSULIN LISPRO PROTAMINE SUSPENSION (RDNA ORIGIN).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63835, 12028, 'INSULIN LISPRO PROTAMINE SUSPENSION', 'I', 50, 'UNIT', '', '', 'N', 'ML', '100 UNITS/ML: 50% INSULIN LISPRO INJECTION, 50% INSULIN LISPRO PROTAMINE SUSPENSION (RDNA ORIGIN).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36481, 12030, 'DEXAMETHASONE PHOSPHATE (DEXAMETHASONE SODIUM PHOSPHATE)', 'I', 10, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: DEXAMETHASONE PHOSPHATE ((AS DEX.NA PHOS.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36480, 12030, 'DEXAMETHASONE PHOSPHATE (DEXAMETHASONE SODIUM PHOSPHATE)', 'I', 4, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: DEXAMETHASONE PHOSPHATE ((AS DEX.NA PHOS.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13255, 12030, 'DEXAMETHASONE PHOSPHATE (DEXAMETHASONE SODIUM PHOSPHATE)', 'I', 4, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXAMETHASONE SOD PHOS ((DEXAMETH PHOS EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11011, 12030, 'DEXAMETHASONE PHOSPHATE (DEXAMETHASONE SODIUM PHOSPHATE)', 'I', 10, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: DEXAMETH SOD PHOSPHATE ((DEXAMETH PHOSPH EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9613, 12030, 'DEXAMETHASONE PHOSPHATE (DEXAMETHASONE SODIUM PHOSPHATE)', 'I', 4, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: DEXAMETHASONE SOD PHOSPH ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9616, 12030, 'DEXAMETHASONE PHOSPHATE (DEXAMETHASONE SODIUM PHOSPHATE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: DEXAMETHASONE SOD PHOSPH ((DEXMETH PHOSPH EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6593, 12030, 'DEXAMETHASONE PHOSPHATE (DEXAMETHASONE SODIUM PHOSPHATE)', 'I', 4, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXAMETHAZONE SOD PHOS ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2252, 12030, 'DEXAMETHASONE PHOSPHATE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXAMETHASONE 21-PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1501, 12030, 'DEXAMETHASONE PHOSPHATE', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXAMETHASONE 21-PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74553, 12030, 'DEXAMETHASONE PHOSPHATE (DEXAMETHASONE SODIUM PHOSPHATE)', 'I', 10, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: DEXAMETH SOD PHOSPHATE ((DEXAMETH PHOSPH EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76019, 12032, 'ETANERCEPT', 'I', 50, 'MG', '', '', 'N', 'ML', '(0.98ML)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66735, 12032, 'ETANERCEPT', 'I', 25, 'MG', '', '', 'N', 'KIT', '25 MG/VIAL/KIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78104, 12033, 'BUPRENORPHINE (BUPRENORPHINE HYDROCHLORIDE)', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78105, 12033, 'BUPRENORPHINE (BUPRENORPHINE HYDROCHLORIDE)', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82671, 12033, 'BUPRENORPHINE', 'I', 5, 'µG', '', '', 'N', 'HOUR', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82676, 12033, 'BUPRENORPHINE', 'I', 20, 'µG', '', '', 'N', 'HOUR', 'BUPRENORPHINE 20µG/HOUR FOR 7 DAYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82675, 12033, 'BUPRENORPHINE', 'I', 10, 'µG', '', '', 'N', 'HOUR', 'BUPRENORPHINE 10µG/HOUR FOR 7 DAYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66804, 12034, 'MOXIFLOXACIN (MOXIFLOXACIN HYDROCHLORIDE)', 'I', 400, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73714, 12034, 'MOXIFLOXACIN (MOXIFLOXACIN HYDROCHLORIDE)', 'I', 0.5, '%', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70586, 12034, 'MOXIFLOXACIN (MOXIFLOXACIN HYDROCHLORIDE)', 'I', 400, 'MG', '', '250', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66805, 12036, 'PEGINTERFERON ALFA-2B', 'I', 74, 'µG', '', '', 'N', 'VIAL', 'IT DELIVERS 50MCG/0.5ML OF RECONSTITUTED SOLUTION.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66806, 12036, 'PEGINTERFERON ALFA-2B', 'I', 118.4, 'µG', '', '', 'N', 'VIAL', 'IT DELIVERS 80MCG/0.5ML OF RECONSTITUTED SOLUTION.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66807, 12036, 'PEGINTERFERON ALFA-2B', 'I', 177.6, 'µG', '', '', 'N', 'VIAL', 'IT DELIVERS 120MCG/0.5ML  OF RECONSTITUTED SOLUTION.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66808, 12036, 'PEGINTERFERON ALFA-2B', 'I', 222, 'µG', '', '', 'N', 'VIAL', 'IT DELIVERS 150MCG/0.5ML OF RECONSTITUTED SOLUTION.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70155, 12036, 'PEGINTERFERON ALFA-2B', 'I', 50, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70156, 12036, 'PEGINTERFERON ALFA-2B', 'I', 80, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70157, 12036, 'PEGINTERFERON ALFA-2B', 'I', 100, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70158, 12036, 'PEGINTERFERON ALFA-2B', 'I', 120, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70159, 12036, 'PEGINTERFERON ALFA-2B', 'I', 150, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73948, 12036, 'PEGINTERFERON ALFA-2B', 'I', 80, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73950, 12036, 'PEGINTERFERON ALFA-2B', 'I', 100, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73951, 12036, 'PEGINTERFERON ALFA-2B', 'I', 120, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73952, 12036, 'PEGINTERFERON ALFA-2B', 'I', 150, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85660, 12036, 'PEGINTERFERON ALFA-2B', 'I', 80, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85661, 12036, 'PEGINTERFERON ALFA-2B', 'I', 100, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85662, 12036, 'PEGINTERFERON ALFA-2B', 'I', 120, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85663, 12036, 'PEGINTERFERON ALFA-2B', 'I', 150, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84468, 12037, 'CLINDAMYCIN PHOSPHATE', 'I', 1.200, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66820, 12038, 'FOMEPIZOLE', 'I', 1, 'G', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66826, 12039, 'GADOVERSETAMIDE', 'I', 330.9, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42310, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: 2-ETHYLHEXYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30927, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: 2-ETHYLHEXYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18691, 12048, 'OCTISALATE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: 2-ETHYLHEXYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15869, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: 2-ETHYLHEXYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50532, 12048, 'OCTISALATE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53823, 12048, 'OCTISALATE', 'I', 4, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61295, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61296, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62357, 12048, 'OCTISALATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60325, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62463, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63264, 12048, 'OCTISALATE', 'I', 4.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64081, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63348, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64701, 12048, 'OCTISALATE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64702, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64225, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64289, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65907, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65424, 12048, 'OCTISALATE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65426, 12048, 'OCTISALATE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65425, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64883, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66706, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66828, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66892, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66974, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68325, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68818, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68355, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69420, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68051, 12048, 'OCTISALATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68574, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71359, 12048, 'OCTISALATE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71383, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71384, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71386, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72275, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70085, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71534, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70856, 12048, 'OCTISALATE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69552, 12048, 'OCTISALATE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70253, 12048, 'OCTISALATE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70878, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70880, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71649, 12048, 'OCTISALATE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71650, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71098, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71099, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71101, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71148, 12048, 'OCTISALATE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69886, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71277, 12048, 'OCTISALATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75172, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75229, 12048, 'OCTISALATE', 'I', 2.0, '%', '', '', 'N', '', 'V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76634, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76635, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74004, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75271, 12048, 'OCTISALATE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75298, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76711, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74106, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75404, 12048, 'OCTISALATE', 'I', 1.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75409, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75413, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75414, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74244, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75512, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75513, 12048, 'OCTISALATE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72332, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72336, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72339, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74321, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75531, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75557, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75594, 12048, 'OCTISALATE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72392, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75697, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75709, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73166, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74441, 12048, 'OCTISALATE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74447, 12048, 'OCTISALATE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: 2-ETHYLHEXYLSALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74448, 12048, 'OCTISALATE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: 2-ETHYLHEXYLSALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72581, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72582, 12048, 'OCTISALATE', 'I', 4.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72585, 12048, 'OCTISALATE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74548, 12048, 'OCTISALATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74554, 12048, 'OCTISALATE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74559, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74560, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74591, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75847, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74651, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74654, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75919, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73323, 12048, 'OCTISALATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73324, 12048, 'OCTISALATE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74749, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76004, 12048, 'OCTISALATE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73436, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75779, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73522, 12048, 'OCTISALATE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74916, 12048, 'OCTISALATE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76179, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76213, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76214, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73587, 12048, 'OCTISALATE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74918, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74992, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73755, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73756, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74998, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76325, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76328, 12048, 'OCTISALATE', 'I', 2.6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76349, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73821, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77488, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78108, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78156, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78164, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77065, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77531, 12048, 'OCTISALATE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77533, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77441, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77461, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77550, 12048, 'OCTISALATE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77551, 12048, 'OCTISALATE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77577, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77578, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77610, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77612, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77613, 12048, 'OCTISALATE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78220, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76897, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76898, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77058, 12048, 'OCTISALATE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77436, 12048, 'OCTISALATE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77517, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77611, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77614, 12048, 'OCTISALATE', 'I', 5.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77629, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77630, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77608, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76890, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77681, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77682, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77812, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77883, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78240, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77076, 12048, 'OCTISALATE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76869, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'Historic Freeform Text: 2-ETHYLHEXYLSALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77299, 12048, 'OCTISALATE', 'I', 2, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78310, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78311, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78317, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77768, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77927, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77928, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77581, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76934, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77321, 12048, 'OCTISALATE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77322, 12048, 'OCTISALATE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77323, 12048, 'OCTISALATE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77324, 12048, 'OCTISALATE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77325, 12048, 'OCTISALATE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77326, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78014, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78019, 12048, 'OCTISALATE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78020, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78047, 12048, 'OCTISALATE', 'I', 3.50, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77513, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77515, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77617, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77618, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78331, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77287, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82245, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79960, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79018, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78658, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78689, 12048, 'OCTISALATE', 'I', 4.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78690, 12048, 'OCTISALATE', 'I', 5.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79082, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79181, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79182, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78611, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78700, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78701, 12048, 'OCTISALATE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79256, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79262, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79263, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79265, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78709, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78989, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79294, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79798, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78959, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79719, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79407, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80173, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78621, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78895, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79252, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79253, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79255, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79257, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78605, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78606, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78929, 12048, 'OCTISALATE', 'I', 5.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78930, 12048, 'OCTISALATE', 'I', 5.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79533, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80565, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79238, 12048, 'OCTISALATE', 'I', 5.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79319, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79320, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79321, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79322, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79930, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79931, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79197, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78629, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78635, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79982, 12048, 'OCTISALATE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79067, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79226, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79227, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79232, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79233, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79992, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80227, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80110, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80111, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80045, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78647, 12048, 'OCTISALATE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82839, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82383, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79090, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79184, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79187, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79086, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78589, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79251, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82461, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82622, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80457, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80820, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83915, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83916, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84348, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84347, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84353, 12048, 'OCTISALATE', 'I', 0.49, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84379, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84541, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84553, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84603, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84903, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85091, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16229, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67685, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70086, 12048, 'OCTISALATE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75370, 12048, 'OCTISALATE', 'I', 5.00, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75591, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72583, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75934, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75980, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74849, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74883, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74884, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74885, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76200, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76215, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74999, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76204, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76351, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72764, 12048, 'OCTISALATE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77462, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77463, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77389, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77390, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77391, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77392, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77473, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77288, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76938, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76894, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76863, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76891, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76892, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77633, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77721, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76941, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78222, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79440, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81654, 12048, 'OCTISALATE', 'I', 3.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81656, 12048, 'OCTISALATE', 'I', 4.50, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81175, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79851, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80135, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81909, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79531, 12048, 'OCTISALATE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79849, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79850, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81268, 12048, 'OCTISALATE', 'I', 4.75, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82154, 12048, 'OCTISALATE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82780, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82843, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79579, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80128, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80480, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80566, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82206, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82210, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80985, 12048, 'OCTISALATE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82242, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82930, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82931, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82964, 12048, 'OCTISALATE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79731, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78685, 12048, 'OCTISALATE', 'I', 4.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78686, 12048, 'OCTISALATE', 'I', 5.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79183, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80487, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80488, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79766, 12048, 'OCTISALATE', 'I', 5.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80527, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80723, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82834, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79773, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80747, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80748, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80791, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81406, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82015, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82016, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82018, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82268, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82161, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82592, 12048, 'OCTISALATE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81716, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79466, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79468, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79469, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79470, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80088, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82602, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80025, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80026, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80027, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80174, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80175, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80435, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80176, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80436, 12048, 'OCTISALATE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80398, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80400, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81451, 12048, 'OCTISALATE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81017, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80049, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80055, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80051, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80052, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80056, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82493, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82494, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82987, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80198, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80199, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80200, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81605, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'Y', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81708, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81709, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81557, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81779, 12048, 'OCTISALATE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81842, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82014, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82013, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82508, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82617, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80219, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80478, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80568, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79980, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79983, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80024, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80022, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80023, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80411, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81076, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79647, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79989, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80228, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80113, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80114, 12048, 'OCTISALATE', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80577, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81301, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81660, 12048, 'OCTISALATE', 'I', 3.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79618, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80460, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80069, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80070, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80696, 12048, 'OCTISALATE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81829, 12048, 'OCTISALATE', 'I', 4.75, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82305, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82515, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80393, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80858, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81926, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'SEE PRODUCT NOTE FIELD.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81927, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81928, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81929, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'SEE PRODUCT NOTE FIELD.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81930, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'SEE PRODUCT NOTE FIELD.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81293, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82380, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82381, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82415, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79484, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80382, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', 'W/W', 'AMOUNT OF OCTISALATE CHANGED FROM 3.5% TO 3.0% AS PER ORIGINAL FORM 3011, THE NEW LABEL HAS BEEN COR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80383, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80392, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80424, 12048, 'OCTISALATE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80425, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81911, 12048, 'OCTISALATE', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81912, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80061, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80516, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80517, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80525, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80524, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80526, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81043, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81044, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82368, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82367, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82372, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79871, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82017, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82019, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82020, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80669, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80670, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80671, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81913, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81914, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81915, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81916, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81919, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81920, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81921, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82621, 12048, 'OCTISALATE', 'I', 4.75, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80503, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80504, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83050, 12048, 'OCTISALATE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79249, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82244, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82373, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82462, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80256, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80537, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80539, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82060, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82062, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82065, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82063, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82066, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82067, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80034, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80035, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80178, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81069, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80099, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80302, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82543, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78779, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80864, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80865, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80879, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83001, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79868, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80380, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80567, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80595, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82779, 12048, 'OCTISALATE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83072, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83098, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83101, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83111, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83112, 12048, 'OCTISALATE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83116, 12048, 'OCTISALATE', 'I', 0.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83168, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83278, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83388, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83389, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83391, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83403, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83420, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83580, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83581, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83677, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83737, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83786, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83785, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83787, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83859, 12048, 'OCTISALATE', 'I', 5.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83866, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83869, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83881, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83902, 12048, 'OCTISALATE', 'I', 4.9, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83903, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83908, 12048, 'OCTISALATE', 'I', 4.75, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83983, 12048, 'OCTISALATE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83984, 12048, 'OCTISALATE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84003, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84004, 12048, 'OCTISALATE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84006, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84034, 12048, 'OCTISALATE', 'I', 4.75, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84035, 12048, 'OCTISALATE', 'I', 4.75, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84036, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84042, 12048, 'OCTISALATE', 'I', 4.75, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84061, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84076, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84092, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84207, 12048, 'OCTISALATE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84257, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84291, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84292, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84403, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84415, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84414, 12048, 'OCTISALATE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84423, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84424, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84431, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84472, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84519, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84520, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84530, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84574, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84576, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84579, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84580, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84664, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84706, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84707, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84715, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84959, 12048, 'OCTISALATE', 'I', 5.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84962, 12048, 'OCTISALATE', 'I', 5.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84974, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84975, 12048, 'OCTISALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85096, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85097, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85098, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85099, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85341, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85343, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15799, 12048, 'OCTISALATE', 'I', 4, '%', '', '', 'N', '%', 'Historic Freeform Text: 2-ETHYLHEXYLSALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53421, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53422, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53423, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53424, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53425, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53426, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61886, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '%', 'Historic Freeform Text: OCTYL SALICYLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60302, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60326, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60327, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60328, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63346, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63349, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63351, 12048, 'OCTISALATE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63661, 12048, 'OCTISALATE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63662, 12048, 'OCTISALATE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83672, 12048, 'OCTISALATE', 'I', 3, '%', '', '50', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62467, 12048, 'OCTISALATE', 'I', 5, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71227, 12048, 'OCTISALATE', 'I', 3, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62885, 12048, 'OCTISALATE', 'I', 20, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67049, 12053, 'PERFLUTREN', 'I', 150, 'µL', '', '', 'N', 'ML', '150+OR-100MCL/ML WHEN SHAKEN (ACTIVATED).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74247, 12056, 'GATIFLOXACIN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4222, 12057, 'PIZOTIFEN (PIZOTIFEN MALATE)', 'I', 1, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: PIZOTYLINE HYDROGEN ((MALATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48362, 12057, 'PIZOTIFEN (PIZOTIFEN MALATE)', 'I', 0.50, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: PIZOTYLINE ((HYDROGEN MALATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67103, 12058, 'POLYOXYPROPYLENE/POLY-OXYETHYLENE BLOCK COPOLYMER-IODINE COMPLEX', 'I', 5.6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71350, 12064, 'SIROLIMUS', 'I', 1.0, 'MG', '', '', 'N', '', 'ACCORDING TO DPIF REC''D ON 2008.08.05 (3RD UPDATE), LACTOSE MONOHYDRATE USES NON-ANIMAL DERIVED RAW ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67127, 12064, 'SIROLIMUS', 'I', 1.0, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67151, 12066, 'MEQUINOL', 'I', 2, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71480, 12077, 'PIMECROLIMUS', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4989, 318, 'AMMONIUM CHLORIDE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11229, 318, 'AMMONIUM CHLORIDE', 'I', 125, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6844, 318, 'AMMONIUM CHLORIDE', 'I', 125, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4469, 318, 'AMMONIUM CHLORIDE', 'I', 125, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66839, 318, 'AMMONIUM CHLORIDE', 'I', 125, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67953, 318, 'AMMONIUM CHLORIDE', 'I', 125, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69689, 318, 'AMMONIUM CHLORIDE', 'I', 125, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2480, 318, 'AMMONIUM CHLORIDE', 'I', 226.8, 'G', '', '454', 'N', 'G', 'Historic Freeform Text: AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2195, 318, 'AMMONIUM CHLORIDE', 'I', 226.8, 'G', '', '454', 'N', 'G', 'Historic Freeform Text: AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3998, 2913, 'AMMONIUM HYDROXIDE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: AMMONIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2022, 2913, 'AMMONIUM HYDROXIDE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: AMMONIUM HYDROXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2645, 6977, 'OXYQUINOLINE SULFATE', 'I', 100, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: OXYQUINOLINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15808, 10292, 'SODIUM ACETATE', 'I', 229, 'MG', '', '', 'N', '', 'Historic Freeform Text: SODIUM ACETATE ((3H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15809, 10292, 'SODIUM ACETATE', 'I', 229, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5698, 10292, 'SODIUM ACETATE', 'I', 380, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6202, 10292, 'SODIUM ACETATE', 'I', 229, 'MG', '', '', 'N', '', 'SODIUM ACETATE TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2479, 10292, 'SODIUM ACETATE', 'I', 24, 'MG', '', '', 'N', '', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2191, 10292, 'SODIUM ACETATE', 'I', 24, 'MG', '', '', 'N', '', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66863, 10292, 'SODIUM ACETATE', 'I', 229, 'MG', '', '', 'N', '', 'SODIUM ACETATE TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15177, 10292, 'SODIUM ACETATE', 'I', 0.39, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM ACETATE ((TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35667, 10292, 'SODIUM ACETATE', 'I', 11.59, '%', '', '', 'N', '%', 'Historic Freeform Text: SODIUM ACETATE ((TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31465, 10292, 'SODIUM ACETATE', 'I', 9.845, 'G', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: SODIUM ACETATE ANHYDROUS.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36695, 10292, 'SODIUM ACETATE', 'I', 3.05, 'G', '', '30', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE ((TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23184, 10292, 'SODIUM ACETATE', 'I', 2.72, 'G', '', '25', 'N', 'ML', 'SODIUM ACETATE.3H2O');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9833, 10292, 'SODIUM ACETATE', 'I', 13.6, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3407, 10292, 'SODIUM ACETATE', 'I', 3.8, 'G', '', '60', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2002, 10292, 'SODIUM ACETATE', 'I', 4.68, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1615, 10292, 'SODIUM ACETATE', 'I', 4.68, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7141, 10292, 'SODIUM ACETATE', 'I', 3, 'G', '', '1000', 'N', 'ML', 'SODIUM ACETATE TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35083, 10292, 'SODIUM ACETATE', 'I', 328, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM ACETATE ((ANHYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31360, 10292, 'SODIUM ACETATE', 'I', 328, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE ((ANHYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 10292, 'SODIUM ACETATE', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21767, 10292, 'SODIUM ACETATE', 'I', 280, 'MG', '', '100', 'N', 'ML', 'SODIUM ACETATE TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21764, 10292, 'SODIUM ACETATE', 'I', 330, 'MG', '', '100', 'N', 'ML', 'SODIUM ACETATE TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21757, 10292, 'SODIUM ACETATE', 'I', 370, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21691, 10292, 'SODIUM ACETATE', 'I', 680, 'MG', '', '20', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21998, 10292, 'SODIUM ACETATE', 'I', 370, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 10292, 'SODIUM ACETATE', 'I', 297, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 10292, 'SODIUM ACETATE', 'I', 297, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 10292, 'SODIUM ACETATE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13686, 2072, 'ALPRAZOLAM', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 10292, 'SODIUM ACETATE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 10292, 'SODIUM ACETATE', 'I', 170, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 10292, 'SODIUM ACETATE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 10292, 'SODIUM ACETATE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE ((HYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18029, 10292, 'SODIUM ACETATE', 'I', 3.9, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 10292, 'SODIUM ACETATE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 10292, 'SODIUM ACETATE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 10292, 'SODIUM ACETATE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 10292, 'SODIUM ACETATE', 'I', 297, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 10292, 'SODIUM ACETATE', 'I', 170, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 10292, 'SODIUM ACETATE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 10292, 'SODIUM ACETATE', 'I', 297, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE ((HYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14578, 10292, 'SODIUM ACETATE', 'I', 220, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12741, 10292, 'SODIUM ACETATE', 'I', 370, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11905, 10292, 'SODIUM ACETATE', 'I', 4.08, 'MG', '', '', 'N', 'ML', 'SODIUM ACETATE TRIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8169, 10292, 'SODIUM ACETATE', 'I', 2.36, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM ACETATE ((TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 10292, 'SODIUM ACETATE', 'I', 250, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6360, 10292, 'SODIUM ACETATE', 'I', 3.9, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5535, 10292, 'SODIUM ACETATE', 'I', 121, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM ACETATE (ANHYDROUS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 10292, 'SODIUM ACETATE', 'I', 250, 'MG', '', '100', 'N', 'ML', 'SODIUM ACETATE TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3820, 10292, 'SODIUM ACETATE', 'I', 295, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 10292, 'SODIUM ACETATE', 'I', 250, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 10292, 'SODIUM ACETATE', 'I', 250, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 10292, 'SODIUM ACETATE', 'I', 680, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1737, 10292, 'SODIUM ACETATE', 'I', 2.22, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1738, 10292, 'SODIUM ACETATE', 'I', 2.22, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1622, 10292, 'SODIUM ACETATE', 'I', 368, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1623, 10292, 'SODIUM ACETATE', 'I', 368, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82495, 10292, 'SODIUM ACETATE', 'I', 368, 'MG', '', '100', 'N', 'ML', '2009.12.08. SODIUM ACETATE TRIHYDRATE AS PER CURRENT LABEL./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85140, 10292, 'SODIUM ACETATE', 'I', 1.11, 'G', '', '', 'N', 'L', 'CONTENT BEFORE DILUTION. EQUIVALENT TO 13.5 MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85141, 10292, 'SODIUM ACETATE', 'I', 1.11, 'G', '', '', 'N', 'L', 'CONTENT BEFORE DILUTION. EQUIVALENT TO 13.5 MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85142, 10292, 'SODIUM ACETATE', 'I', 1.11, 'G', '', '', 'N', 'L', 'CONTENT BEFORE DILUTION. EQUIVALENT TO 13.5 MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 10292, 'SODIUM ACETATE', 'I', 9.53, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36843, 10292, 'SODIUM ACETATE', 'I', 35.71, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78024, 5184, 'SULISOBENZONE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17818, 10292, 'SODIUM ACETATE', 'I', 35.71, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17121, 10292, 'SODIUM ACETATE', 'I', 35.71, 'G', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 10292, 'SODIUM ACETATE', 'I', 4.166, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14165, 10292, 'SODIUM ACETATE', 'I', 2.8, 'G', '', '450', 'N', 'G', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15158, 10292, 'SODIUM ACETATE', 'I', 13.125, 'G', '', '80', 'N', 'G', 'Historic Freeform Text: SODIUM ACETATE ((ANYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12827, 10292, 'SODIUM ACETATE', 'I', 13.125, 'G', '', '184', 'N', 'G', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10794, 10292, 'SODIUM ACETATE', 'I', 13.125, 'G', '', '73', 'N', 'G', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11333, 10292, 'SODIUM ACETATE', 'I', 13.125, 'G', '', '184', 'N', 'G', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8101, 10292, 'SODIUM ACETATE', 'I', 2.5, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3926, 10292, 'SODIUM ACETATE', 'I', 2.8, 'G', '', '450', 'N', 'G', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65789, 10292, 'SODIUM ACETATE', 'I', 13.125, 'G', '', '76', 'N', 'G', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65790, 10292, 'SODIUM ACETATE', 'I', 13.127, 'G', '', '185', 'N', 'G', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76260, 10292, 'SODIUM ACETATE', 'I', 13.125, 'G', '', '184', 'N', 'G', 'ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33790, 10292, 'SODIUM ACETATE', 'I', 19.23, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12923, 10292, 'SODIUM ACETATE', 'I', 344, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15001, 10292, 'SODIUM ACETATE', 'I', 19.23, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SOD.ACET. ((NA EQ. TO 5.39MG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5322, 10292, 'SODIUM ACETATE', 'I', 0.33, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SODIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41578, 11977, 'MYROXYLON BALSAMUM', 'I', 4, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: BALSAM TOLU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42295, 3836, 'DISODIUM EDETATE', 'I', 0.025, '%', '', '', 'N', '', 'Historic Freeform Text: DISODIUM EDETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42237, 3836, 'DISODIUM EDETATE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: DISODIUM EDETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41994, 3836, 'DISODIUM EDETATE', 'I', 0.10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DISODIUM EDETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49610, 3836, 'DISODIUM EDETATE', 'I', 0.10, '%', '', '', 'N', '', 'QTY. 0.1%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60122, 3836, 'DISODIUM EDETATE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80971, 3836, 'DISODIUM EDETATE', 'I', 0.10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80854, 3836, 'DISODIUM EDETATE', 'I', 0.10, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1248, 3836, 'DISODIUM EDETATE', 'I', 15, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: DISODIUM EDETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60180, 684, 'ALOE (ALOE FEROX)', 'I', 83, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3567, 684, 'ALOE', 'I', 7.54, '%', '', '', 'N', '%', 'Historic Freeform Text: ALOE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41578, 684, 'ALOE', 'I', 2, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: ALOE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (134, 684, 'ALOE', 'I', 60, 'G', '', '11.35', 'N', 'KG', 'Historic Freeform Text: ALOE ((TINCTURE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42462, 7152, 'CETYLPYRIDINIUM CHLORIDE', 'I', 1.4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4665, 7152, 'CETYLPYRIDINIUM CHLORIDE', 'I', 1.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CETYLPYRIDINIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4666, 7152, 'CETYLPYRIDINIUM CHLORIDE', 'I', 1.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CETYLPYRIDINIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78568, 7152, 'CETYLPYRIDINIUM CHLORIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42480, 7152, 'CETYLPYRIDINIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: CETYLPYRIDINIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42483, 7152, 'CETYLPYRIDINIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: CETYLPYRIDINIUM CHLORIDE ((MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15550, 7152, 'CETYLPYRIDINIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: CETYLPYRIDINIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5812, 7152, 'CETYLPYRIDINIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: CETYLPYRIDINIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67489, 7152, 'CETYLPYRIDINIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75427, 7152, 'CETYLPYRIDINIUM CHLORIDE', 'I', 0.07, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79990, 7152, 'CETYLPYRIDINIUM CHLORIDE', 'I', 0.07, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42479, 7152, 'CETYLPYRIDINIUM CHLORIDE', 'I', 0.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CETYLPYRIDINIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1291, 3560, 'CINNAMON OIL', 'I', 5, 'ML', '', '100', 'N', 'ML', 'Historic Freeform Text: OIL OF CINNAMON');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37743, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZETHONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37547, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.28, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZETHONIUM CHLORIDE STRENGTH AT INITIAL DIN ISSUANCE WAS 0.25%, THIS IS MI');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20013, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.28, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZETHONIUM CHLORIDE STRENGTH WAS 0.25% AT INITIAL DIN ISSUANCE AS MINIMUM ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13584, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6345, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.023, '%', '', '', 'N', '', 'Historic Freeform Text: BENZETHONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6696, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.03, '%', '', '', 'N', '', 'Historic Freeform Text: BENZETHONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65889, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.28, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65545, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70138, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.28, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76393, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76652, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75279, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74263, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.28, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74299, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75711, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.35, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75722, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.35, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73352, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73590, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73676, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79250, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47404, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70020, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73832, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78942, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82271, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83325, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83401, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84430, 783, 'BENZETHONIUM CHLORIDE', 'I', 0.13, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37257, 13418, 'MACROGOL', 'I', 15, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBOWAX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8563, 13418, 'MACROGOL', 'I', 15, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBOWAX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4885, 13418, 'MACROGOL', 'I', 15, '%', '', '', 'N', '', 'Historic Freeform Text: CARBOWAX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4886, 13418, 'MACROGOL', 'I', 15, '%', '', '', 'N', '', 'Historic Freeform Text: CARBOWAX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9351, 13418, 'MACROGOL', 'I', 238.18, 'G', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: CARBOWAX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11232, 13418, 'MACROGOL', 'I', 160, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CARBOWAX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9631, 13418, 'MACROGOL', 'I', 59.55, 'G', '', '', 'N', 'L', 'HISTORIC FREEFORM TEXT: CARBOWAX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6370, 13418, 'MACROGOL', 'I', 236, 'G', '', '4', 'N', 'L', 'HISTORIC FREEFORM TEXT: CARBOWAX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10299, 13418, 'MACROGOL', 'I', 152, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: CARBOWAX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75262, 14828, 'PEGAPTANIB', 'I', 0.3, 'MG', '', '90', 'N', 'µL', '(PER SYRINGE). EQUIVALENT TO THE OLIGONUCLEOTIDE MOIETY.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78023, 5184, 'SULISOBENZONE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66247, 2142, 'BUTORPHANOL TARTRATE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68484, 2142, 'BUTORPHANOL TARTRATE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43292, 2143, 'CYCLOBENZAPRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: CYCLOBENZAPRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19827, 2143, 'CYCLOBENZAPRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CYCLOBENZAPRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18806, 2143, 'CYCLOBENZAPRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: CYCLOBENZAPRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18760, 2143, 'CYCLOBENZAPRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: CYCLOBENZAPRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15912, 2143, 'CYCLOBENZAPRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: CYCLOBENZAPRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50662, 2143, 'CYCLOBENZAPRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59925, 2143, 'CYCLOBENZAPRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62061, 2143, 'CYCLOBENZAPRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65753, 2143, 'CYCLOBENZAPRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: CYCLOBENZAPRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73419, 2143, 'CYCLOBENZAPRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: CYCLOBENZAPRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77249, 2143, 'CYCLOBENZAPRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81060, 2143, 'CYCLOBENZAPRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CYCLOBENZAPRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83419, 2143, 'CYCLOBENZAPRINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15696, 2144, 'PINDOLOL', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15687, 2144, 'PINDOLOL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11180, 2144, 'PINDOLOL', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11181, 2144, 'PINDOLOL', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11182, 2144, 'PINDOLOL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10949, 2144, 'PINDOLOL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10950, 2144, 'PINDOLOL', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10951, 2144, 'PINDOLOL', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9167, 2144, 'PINDOLOL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9168, 2144, 'PINDOLOL', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9169, 2144, 'PINDOLOL', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9899, 2144, 'PINDOLOL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9900, 2144, 'PINDOLOL', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9901, 2144, 'PINDOLOL', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5156, 2144, 'PINDOLOL', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5157, 2144, 'PINDOLOL', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3089, 2144, 'PINDOLOL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3090, 2144, 'PINDOLOL', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3091, 2144, 'PINDOLOL', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50877, 2144, 'PINDOLOL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50879, 2144, 'PINDOLOL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50882, 2144, 'PINDOLOL', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51024, 2144, 'PINDOLOL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61430, 2144, 'PINDOLOL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61431, 2144, 'PINDOLOL', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74715, 2144, 'PINDOLOL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74716, 2144, 'PINDOLOL', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74717, 2144, 'PINDOLOL', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINDOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44132, 2092, 'PRAZIQUANTEL', 'I', 34, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PRAZIQUANTEL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44133, 2092, 'PRAZIQUANTEL', 'I', 23, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PRAZIQUANTEL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44134, 2092, 'PRAZIQUANTEL', 'I', 18.2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PRAZIQUANTEL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44136, 2092, 'PRAZIQUANTEL', 'I', 22.7, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PRAZIQUANTEL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44137, 2092, 'PRAZIQUANTEL', 'I', 68, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PRAZIQUANTEL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50175, 2092, 'PRAZIQUANTEL', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63584, 2092, 'PRAZIQUANTEL', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77731, 2092, 'PRAZIQUANTEL', 'I', 10, 'MG', '', '', 'N', '', 'PH EUR STD.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77732, 2092, 'PRAZIQUANTEL', 'I', 40, 'MG', '', '', 'N', '', 'PH EUR STD');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81380, 2092, 'PRAZIQUANTEL', 'I', 10.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81381, 2092, 'PRAZIQUANTEL', 'I', 50.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81382, 2092, 'PRAZIQUANTEL', 'I', 125.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70799, 2092, 'PRAZIQUANTEL', 'I', 9, '%', '', '', 'N', '', 'CORRESPS TO 600MG PRAZIQUANTEL/6.67G SYR. ONE6.67SYR CORRESPS TO 600KG OF HORSE''S BODY WT.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76227, 2092, 'PRAZIQUANTEL', 'I', 14.03, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77545, 2092, 'PRAZIQUANTEL', 'I', 7.75, '%', '', '', 'N', '', 'W/W. 570MG/SYR.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44135, 2092, 'PRAZIQUANTEL', 'I', 56.8, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PRAZIQUANTEL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76244, 2092, 'PRAZIQUANTEL', 'I', 125, 'MG', '', '', 'N', 'ML', '12.5%W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80166, 2092, 'PRAZIQUANTEL', 'I', 30.0, 'MG', '', '0.35', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80167, 2092, 'PRAZIQUANTEL', 'I', 60.0, 'MG', '', '0.70', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80168, 2092, 'PRAZIQUANTEL', 'I', 96.0, 'MG', '', '1.12', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16965, 2099, 'NADOLOL', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: NADOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16966, 2099, 'NADOLOL', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: NADOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9176, 2099, 'NADOLOL', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: NADOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9177, 2099, 'NADOLOL', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: NADOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9178, 2099, 'NADOLOL', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: NADOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9906, 2099, 'NADOLOL', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: NADOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9897, 2099, 'NADOLOL', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: NADOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9898, 2099, 'NADOLOL', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: NADOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3348, 2100, 'MITOTANE', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MITOTANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19428, 2103, 'ESTRAMUSTINE PHOSPHATE SODIUM', 'I', 140, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ESTRAMUSTINE PHOSPHATE DISODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20308, 2104, 'BACLOFEN', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20309, 2104, 'BACLOFEN', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18752, 2104, 'BACLOFEN', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18753, 2104, 'BACLOFEN', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17246, 2104, 'BACLOFEN', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17247, 2104, 'BACLOFEN', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16532, 2104, 'BACLOFEN', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16534, 2104, 'BACLOFEN', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15547, 2104, 'BACLOFEN', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15548, 2104, 'BACLOFEN', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16890, 2104, 'BACLOFEN', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16891, 2104, 'BACLOFEN', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6244, 2104, 'BACLOFEN', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3182, 2104, 'BACLOFEN', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48389, 2104, 'BACLOFEN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48390, 2104, 'BACLOFEN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59927, 2104, 'BACLOFEN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59928, 2104, 'BACLOFEN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60258, 2104, 'BACLOFEN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60259, 2104, 'BACLOFEN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65828, 2104, 'BACLOFEN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65829, 2104, 'BACLOFEN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77246, 2104, 'BACLOFEN', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77247, 2104, 'BACLOFEN', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17954, 2104, 'BACLOFEN', 'I', 0.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17276, 2104, 'BACLOFEN', 'I', 2, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17277, 2104, 'BACLOFEN', 'I', 0.05, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: BACLOFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37574, 2111, 'SINCALIDE', 'I', 5, 'µG', '', '', 'N', 'VIAL', 'Historic Freeform Text: SINCALIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13579, 2047, 'BENZYDAMINE HYDROCHLORIDE', 'I', 0.15, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BENZYDAMINE HCL 15MG/10ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62497, 2047, 'BENZYDAMINE HYDROCHLORIDE', 'I', 0.15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48059, 2047, 'BENZYDAMINE HYDROCHLORIDE', 'I', 1.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48124, 2047, 'BENZYDAMINE HYDROCHLORIDE', 'I', 1.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63013, 2047, 'BENZYDAMINE HYDROCHLORIDE', 'I', 1.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79606, 2047, 'BENZYDAMINE HYDROCHLORIDE', 'I', 1.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19817, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: SOTALOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19662, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: SOTALOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19663, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: SOTALOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20002, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: SOTALOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18779, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: SOTALOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18350, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 160, 'MG', '', '', 'N', '', 'Historic Freeform Text: SOTALOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48060, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48061, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50489, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50490, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49903, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49907, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49910, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 240, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62062, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62063, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62204, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62205, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61729, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61730, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65834, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65835, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74307, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SOTALOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74308, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 160, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SOTALOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75600, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75601, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75769, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81061, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81062, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80201, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80202, 2048, 'SOTALOL HYDROCHLORIDE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4941, 2071, 'NABILONE', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NABILONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74143, 2071, 'NABILONE', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: NABILONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79778, 2071, 'NABILONE', 'I', 0.25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NABILONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17972, 2072, 'ALPRAZOLAM', 'I', 0.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALPRAZOLAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17973, 2072, 'ALPRAZOLAM', 'I', 0.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALPRAZOLAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13685, 2072, 'ALPRAZOLAM', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11803, 2072, 'ALPRAZOLAM', 'I', 0.25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALPRAZOLAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11804, 2072, 'ALPRAZOLAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALPRAZOLAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12175, 2072, 'ALPRAZOLAM', 'I', 0.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALPRAZOLAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12180, 2072, 'ALPRAZOLAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALPRAZOLAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10904, 2072, 'ALPRAZOLAM', 'I', 0.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALPRAZOLAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11484, 2072, 'ALPRAZOLAM', 'I', 0.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALPRAZOLAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11485, 2072, 'ALPRAZOLAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALPRAZOLAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10905, 2072, 'ALPRAZOLAM', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALPRAZOLAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4471, 2072, 'ALPRAZOLAM', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4472, 2072, 'ALPRAZOLAM', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48166, 2072, 'ALPRAZOLAM', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48167, 2072, 'ALPRAZOLAM', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67530, 2072, 'ALPRAZOLAM', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67531, 2072, 'ALPRAZOLAM', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73070, 2072, 'ALPRAZOLAM', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83451, 2072, 'ALPRAZOLAM', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83452, 2072, 'ALPRAZOLAM', 'I', 0.50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43282, 2007, 'BROMAZEPAM', 'I', 3, 'MG', '', '', 'N', '', 'Historic Freeform Text: BROMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43283, 2007, 'BROMAZEPAM', 'I', 6, 'MG', '', '', 'N', '', 'Historic Freeform Text: BROMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20147, 2007, 'BROMAZEPAM', 'I', 1.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: BROMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18846, 2007, 'BROMAZEPAM', 'I', 1.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: BROMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18847, 2007, 'BROMAZEPAM', 'I', 3, 'MG', '', '', 'N', '', 'Historic Freeform Text: BROMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18848, 2007, 'BROMAZEPAM', 'I', 6, 'MG', '', '', 'N', '', 'Historic Freeform Text: BROMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19047, 2007, 'BROMAZEPAM', 'I', 6, 'MG', '', '', 'N', '', 'Historic Freeform Text: BROMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19056, 2007, 'BROMAZEPAM', 'I', 3, 'MG', '', '', 'N', '', 'Historic Freeform Text: BROMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19057, 2007, 'BROMAZEPAM', 'I', 1.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: BROMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4157, 2007, 'BROMAZEPAM', 'I', 3, 'MG', '', '', 'N', '', 'Historic Freeform Text: BROMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4158, 2007, 'BROMAZEPAM', 'I', 6, 'MG', '', '', 'N', '', 'Historic Freeform Text: BROMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49693, 2007, 'BROMAZEPAM', 'I', 3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49694, 2007, 'BROMAZEPAM', 'I', 6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13963, 2008, 'NALBUPHINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NALBUPHINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13803, 2008, 'NALBUPHINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NALBUPHINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68669, 2009, 'FLOCTAFENINE', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLOCTAFENINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68668, 2009, 'FLOCTAFENINE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLOCTAFENINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4010, 2011, 'MINOXIDIL', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: MINOXIDIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76938, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4011, 2011, 'MINOXIDIL', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: MINOXIDIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66088, 2011, 'MINOXIDIL', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43482, 2011, 'MINOXIDIL', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MINOXIDIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12757, 2011, 'MINOXIDIL', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MINOXIDIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7084, 2011, 'MINOXIDIL', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MINOXIDIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84173, 2011, 'MINOXIDIL', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43472, 2013, 'DICLOFENAC SODIUM', 'I', 75, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43473, 2013, 'DICLOFENAC SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43393, 2013, 'DICLOFENAC SODIUM', 'I', 75, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43394, 2013, 'DICLOFENAC SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20263, 2013, 'DICLOFENAC SODIUM', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19678, 2013, 'DICLOFENAC SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18239, 2013, 'DICLOFENAC SODIUM', 'I', 75, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14717, 2013, 'DICLOFENAC SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13636, 2013, 'DICLOFENAC SODIUM', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DICLOFENAC SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11193, 2013, 'DICLOFENAC SODIUM', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11194, 2013, 'DICLOFENAC SODIUM', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10772, 2013, 'DICLOFENAC SODIUM', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DICLOFENAC SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10036, 2013, 'DICLOFENAC SODIUM', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10037, 2013, 'DICLOFENAC SODIUM', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9943, 2013, 'DICLOFENAC SODIUM', 'I', 75, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DICLOFENAC SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9888, 2013, 'DICLOFENAC SODIUM', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9889, 2013, 'DICLOFENAC SODIUM', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6461, 2013, 'DICLOFENAC SODIUM', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6462, 2013, 'DICLOFENAC SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6379, 2013, 'DICLOFENAC SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4043, 2013, 'DICLOFENAC SODIUM', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DICLOFENAC SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48191, 2013, 'DICLOFENAC SODIUM', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50843, 2013, 'DICLOFENAC SODIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50842, 2013, 'DICLOFENAC SODIUM', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50844, 2013, 'DICLOFENAC SODIUM', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50845, 2013, 'DICLOFENAC SODIUM', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50847, 2013, 'DICLOFENAC SODIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50848, 2013, 'DICLOFENAC SODIUM', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51037, 2013, 'DICLOFENAC SODIUM', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51039, 2013, 'DICLOFENAC SODIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51040, 2013, 'DICLOFENAC SODIUM', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74726, 2013, 'DICLOFENAC SODIUM', 'I', 75, 'MG', '', '', 'N', '', 'UNCOATED TABLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74727, 2013, 'DICLOFENAC SODIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74728, 2013, 'DICLOFENAC SODIUM', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74729, 2013, 'DICLOFENAC SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74730, 2013, 'DICLOFENAC SODIUM', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74731, 2013, 'DICLOFENAC SODIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78791, 2013, 'DICLOFENAC SODIUM', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78792, 2013, 'DICLOFENAC SODIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83766, 2013, 'DICLOFENAC SODIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83767, 2013, 'DICLOFENAC SODIUM', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71508, 2013, 'DICLOFENAC SODIUM', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11969, 2013, 'DICLOFENAC SODIUM', 'I', 0.1, '%', '', '', 'N', 'W/V', 'HISTORIC FREEFORM TEXT: DICLOFENAC SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19125, 2013, 'DICLOFENAC SODIUM', 'I', 75, 'MG', '', '', 'N', 'SRT', 'Historic Freeform Text: DICLOFENAC SODIUM Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16471, 2013, 'DICLOFENAC SODIUM', 'I', 100, 'MG', '', '', 'N', 'SRT', 'Historic Freeform Text: DICLOFENAC SODIUM Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43430, 2019, 'ISOFLURANE', 'I', 100, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ISOFLURANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20160, 2019, 'ISOFLURANE', 'I', 100, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ISOFLURANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14158, 2019, 'ISOFLURANE', 'I', 99.9, '%', '', '', 'N', '', 'PURITY EXCEEDS 99.9%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51381, 2019, 'ISOFLURANE', 'I', 99.9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60853, 2019, 'ISOFLURANE', 'I', 99.9, '%', '', '', 'N', '', 'V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64934, 2019, 'ISOFLURANE', 'I', 99.9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44067, 2019, 'ISOFLURANE', 'I', 100, '%', '', '', 'N', '%', 'Historic Freeform Text: ISOFLURANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14631, 2019, 'ISOFLURANE', 'I', 99.9, '%', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ISOFLURANE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5708, 2021, 'CHROMIC CHLORIDE', 'I', 6.0, 'µG', '', '', 'N', 'ML', 'CHROMIC CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19192, 2023, 'SUCRALFATE', 'I', 1, 'G', '', '', 'N', '', 'Historic Freeform Text: SUCRALFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17250, 2023, 'SUCRALFATE', 'I', 1, 'G', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SUCRALFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16656, 2023, 'SUCRALFATE', 'I', 1, 'G', '', '', 'N', '', 'Historic Freeform Text: SUCRALFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16899, 2023, 'SUCRALFATE', 'I', 1, 'G', '', '', 'N', '', 'Historic Freeform Text: SUCRALFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14504, 2023, 'SUCRALFATE', 'I', 1, 'G', '', '', 'N', '', 'Historic Freeform Text: SUCRALFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63412, 2023, 'SUCRALFATE', 'I', 1000, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61602, 2023, 'SUCRALFATE', 'I', 1000, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17852, 2023, 'SUCRALFATE', 'I', 1, 'G', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SUCRALFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43270, 2027, 'HONEY BEE VENOM PROTEIN', 'I', 550, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: HONEY BEE VENOM PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37436, 2027, 'HONEY BEE VENOM PROTEIN', 'I', 120, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: HONEY BEE VENOM PROTEIN (120 MCG/VIAL, 6 VIALS PER KIT)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43272, 2028, 'WASP VENOM PROTEIN', 'I', 550, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: WASP VENOM PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37438, 2028, 'WASP VENOM PROTEIN', 'I', 120, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: WASP VENOM PROTEIN (120 MCG/VIAL, 6 VIALS PER KIT)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43302, 2029, 'WHITE FACED HORNET VENOM PROTEIN', 'I', 550, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: WHITE FACED HORNET VENOM PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43273, 2029, 'WHITE FACED HORNET VENOM PROTEIN', 'I', 550, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: WHITE FACED HORNET VENOM PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37445, 2029, 'WHITE FACED HORNET VENOM PROTEIN', 'I', 120, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: WHITE FACED HORNET VENOM PR (120MCG/VIAL, 6 VIALS PER KIT)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37440, 2029, 'WHITE FACED HORNET VENOM PROTEIN', 'I', 120, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: WHITE FACED HORNET VENOM P. (120MCG/VIAL, 6 VIALS PER KIT)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14599, 2029, 'WHITE FACED HORNET VENOM PROTEIN', 'I', 120, 'µG', '', '', 'N', 'VIAL', 'Historic Freeform Text: WHITE FACED HORNET VENOM PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50135, 2029, 'WHITE FACED HORNET VENOM PROTEIN', 'I', 1300, 'µG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14101, 2029, 'WHITE FACED HORNET VENOM PROTEIN', 'I', 1.1, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: WHITE FACED HORNET VENOM PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43302, 2030, 'YELLOW JACKET VENOM PROTEIN', 'I', 550, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: YELLOW JACKET VENOM PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43274, 2030, 'YELLOW JACKET VENOM PROTEIN', 'I', 550, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: YELLOW JACKET VENOM PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37444, 2030, 'YELLOW JACKET VENOM PROTEIN', 'I', 120, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: YELLOW JACKET VENOM PROTEIN (120MCG/VIAL, 6 VIALS PER KIT)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37445, 2030, 'YELLOW JACKET VENOM PROTEIN', 'I', 120, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT:  YELLOW JACKET VENOM PROTEIN (120MCG/VIAL, 6 VIALS PER KIT)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14599, 2030, 'YELLOW JACKET VENOM PROTEIN', 'I', 120, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: YELLOW JACKET VENOM PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50135, 2030, 'YELLOW JACKET VENOM PROTEIN', 'I', 1300, 'µG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14101, 2030, 'YELLOW JACKET VENOM PROTEIN', 'I', 1.1, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: YELLOW JACKET VENOM PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43302, 2031, 'YELLOW HORNET VENOM PROTEIN', 'I', 550, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: YELLOW HORNET VENOM PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43271, 2031, 'YELLOW HORNET VENOM PROTEIN', 'I', 550, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: YELLOW HORNET VENOM PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37445, 2031, 'YELLOW HORNET VENOM PROTEIN', 'I', 120, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: YELLOW HORNET VENOM PROTEIN (120MCG/VIAL, 6 VIALS PER KIT)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37442, 2031, 'YELLOW HORNET VENOM PROTEIN', 'I', 120, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: YELLOW HORNET VENOM PROTEIN (120MCG/VIAL, 6 VIALS PER KIT)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14599, 2031, 'YELLOW HORNET VENOM PROTEIN', 'I', 120, 'µG', '', '', 'N', 'VIAL', 'Historic Freeform Text: YELLOW HORNET VENOM PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50135, 2031, 'YELLOW HORNET VENOM PROTEIN', 'I', 1300, 'µG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14101, 2031, 'YELLOW HORNET VENOM PROTEIN', 'I', 1.1, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: YELLOW HORNET VENOM PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44029, 2037, 'NAPROXEN SODIUM', 'I', 550, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19446, 2037, 'NAPROXEN SODIUM', 'I', 275, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19313, 2037, 'NAPROXEN SODIUM', 'I', 550, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NAPROXEN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17199, 2037, 'NAPROXEN SODIUM', 'I', 275, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14048, 2037, 'NAPROXEN SODIUM', 'I', 550, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NAPROXEN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13848, 2037, 'NAPROXEN SODIUM', 'I', 550, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NAPROXEN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9241, 2037, 'NAPROXEN SODIUM', 'I', 275, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NAPROXEN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10035, 2037, 'NAPROXEN SODIUM', 'I', 275, 'MG', '', '', 'N', '', 'Historic Freeform Text: NAPROXEN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64418, 2037, 'NAPROXEN SODIUM', 'I', 275, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64419, 2037, 'NAPROXEN SODIUM', 'I', 550, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78704, 2037, 'NAPROXEN SODIUM', 'I', 220, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83619, 2037, 'NAPROXEN SODIUM', 'I', 275, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83620, 2037, 'NAPROXEN SODIUM', 'I', 550, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84744, 2037, 'NAPROXEN SODIUM', 'I', 220, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19286, 2038, 'FENBENDAZOLE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: FENBENDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18695, 2038, 'FENBENDAZOLE', 'I', 10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FENBENDAZOLE 100MG/G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18993, 2038, 'FENBENDAZOLE', 'I', 10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FENBENDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6887, 2038, 'FENBENDAZOLE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FENBENDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13564, 2038, 'FENBENDAZOLE', 'I', 200, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: FENBENDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6886, 2038, 'FENBENDAZOLE', 'I', 222, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: FENBENDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78239, 2038, 'FENBENDAZOLE', 'I', 222, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19691, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19692, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17904, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17905, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17906, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18188, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18161, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18139, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11142, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11143, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11964, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11965, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9174, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9175, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9905, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9904, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47357, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47358, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51110, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51112, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60939, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60940, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61718, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61719, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65768, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65769, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71424, 2041, 'ATENOLOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70768, 2041, 'ATENOLOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75207, 2041, 'ATENOLOL', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75337, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75338, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74074, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74075, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73131, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73132, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76301, 2041, 'ATENOLOL', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78896, 2041, 'ATENOLOL', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78821, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78822, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ATENOLOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81205, 2041, 'ATENOLOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83656, 2041, 'ATENOLOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83657, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83658, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85239, 2041, 'ATENOLOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85240, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85241, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85283, 2041, 'ATENOLOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85284, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85285, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85363, 2041, 'ATENOLOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85364, 2041, 'ATENOLOL', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85365, 2041, 'ATENOLOL', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42310, 1970, 'HOMOSALATE', 'I', 4.5, '%', '', '', 'N', '', 'Historic Freeform Text: HOMOSALATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77513, 1970, 'HOMOSALATE', 'I', 9.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15869, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: HOMOSALATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76600, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62463, 1970, 'HOMOSALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63264, 1970, 'HOMOSALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63348, 1970, 'HOMOSALATE', 'I', 9.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64225, 1970, 'HOMOSALATE', 'I', 8.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63102, 1970, 'HOMOSALATE', 'I', 14.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66706, 1970, 'HOMOSALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66828, 1970, 'HOMOSALATE', 'I', 9.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66974, 1970, 'HOMOSALATE', 'I', 8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68325, 1970, 'HOMOSALATE', 'I', 8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68818, 1970, 'HOMOSALATE', 'I', 13, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67949, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68574, 1970, 'HOMOSALATE', 'I', 12.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68117, 1970, 'HOMOSALATE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71383, 1970, 'HOMOSALATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71384, 1970, 'HOMOSALATE', 'I', 8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71386, 1970, 'HOMOSALATE', 'I', 9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71100, 1970, 'HOMOSALATE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75172, 1970, 'HOMOSALATE', 'I', 9.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74004, 1970, 'HOMOSALATE', 'I', 8.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75409, 1970, 'HOMOSALATE', 'I', 10.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75450, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73044, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75512, 1970, 'HOMOSALATE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75709, 1970, 'HOMOSALATE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72581, 1970, 'HOMOSALATE', 'I', 9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74630, 1970, 'HOMOSALATE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75779, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76213, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76214, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74918, 1970, 'HOMOSALATE', 'I', 8.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73755, 1970, 'HOMOSALATE', 'I', 8.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73756, 1970, 'HOMOSALATE', 'I', 8.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74998, 1970, 'HOMOSALATE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76325, 1970, 'HOMOSALATE', 'I', 7.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77488, 1970, 'HOMOSALATE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78108, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77461, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77550, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77551, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77610, 1970, 'HOMOSALATE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77612, 1970, 'HOMOSALATE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77613, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77611, 1970, 'HOMOSALATE', 'I', 6.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77614, 1970, 'HOMOSALATE', 'I', 10.50, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77608, 1970, 'HOMOSALATE', 'I', 8.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76890, 1970, 'HOMOSALATE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77681, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77682, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77883, 1970, 'HOMOSALATE', 'I', 9.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77581, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76934, 1970, 'HOMOSALATE', 'I', 12.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77515, 1970, 'HOMOSALATE', 'I', 9.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77618, 1970, 'HOMOSALATE', 'I', 9.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82245, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79960, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79018, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78689, 1970, 'HOMOSALATE', 'I', 8.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78690, 1970, 'HOMOSALATE', 'I', 15.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78611, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78700, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78701, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79262, 1970, 'HOMOSALATE', 'I', 8.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79263, 1970, 'HOMOSALATE', 'I', 8.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78709, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78990, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79294, 1970, 'HOMOSALATE', 'I', 8.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79798, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78957, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78958, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79719, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79252, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79253, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79255, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79256, 1970, 'HOMOSALATE', 'I', 9.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79257, 1970, 'HOMOSALATE', 'I', 10.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78605, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78606, 1970, 'HOMOSALATE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78929, 1970, 'HOMOSALATE', 'I', 15.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78930, 1970, 'HOMOSALATE', 'I', 10.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80565, 1970, 'HOMOSALATE', 'I', 9.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79238, 1970, 'HOMOSALATE', 'I', 10.50, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79319, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79320, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79321, 1970, 'HOMOSALATE', 'I', 9.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79322, 1970, 'HOMOSALATE', 'I', 9.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79930, 1970, 'HOMOSALATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79931, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79197, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78629, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78635, 1970, 'HOMOSALATE', 'I', 13, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79992, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80227, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82839, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79187, 1970, 'HOMOSALATE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79086, 1970, 'HOMOSALATE', 'I', 8.0, '%', '', '', 'N', '', 'W/W AS PER 3011 FORM.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79251, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83915, 1970, 'HOMOSALATE', 'I', 7.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83916, 1970, 'HOMOSALATE', 'I', 7.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84541, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84553, 1970, 'HOMOSALATE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85091, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75370, 1970, 'HOMOSALATE', 'I', 5.00, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75591, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72549, 1970, 'HOMOSALATE', 'I', 8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74849, 1970, 'HOMOSALATE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74884, 1970, 'HOMOSALATE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76200, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76215, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76204, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77463, 1970, 'HOMOSALATE', 'I', 6.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77389, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77390, 1970, 'HOMOSALATE', 'I', 8.78, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77391, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77392, 1970, 'HOMOSALATE', 'I', 8.78, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77473, 1970, 'HOMOSALATE', 'I', 9.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78222, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76894, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76863, 1970, 'HOMOSALATE', 'I', 13.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76891, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76892, 1970, 'HOMOSALATE', 'I', 5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77721, 1970, 'HOMOSALATE', 'I', 12, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76941, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79440, 1970, 'HOMOSALATE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79851, 1970, 'HOMOSALATE', 'I', 8.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81909, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79849, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79850, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82843, 1970, 'HOMOSALATE', 'I', 13, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80128, 1970, 'HOMOSALATE', 'I', 8.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80480, 1970, 'HOMOSALATE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80566, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82206, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82210, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82242, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79731, 1970, 'HOMOSALATE', 'I', 7.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78685, 1970, 'HOMOSALATE', 'I', 8.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78686, 1970, 'HOMOSALATE', 'I', 15.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80488, 1970, 'HOMOSALATE', 'I', 9.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79766, 1970, 'HOMOSALATE', 'I', 10.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80723, 1970, 'HOMOSALATE', 'I', 2.9, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82834, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80747, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81406, 1970, 'HOMOSALATE', 'I', 13.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82015, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82016, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82018, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82161, 1970, 'HOMOSALATE', 'I', 12, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82592, 1970, 'HOMOSALATE', 'I', 8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80088, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79605, 1970, 'HOMOSALATE', 'I', 8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80025, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80026, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80027, 1970, 'HOMOSALATE', 'I', 8.78, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80175, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80176, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80436, 1970, 'HOMOSALATE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80055, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80050, 1970, 'HOMOSALATE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80056, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80051, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80052, 1970, 'HOMOSALATE', 'I', 8.78, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80960, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82493, 1970, 'HOMOSALATE', 'I', 13, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82494, 1970, 'HOMOSALATE', 'I', 13, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80198, 1970, 'HOMOSALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80199, 1970, 'HOMOSALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80200, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81605, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'Y', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81708, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81709, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81779, 1970, 'HOMOSALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81842, 1970, 'HOMOSALATE', 'I', 13.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82508, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80219, 1970, 'HOMOSALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80478, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80568, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79983, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80022, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80023, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80024, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80411, 1970, 'HOMOSALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81076, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79595, 1970, 'HOMOSALATE', 'I', 8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79647, 1970, 'HOMOSALATE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80228, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80113, 1970, 'HOMOSALATE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81301, 1970, 'HOMOSALATE', 'I', 8.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80460, 1970, 'HOMOSALATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80069, 1970, 'HOMOSALATE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81266, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82515, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81926, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81927, 1970, 'HOMOSALATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81928, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81929, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81930, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82381, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79484, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81911, 1970, 'HOMOSALATE', 'I', 10.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80061, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80517, 1970, 'HOMOSALATE', 'I', 9.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80525, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80524, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80526, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81043, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81044, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82017, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82019, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82020, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81913, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81914, 1970, 'HOMOSALATE', 'I', 7.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81915, 1970, 'HOMOSALATE', 'I', 10.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81916, 1970, 'HOMOSALATE', 'I', 13.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81919, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81921, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81920, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80503, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80504, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83050, 1970, 'HOMOSALATE', 'I', 8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82373, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82462, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80256, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80537, 1970, 'HOMOSALATE', 'I', 12.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80539, 1970, 'HOMOSALATE', 'I', 13, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82060, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82062, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82063, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82065, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82066, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82067, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80034, 1970, 'HOMOSALATE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80035, 1970, 'HOMOSALATE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81069, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80099, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82543, 1970, 'HOMOSALATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78779, 1970, 'HOMOSALATE', 'I', 12.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83001, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79868, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80380, 1970, 'HOMOSALATE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80595, 1970, 'HOMOSALATE', 'I', 8.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82780, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83072, 1970, 'HOMOSALATE', 'I', 12, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83098, 1970, 'HOMOSALATE', 'I', 4.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83101, 1970, 'HOMOSALATE', 'I', 12.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83388, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83389, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83391, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83403, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83420, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83564, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83581, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83787, 1970, 'HOMOSALATE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83859, 1970, 'HOMOSALATE', 'I', 15.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83866, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83869, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83881, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83902, 1970, 'HOMOSALATE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83903, 1970, 'HOMOSALATE', 'I', 9.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83983, 1970, 'HOMOSALATE', 'I', 13.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83984, 1970, 'HOMOSALATE', 'I', 13.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84003, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84004, 1970, 'HOMOSALATE', 'I', 8.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84006, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84034, 1970, 'HOMOSALATE', 'I', 9.50, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84035, 1970, 'HOMOSALATE', 'I', 8.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84036, 1970, 'HOMOSALATE', 'I', 2.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84042, 1970, 'HOMOSALATE', 'I', 8.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84061, 1970, 'HOMOSALATE', 'I', 12, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84076, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84092, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84207, 1970, 'HOMOSALATE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84291, 1970, 'HOMOSALATE', 'I', 12.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84292, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84403, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84415, 1970, 'HOMOSALATE', 'I', 12.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84424, 1970, 'HOMOSALATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84431, 1970, 'HOMOSALATE', 'I', 10.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84519, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84520, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84574, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84576, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84579, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84580, 1970, 'HOMOSALATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84706, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84707, 1970, 'HOMOSALATE', 'I', 4.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84715, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84959, 1970, 'HOMOSALATE', 'I', 10.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84962, 1970, 'HOMOSALATE', 'I', 10.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84974, 1970, 'HOMOSALATE', 'I', 15, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84975, 1970, 'HOMOSALATE', 'I', 15.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85096, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85097, 1970, 'HOMOSALATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85099, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85098, 1970, 'HOMOSALATE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63351, 1970, 'HOMOSALATE', 'I', 9, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15950, 1978, 'PYRITHIONE DISULFIDE', 'I', 1.0, '%', '', '', 'N', '', 'Historic Freeform Text: PYRITHIONE DISULFIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18869, 1983, 'CAPTOPRIL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18870, 1983, 'CAPTOPRIL', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18871, 1983, 'CAPTOPRIL', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18872, 1983, 'CAPTOPRIL', 'I', 12.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13401, 1983, 'CAPTOPRIL', 'I', 6.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11763, 1983, 'CAPTOPRIL', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11764, 1983, 'CAPTOPRIL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11765, 1983, 'CAPTOPRIL', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11760, 1983, 'CAPTOPRIL', 'I', 12.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12176, 1983, 'CAPTOPRIL', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12177, 1983, 'CAPTOPRIL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12178, 1983, 'CAPTOPRIL', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12179, 1983, 'CAPTOPRIL', 'I', 12.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10907, 1983, 'CAPTOPRIL', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10908, 1983, 'CAPTOPRIL', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10900, 1983, 'CAPTOPRIL', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11490, 1983, 'CAPTOPRIL', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10906, 1983, 'CAPTOPRIL', 'I', 12.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4619, 1983, 'CAPTOPRIL', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAPTOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48901, 1983, 'CAPTOPRIL', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48902, 1983, 'CAPTOPRIL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48903, 1983, 'CAPTOPRIL', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48904, 1983, 'CAPTOPRIL', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61978, 1983, 'CAPTOPRIL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61977, 1983, 'CAPTOPRIL', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61979, 1983, 'CAPTOPRIL', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61980, 1983, 'CAPTOPRIL', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61982, 1983, 'CAPTOPRIL', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61983, 1983, 'CAPTOPRIL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61984, 1983, 'CAPTOPRIL', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61985, 1983, 'CAPTOPRIL', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66611, 1983, 'CAPTOPRIL', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66612, 1983, 'CAPTOPRIL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66613, 1983, 'CAPTOPRIL', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66614, 1983, 'CAPTOPRIL', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67347, 12081, 'NITENPYRAM', 'I', 11.4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67348, 12081, 'NITENPYRAM', 'I', 57, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71369, 12084, 'DROTRECOGIN ALFA (ACTIVATED)', 'I', 5, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71370, 12084, 'DROTRECOGIN ALFA (ACTIVATED)', 'I', 20, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77104, 12093, 'LOPINAVIR', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79781, 12093, 'LOPINAVIR', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67570, 12093, 'LOPINAVIR', 'I', 80, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67959, 12094, 'INFLIXIMAB', 'I', 100, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69977, 12108, 'BIMATOPROST', 'I', 0.03, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81041, 12108, 'BIMATOPROST', 'I', 0.01, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83612, 12108, 'BIMATOPROST', 'I', 0.03, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67614, 12110, 'LINEZOLID', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81601, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67615, 12110, 'LINEZOLID', 'I', 2, 'MG', '', '', 'N', 'ML', 'ACTIVE INGREDIENT FOR LINEZOLID IS NOT MANUFACTURED FROM ANIMAL SOURCE MATERIAL SINCE JUNE 2005. /DP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67616, 12110, 'LINEZOLID', 'I', 3, 'G', '', '', 'N', 'BOTTLE', '100MG/5ML WHEN RECONSTITUTED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71005, 12118, 'ANTI-THYMOCYTE GLOBULIN (RABBIT)', 'I', 25, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41367, 12121, 'WHITE PETROLATUM', 'I', 100, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9820, 12121, 'WHITE PETROLATUM', 'I', 57.3, '%', '', '', 'N', '', 'THE CONC. OF PETROLATUM INCREASED FROM 55.5 TO 57.3% (LESS THAN 10%) CONSIDERED ACCEPTABLE BY REVIEW');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73888, 12121, 'WHITE PETROLATUM', 'I', 30, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75311, 12121, 'WHITE PETROLATUM', 'I', 100, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80620, 12121, 'WHITE PETROLATUM', 'I', 100, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82792, 12121, 'WHITE PETROLATUM', 'I', 88.7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79066, 12121, 'WHITE PETROLATUM', 'I', 100, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80621, 12121, 'WHITE PETROLATUM', 'I', 99.9, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83796, 12121, 'WHITE PETROLATUM', 'I', 38.55, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41564, 12121, 'WHITE PETROLATUM', 'I', 99.96, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76338, 12121, 'WHITE PETROLATUM', 'I', 71.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82304, 12121, 'WHITE PETROLATUM', 'I', 80.3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4518, 12121, 'WHITE PETROLATUM', 'I', 474, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: PETROLATUM INGREDIENT CHANGED FROM PETROLATUM TO WHITE PETROLATUM BY VDD - C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80731, 12121, 'WHITE PETROLATUM', 'I', 214, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: IRON PEPTONIZED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79248, 12121, 'WHITE PETROLATUM', 'I', 214, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67698, 12126, 'ENTACAPONE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82347, 12126, 'ENTACAPONE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82348, 12126, 'ENTACAPONE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79150, 12126, 'ENTACAPONE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79151, 12126, 'ENTACAPONE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79152, 12126, 'ENTACAPONE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79974, 12149, 'RABEPRAZOLE SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67734, 12149, 'RABEPRAZOLE SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67735, 12149, 'RABEPRAZOLE SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78200, 12149, 'RABEPRAZOLE SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78199, 12149, 'RABEPRAZOLE SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78338, 12149, 'RABEPRAZOLE SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78339, 12149, 'RABEPRAZOLE SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80074, 12149, 'RABEPRAZOLE SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80075, 12149, 'RABEPRAZOLE SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80602, 12149, 'RABEPRAZOLE SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80603, 12149, 'RABEPRAZOLE SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79975, 12149, 'RABEPRAZOLE SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79643, 12149, 'RABEPRAZOLE SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79644, 12149, 'RABEPRAZOLE SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81584, 12149, 'RABEPRAZOLE SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81585, 12149, 'RABEPRAZOLE SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84166, 12149, 'RABEPRAZOLE SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84167, 12149, 'RABEPRAZOLE SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67759, 12152, 'MENINGOCOCCAL GROUP C OLIGOSACCHARIDE', 'I', 10, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73006, 12152, 'MENINGOCOCCAL GROUP C OLIGOSACCHARIDE', 'I', 10, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83276, 12152, 'MENINGOCOCCAL GROUP C OLIGOSACCHARIDE', 'I', 5, 'µG', '', '0.5', 'N', 'ML', 'CONJUGATED TO CORYNEBACTERIUM DIPHTHERIAE CRM 197 PROTEIN 7.1 TO 12.5 MCG (AS PER PM).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68040, 12153, 'CORYNEBACTERIUM DIPHTHERIAE CRM-197 PROTEIN', 'I', 20, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67759, 12153, 'CORYNEBACTERIUM DIPHTHERIAE CRM-197 PROTEIN', 'I', 25, 'µG', '', '0.5', 'N', 'ML', 'STRENGTH 12.5 TO 25.0 µG/0.5 ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73006, 12153, 'CORYNEBACTERIUM DIPHTHERIAE CRM-197 PROTEIN', 'I', 15, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82074, 12153, 'CORYNEBACTERIUM DIPHTHERIAE CRM-197 PROTEIN', 'I', 34, 'µG', '', '0.5', 'N', 'ML', 'APPROXIMATELY 34 MCG/0.5ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83276, 12153, 'CORYNEBACTERIUM DIPHTHERIAE CRM-197 PROTEIN', 'I', 47, 'µG', '', '0.5', 'N', 'ML', 'APPROXIMATELY 47 MCG (AS PER PM) AND RECORDED AS 47MCG AS PER A REQUEST FROM BGTD/SABRINA KHAMISA.EW');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72637, 12172, 'NORELGESTROMIN', 'I', 6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67776, 12184, 'ARGATROBAN', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67778, 12187, 'EFLORNITHINE HYDROCHLORIDE', 'I', 13.9, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (230, 9231, 'POTASSIUM IODIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: POTASSIUM IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79816, 9231, 'POTASSIUM IODIDE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3665, 9231, 'POTASSIUM IODIDE', 'I', 0.0267, '%', '', '', 'N', '%', 'Historic Freeform Text: POTASSIUM IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2253, 9231, 'POTASSIUM IODIDE', 'I', 5, '%', '', '', 'N', '%', 'Historic Freeform Text: POTASSIUM IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62056, 9231, 'POTASSIUM IODIDE', 'I', 2.22, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62060, 9231, 'POTASSIUM IODIDE', 'I', 1.3, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6564, 9231, 'POTASSIUM IODIDE', 'I', 5, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6248, 9231, 'POTASSIUM IODIDE', 'I', 30.6, 'G', '', '940', 'N', 'ML', 'Historic Freeform Text: POTASSIUM IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70822, 9231, 'POTASSIUM IODIDE', 'I', 6.6, 'G', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5925, 9231, 'POTASSIUM IODIDE', 'I', 1.76, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6694, 9231, 'POTASSIUM IODIDE', 'I', 26, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5147, 9231, 'POTASSIUM IODIDE', 'I', 1.76, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1980, 9231, 'POTASSIUM IODIDE', 'I', 16, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (818, 9231, 'POTASSIUM IODIDE', 'I', 13.77, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 9231, 'POTASSIUM IODIDE', 'I', 13, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: POTASSIUM IODIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9819, 4300, 'ROSE BENGAL', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ROSE BENGAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69987, 6584, 'POLYCARBOPHIL (CALCIUM POLYCARBOPHIL)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71429, 6584, 'POLYCARBOPHIL (CALCIUM POLYCARBOPHIL)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13013, 8689, 'RESORCINOL', 'I', 1.0, '%', '', '', 'N', '', 'W/W HISTORIC FREEFORM TEXT: RESORCINOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15975, 3019, 'SILVER (SILVER GLUCONATE)', 'I', 0.06, 'MG', '', '2', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SILVER GLUCONATE ((SILVER EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2193, 8746, 'ZINC SULFATE', 'I', 1.43, 'G', '', '', 'N', '', 'Historic Freeform Text: ZINC SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83632, 1395, 'FAMOTIDINE', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2182, 8746, 'ZINC SULFATE', 'I', 1.43, 'G', '', '', 'N', '', 'Historic Freeform Text: ZINC SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36799, 8746, 'ZINC SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ZINC SULPHATE ((MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12763, 8746, 'ZINC SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: ZINC SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6418, 8746, 'ZINC SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: ZINC SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4629, 8746, 'ZINC SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ZINC SULFATE ((AS MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4630, 8746, 'ZINC SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'ZINC SULFATE ((AS MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59873, 8746, 'ZINC SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'ZINC SULFATE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64442, 8746, 'ZINC SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'ZINC SULFATE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66620, 8746, 'ZINC SULFATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66621, 8746, 'ZINC SULFATE', 'I', 10, 'MG', '', '', 'N', '', 'ZINC SULFATE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42685, 8746, 'ZINC SULFATE', 'I', 0.25, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72053, 12049, 'OCTINOXATE', 'I', 1.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18240, 8746, 'ZINC SULFATE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: ZINC SULPHATE ((MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12764, 8746, 'ZINC SULFATE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6417, 8746, 'ZINC SULFATE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: ZINC SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4390, 8746, 'ZINC SULFATE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: ZINC SULFATE ((AS MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4389, 8746, 'ZINC SULFATE', 'I', 0.5, '%', '', '', 'N', '', 'ZINC SULFATE ((AS MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (128, 8746, 'ZINC SULFATE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: ZINC SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (55837, 8746, 'ZINC SULFATE', 'I', 0.5, '%', '', '', 'N', '', 'ZINC SULFATE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61410, 8746, 'ZINC SULFATE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72379, 8746, 'ZINC SULFATE', 'I', 0.25, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73264, 8746, 'ZINC SULFATE', 'I', 0.5, '%', '', '', 'N', '', 'ZINC SULFATE MONOHYDRATE 0.5%W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73689, 8746, 'ZINC SULFATE', 'I', 0.5, '%', '', '', 'N', '', '0.5% W/W ZINC SULFATE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77592, 8746, 'ZINC SULFATE', 'I', 0.25, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37185, 8746, 'ZINC SULFATE', 'I', 0.5, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: ZINC SULFATE ((MONOHYDRATE,PETROLEUM BASE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63617, 8746, 'ZINC SULFATE', 'I', 10, 'MG', '', '', 'N', 'SUP', 'ZINC SULPHATE MONOHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34945, 8746, 'ZINC SULFATE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: ZINC SULFATE ((MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6716, 8746, 'ZINC SULFATE', 'I', 40, 'MG', '', '7.5', 'N', 'ML', 'Historic Freeform Text: ZINC SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 8746, 'ZINC SULFATE', 'I', 0.05, 'G', '', '', 'N', 'KG', 'ADDED 2010.04.14 AS PER VDD REQUEST./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47888, 8746, 'ZINC SULFATE', 'I', 6.6, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71955, 8746, 'ZINC SULFATE', 'I', 5, 'MG', '', '', 'N', 'G', 'ZINC SULFATE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71956, 8746, 'ZINC SULFATE', 'I', 5, 'MG', '', '', 'N', 'G', 'ZINC SULFATE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72775, 8746, 'ZINC SULFATE', 'I', 5, 'MG', '', '', 'N', 'G', 'ZINC SULFATE MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15809, 49, 'MAGNESIUM CHLORIDE', 'I', 11, 'MG', '', '', 'N', '', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((6H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15808, 49, 'MAGNESIUM CHLORIDE', 'I', 11, 'MG', '', '', 'N', '', 'MAGNESIUM CHLORIDE HEXAHYDRATE ((6H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6202, 49, 'MAGNESIUM CHLORIDE', 'I', 11, 'MG', '', '', 'N', '', ' MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66863, 49, 'MAGNESIUM CHLORIDE', 'I', 11, 'MG', '', '', 'N', '', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15177, 49, 'MAGNESIUM CHLORIDE', 'I', 0.03, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13009, 49, 'MAGNESIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7474, 49, 'MAGNESIUM CHLORIDE', 'I', 0.03, '%', '', '', 'N', '', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6366, 49, 'MAGNESIUM CHLORIDE', 'I', 0.03, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MAGNESIUM CHLORIDE  2008.11.28. HEXAHYDRATE ADDED TO A. I. MAGNESIUM CHLORID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4913, 49, 'MAGNESIUM CHLORIDE', 'I', 0.02, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3326, 49, 'MAGNESIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12924, 49, 'MAGNESIUM CHLORIDE (MAGNESIUM CHLORIDE)', 'I', 4.5, '%', '', '', 'N', '', 'MAGNESIUM CHLORIDE HEXAHYDRATE 4.5% W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1979, 49, 'MAGNESIUM CHLORIDE', 'I', 2.81, '%', '', '', 'N', '%', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2009, 49, 'MAGNESIUM CHLORIDE', 'I', 2.81, '%', '', '', 'N', '%', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9833, 49, 'MAGNESIUM CHLORIDE', 'I', 4.07, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7141, 49, 'MAGNESIUM CHLORIDE', 'I', 0.3, 'G', '', '1000', 'N', 'ML', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66962, 49, 'MAGNESIUM CHLORIDE', 'I', 2.033, 'G', '', '1000', 'N', 'ML', 'AS HEXAHYDRATE COMPARTMENT A  ACTIVE CHANGED FROM OLD LABEL TO NEW 0.103G TO 2.033G, APPROVED BY BPS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70916, 49, 'MAGNESIUM CHLORIDE', 'I', 0.054, 'G', '', '1000', 'N', 'ML', 'MAGNESIUM CHLORIDE HEXAHYDRATE - COMPARTMENT C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70917, 49, 'MAGNESIUM CHLORIDE', 'I', 0.054, 'G', '', '1000', 'N', 'ML', 'MAGNESIUM CHLORIDE HEXAHYDRATE - COMPARTMENT C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76040, 49, 'MAGNESIUM CHLORIDE', 'I', 0.108, 'G', '', '1000', 'N', 'ML', 'HEXAHYDRATE - COMPARTMENT B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76308, 49, 'MAGNESIUM CHLORIDE', 'I', 2.033, 'G', '', '1000', 'N', 'ML', 'HEXAHYDRATE. SOLUTION A  INGREDIENT STRENGTH CHANGED FROM 2.036 TO 2.033G, APPROVED BY BPS, CONTROL ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76310, 49, 'MAGNESIUM CHLORIDE', 'I', 2.033, 'G', '', '1000', 'N', 'ML', 'HEXAHYDRATE. SOLUTION A  INGREDIENT STRENGTH CHANGED FROM 2.036 TO 2.033G, APPROVED BY BPS, CONTROL ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 49, 'MAGNESIUM CHLORIDE', 'I', 51, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGN CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36695, 49, 'MAGNESIUM CHLORIDE', 'I', 150, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21764, 49, 'MAGNESIUM CHLORIDE', 'I', 31, 'MG', '', '100', 'N', 'ML', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21757, 49, 'MAGNESIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21691, 49, 'MAGNESIUM CHLORIDE', 'I', 510, 'MG', '', '20', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21998, 49, 'MAGNESIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 49, 'MAGNESIUM CHLORIDE', 'I', 51, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 49, 'MAGNESIUM CHLORIDE', 'I', 51, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 49, 'MAGNESIUM CHLORIDE', 'I', 51, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 49, 'MAGNESIUM CHLORIDE', 'I', 51, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 49, 'MAGNESIUM CHLORIDE', 'I', 25.5, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 49, 'MAGNESIUM CHLORIDE', 'I', 51, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 49, 'MAGNESIUM CHLORIDE', 'I', 51, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 49, 'MAGNESIUM CHLORIDE', 'I', 51, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGN CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 49, 'MAGNESIUM CHLORIDE', 'I', 51, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGN CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 49, 'MAGNESIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 49, 'MAGNESIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 49, 'MAGNESIUM CHLORIDE', 'I', 102, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18029, 49, 'MAGNESIUM CHLORIDE', 'I', 0.3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81595, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 49, 'MAGNESIUM CHLORIDE', 'I', 51, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15778, 49, 'MAGNESIUM CHLORIDE', 'I', 15.2, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15769, 49, 'MAGNESIUM CHLORIDE', 'I', 5.08, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15772, 49, 'MAGNESIUM CHLORIDE', 'I', 5.08, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15768, 49, 'MAGNESIUM CHLORIDE', 'I', 5.08, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15763, 49, 'MAGNESIUM CHLORIDE', 'I', 15.2, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81602, 49, 'MAGNESIUM CHLORIDE', 'I', 4.57, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15764, 49, 'MAGNESIUM CHLORIDE', 'I', 15.2, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 49, 'MAGNESIUM CHLORIDE', 'I', 51, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 49, 'MAGNESIUM CHLORIDE', 'I', 51, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 49, 'MAGNESIUM CHLORIDE', 'I', 51, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 49, 'MAGNESIUM CHLORIDE', 'I', 25.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 49, 'MAGNESIUM CHLORIDE', 'I', 51, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 49, 'MAGNESIUM CHLORIDE', 'I', 51, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14578, 49, 'MAGNESIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10512, 49, 'MAGNESIUM CHLORIDE', 'I', 15.2, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12741, 49, 'MAGNESIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10865, 49, 'MAGNESIUM CHLORIDE', 'I', 5.08, 'MG', '', '100', 'N', 'ML', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10863, 49, 'MAGNESIUM CHLORIDE', 'I', 5.08, 'MG', '', '100', 'N', 'ML', 'AS MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10864, 49, 'MAGNESIUM CHLORIDE', 'I', 5.08, 'MG', '', '100', 'N', 'ML', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11905, 49, 'MAGNESIUM CHLORIDE', 'I', 0.20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10143, 49, 'MAGNESIUM CHLORIDE', 'I', 15.2, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10144, 49, 'MAGNESIUM CHLORIDE', 'I', 15.2, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8169, 49, 'MAGNESIUM CHLORIDE', 'I', 0.14, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10009, 49, 'MAGNESIUM CHLORIDE', 'I', 15.2, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5373, 49, 'MAGNESIUM CHLORIDE', 'I', 0.407, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5950, 49, 'MAGNESIUM CHLORIDE', 'I', 3.253, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 49, 'MAGNESIUM CHLORIDE', 'I', 102, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6360, 49, 'MAGNESIUM CHLORIDE', 'I', 0.3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5535, 49, 'MAGNESIUM CHLORIDE', 'I', 25.4, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MAGNESIUM CHLORIDE (HEXAHYDRATE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3820, 49, 'MAGNESIUM CHLORIDE', 'I', 169.6, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3407, 49, 'MAGNESIUM CHLORIDE', 'I', 300, 'MG', '', '60', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2002, 49, 'MAGNESIUM CHLORIDE', 'I', 270, 'MG', '', '500', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 49, 'MAGNESIUM CHLORIDE', 'I', 102, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1738, 49, 'MAGNESIUM CHLORIDE', 'I', 0.14, 'MG', '', '', 'N', 'ML', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1737, 49, 'MAGNESIUM CHLORIDE', 'I', 0.14, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1623, 49, 'MAGNESIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1622, 49, 'MAGNESIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1615, 49, 'MAGNESIUM CHLORIDE', 'I', 270, 'MG', '', '500', 'N', 'ML', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (745, 49, 'MAGNESIUM CHLORIDE', 'I', 0.116, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 49, 'MAGNESIUM CHLORIDE', 'I', 5.1, 'MG', '', '100', 'N', 'ML', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82495, 49, 'MAGNESIUM CHLORIDE', 'I', 30, 'MG', '', '100', 'N', 'ML', '2009.12.08. MAGNESIUM CHLORIDE HEXAHYDRATE AS PER BOTH ORIGINAL AND CURRENT LABELS./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36836, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36814, 49, 'MAGNESIUM CHLORIDE', 'I', 3.21, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34881, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34878, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34879, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19744, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20121, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20115, 49, 'MAGNESIUM CHLORIDE', 'I', 3.21, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20116, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20118, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20119, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20111, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20112, 49, 'MAGNESIUM CHLORIDE', 'I', 20.5, 'G', '', '4.5', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20114, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19739, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19735, 49, 'MAGNESIUM CHLORIDE', 'I', 3.21, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20076, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20044, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20045, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20046, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20040, 49, 'MAGNESIUM CHLORIDE', 'I', 3.21, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20041, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18268, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18206, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18202, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18199, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71178, 9152, 'DOCUSATE SODIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18200, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18167, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10820, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9854, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9852, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9848, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9845, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9131, 49, 'MAGNESIUM CHLORIDE', 'I', 3.21, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9129, 49, 'MAGNESIUM CHLORIDE', 'I', 3.21, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9130, 49, 'MAGNESIUM CHLORIDE', 'I', 3.21, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10114, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10115, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8585, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8586, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'Historic Freeform Text: MAGNESIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49558, 49, 'MAGNESIUM CHLORIDE', 'I', 0.152, 'G', '', '', 'N', 'L', 'MG CHLORIDE.6H2O');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49559, 49, 'MAGNESIUM CHLORIDE', 'I', 0.152, 'G', '', '', 'N', 'L', 'MG CHLORIDE.6H2O');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49560, 49, 'MAGNESIUM CHLORIDE', 'I', 0.152, 'G', '', '', 'N', 'L', 'MG CHLORIDE.6H2O');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62960, 49, 'MAGNESIUM CHLORIDE', 'I', 3.21, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62964, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62965, 49, 'MAGNESIUM CHLORIDE', 'I', 3.21, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66299, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67542, 49, 'MAGNESIUM CHLORIDE', 'I', 2.06, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71993, 49, 'MAGNESIUM CHLORIDE', 'I', 0.14, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71997, 49, 'MAGNESIUM CHLORIDE', 'I', 0.14, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE. BAG A.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71998, 49, 'MAGNESIUM CHLORIDE', 'I', 0.14, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73901, 49, 'MAGNESIUM CHLORIDE', 'I', 3.21, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73902, 49, 'MAGNESIUM CHLORIDE', 'I', 3.21, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73903, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73904, 49, 'MAGNESIUM CHLORIDE', 'I', 3.21, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73905, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73915, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73916, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73917, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73919, 49, 'MAGNESIUM CHLORIDE', 'I', 3.21, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73921, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73922, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73923, 49, 'MAGNESIUM CHLORIDE', 'I', 3.21, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73924, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73925, 49, 'MAGNESIUM CHLORIDE', 'I', 3.21, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73927, 49, 'MAGNESIUM CHLORIDE', 'I', 3.21, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73929, 49, 'MAGNESIUM CHLORIDE', 'I', 3.21, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75411, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', '(HEXAHYDRATE). BEFORE DILUTION;EQUIVALENT TO 16.9MMOL/L AFTER DILUTION: MAGNESIUM: 0.38MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75804, 49, 'MAGNESIUM CHLORIDE', 'I', 2.12, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75805, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75811, 49, 'MAGNESIUM CHLORIDE', 'I', 2.12, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75812, 49, 'MAGNESIUM CHLORIDE', 'I', 2.12, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73193, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74647, 49, 'MAGNESIUM CHLORIDE', 'I', 0.1017, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74648, 49, 'MAGNESIUM CHLORIDE', 'I', 0.1017, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74649, 49, 'MAGNESIUM CHLORIDE', 'I', 0.1017, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74785, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74787, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74790, 49, 'MAGNESIUM CHLORIDE', 'I', 1.61, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74791, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74792, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74793, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76226, 49, 'MAGNESIUM CHLORIDE', 'I', 2.06, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78010, 49, 'MAGNESIUM CHLORIDE', 'I', 0.136, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE    LARGE COMPARTMENT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78012, 49, 'MAGNESIUM CHLORIDE', 'I', 0.136, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE  LARGE COMPARTMENT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81573, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', 'HEXAHYDRATE.2009.07.13./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81574, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', 'HEXAHYDRATE.2009.07.13./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81576, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81578, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', 'HEXAHYDRATE. 2009.07.13./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81236, 49, 'MAGNESIUM CHLORIDE', 'I', 4.57, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81237, 49, 'MAGNESIUM CHLORIDE', 'I', 4.57, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81238, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81262, 49, 'MAGNESIUM CHLORIDE', 'I', 6.86, 'G', '', '', 'N', 'L', 'AS HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81265, 49, 'MAGNESIUM CHLORIDE', 'I', 6.86, 'G', '', '', 'N', 'L', 'AS HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81270, 49, 'MAGNESIUM CHLORIDE', 'I', 4.57, 'G', '', '', 'N', 'L', 'AS HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81271, 49, 'MAGNESIUM CHLORIDE', 'I', 6.861, 'G', '', '', 'N', 'L', 'AS HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81272, 49, 'MAGNESIUM CHLORIDE', 'I', 4.57, 'G', '', '', 'N', 'L', 'AS HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81577, 49, 'MAGNESIUM CHLORIDE', 'I', 4.57, 'G', '', '', 'N', 'L', 'AS MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81579, 49, 'MAGNESIUM CHLORIDE', 'I', 4.57, 'G', '', '', 'N', 'L', 'AS MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81580, 49, 'MAGNESIUM CHLORIDE', 'I', 4.57, 'G', '', '', 'N', 'L', 'AS MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81227, 49, 'MAGNESIUM CHLORIDE', 'I', 4.57, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81224, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81225, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81226, 49, 'MAGNESIUM CHLORIDE', 'I', 4.57, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81280, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', 'AS HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81282, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', 'AS HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81592, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81593, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81594, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81596, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81598, 49, 'MAGNESIUM CHLORIDE', 'I', 4.57, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81600, 49, 'MAGNESIUM CHLORIDE', 'I', 4.57, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81279, 49, 'MAGNESIUM CHLORIDE', 'I', 4.57, 'G', '', '', 'N', 'L', 'AS HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81281, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', 'AS HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81283, 49, 'MAGNESIUM CHLORIDE', 'I', 4.57, 'G', '', '', 'N', 'L', 'AS HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81284, 49, 'MAGNESIUM CHLORIDE', 'I', 6.86, 'G', '', '', 'N', 'L', 'AS HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81239, 49, 'MAGNESIUM CHLORIDE', 'I', 6.86, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81240, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81241, 49, 'MAGNESIUM CHLORIDE', 'I', 4.57, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81242, 49, 'MAGNESIUM CHLORIDE', 'I', 4.57, 'G', '', '', 'N', 'L', 'AS HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81275, 49, 'MAGNESIUM CHLORIDE', 'I', 6.86, 'G', '', '', 'N', 'L', 'AS HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80217, 49, 'MAGNESIUM CHLORIDE', 'I', 6.86, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80218, 49, 'MAGNESIUM CHLORIDE', 'I', 3.43, 'G', '', '', 'N', 'L', 'HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81222, 49, 'MAGNESIUM CHLORIDE', 'I', 4.57, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 49, 'MAGNESIUM CHLORIDE', 'I', 0.45, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 49, 'MAGNESIUM CHLORIDE', 'I', 0.81, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 49, 'MAGNESIUM CHLORIDE', 'I', 0.81, 'G', '', '', 'N', 'L', 'MAGNESIUM CHLORIDE HEXAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85140, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'CONTENT BEFORE DILUTION. EQUIVALENT TO 22.5 MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85141, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'CONTENT BEFORE DILUTION. EQUIVALENT TO 22.5 MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85142, 49, 'MAGNESIUM CHLORIDE', 'I', 2.14, 'G', '', '', 'N', 'L', 'CONTENT BEFORE DILUTION. EQUIVALENT TO 22.5 MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64397, 49, 'MAGNESIUM CHLORIDE', 'I', 51, 'MG', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36843, 49, 'MAGNESIUM CHLORIDE', 'I', 7.14, 'G', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: MAGNESIUM CHLORIDE ((MAGNESIUM EQ.1.82G))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14253, 49, 'MAGNESIUM CHLORIDE', 'I', 11.52, 'G', '', '200', 'N', 'G', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((HEXAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64039, 49, 'MAGNESIUM CHLORIDE', 'I', 25, 'G', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33790, 49, 'MAGNESIUM CHLORIDE', 'I', 70.76, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((MAGNESIUM EQ. 18 MG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15001, 49, 'MAGNESIUM CHLORIDE', 'I', 70.76, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: MAGNESIUM CHLORIDE ((MG EQ. 18MG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47888, 49, 'MAGNESIUM CHLORIDE', 'I', 15.7, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82299, 7065, 'METHENAMINE', 'I', 0.13, 'G', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70300, 6353, 'ZINC ACETATE', 'I', 0.1, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76655, 6353, 'ZINC ACETATE', 'I', 0.1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80391, 6353, 'ZINC ACETATE', 'I', 0.1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76653, 6353, 'ZINC ACETATE', 'I', 0.1, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1731, 9458, 'TROMETHAMINE', 'I', 36, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TROMETHAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15809, 51, 'CALCIUM CHLORIDE', 'I', 11, 'MG', '', '', 'N', '', 'Historic Freeform Text: CALCIUM CHLORIDE ((2H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15808, 51, 'CALCIUM CHLORIDE (CALCIUM CHLORIDE)', 'I', 11, 'MG', '', '', 'N', '', 'Historic Freeform Text: CALCIUM CHLORIDE ((2H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6202, 51, 'CALCIUM CHLORIDE', 'I', 11, 'MG', '', '', 'N', '', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66863, 51, 'CALCIUM CHLORIDE', 'I', 11, 'MG', '', '', 'N', '', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15177, 51, 'CALCIUM CHLORIDE', 'I', 0.048, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CALCIUM CHLORIDE ((DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7474, 51, 'CALCIUM CHLORIDE', 'I', 0.048, '%', '', '', 'N', '', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6366, 51, 'CALCIUM CHLORIDE', 'I', 0.048, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CALCIUM CHLORIDE  2008.11.28. DIHYDRATE ADDED TO A. I. CALCIUM CHLORIDE AS R');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4913, 51, 'CALCIUM CHLORIDE', 'I', 0.0154, '%', '', '', 'N', '', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1979, 51, 'CALCIUM CHLORIDE', 'I', 11.32, '%', '', '', 'N', '%', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2009, 51, 'CALCIUM CHLORIDE', 'I', 11.32, '%', '', '', 'N', '%', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18321, 51, 'CALCIUM CHLORIDE', 'I', 14.9, 'G', '', '', 'N', 'PCK', 'Historic Freeform Text: CALCIUM CHLORIDE ((USP))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18310, 51, 'CALCIUM CHLORIDE', 'I', 7.45, 'G', '', '', 'N', 'PCK', 'Historic Freeform Text: CALCIUM CHLORIDE ((USP))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9833, 51, 'CALCIUM CHLORIDE', 'I', 1.84, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7141, 51, 'CALCIUM CHLORIDE', 'I', 0.4, 'G', '', '1000', 'N', 'ML', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66962, 51, 'CALCIUM CHLORIDE', 'I', 5.145, 'G', '', '1000', 'N', 'ML', 'AS DIHYDRATE COMPARTMENT A  ACTIVE CHANGED FROM OLD LABEL TO NEW 0.257G TO 5.145G  APPROVED BY BPS, ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70916, 51, 'CALCIUM CHLORIDE', 'I', 0.271, 'G', '', '1000', 'N', 'ML', 'CALCIUM CHLORIDE DIHYDRATE - COMPARTMENT C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70917, 51, 'CALCIUM CHLORIDE', 'I', 0.209, 'G', '', '1000', 'N', 'ML', 'CALCIUM CHLORIDE DIHYDRATE - COMPARTMENT C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76308, 51, 'CALCIUM CHLORIDE', 'I', 5.145, 'G', '', '1000', 'Y', 'ML', 'DIHYDRATE. SOLUTION A INGREDIENT STRENGTH CHANGED FROM 5.148 TO 5.145G, APPROVED BY BPS, CONTROL NO.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76310, 51, 'CALCIUM CHLORIDE', 'I', 5.145, 'G', '', '1000', 'N', 'ML', 'DIHYDRATE. SOLUTION A  INGREDIENT STRENGTH CHANGED FROM 5.148 TO 5.145G, APPROVED BY BPS, CONTROL NO');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 51, 'CALCIUM CHLORIDE', 'I', 37, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALC CHLORIDE ((DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36695, 51, 'CALCIUM CHLORIDE', 'I', 150, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE ((DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 51, 'CALCIUM CHLORIDE', 'I', 0.15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21764, 51, 'CALCIUM CHLORIDE', 'I', 37, 'MG', '', '100', 'N', 'ML', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21756, 51, 'CALCIUM CHLORIDE', 'I', 10, 'MG', '', '100', 'N', 'ML', ' CALCIUM CHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21691, 51, 'CALCIUM CHLORIDE', 'I', 370, 'MG', '', '20', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21999, 51, 'CALCIUM CHLORIDE', 'I', 33, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 51, 'CALCIUM CHLORIDE', 'I', 37, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALC CHLORIDE ((DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 51, 'CALCIUM CHLORIDE', 'I', 37, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALC CHLORIDE ((DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18029, 51, 'CALCIUM CHLORIDE', 'I', 0.48, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15778, 51, 'CALCIUM CHLORIDE', 'I', 25.7, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15769, 51, 'CALCIUM CHLORIDE', 'I', 18.4, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15772, 51, 'CALCIUM CHLORIDE', 'I', 18.4, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15768, 51, 'CALCIUM CHLORIDE', 'I', 18.4, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15763, 51, 'CALCIUM CHLORIDE', 'I', 25.7, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15764, 51, 'CALCIUM CHLORIDE', 'I', 25.7, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14250, 51, 'CALCIUM CHLORIDE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10512, 51, 'CALCIUM CHLORIDE', 'I', 23.9, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11197, 51, 'CALCIUM CHLORIDE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10936, 51, 'CALCIUM CHLORIDE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10937, 51, 'CALCIUM CHLORIDE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12186, 51, 'CALCIUM CHLORIDE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10865, 51, 'CALCIUM CHLORIDE', 'I', 18.3, 'MG', '', '100', 'N', 'ML', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10862, 51, 'CALCIUM CHLORIDE', 'I', 33, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10863, 51, 'CALCIUM CHLORIDE', 'I', 18.3, 'MG', '', '100', 'N', 'ML', 'AS CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10864, 51, 'CALCIUM CHLORIDE', 'I', 18.3, 'MG', '', '100', 'N', 'ML', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10770, 51, 'CALCIUM CHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9830, 51, 'CALCIUM CHLORIDE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10143, 51, 'CALCIUM CHLORIDE', 'I', 23.9, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10144, 51, 'CALCIUM CHLORIDE', 'I', 23.9, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8169, 51, 'CALCIUM CHLORIDE', 'I', 0.36, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CALCIUM CHLORIDE ((DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8601, 51, 'CALCIUM CHLORIDE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE ((DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10009, 51, 'CALCIUM CHLORIDE', 'I', 23.9, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 51, 'CALCIUM CHLORIDE', 'I', 15, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5373, 51, 'CALCIUM CHLORIDE', 'I', 0.367, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5950, 51, 'CALCIUM CHLORIDE', 'I', 0.176, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6360, 51, 'CALCIUM CHLORIDE', 'I', 0.48, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5535, 51, 'CALCIUM CHLORIDE', 'I', 16.55, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CALCIUM CHLORIDE (DIHYDRATE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 51, 'CALCIUM CHLORIDE', 'I', 15, 'MG', '', '100', 'N', 'ML', 'AS CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4230, 51, 'CALCIUM CHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3407, 51, 'CALCIUM CHLORIDE', 'I', 230, 'MG', '', '60', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 51, 'CALCIUM CHLORIDE', 'I', 15, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2002, 51, 'CALCIUM CHLORIDE', 'I', 490, 'MG', '', '500', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 51, 'CALCIUM CHLORIDE', 'I', 15, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1749, 51, 'CALCIUM CHLORIDE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1745, 51, 'CALCIUM CHLORIDE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1673, 51, 'CALCIUM CHLORIDE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1628, 51, 'CALCIUM CHLORIDE', 'I', 20, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1615, 51, 'CALCIUM CHLORIDE', 'I', 490, 'MG', '', '500', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (745, 51, 'CALCIUM CHLORIDE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 51, 'CALCIUM CHLORIDE', 'I', 18.4, 'MG', '', '100', 'N', 'ML', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67329, 51, 'CALCIUM CHLORIDE', 'I', 20, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70277, 51, 'CALCIUM CHLORIDE', 'I', 20, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75707, 51, 'CALCIUM CHLORIDE', 'I', 470, 'MG', '', '', 'N', 'ML', 'ANHYDROUS.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53282, 51, 'CALCIUM CHLORIDE', 'I', 40, 'µMOL', '', '1', 'N', 'ML', 'CALCIUM CHLORIDE SOLUTION (DILUENT)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53284, 51, 'CALCIUM CHLORIDE', 'I', 200, 'µMOL', '', '5', 'N', 'ML', 'CALCIUM CHLORIDE SOLUTION (DILUENT)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81151, 51, 'CALCIUM CHLORIDE', 'I', 40, 'µMOL', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36836, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36814, 51, 'CALCIUM CHLORIDE', 'I', 2.5, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34881, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34878, 51, 'CALCIUM CHLORIDE', 'I', 7.49, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34879, 51, 'CALCIUM CHLORIDE', 'I', 2.49, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19744, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20121, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20116, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20118, 51, 'CALCIUM CHLORIDE', 'I', 4.99, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20119, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20111, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20114, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20115, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19739, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19735, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20076, 51, 'CALCIUM CHLORIDE', 'I', 7.48, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20044, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20045, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20046, 51, 'CALCIUM CHLORIDE', 'I', 4.99, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20040, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20041, 51, 'CALCIUM CHLORIDE', 'I', 7.48, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18268, 51, 'CALCIUM CHLORIDE', 'I', 7.49, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18206, 51, 'CALCIUM CHLORIDE', 'I', 7.49, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18202, 51, 'CALCIUM CHLORIDE', 'I', 7.49, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18199, 51, 'CALCIUM CHLORIDE', 'I', 7.49, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18200, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18167, 51, 'CALCIUM CHLORIDE', 'I', 7.49, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10820, 51, 'CALCIUM CHLORIDE', 'I', 7.49, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9854, 51, 'CALCIUM CHLORIDE', 'I', 4.99, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9852, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9845, 51, 'CALCIUM CHLORIDE', 'I', 4.99, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYSIS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9131, 51, 'CALCIUM CHLORIDE', 'I', 7.74, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9129, 51, 'CALCIUM CHLORIDE', 'I', 7.74, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9130, 51, 'CALCIUM CHLORIDE', 'I', 7.74, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10115, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10114, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78932, 6633, 'SODIUM CARBOXYMETHYL CELLULOSE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8585, 51, 'CALCIUM CHLORIDE', 'I', 7.49, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE HEMODIALYS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8586, 51, 'CALCIUM CHLORIDE', 'I', 7.49, 'G', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49558, 51, 'CALCIUM CHLORIDE', 'I', 0.257, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE.2H20');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49559, 51, 'CALCIUM CHLORIDE', 'I', 0.257, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE.2H20');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49560, 51, 'CALCIUM CHLORIDE', 'I', 0.257, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE.2H20');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62960, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62964, 51, 'CALCIUM CHLORIDE', 'I', 7.49, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62965, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63009, 51, 'CALCIUM CHLORIDE', 'I', 0.2, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66299, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71993, 51, 'CALCIUM CHLORIDE', 'I', 0.507, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71997, 51, 'CALCIUM CHLORIDE', 'I', 0.507, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE. BAG A.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71998, 51, 'CALCIUM CHLORIDE', 'I', 0.507, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73901, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73902, 51, 'CALCIUM CHLORIDE', 'I', 7.74, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73903, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73904, 51, 'CALCIUM CHLORIDE', 'I', 5.00, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73905, 51, 'CALCIUM CHLORIDE', 'I', 7.49, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73915, 51, 'CALCIUM CHLORIDE', 'I', 7.47, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73916, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73917, 51, 'CALCIUM CHLORIDE', 'I', 5.0, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73919, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73921, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73922, 51, 'CALCIUM CHLORIDE', 'I', 7.47, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73923, 51, 'CALCIUM CHLORIDE', 'I', 7.47, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73924, 51, 'CALCIUM CHLORIDE', 'I', 7.47, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73925, 51, 'CALCIUM CHLORIDE', 'I', 7.74, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73927, 51, 'CALCIUM CHLORIDE', 'I', 7.74, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73929, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75411, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', '(DIHYDRATE). BEFORE DILUTION; EQUIVALENT TO 56.3MMOL/L. AFTER DILUTION: CALCIUM:1.25MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75804, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75805, 51, 'CALCIUM CHLORIDE', 'I', 7.49, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75811, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75812, 51, 'CALCIUM CHLORIDE', 'I', 7.49, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73193, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74647, 51, 'CALCIUM CHLORIDE', 'I', 0.1838, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74648, 51, 'CALCIUM CHLORIDE', 'I', 0.1838, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74649, 51, 'CALCIUM CHLORIDE', 'I', 0.1838, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74785, 51, 'CALCIUM CHLORIDE', 'I', 7.47, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74787, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74790, 51, 'CALCIUM CHLORIDE', 'I', 7.47, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74791, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74792, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74793, 51, 'CALCIUM CHLORIDE', 'I', 5.00, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78010, 51, 'CALCIUM CHLORIDE', 'I', 0.343, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE    LARGE COMPARTMENT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78012, 51, 'CALCIUM CHLORIDE', 'I', 0.343, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE  LARGE COMPARTMENT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81573, 51, 'CALCIUM CHLORIDE', 'I', 7.44, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81574, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', 'DIHYDRATE. 2009.07.13./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81576, 51, 'CALCIUM CHLORIDE', 'I', 9.92, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81578, 51, 'CALCIUM CHLORIDE', 'I', 9.92, 'G', '', '', 'N', 'L', 'DIHYDRATE. 2009.07.13./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81236, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81237, 51, 'CALCIUM CHLORIDE', 'I', 9.92, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81238, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81262, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', 'AS DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81265, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', 'AS DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81270, 51, 'CALCIUM CHLORIDE', 'I', 9.92, 'G', '', '', 'N', 'L', 'AS DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81271, 51, 'CALCIUM CHLORIDE', 'I', 8.268, 'G', '', '', 'N', 'L', 'AS DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81272, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', 'AS DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81577, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', 'AS CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81579, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', 'AS CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81580, 51, 'CALCIUM CHLORIDE', 'I', 6.62, 'G', '', '', 'N', 'L', 'AS CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81227, 51, 'CALCIUM CHLORIDE', 'I', 9.92, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81224, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81225, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81226, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81280, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', 'AS DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81282, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', 'AS DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81592, 51, 'CALCIUM CHLORIDE', 'I', 9.92, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81593, 51, 'CALCIUM CHLORIDE', 'I', 9.92, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81594, 51, 'CALCIUM CHLORIDE', 'I', 9.92, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81595, 51, 'CALCIUM CHLORIDE', 'I', 9.92, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81596, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81598, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81600, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81601, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81602, 51, 'CALCIUM CHLORIDE', 'I', 6.61, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80860, 51, 'CALCIUM CHLORIDE', 'I', 400, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81279, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', 'AS DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81281, 51, 'CALCIUM CHLORIDE', 'I', 7.44, 'G', '', '', 'N', 'L', 'AS DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81283, 51, 'CALCIUM CHLORIDE', 'I', 6.61, 'G', '', '', 'N', 'L', 'AS DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81284, 51, 'CALCIUM CHLORIDE', 'I', 9.92, 'G', '', '', 'N', 'L', 'AS DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81239, 51, 'CALCIUM CHLORIDE', 'I', 9.92, 'G', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81240, 51, 'CALCIUM CHLORIDE', 'I', 9.92, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81241, 51, 'CALCIUM CHLORIDE', 'I', 6.62, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81242, 51, 'CALCIUM CHLORIDE', 'I', 3.31, 'G', '', '', 'N', 'L', 'AS DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81275, 51, 'CALCIUM CHLORIDE', 'I', 9.92, 'G', '', '', 'N', 'L', 'AS DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80217, 51, 'CALCIUM CHLORIDE', 'I', 10.25, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80218, 51, 'CALCIUM CHLORIDE', 'I', 11.58, 'G', '', '', 'N', 'L', 'DIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81222, 51, 'CALCIUM CHLORIDE', 'I', 8.27, 'G', '', '', 'N', 'L', 'DIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 51, 'CALCIUM CHLORIDE', 'I', 0.30, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 51, 'CALCIUM CHLORIDE', 'I', 0.52, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 51, 'CALCIUM CHLORIDE', 'I', 0.52, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85140, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'CONTENT BEFORE DILUTION. EQUIVALENT TO 56.2 MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85141, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'CONTENT BEFORE DILUTION. EQUIVALENT TO 56.2 MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85142, 51, 'CALCIUM CHLORIDE', 'I', 6.24, 'G', '', '', 'N', 'L', 'CONTENT BEFORE DILUTION. EQUIVALENT TO 56.2 MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7143, 51, 'CALCIUM CHLORIDE', 'I', 200, 'MG', '', '', 'N', 'L', 'CALCIUM CHLORIDE DIHYDRATE 200MG/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5663, 51, 'CALCIUM CHLORIDE', 'I', 200, 'MG', '', '', 'N', 'L', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64397, 51, 'CALCIUM CHLORIDE', 'I', 257, 'MG', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 51, 'CALCIUM CHLORIDE', 'I', 1.05, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14253, 51, 'CALCIUM CHLORIDE', 'I', 12.58, 'G', '', '200', 'N', 'G', 'Historic Freeform Text: CALCIUM CHLORIDE ((DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64039, 51, 'CALCIUM CHLORIDE', 'I', 107.8, 'G', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64903, 51, 'CALCIUM CHLORIDE', 'I', 118, 'G', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66864, 51, 'CALCIUM CHLORIDE', 'I', 5, 'G', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66865, 51, 'CALCIUM CHLORIDE', 'I', 5, 'G', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14165, 51, 'CALCIUM CHLORIDE', 'I', 250, 'MG', '', '450', 'N', 'G', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8101, 51, 'CALCIUM CHLORIDE', 'I', 220, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5322, 51, 'CALCIUM CHLORIDE', 'I', 0.33, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3926, 51, 'CALCIUM CHLORIDE', 'I', 250, 'MG', '', '450', 'N', 'G', 'Historic Freeform Text: CALCIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2191, 6757, 'LACTOSE', 'I', 900, 'MG', '', '', 'N', '', 'Historic Freeform Text: LACTOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62057, 6996, 'SODIUM BORATE', 'I', 3.44, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62300, 6996, 'SODIUM BORATE', 'I', 13, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2479, 10021, 'CITRIC ACID', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: CITRIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2191, 10021, 'CITRIC ACID', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: CITRIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69406, 10021, 'CITRIC ACID', 'I', 1000, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76536, 10021, 'CITRIC ACID', 'I', 27.7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71086, 10021, 'CITRIC ACID', 'I', 4.875, '%', '', '', 'N', '', '/WT.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78664, 10021, 'CITRIC ACID', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80092, 10021, 'CITRIC ACID', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76049, 10021, 'CITRIC ACID', 'I', 5.33, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83163, 10021, 'CITRIC ACID', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82082, 10021, 'CITRIC ACID', 'I', 4.846, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78823, 10021, 'CITRIC ACID', 'I', 59.9, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42652, 10021, 'CITRIC ACID', 'I', 1, 'G', '', '', 'N', 'EVT', 'Historic Freeform Text: CITRIC ACID Qty Unit: EVT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7388, 10021, 'CITRIC ACID', 'I', 20, '%', '', '', 'N', '%', 'Historic Freeform Text: CITRIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73995, 10021, 'CITRIC ACID', 'I', 12, 'G', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78587, 10021, 'CITRIC ACID', 'I', 12, 'G', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80347, 10021, 'CITRIC ACID', 'I', 12, 'G', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84334, 10021, 'CITRIC ACID', 'I', 12, 'G', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23039, 10021, 'CITRIC ACID', 'I', 189, 'MG', '', '63', 'N', 'ML', 'Historic Freeform Text: CITRIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21993, 10021, 'CITRIC ACID', 'I', 37, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CITRIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16794, 10021, 'CITRIC ACID', 'I', 93, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: CITRIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11376, 10021, 'CITRIC ACID', 'I', 730, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CITRIC ACID (ANHYDROUS)./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11354, 10021, 'CITRIC ACID', 'I', 440, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CITRIC ACID (ANHYDROUS)./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2122, 10021, 'CITRIC ACID', 'I', 32.4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CITRIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (744, 10021, 'CITRIC ACID', 'I', 148, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CITRIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85140, 10021, 'CITRIC ACID', 'I', 6.91, 'G', '', '', 'N', 'L', 'CONTENT BEFORE DILUTION. EQUIVALENT TO 108 MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85141, 10021, 'CITRIC ACID', 'I', 6.91, 'G', '', '', 'N', 'L', 'CONTENT BEFORE DILUTION. EQUIVALENT TO 108 MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85142, 10021, 'CITRIC ACID', 'I', 6.91, 'G', '', '', 'N', 'L', 'CONTENT BEFORE DILUTION. EQUIVALENT TO 108 MMOL/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15158, 10021, 'CITRIC ACID', 'I', 1.000, 'G', '', '80', 'N', 'G', 'Historic Freeform Text: CITRIC ACID ((ANHYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12827, 10021, 'CITRIC ACID', 'I', 1.000, 'G', '', '184', 'N', 'G', 'Historic Freeform Text: CITRIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10794, 10021, 'CITRIC ACID', 'I', 1, 'G', '', '73', 'N', 'G', 'Historic Freeform Text: CITRIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11333, 10021, 'CITRIC ACID', 'I', 1, 'G', '', '184', 'N', 'G', 'Historic Freeform Text: CITRIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76260, 10021, 'CITRIC ACID', 'I', 1.000, 'G', '', '184', 'N', 'G', 'ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2043, 10021, 'CITRIC ACID', 'I', 75, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: CITRIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25675, 13446, 'EDETATE SODIUM', 'I', 1.6, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM EDETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15899, 13446, 'EDETATE SODIUM', 'I', 0.38, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM EDETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16133, 13446, 'EDETATE SODIUM', 'I', 2.28, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM EDETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15508, 13446, 'EDETATE SODIUM', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM EDETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13767, 13446, 'EDETATE SODIUM', 'I', 0.38, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM EDETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3594, 13446, 'EDETATE SODIUM', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM EDETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2486, 13446, 'EDETATE SODIUM', 'I', 2.3, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM EDETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2487, 13446, 'EDETATE SODIUM', 'I', 1.4, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM EDETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2679, 13446, 'EDETATE SODIUM', 'I', 1.5, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM EDETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78430, 13446, 'EDETATE SODIUM', 'I', 1.6, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM EDETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82120, 13446, 'EDETATE SODIUM', 'I', 1.6, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM EDETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2305, 4354, 'SODIUM TRIPOLYPHOSPHATE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM TRIPOLYPHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31283, 8910, 'SODIUM THIOSULFATE', 'I', 25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM THIOSULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2072, 8910, 'SODIUM THIOSULFATE', 'I', 8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM THIOSULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (233, 8910, 'SODIUM THIOSULFATE', 'I', 16.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM THIOSULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64083, 8910, 'SODIUM THIOSULFATE', 'I', 10, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18637, 8910, 'SODIUM THIOSULFATE', 'I', 1.1, 'G', '', '28.35', 'N', 'G', 'HISTORIC FREEFORM TEXT: SODIUM THIOSULPHATE ((PENTAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21757, 6337, 'POTASSIUM PHOSPHATE MONOBASIC', 'I', 820, 'µG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE MONOBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19442, 6337, 'POTASSIUM PHOSPHATE MONOBASIC', 'I', 224, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM PHOSPHATE MONOBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10509, 6337, 'POTASSIUM PHOSPHATE MONOBASIC', 'I', 224, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE MONOBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10939, 6337, 'POTASSIUM PHOSPHATE MONOBASIC', 'I', 6.25, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE MONOBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8119, 6337, 'POTASSIUM PHOSPHATE MONOBASIC', 'I', 176, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE MONOBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69934, 6337, 'POTASSIUM PHOSPHATE MONOBASIC', 'I', 224, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1958, 6337, 'POTASSIUM PHOSPHATE MONOBASIC', 'I', 34.3905, 'KG', '', '576', 'N', 'L', 'Historic Freeform Text: POTASSIUM PHOSPHATE MONOBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42486, 6633, 'SODIUM CARBOXYMETHYL CELLULOSE', 'I', 13.3, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CARBOXYMETHYL CELLULOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11138, 6633, 'SODIUM CARBOXYMETHYL CELLULOSE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM CARBOXYMETHYL CELLULOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50289, 6633, 'SODIUM CARBOXYMETHYL CELLULOSE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65756, 6633, 'SODIUM CARBOXYMETHYL CELLULOSE', 'I', 0.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73225, 6633, 'SODIUM CARBOXYMETHYL CELLULOSE', 'I', 0.25, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77230, 6633, 'SODIUM CARBOXYMETHYL CELLULOSE', 'I', 1.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77181, 6633, 'SODIUM CARBOXYMETHYL CELLULOSE', 'I', 0.25, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79819, 6633, 'SODIUM CARBOXYMETHYL CELLULOSE', 'I', 0.5, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79819, 6633, 'SODIUM CARBOXYMETHYL CELLULOSE', 'I', 1.0, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27183, 6633, 'SODIUM CARBOXYMETHYL CELLULOSE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM CARBOXYMETHYL CELLULOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68637, 6633, 'SODIUM CARBOXYMETHYL CELLULOSE', 'I', 10, 'MG', '', '', 'N', 'ML', '1%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15207, 1832, 'MUPIROCIN', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: MUPIROCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63239, 1832, 'MUPIROCIN (MUPIROCIN CALCIUM DIHYDRATE)', 'I', 2, '%', '', '', 'Y', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76560, 1832, 'MUPIROCIN', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44066, 1840, 'DOMPERIDONE (DOMPERIDONE MALEATE)', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DOMPERIDONE ((AS DOMPERIDONE MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13180, 1840, 'DOMPERIDONE (DOMPERIDONE MALEATE)', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DOMPERIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50801, 1840, 'DOMPERIDONE (DOMPERIDONE MALEATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59887, 1840, 'DOMPERIDONE (DOMPERIDONE MALEATE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60147, 1840, 'DOMPERIDONE (DOMPERIDONE MALEATE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61717, 1840, 'DOMPERIDONE (DOMPERIDONE MALEATE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61748, 1840, 'DOMPERIDONE (DOMPERIDONE MALEATE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76423, 1840, 'DOMPERIDONE (DOMPERIDONE MALEATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75346, 1840, 'DOMPERIDONE (DOMPERIDONE MALEATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43813, 1840, 'DOMPERIDONE (DOMPERIDONE MALEATE)', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DOMPERIDONE MALEATE 2009.8.26. FURTHER TO A SIPDMAIL, AI REVISED TO DOMPERID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83565, 1840, 'DOMPERIDONE (DOMPERIDONE MALEATE)', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DOMPERIDONE ((AS DOMPERIDONE MALEATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43664, 1847, 'FLUTAMIDE', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUTAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6035, 1847, 'FLUTAMIDE', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUTAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48621, 1847, 'FLUTAMIDE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48636, 1847, 'FLUTAMIDE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50149, 1847, 'FLUTAMIDE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62498, 1847, 'FLUTAMIDE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61987, 1847, 'FLUTAMIDE', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43034, 1848, 'LEVOBUNOLOL HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: LEVOBUNOLOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19584, 1848, 'LEVOBUNOLOL HYDROCHLORIDE', 'I', 0.25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LEVOBUNOLOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19592, 1848, 'LEVOBUNOLOL HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LEVOBUNOLOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20355, 1848, 'LEVOBUNOLOL HYDROCHLORIDE', 'I', 0.25, '%', '', '', 'N', '', 'Historic Freeform Text: LEVOBUNOLOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20356, 1848, 'LEVOBUNOLOL HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: LEVOBUNOLOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11894, 1848, 'LEVOBUNOLOL HYDROCHLORIDE', 'I', 0.25, '%', '', '', 'N', '', 'Historic Freeform Text: LEVOBUNOLOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65228, 1848, 'LEVOBUNOLOL HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', '', 'STRENGTH ALSO STATED AS 5.00 G/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65229, 1848, 'LEVOBUNOLOL HYDROCHLORIDE', 'I', 0.25, '%', '', '', 'N', '', 'STRENGTH ALSO STATED AS 2.50 G/L');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65379, 1848, 'LEVOBUNOLOL HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', '', '0.5%W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65378, 1848, 'LEVOBUNOLOL HYDROCHLORIDE', 'I', 0.25, '%', '', '', 'N', '', '0.25%W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61367, 1848, 'LEVOBUNOLOL HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6230, 1848, 'LEVOBUNOLOL HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LEVOBUNOLOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43830, 1855, 'KETOCONAZOLE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: KETOCONAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50343, 1855, 'KETOCONAZOLE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60554, 1855, 'KETOCONAZOLE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44259, 1855, 'KETOCONAZOLE', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: KETOCONAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69762, 1855, 'KETOCONAZOLE', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: KETOCONAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15819, 1791, 'GLYCOSAMINOGLYCAN POLYSULFATE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GLYCOSAMINOGLYCAN POLYSULPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10546, 1791, 'GLYCOSAMINOGLYCAN POLYSULFATE', 'I', 250, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GLYCOSAMINOGLYCAN POLYSULPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11356, 1791, 'GLYCOSAMINOGLYCAN POLYSULFATE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: GLYCOSAMINOGLYCAN POLYSULPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82159, 1796, 'DOCOSAHEXAENOIC ACID', 'I', 40, 'MG', '', '8', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82159, 1798, 'EICOSAPENTAENOIC ACID', 'I', 58, 'MG', '', '8', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16128, 1810, 'ENALAPRIL MALEATE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: ENALAPRIL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16129, 1810, 'ENALAPRIL MALEATE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: ENALAPRIL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16119, 1810, 'ENALAPRIL MALEATE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: ENALAPRIL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16120, 1810, 'ENALAPRIL MALEATE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ENALAPRIL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16121, 1810, 'ENALAPRIL MALEATE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: ENALAPRIL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14388, 1810, 'ENALAPRIL MALEATE', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ENALAPRIL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14387, 1810, 'ENALAPRIL MALEATE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ENALAPRIL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14385, 1810, 'ENALAPRIL MALEATE', 'I', 2.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ENALAPRIL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14386, 1810, 'ENALAPRIL MALEATE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: ENALAPRIL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79698, 1810, 'ENALAPRIL MALEATE', 'I', 2.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ENALAPRIL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79699, 1810, 'ENALAPRIL MALEATE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: ENALAPRIL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79700, 1810, 'ENALAPRIL MALEATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: ENALAPRIL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79701, 1810, 'ENALAPRIL MALEATE', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ENALAPRIL MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83816, 1810, 'ENALAPRIL MALEATE', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83817, 1810, 'ENALAPRIL MALEATE', 'I', 10.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43361, 1751, 'INTERFERON ALFA-2B', 'I', 10000000, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: INTERFERON ALFA 2B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51025, 1751, 'INTERFERON ALFA-2B', 'I', 18, 'MIU', '', '', 'N', 'VIAL', '18 MILLION IU/VIAL IN KIT.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62105, 1751, 'INTERFERON ALFA-2B', 'I', 6000000, 'UNIT', '', '', 'N', 'ML', '6 X 10 TO THE POWER OF 6 IU PER ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62106, 1751, 'INTERFERON ALFA-2B', 'I', 10000000, 'UNIT', '', '', 'N', 'ML', '10 X 10 TO THE POWER OF 6 IU PER ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64280, 1751, 'INTERFERON ALFA-2B', 'I', 15000000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64281, 1751, 'INTERFERON ALFA-2B', 'I', 25000000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64282, 1751, 'INTERFERON ALFA-2B', 'I', 50000000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43846, 1755, 'CARBOPLATIN', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CARBOPLATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17830, 1755, 'CARBOPLATIN', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CARBOPLATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13443, 1756, 'LEUPROLIDE ACETATE', 'I', 3.75, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: LEUPROLIDE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10318, 1756, 'LEUPROLIDE ACETATE', 'I', 7.5, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: LEUPROLIDE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48922, 1756, 'LEUPROLIDE ACETATE', 'I', 22.5, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63320, 1756, 'LEUPROLIDE ACETATE', 'I', 30, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63321, 1756, 'LEUPROLIDE ACETATE', 'I', 11.25, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75428, 1756, 'LEUPROLIDE ACETATE', 'I', 58.2, 'MG', '', '', 'N', 'SYR', '45 MG (56.3 MG ACTIVE PER SYR.) (6 MONTHS) 2007.05.10 AMOUNT OF ACTIVE CHANGED TO 58.2 PER SYRINGE B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72576, 1756, 'LEUPROLIDE ACETATE', 'I', 10.2, 'MG', '', '', 'N', 'SYR', '7.5MG(10.2MG ACTIVE PER SYRINGE)(1-MONTH)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72577, 1756, 'LEUPROLIDE ACETATE', 'I', 28.2, 'MG', '', '', 'N', 'SYR', '22.5MG(28.2MG ACTIVE PER SYRINGE)(3-MONTH)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73384, 1756, 'LEUPROLIDE ACETATE', 'I', 35.8, 'MG', '', '', 'N', 'SYR', '30 MG (35.8 MG ACTIVE PER SYR.) (4 MONTHS)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83631, 1395, 'FAMOTIDINE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7367, 1756, 'LEUPROLIDE ACETATE', 'I', 5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LEUPROLIDE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18692, 1769, 'D&C RED NO. 28', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: D AND C RED NO 28');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13846, 1739, 'CLADRIBINE', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CLADRIBINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80536, 1739, 'CLADRIBINE', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64988, 1747, 'IFOSFAMIDE', 'I', 3, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64989, 1747, 'IFOSFAMIDE', 'I', 1, 'G', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70748, 1747, 'IFOSFAMIDE', 'I', 1, 'G', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67852, 12209, 'MIRTAZAPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72897, 12209, 'MIRTAZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72898, 12209, 'MIRTAZAPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72899, 12209, 'MIRTAZAPINE', 'I', 45, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76547, 12209, 'MIRTAZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76548, 12209, 'MIRTAZAPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76549, 12209, 'MIRTAZAPINE', 'I', 45, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76737, 12209, 'MIRTAZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76739, 12209, 'MIRTAZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74133, 12209, 'MIRTAZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74134, 12209, 'MIRTAZAPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74135, 12209, 'MIRTAZAPINE', 'I', 45, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73130, 12209, 'MIRTAZAPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75631, 12209, 'MIRTAZAPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74461, 12209, 'MIRTAZAPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75981, 12209, 'MIRTAZAPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73540, 12209, 'MIRTAZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73541, 12209, 'MIRTAZAPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73715, 12209, 'MIRTAZAPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73716, 12209, 'MIRTAZAPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75075, 12209, 'MIRTAZAPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75940, 12209, 'MIRTAZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77206, 12209, 'MIRTAZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77207, 12209, 'MIRTAZAPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77208, 12209, 'MIRTAZAPINE', 'I', 45, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79829, 12209, 'MIRTAZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79830, 12209, 'MIRTAZAPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81058, 12209, 'MIRTAZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81059, 12209, 'MIRTAZAPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78516, 12209, 'MIRTAZAPINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78517, 12209, 'MIRTAZAPINE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78518, 12209, 'MIRTAZAPINE', 'I', 45, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67861, 12210, 'DESLORATADINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78346, 12210, 'DESLORATADINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79491, 12210, 'DESLORATADINE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82406, 12210, 'DESLORATADINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71435, 12210, 'DESLORATADINE', 'I', 0.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75009, 12213, 'TICK-BORNE ENCEPHALITIS VACCINE (INACTIVATED)', 'I', 2.4, 'µG', '', '0.5', 'N', 'ML', 'TARGET VALUE, STRAIN NEUDORFL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67875, 12216, 'AMINOLEVULINIC ACID HYDROCHLORIDE', 'I', 20, '%', '', '', 'N', '', 'THE TOPICAL SOL. IS ADMIXED TO PRODUCE A 20% SOLUTION PRIOR TO USE.  ONE AMPULE CONTAINS 1.5ML OF SO');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71368, 12251, 'TENOFOVIR DISOPROXIL FUMARATE', 'I', 300, 'MG', '', '', 'N', '', 'EQUIVALENT TO 245 MG TENOFOVIR DISOPROXIL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76043, 12251, 'TENOFOVIR DISOPROXIL FUMARATE', 'I', 300, 'MG', '', '', 'N', '', 'EQUIVALENT TO 245 MG TENOFOVIR DISOPROXIL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78602, 12251, 'TENOFOVIR DISOPROXIL FUMARATE', 'I', 300, 'MG', '', '', 'N', '', 'EQUIVALENT TO 245 MG TENOFOVIR DISOPROXIL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69618, 12253, 'FONDAPARINUX SODIUM', 'I', 2.5, 'MG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74328, 12253, 'FONDAPARINUX SODIUM', 'I', 12.5, 'MG', '', '', 'N', 'ML', '1 DIN GENERATED 12.5MG/ML AS PER REQUEST FROM PID/SMAB -CONFIRMED WITH CO. THIS DIN COVERS DIFFERENT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20287, 12267, 'SALMONELLA TYPHI VI CAPSULAR POLYSACCHARIDE VACCINE', 'I', 25, 'µG', '', '0.5', 'N', 'ML', 'Historic Freeform Text: VI POLYSACCHARIDE OF SALMONELLA TYPHI');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66534, 12267, 'SALMONELLA TYPHI VI CAPSULAR POLYSACCHARIDE VACCINE', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72706, 12267, 'SALMONELLA TYPHI VI CAPSULAR POLYSACCHARIDE VACCINE', 'I', 25, 'µG', '', '0.5', 'N', 'ML', 'SOLUTION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72643, 12297, 'GADOBENATE DIMEGLUMINE', 'I', 529, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11257, 672, 'BELLADONNA', 'I', 15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BELLADONNA ((DRY EXTRACT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11124, 672, 'BELLADONNA', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: BELLADONA ((PWR EXT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48361, 672, 'BELLADONNA', 'I', 0.2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BELLADONNA ((LEVO)) L-ALKALOIDS OF BELLADONNA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41695, 1637, 'PINE TAR', 'I', 0.166, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PINE TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7049, 1637, 'PINE TAR', 'I', 3.5, '%', '', '', 'N', '', 'Historic Freeform Text: PINE TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5557, 1637, 'PINE TAR', 'I', 0.33, '%', '', '', 'N', '', 'Historic Freeform Text: PINE TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2984, 1637, 'PINE TAR', 'I', 0.09, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PINE TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1495, 1637, 'PINE TAR', 'I', 0.16, '%', '', '', 'N', '', 'Historic Freeform Text: PINE TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64533, 1637, 'PINE TAR', 'I', 0.33, '%', '', '', 'N', '', 'Historic Freeform Text: PINE TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79816, 1637, 'PINE TAR', 'I', 47.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5577, 1637, 'PINE TAR', 'I', 3.34, '%', '', '', 'N', '%', 'Historic Freeform Text: PINE TAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62056, 1637, 'PINE TAR', 'I', 64.99, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62060, 1637, 'PINE TAR', 'I', 38.12, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74044, 1637, 'PINE TAR', 'I', 85, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73463, 12313, 'PEGFILGRASTIM', 'I', 10, 'MG', '', '', 'N', 'ML', '6 MG PER PRE-FILLED SYRINGE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75213, 12329, 'GALANTAMINE (GALANTAMINE HYDROBROMIDE)', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75214, 12329, 'GALANTAMINE (GALANTAMINE HYDROBROMIDE)', 'I', 16, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75215, 12329, 'GALANTAMINE (GALANTAMINE HYDROBROMIDE)', 'I', 24, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80244, 12329, 'GALANTAMINE (GALANTAMINE HYDROBROMIDE)', 'I', 8, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80245, 12329, 'GALANTAMINE (GALANTAMINE HYDROBROMIDE)', 'I', 16, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80246, 12329, 'GALANTAMINE (GALANTAMINE HYDROBROMIDE)', 'I', 24, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82505, 12329, 'GALANTAMINE (GALANTAMINE HYDROBROMIDE)', 'I', 8, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82506, 12329, 'GALANTAMINE (GALANTAMINE HYDROBROMIDE)', 'I', 16, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82507, 12329, 'GALANTAMINE (GALANTAMINE HYDROBROMIDE)', 'I', 24, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68232, 12330, 'CASPOFUNGIN (CASPOFUNGIN ACETATE)', 'I', 50, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68233, 12330, 'CASPOFUNGIN (CASPOFUNGIN ACETATE)', 'I', 70, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75090, 12335, 'INSULIN ASPART', 'I', 30, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68321, 12335, 'INSULIN ASPART', 'I', 100, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69441, 12335, 'INSULIN ASPART', 'I', 100, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68108, 12343, 'SUFENTANIL (SUFENTANIL CITRATE)', 'I', 50, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72410, 12346, 'TADALAFIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72411, 12346, 'TADALAFIL', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78223, 12346, 'TADALAFIL', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78224, 12346, 'TADALAFIL', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82395, 12346, 'TADALAFIL', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71450, 12357, 'VIBRIO CHOLERAE INABA 6973 E1 TOR BIOTYPE, FORMALIN INACTIVATED', 'I', 25000000000, 'UNIT', '', '', 'N', 'DOSE', '2.5X10 TO THE POWER OF 10 VIBRIOS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71450, 12358, 'VIBRIO CHOLERAE INABA 48 CLASSICAL BIOTYPE, HEAT INACTIVATED', 'I', 25000000000, 'UNIT', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71450, 12359, 'VIBRIO CHOLERAE OGAWA 50 CLASSICAL BIOTYPE, HEAT INACTIVATED', 'I', 25000000000, 'UNIT', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71450, 12360, 'VIBRIO CHOLERAE OGAWA 50 CLASSICAL BIOTYPE, FORMALIN INACTIVATED', 'I', 25000000000, 'UNIT', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71450, 12361, 'RECOMBINANT CHOLERA TOXIN B SUBUNIT', 'I', 1, 'MG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68498, 12371, 'ESOMEPRAZOLE (ESOMEPRAZOLE MAGNESIUM TRIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68499, 12371, 'ESOMEPRAZOLE (ESOMEPRAZOLE MAGNESIUM TRIHYDRATE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82473, 12371, 'ESOMEPRAZOLE (ESOMEPRAZOLE MAGNESIUM)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84676, 12371, 'ESOMEPRAZOLE (ESOMEPRAZOLE MAGNESIUM TRIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84677, 12371, 'ESOMEPRAZOLE (ESOMEPRAZOLE MAGNESIUM TRIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78581, 12371, 'ESOMEPRAZOLE (ESOMEPRAZOLE MAGNESIUM TRIHYDRATE)', 'I', 10, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61485, 12376, 'POTASSIUM PEROXYMONOSULFATE', 'I', 23, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71548, 12376, 'POTASSIUM PEROXYMONOSULFATE', 'I', 23, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73885, 12376, 'POTASSIUM PEROXYMONOSULFATE', 'I', 21.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75119, 12376, 'POTASSIUM PEROXYMONOSULFATE', 'I', 23, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30727, 12376, 'POTASSIUM PEROXYMONOSULFATE', 'I', 21.4, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: POTASSIUM MONOPERSULFATE W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72199, 12376, 'POTASSIUM PEROXYMONOSULFATE', 'I', 34.4, '%', '', '', 'N', 'W/W', 'AS PER REVIEWER THIS PRODUCT CONTAINS OXONE - WHICH CONTAINS POTASSIUM PEROXYMONOSULFATE 34.4% OF WH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76203, 12376, 'POTASSIUM PEROXYMONOSULFATE', 'I', 21.4, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78435, 12378, 'CICLOPIROX', 'I', 8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73535, 12378, 'CICLOPIROX', 'I', 80, 'MG', '', '', 'N', 'G', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74742, 12389, 'CHORIOGONADOTROPIN ALPHA', 'I', 250, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37084, 12399, 'HYPROMELLOSE', 'I', 0.3, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROXYPROPYLMETHYLCELLULOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13167, 12399, 'HYPROMELLOSE', 'I', 0.3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROXYPROPYLMETHYLCELLULOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11709, 12399, 'HYPROMELLOSE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROXYPROPYLMETHYLCELLULOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10032, 12399, 'HYPROMELLOSE', 'I', 0.3, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROXYPROPYLMETHYLCELLULOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2682, 12399, 'HYPROMELLOSE', 'I', 0.3, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROXYPROPYLMETHYLCELLULOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (793, 12399, 'HYPROMELLOSE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROXYPROPYLMETHYLCELLULOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (794, 12399, 'HYPROMELLOSE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROXYPROPYLMETHYLCELLULOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47379, 12399, 'HYPROMELLOSE', 'I', 0.2, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66817, 12399, 'HYPROMELLOSE', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66850, 12399, 'HYPROMELLOSE', 'I', 0.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70567, 12399, 'HYPROMELLOSE', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77181, 12399, 'HYPROMELLOSE', 'I', 0.3, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78028, 12399, 'HYPROMELLOSE', 'I', 0.8, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83970, 12399, 'HYPROMELLOSE', 'I', 0.2, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11898, 12399, 'HYPROMELLOSE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HYDROXYPROPYLMETHYLCELLULOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50599, 12399, 'HYPROMELLOSE', 'I', 3, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76495, 13584, 'ATOMOXETINE (ATOMOXETINE HYDROCHLORIDE)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76496, 13584, 'ATOMOXETINE (ATOMOXETINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74816, 13584, 'ATOMOXETINE (ATOMOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74817, 13584, 'ATOMOXETINE (ATOMOXETINE HYDROCHLORIDE)', 'I', 18, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74820, 13584, 'ATOMOXETINE (ATOMOXETINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74822, 13584, 'ATOMOXETINE (ATOMOXETINE HYDROCHLORIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74823, 13584, 'ATOMOXETINE (ATOMOXETINE HYDROCHLORIDE)', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80353, 13584, 'ATOMOXETINE (ATOMOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80354, 13584, 'ATOMOXETINE (ATOMOXETINE HYDROCHLORIDE)', 'I', 18, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80355, 13584, 'ATOMOXETINE (ATOMOXETINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80356, 13584, 'ATOMOXETINE (ATOMOXETINE HYDROCHLORIDE)', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80357, 13584, 'ATOMOXETINE (ATOMOXETINE HYDROCHLORIDE)', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80358, 13584, 'ATOMOXETINE (ATOMOXETINE HYDROCHLORIDE)', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80359, 13584, 'ATOMOXETINE (ATOMOXETINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74862, 13585, 'ESCITALOPRAM (ESCITALOPRAM OXALATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74864, 13585, 'ESCITALOPRAM (ESCITALOPRAM OXALATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74889, 13589, 'IMIDACLOPRID', 'I', 40, 'MG', '', '0.4', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74890, 13589, 'IMIDACLOPRID', 'I', 80, 'MG', '', '0.8', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74891, 13589, 'IMIDACLOPRID', 'I', 250, 'MG', '', '2.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74892, 13589, 'IMIDACLOPRID', 'I', 100, 'MG', '', '1.0', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74893, 13589, 'IMIDACLOPRID', 'I', 40, 'MG', '', '0.4', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74894, 13589, 'IMIDACLOPRID', 'I', 400, 'MG', '', '4.0', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 6989, 'COPPER SULFATE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: COPPER SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (622, 6989, 'COPPER SULFATE', 'I', 13, '%', '', '', 'N', '', 'Historic Freeform Text: COPPER SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2181, 6989, 'COPPER SULFATE', 'I', 51.5, '%', '', '', 'N', '', 'Historic Freeform Text: COPPER SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49958, 6989, 'COPPER SULFATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76196, 6989, 'COPPER SULFATE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 6989, 'COPPER SULFATE', 'I', 1.6, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: COPPER SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 6989, 'COPPER SULFATE', 'I', 0.005, 'G', '', '', 'N', 'KG', 'ADDED 2010.04.14 AS PER VDD REQUEST./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49592, 6989, 'COPPER SULFATE', 'I', 510, 'MG', '', '', 'N', 'G', 'PENTAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47888, 6989, 'COPPER SULFATE', 'I', 3.15, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66864, 6989, 'COPPER SULFATE', 'I', 119.5, 'MG', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66865, 6989, 'COPPER SULFATE', 'I', 119.5, 'MG', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3667, 6274, 'CHLORO-M-CRESOL', 'I', 0.41, '%', '', '', 'N', '%', 'Historic Freeform Text: 4-CHLORO-M-CRESOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36721, 7150, 'ALLANTOIN', 'I', 0.2, '%', '', '', 'N', '', 'Historic Freeform Text: ALLANTOIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5348, 7150, 'ALLANTOIN', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALLANTOIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75230, 7150, 'ALLANTOIN', 'I', 1.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3888, 7150, 'ALLANTOIN', 'I', 12, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ALLANTOIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 13620, 'METHYLCHLOROISOTHIAZOLINONE', 'I', 0.0032, 'MG', '', '', 'N', 'PATCH', 'KATHON CG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75308, 15082, 'RABIES VACCINE INACTIVATED (PURIFIED CHICK EMBRYO CELL CULTURE)', 'I', 2.5, 'UNIT', '', '', 'N', 'DOSE', '1DOSE=1ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 7196, 'DRIED YEAST', 'I', 3.5, 'G', '', '', 'N', '', 'Historic Freeform Text: DRIED YEAST');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42879, 1395, 'FAMOTIDINE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: FAMOTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19913, 1395, 'FAMOTIDINE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: FAMOTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19915, 1395, 'FAMOTIDINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: FAMOTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15563, 1395, 'FAMOTIDINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: FAMOTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15564, 1395, 'FAMOTIDINE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: FAMOTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13654, 1395, 'FAMOTIDINE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: FAMOTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13655, 1395, 'FAMOTIDINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: FAMOTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13583, 1395, 'FAMOTIDINE', 'I', 40, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FAMOTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13572, 1395, 'FAMOTIDINE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: FAMOTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7087, 1395, 'FAMOTIDINE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: FAMOTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7088, 1395, 'FAMOTIDINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: FAMOTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50715, 1395, 'FAMOTIDINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50389, 1395, 'FAMOTIDINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50911, 1395, 'FAMOTIDINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50426, 1395, 'FAMOTIDINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60466, 1395, 'FAMOTIDINE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60467, 1395, 'FAMOTIDINE', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60544, 1395, 'FAMOTIDINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63963, 1395, 'FAMOTIDINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66915, 1395, 'FAMOTIDINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75884, 1395, 'FAMOTIDINE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68883, 1395, 'FAMOTIDINE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FAMOTIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68997, 1395, 'FAMOTIDINE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72016, 1395, 'FAMOTIDINE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72026, 1395, 'FAMOTIDINE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16938, 1399, 'LITHIUM (LITHIUM CITRATE)', 'I', 8, 'MMO', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LITHIUM ION ((LI AS LITHIUM CITRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15489, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMIODARONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63322, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63581, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64175, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66199, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67777, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71459, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70344, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70495, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69894, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77754, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78625, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79532, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84924, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66036, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69271, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69797, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71180, 1400, 'AMIODARONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 1366, 'TAURINE', 'I', 50, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TAURINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 1366, 'TAURINE', 'I', 70, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: TAURINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 1366, 'TAURINE', 'I', 60, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14334, 1374, 'BUMETANIDE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUMETANIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14322, 1374, 'BUMETANIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUMETANIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42295, 1383, 'POLYHEXANIDE', 'I', 0.0001, '%', '', '', 'N', '', 'Historic Freeform Text: POLYHEXANIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71357, 1383, 'POLYHEXANIDE', 'I', 0.0001, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71150, 1383, 'POLYHEXANIDE', 'I', 0.0001, '%', '', '', 'N', '', 'POLYHEXAMETHYLENE BIGUANIDE HCL DISSOLVED FROM 0.0055MG/G(INCLDE 10% OVERAGE) OR 0.00055% OF A 20% S');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75193, 1383, 'POLYHEXANIDE', 'I', 0.0001, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75250, 1383, 'POLYHEXANIDE', 'I', 0.0001, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72573, 1383, 'POLYHEXANIDE', 'I', 0.0001, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77650, 1383, 'POLYHEXANIDE', 'I', 0.0001, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11656, 1322, 'ENILCONAZOLE', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ENILCONAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65043, 1324, 'NEDOCROMIL SODIUM', 'I', 2, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12473, 1347, 'DETOMIDINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DETOMIDINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82105, 1347, 'DETOMIDINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82159, 1350, 'GAMMA-LINOLENIC ACID', 'I', 16, 'MG', '', '8', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19306, 1353, 'N-ACETYL-L-TYROSINE', 'I', 405, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: N-ACETYL-L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 1353, 'N-ACETYL-L-TYROSINE', 'I', 115, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: N-ACETYL-L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 1353, 'N-ACETYL-L-TYROSINE', 'I', 115, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: N-ACETYL-L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 1353, 'N-ACETYL-L-TYROSINE', 'I', 94, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: N-ACETYL-L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 1353, 'N-ACETYL-L-TYROSINE', 'I', 115, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: N-ACETYL-L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 1353, 'N-ACETYL-L-TYROSINE', 'I', 135, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: N-ACETYL-L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 1353, 'N-ACETYL-L-TYROSINE', 'I', 94, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: N-ACETYL-L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 1353, 'N-ACETYL-L-TYROSINE', 'I', 115, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: N-ACETYL-L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 1353, 'N-ACETYL-L-TYROSINE', 'I', 94, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: N-ACETYL-L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18644, 1353, 'N-ACETYL-L-TYROSINE', 'I', 270, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: N-ACETYL-L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 1353, 'N-ACETYL-L-TYROSINE', 'I', 270, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: N-ACETYL-L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18608, 1353, 'N-ACETYL-L-TYROSINE', 'I', 189, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: N-ACETYL-L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18607, 1353, 'N-ACETYL-L-TYROSINE', 'I', 230, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: N-ACETYL-L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65047, 1281, 'MESNA', 'I', 100, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68929, 1281, 'MESNA', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73824, 12429, 'IMATINIB (IMATINIB MESYLATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73825, 12429, 'IMATINIB (IMATINIB MESYLATE)', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68816, 12468, 'TENECTEPLASE', 'I', 50, 'MG', '', '', 'N', 'VIAL', '10,000UNIT/VIAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76384, 12477, 'TRAVOPROST', 'I', 0.004, '%', '', '', 'N', '', 'W/V.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80351, 12477, 'TRAVOPROST', 'I', 0.004, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75441, 12481, 'ERLOTINIB (ERLOTINIB HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75442, 12481, 'ERLOTINIB (ERLOTINIB HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75443, 12481, 'ERLOTINIB (ERLOTINIB HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77636, 12491, 'ALEMTUZUMAB', 'I', 30, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42328, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (29540, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26561, 9152, 'DOCUSATE SODIUM', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16492, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14487, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13945, 9152, 'DOCUSATE SODIUM', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11028, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10975, 9152, 'DOCUSATE SODIUM', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10986, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9782, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8974, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6258, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7365, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2133, 9152, 'DOCUSATE SODIUM', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52463, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63130, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69083, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69227, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'Y', '', '(50% DOCUSATE SODIUM IN POLYETHYLENE GLYCOL)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71374, 9152, 'DOCUSATE SODIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70070, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70167, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71630, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71635, 9152, 'DOCUSATE SODIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76671, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77658, 9152, 'DOCUSATE SODIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78347, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78912, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81142, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82068, 9152, 'DOCUSATE SODIUM', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82069, 9152, 'DOCUSATE SODIUM', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84243, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84277, 9152, 'DOCUSATE SODIUM', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3269, 9152, 'DOCUSATE SODIUM', 'I', 1.952, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1686, 9152, 'DOCUSATE SODIUM', 'I', 5.0, '%', '', '', 'N', '', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66816, 9152, 'DOCUSATE SODIUM', 'I', 1.1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28453, 9152, 'DOCUSATE SODIUM', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28280, 9152, 'DOCUSATE SODIUM', 'I', 4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26438, 9152, 'DOCUSATE SODIUM', 'I', 20, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18776, 9152, 'DOCUSATE SODIUM', 'I', 4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13039, 9152, 'DOCUSATE SODIUM', 'I', 20, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14590, 9152, 'DOCUSATE SODIUM', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10575, 9152, 'DOCUSATE SODIUM', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11520, 9152, 'DOCUSATE SODIUM', 'I', 20, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11521, 9152, 'DOCUSATE SODIUM', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12795, 9152, 'DOCUSATE SODIUM', 'I', 60, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10878, 9152, 'DOCUSATE SODIUM', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9812, 9152, 'DOCUSATE SODIUM', 'I', 4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8116, 9152, 'DOCUSATE SODIUM', 'I', 20, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7366, 9152, 'DOCUSATE SODIUM', 'I', 4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1388, 9152, 'DOCUSATE SODIUM', 'I', 60, 'MG', '', '30', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (614, 9152, 'DOCUSATE SODIUM', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2431, 9152, 'DOCUSATE SODIUM', 'I', 60, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1724, 9152, 'DOCUSATE SODIUM', 'I', 60, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47965, 9152, 'DOCUSATE SODIUM', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62055, 9152, 'DOCUSATE SODIUM', 'I', 2.11, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61679, 9152, 'DOCUSATE SODIUM', 'I', 20, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71056, 9152, 'DOCUSATE SODIUM', 'I', 20, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DIOCTYL SODIUM SULFOSUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76885, 9152, 'DOCUSATE SODIUM', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76886, 9152, 'DOCUSATE SODIUM', 'I', 4, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81816, 9152, 'DOCUSATE SODIUM', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 7049, 'PERUVIAN BALSAM', 'I', 0.65, 'MG', '', '', 'N', 'PATCH', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3666, 7049, 'PERUVIAN BALSAM', 'I', 0.15, '%', '', '', 'N', '%', 'Historic Freeform Text: BALSAM PERU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1477, 7049, 'PERUVIAN BALSAM', 'I', 5, '%', '', '', 'N', '%', 'Historic Freeform Text: BALSAM PERU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4161, 7049, 'PERUVIAN BALSAM', 'I', 1.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: BALSAM PERU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76049, 15159, 'OCTANOIC ACID', 'I', 3.05, '%', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80441, 15159, 'OCTANOIC ACID', 'I', 0.099, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76814, 15161, 'IMMUNOGLOBULIN G (HUMAN)', 'I', 160, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47182, 3487, 'LACTIC ACID', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16939, 3487, 'LACTIC ACID', 'I', 1.7, '%', '', '', 'N', '', 'Historic Freeform Text: DL-LACTIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15101, 3487, 'LACTIC ACID', 'I', 2.64, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LACTIC ACID ((ACTIVATOR))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10853, 3487, 'LACTIC ACID', 'I', 2.64, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75154, 3487, 'LACTIC ACID', 'I', 2.6044, '%', '', '', 'N', '', 'LACTIC ACID 90% W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80959, 3487, 'LACTIC ACID', 'I', 3.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63492, 3487, 'LACTIC ACID', 'I', 1.76, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79691, 3487, 'LACTIC ACID', 'I', 1.78, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66816, 3487, 'LACTIC ACID', 'I', 1.76, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76040, 3487, 'LACTIC ACID', 'I', 0.284, 'G', '', '1000', 'N', 'ML', 'COMPARTMENT B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66962, 3487, 'LACTIC ACID', 'I', 5.4, 'G', '', '1000', 'N', 'ML', 'COMPARTMENT A ACTIVE CHANGED FROM SODIUM LACTATE 0.336G AS LACTIC ACID TO LACTIC ACID 5.4G APPROVED ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74940, 418, 'L-MENTHOL', 'I', 4.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61438, 418, 'L-MENTHOL', 'I', 1.00, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9526, 293, 'PHOSPHORUS (CALCIUM HYPOPHOSPHITE)', 'I', 7.09, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: CALCIUM HYPOPHOSPHITE ((PHOS EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13000, 293, 'PHOSPHORUS (CALCIUM HYPOPHOSPHITE)', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PHOSPHORUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76977, 15231, 'SORAFENIB (SORAFENIB TOSYLATE)', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76776, 15233, 'ABATACEPT', 'I', 250, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18096, 9754, 'PANCREATIN', 'I', 325, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PANCREATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50394, 9754, 'PANCREATIN', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64083, 1559, 'LINUM USITATISSIMUM', 'I', 0.1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68979, 12538, 'BOSENTAN (BOSENTAN MONOHYDRATE)', 'I', 62.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68980, 12538, 'BOSENTAN (BOSENTAN MONOHYDRATE)', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70520, 12550, 'DARBEPOETIN ALFA', 'I', 25, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70521, 12550, 'DARBEPOETIN ALFA', 'I', 40, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70523, 12550, 'DARBEPOETIN ALFA', 'I', 100, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70524, 12550, 'DARBEPOETIN ALFA', 'I', 200, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70526, 12550, 'DARBEPOETIN ALFA', 'I', 500, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74433, 12559, 'ALEFACEPT', 'I', 15, 'MG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77184, 12577, 'NATALIZUMAB', 'I', 300, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72107, 12580, 'DUTASTERIDE', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77180, 12585, 'DIMETHYLBENZYL AMMONIUM CHLORIDE', 'I', 3.17, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80406, 12585, 'DIMETHYLBENZYL AMMONIUM CHLORIDE', 'I', 3.17, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79968, 12585, 'DIMETHYLBENZYL AMMONIUM CHLORIDE', 'I', 3.17, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70735, 12594, 'TREPROSTINIL (TREPROSTINIL SODIUM)', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70736, 12594, 'TREPROSTINIL (TREPROSTINIL SODIUM)', 'I', 2.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70737, 12594, 'TREPROSTINIL (TREPROSTINIL SODIUM)', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70738, 12594, 'TREPROSTINIL (TREPROSTINIL SODIUM)', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69295, 12597, 'GLIMEPIRIDE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69296, 12597, 'GLIMEPIRIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69297, 12597, 'GLIMEPIRIDE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75494, 12597, 'GLIMEPIRIDE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75495, 12597, 'GLIMEPIRIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75497, 12597, 'GLIMEPIRIDE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75861, 12597, 'GLIMEPIRIDE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75862, 12597, 'GLIMEPIRIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75863, 12597, 'GLIMEPIRIDE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75923, 12597, 'GLIMEPIRIDE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75924, 12597, 'GLIMEPIRIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75926, 12597, 'GLIMEPIRIDE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75969, 12597, 'GLIMEPIRIDE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75970, 12597, 'GLIMEPIRIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75972, 12597, 'GLIMEPIRIDE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78068, 12597, 'GLIMEPIRIDE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78069, 12597, 'GLIMEPIRIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78070, 12597, 'GLIMEPIRIDE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77011, 12597, 'GLIMEPIRIDE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77012, 12597, 'GLIMEPIRIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70033, 12604, 'ANAKINRA', 'I', 150, 'MG', '', '', 'N', 'ML', '100MG ANAKINRA PER SYRINGE AS PER PM. ACCORDING TO DPIF, MEDICINAL INGREDIENT NAMED R-METHUIL-1RA.  ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19304, 12611, 'ETIDRONATE DISODIUM', 'I', 400, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETIDRONATE DISODIUM ((TAB- WHITE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69359, 12611, 'ETIDRONATE DISODIUM', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71566, 12611, 'ETIDRONATE DISODIUM', 'I', 400, 'MG', '', '', 'N', '', 'WHITE CAPSULE SHAPED TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73050, 12611, 'ETIDRONATE DISODIUM', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74925, 12611, 'ETIDRONATE DISODIUM', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80967, 12611, 'ETIDRONATE DISODIUM', 'I', 400, 'MG', '', '', 'N', '', 'WHITE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83843, 12611, 'ETIDRONATE DISODIUM', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7144, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 2400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31465, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 0.349, 'G', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 261, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21767, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 130, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 261, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 261, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 261, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 261, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 130.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 261, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 261, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19442, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 236, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 261, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 261, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 522, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE ((DIBASIC))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 261, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 261, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 261, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 261, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 130.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 261, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 261, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10509, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 236, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 522, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3820, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 418, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 522, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69934, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 236, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18635, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 2.4, 'G', '', '19', 'N', 'G', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15158, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 1.742, 'G', '', '80', 'N', 'G', 'HISTORIC FREEFORM TEXT: DIPOTASSIUM PHOSPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12827, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 1.742, 'G', '', '184', 'N', 'G', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10794, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 1.742, 'G', '', '73', 'N', 'G', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11333, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 1.742, 'G', '', '184', 'N', 'G', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65789, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 0.349, 'G', '', '76', 'N', 'G', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65790, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 0.349, 'G', '', '185', 'N', 'G', 'Historic Freeform Text: POTASSIUM PHOSPHATE DIBASIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76260, 5319, 'POTASSIUM PHOSPHATE DIBASIC', 'I', 1.742, 'G', '', '184', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 3180, 'L-METHIONINE', 'I', 73, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 3180, 'L-METHIONINE', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20278, 3180, 'L-METHIONINE', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20279, 3180, 'L-METHIONINE', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 3180, 'L-METHIONINE', 'I', 170, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19306, 3180, 'L-METHIONINE', 'I', 258, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19610, 3180, 'L-METHIONINE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20303, 3180, 'L-METHIONINE', 'I', 170, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20302, 3180, 'L-METHIONINE', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 3180, 'L-METHIONINE', 'I', 170, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 3180, 'L-METHIONINE', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 3180, 'L-METHIONINE', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20289, 3180, 'L-METHIONINE', 'I', 170, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 3180, 'L-METHIONINE', 'I', 100, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 3180, 'L-METHIONINE', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 3180, 'L-METHIONINE', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 3180, 'L-METHIONINE', 'I', 73, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 3180, 'L-METHIONINE', 'I', 73, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 3180, 'L-METHIONINE', 'I', 60, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 3180, 'L-METHIONINE', 'I', 73, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 3180, 'L-METHIONINE', 'I', 73, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19143, 3180, 'L-METHIONINE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 3180, 'L-METHIONINE', 'I', 60, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 3180, 'L-METHIONINE', 'I', 85, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 3180, 'L-METHIONINE', 'I', 60, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 3180, 'L-METHIONINE', 'I', 73, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 3180, 'L-METHIONINE', 'I', 125, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 3180, 'L-METHIONINE', 'I', 60, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18644, 3180, 'L-METHIONINE', 'I', 172, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 3180, 'L-METHIONINE', 'I', 172, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18608, 3180, 'L-METHIONINE', 'I', 120, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18607, 3180, 'L-METHIONINE', 'I', 146, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 3180, 'L-METHIONINE', 'I', 180, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18550, 3180, 'L-METHIONINE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 3180, 'L-METHIONINE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14077, 3180, 'L-METHIONINE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 3180, 'L-METHIONINE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 3180, 'L-METHIONINE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14073, 3180, 'L-METHIONINE', 'I', 246, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 3180, 'L-METHIONINE', 'I', 246, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14071, 3180, 'L-METHIONINE', 'I', 246, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 3180, 'L-METHIONINE', 'I', 145, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 3180, 'L-METHIONINE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 3180, 'L-METHIONINE', 'I', 246, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14067, 3180, 'L-METHIONINE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11329, 3180, 'L-METHIONINE', 'I', 400, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7163, 3180, 'L-METHIONINE', 'I', 726, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 3180, 'L-METHIONINE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5890, 3180, 'L-METHIONINE', 'I', 340, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4661, 3180, 'L-METHIONINE', 'I', 580, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3468, 3180, 'L-METHIONINE', 'I', 400, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4560, 3180, 'L-METHIONINE', 'I', 280, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 3180, 'L-METHIONINE', 'I', 580, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2776, 3180, 'L-METHIONINE', 'I', 200, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-METHIONINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 3180, 'L-METHIONINE', 'I', 240, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 3180, 'L-METHIONINE', 'I', 1.26, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 3180, 'L-METHIONINE', 'I', 2.21, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 3180, 'L-METHIONINE', 'I', 2.84, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 3180, 'L-METHIONINE', 'I', 2.84, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 0.03, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19610, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18550, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14077, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14073, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 246, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 246, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14071, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 246, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 145, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14067, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 246, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10470, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12562, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6071, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4661, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 580, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LYSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78915, 8700, 'L-LYSINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 13800, 'ARGININE HYDROCHLORIDE', 'I', 0.025, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: L-ARGININE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3378, 13800, 'ARGININE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: L-ARGININE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6237, 13830, 'POLLEN AND NON POLLEN', 'I', 20000, 'UNIT', '', '', 'N', 'ML', 'ALLERGENIC EXTRACTS SUPPLIED IN CONC. OF 10,000 AND 20,000 PNU/ML.DOSAGE BASED ON PROTEIN NITROGEN C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43384, 7867, 'ALBUMIN (HUMAN)', 'I', 5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALBUMIN (HUMAN)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43385, 7867, 'ALBUMIN (HUMAN)', 'I', 25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALBUMIN (HUMAN)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43388, 7867, 'ALBUMIN (HUMAN)', 'I', 0.03, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALBUMIN (HUMAN)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (207, 7867, 'ALBUMIN (HUMAN)', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: NORMAL HUMAN SERUM ALBUMIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (208, 7867, 'ALBUMIN (HUMAN)', 'I', 25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NORMAL HUMAN SERUM ALBUMIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76013, 7867, 'ALBUMIN (HUMAN)', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76014, 7867, 'ALBUMIN (HUMAN)', 'I', 25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76932, 7867, 'ALBUMIN (HUMAN)', 'I', 0.03, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42926, 7867, 'ALBUMIN (HUMAN)', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ALBUMIN (HUMAN)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42927, 7867, 'ALBUMIN (HUMAN)', 'I', 250, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ALBUMIN (HUMAN)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8276, 7867, 'ALBUMIN (HUMAN)', 'I', 0.3, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NORMAL HUMAN SERUM ALBUMIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35667, 5454, 'COCONUT OIL', 'I', 13.22, '%', '', '', 'N', '%', 'Historic Freeform Text: COCONUT OIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13020, 4929, 'D-ALPHA TOCOPHERYL ACETATE', 'I', 136, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: TOCOPHERYL D-ALPHA ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16654, 6497, 'POLYSORBATE 80', 'I', 0.8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: POLYSORBATE 80');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82225, 6497, 'POLYSORBATE 80', 'I', 4.86, 'MG', '', '0.5', 'N', 'ML', 'ADJUVANT FULL DOSE, CLASSIFIED UNDER MI AS PER BGTD');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19304, 4803, 'CALCIUM (CALCIUM CARBONATE)', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CA ((FROM 1250MG CA CARBONATE TAB-BLUE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71557, 4803, 'CALCIUM (CALCIUM CARBONATE)', 'I', 270, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71566, 4803, 'CALCIUM (CALCIUM CARBONATE)', 'I', 500, 'MG', '', '', 'N', '', 'YELLOW FILM-COATED TAB CALCIUM CARBONATE FROM OYSTER SHELLS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70202, 4803, 'CALCIUM (CALCIUM CARBONATE)', 'I', 300, 'MG', '', '', 'N', '', 'BLUE TABLET P.M.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76526, 4803, 'CALCIUM (CALCIUM CARBONATE)', 'I', 500, 'MG', '', '', 'N', '', 'BLUE TABLET WITH NE 2');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76186, 4803, 'CALCIUM (CALCIUM CARBONATE)', 'I', 300, 'MG', '', '', 'N', '', 'BLUE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74925, 4803, 'CALCIUM (CALCIUM CARBONATE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80967, 4803, 'CALCIUM (CALCIUM CARBONATE)', 'I', 500, 'MG', '', '', 'N', '', 'BLUE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83843, 4803, 'CALCIUM (CALCIUM CARBONATE)', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9526, 4803, 'CALCIUM (CALCIUM GLUCONATE)', 'I', 12.42, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: CALCIUM GLUCONATE ((CALC EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13000, 4803, 'CALCIUM (CALCIUM BOROGLUCONATE, CALCIUM HYPOPHOSPHITE)', 'I', 22.07, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CALCIUM BOROGLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7401, 4803, 'CALCIUM (CALCIUM BOROGLUCONATE)', 'I', 19.14, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: CALCIUM BOROGLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48834, 4803, 'CALCIUM (CALCIUM GLUCOHEPTONATE, CALCIUM GLUCONATE)', 'I', 39.45, 'MG', '', '', 'Y', 'ML', 'CALCIUM(8.17MG/ML)(CALCIUM GLUCOHEPTONATE(100MG/ML)) & CALCIUM(31.28MG/ML)(CALCIUM GLUCONATE(350MG/M');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6404, 4803, 'CALCIUM (CALCIUM CHLORIDE)', 'I', 5, 'MEQ', '', '', 'N', 'L', 'Historic Freeform Text: CALC CHLORIDE ((CALC EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17121, 4803, 'CALCIUM (CALCIUM ACETATE)', 'I', 1.81, 'G', '', '400', 'Y', 'G', 'Historic Freeform Text: CA ((AS ACETATE 7.14GM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66631, 4803, 'CALCIUM (CALCIUM PHOSPHATE (DIBASIC))', 'I', 36.7, 'G', '', '300', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3758, 10099, 'CRESOL', 'I', 0.75, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CRESOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9551, 10099, 'CRESOL', 'I', 5, '%', '', '', 'N', '%', 'Historic Freeform Text: CRESOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19443, 5881, 'PROTAMINE SULFATE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PROTAMINE SULPHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51049, 5881, 'PROTAMINE SULFATE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64191, 5881, 'PROTAMINE SULFATE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3026, 3835, 'TRISODIUM EDETATE', 'I', 0.4, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRISODIUM EDETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66793, 1283, 'ORMETOPRIM', 'I', 50, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43279, 1290, 'LOVASTATIN', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOVASTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43280, 1290, 'LOVASTATIN', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOVASTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11100, 1290, 'LOVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9253, 1290, 'LOVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50750, 1290, 'LOVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66997, 1290, 'LOVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66999, 1290, 'LOVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69938, 1290, 'LOVASTATIN', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LOVASTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69939, 1290, 'LOVASTATIN', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOVASTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70725, 1290, 'LOVASTATIN', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOVASTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70726, 1290, 'LOVASTATIN', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LOVASTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71473, 1290, 'LOVASTATIN', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOVASTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71474, 1290, 'LOVASTATIN', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOVASTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70139, 1290, 'LOVASTATIN', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOVASTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70140, 1290, 'LOVASTATIN', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOVASTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71221, 1290, 'LOVASTATIN', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOVASTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71222, 1290, 'LOVASTATIN', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOVASTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71291, 1290, 'LOVASTATIN', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOVASTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71292, 1290, 'LOVASTATIN', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOVASTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72927, 1290, 'LOVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72928, 1290, 'LOVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75335, 1290, 'LOVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75336, 1290, 'LOVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75581, 1290, 'LOVASTATIN', 'I', 20, 'MG', '', '', 'N', '', 'TABLET (IMMEDIATE RELEASE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75582, 1290, 'LOVASTATIN', 'I', 20, 'MG', '', '', 'N', '', 'TABLET (IMMEDIATE RELEASE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75781, 1290, 'LOVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75782, 1290, 'LOVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79820, 1290, 'LOVASTATIN', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOVASTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79821, 1290, 'LOVASTATIN', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOVASTATIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83844, 1290, 'LOVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83845, 1290, 'LOVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42850, 1294, 'SELEGILINE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SELEGILINE HYDROCHLORIDE REQUEST BY JOY MACAULAY, FILE 9460-D0611-501, 502 5');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42851, 1294, 'SELEGILINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SELEGILINE HYDROCHLORIDE REQUEST BY JOY MACAULAY FILE 9460-D0611-501, 502, 5');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42852, 1294, 'SELEGILINE HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SELEGILINE HYDROCHLORIDE REQUEST BY JOY MACAULAY  FILES 9460-D0611-501, 502,');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16175, 1294, 'SELEGILINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEPRENYL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48436, 1294, 'SELEGILINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48437, 1294, 'SELEGILINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50319, 1294, 'SELEGILINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49813, 1294, 'SELEGILINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49977, 1294, 'SELEGILINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61495, 1294, 'SELEGILINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61721, 1294, 'SELEGILINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61747, 1294, 'SELEGILINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16804, 1298, 'ISOSORBIDE-5-MONONITRATE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: ISOSORBIDE-5-MONONITRATE Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75834, 1298, 'ISOSORBIDE-5-MONONITRATE', 'I', 60, 'MG', '', '', 'N', '', 'ISOSORBIDE-5-MONONITRATE 70% 85.7 MG EQUVALENT TO 60 MG ISOSORBIDE-5-MONONITRATE ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78661, 1298, 'ISOSORBIDE-5-MONONITRATE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79692, 1298, 'ISOSORBIDE-5-MONONITRATE', 'I', 60, 'MG', '', '', 'N', '', 'ISOSORBIDE-5-MONONITRATE 70% 85.7 MG EQUVALENT TO 60 MG ISOSORBIDE-5-MONONITRATE ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12955, 1299, 'LORATADINE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORATADINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10533, 1299, 'LORATADINE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORATADINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11974, 1299, 'LORATADINE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORATADINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61088, 1299, 'LORATADINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67821, 1299, 'LORATADINE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LORATADINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68939, 1299, 'LORATADINE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORATADINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76583, 1299, 'LORATADINE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: LORATADINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74601, 1299, 'LORATADINE', 'I', 10, 'MG', '', '', 'N', '', '(MICRONIZED) TBL. COATING.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13970, 1299, 'LORATADINE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LORATADINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65175, 1299, 'LORATADINE', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LORATADINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43277, 1305, 'NIZATIDINE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: NIZATIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43278, 1305, 'NIZATIDINE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: NIZATIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44227, 1305, 'NIZATIDINE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: NIZATIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44228, 1305, 'NIZATIDINE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: NIZATIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42870, 1305, 'NIZATIDINE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: NIZATIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8915, 1305, 'NIZATIDINE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: NIZATIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8916, 1305, 'NIZATIDINE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61587, 1305, 'NIZATIDINE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61588, 1305, 'NIZATIDINE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64020, 1305, 'NIZATIDINE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64021, 1305, 'NIZATIDINE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72767, 1310, 'BUTOCONAZOLE NITRATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43324, 1249, 'FELODIPINE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: FELODIPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43322, 1249, 'FELODIPINE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: FELODIPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43323, 1249, 'FELODIPINE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: FELODIPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15574, 1249, 'FELODIPINE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: FELODIPINE Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12458, 1249, 'FELODIPINE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: FELODIPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12459, 1249, 'FELODIPINE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: FELODIPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63844, 1249, 'FELODIPINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63845, 1249, 'FELODIPINE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76593, 1249, 'FELODIPINE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76594, 1249, 'FELODIPINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43827, 1250, 'OMEPRAZOLE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OMEPRAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19716, 1250, 'OMEPRAZOLE (OMEPRAZOLE MAGNESIUM)', 'I', 20, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: OMEPRAZOLE ((AS OMEPRAZOLE MAGNESIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9823, 1250, 'OMEPRAZOLE', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OMEPRAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50000, 1250, 'OMEPRAZOLE (OMEPRAZOLE MAGNESIUM)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69062, 1250, 'OMEPRAZOLE', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OMEPRAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74628, 1250, 'OMEPRAZOLE (OMEPRAZOLE MAGNESIUM)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74629, 1250, 'OMEPRAZOLE (OMEPRAZOLE MAGNESIUM)', 'I', 20, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: OMEPRAZOLE ((AS OMEPRAZOLE MAGNESIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78175, 1250, 'OMEPRAZOLE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78176, 1250, 'OMEPRAZOLE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82550, 1250, 'OMEPRAZOLE', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OMEPRAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81517, 1250, 'OMEPRAZOLE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81518, 1250, 'OMEPRAZOLE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80626, 1250, 'OMEPRAZOLE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79590, 1250, 'OMEPRAZOLE (OMEPRAZOLE MAGNESIUM)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79591, 1250, 'OMEPRAZOLE (OMEPRAZOLE MAGNESIUM)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83404, 1250, 'OMEPRAZOLE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73515, 1250, 'OMEPRAZOLE', 'I', 37, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43221, 1253, 'LISINOPRIL', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43222, 1253, 'LISINOPRIL', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43223, 1253, 'LISINOPRIL', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43224, 1253, 'LISINOPRIL', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17215, 1253, 'LISINOPRIL', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LISINOPRIL INGREDIENT IS PROVIDED AS THE DIHYDRATE 10.89MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17903, 1253, 'LISINOPRIL', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16709, 1253, 'LISINOPRIL', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17123, 1253, 'LISINOPRIL', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LISINOPRIL INGREDIENT IS PROVIDED AS THE DIHYDRATE 21.78MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17126, 1253, 'LISINOPRIL', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LISINOPRIL INGREDIENT IS PROVIDED AS THE DIHYDRATE 5.445MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16636, 1253, 'LISINOPRIL', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16903, 1253, 'LISINOPRIL', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13431, 1253, 'LISINOPRIL', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11101, 1253, 'LISINOPRIL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11102, 1253, 'LISINOPRIL', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11103, 1253, 'LISINOPRIL', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74204, 1253, 'LISINOPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74203, 1253, 'LISINOPRIL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74205, 1253, 'LISINOPRIL', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75690, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LISINOPRIL 5MG, SUPPLIED AS LISINOPRIL DIHYDRATE 5.445 MG./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71277, 12049, 'OCTINOXATE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75691, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LISINOPRIL 10MG, SUPPLIED AS LISINOPRIL DIHYDRATE 10.890 MG./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75692, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LISINOPRIL 20MG, SUPPLIED AS LISINOPRIL DIHYDRATE 21.780 MG./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74732, 1253, 'LISINOPRIL', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74733, 1253, 'LISINOPRIL', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74734, 1253, 'LISINOPRIL', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76037, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76038, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76039, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77059, 1253, 'LISINOPRIL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77060, 1253, 'LISINOPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77061, 1253, 'LISINOPRIL', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77062, 1253, 'LISINOPRIL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77063, 1253, 'LISINOPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77064, 1253, 'LISINOPRIL', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77458, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77459, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77460, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77958, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77959, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77960, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77756, 1253, 'LISINOPRIL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77757, 1253, 'LISINOPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77758, 1253, 'LISINOPRIL', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78307, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78308, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78309, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77994, 1253, 'LISINOPRIL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77995, 1253, 'LISINOPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77996, 1253, 'LISINOPRIL', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77997, 1253, 'LISINOPRIL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77998, 1253, 'LISINOPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77999, 1253, 'LISINOPRIL', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78522, 1253, 'LISINOPRIL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78523, 1253, 'LISINOPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78524, 1253, 'LISINOPRIL', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79658, 1253, 'LISINOPRIL', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79659, 1253, 'LISINOPRIL', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79660, 1253, 'LISINOPRIL', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LISINOPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78744, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78745, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78746, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78633, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78631, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78634, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78710, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78711, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78712, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78769, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78770, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78771, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80292, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80293, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80294, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80698, 1253, 'LISINOPRIL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80699, 1253, 'LISINOPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80702, 1253, 'LISINOPRIL', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84661, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84662, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84663, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84793, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84794, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84795, 1253, 'LISINOPRIL (LISINOPRIL DIHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10851, 1264, 'TILMICOSIN', 'I', 300, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: TILMICOSIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63638, 1264, 'TILMICOSIN (TILMICOSIN PHOSPHATE)', 'I', 200, 'G', '', '', 'Y', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83479, 1264, 'TILMICOSIN (TILMICOSIN PHOSPHATE)', 'I', 200, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75440, 1267, 'RACTOPAMINE HYDROCHLORIDE', 'I', 20, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78042, 1267, 'RACTOPAMINE HYDROCHLORIDE', 'I', 100, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70179, 1208, 'DICLAZURIL', 'I', 5, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16167, 1209, 'ACITRETIN', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACITRETIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16168, 1209, 'ACITRETIN', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACITRETIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13582, 1211, 'PENTASTARCH', 'I', 10, 'G', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PENTASTARCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43250, 1212, 'FLUVOXAMINE MALEATE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUVOXAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43251, 1212, 'FLUVOXAMINE MALEATE', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUVOXAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11751, 1212, 'FLUVOXAMINE MALEATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUVOXAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11752, 1212, 'FLUVOXAMINE MALEATE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUVOXAMINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50637, 1212, 'FLUVOXAMINE MALEATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50638, 1212, 'FLUVOXAMINE MALEATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50499, 1212, 'FLUVOXAMINE MALEATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50500, 1212, 'FLUVOXAMINE MALEATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60040, 1212, 'FLUVOXAMINE MALEATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60041, 1212, 'FLUVOXAMINE MALEATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63456, 1212, 'FLUVOXAMINE MALEATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63457, 1212, 'FLUVOXAMINE MALEATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64266, 1212, 'FLUVOXAMINE MALEATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64267, 1212, 'FLUVOXAMINE MALEATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64977, 1212, 'FLUVOXAMINE MALEATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64978, 1212, 'FLUVOXAMINE MALEATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71289, 1212, 'FLUVOXAMINE MALEATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71290, 1212, 'FLUVOXAMINE MALEATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74072, 1212, 'FLUVOXAMINE MALEATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74073, 1212, 'FLUVOXAMINE MALEATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74800, 1212, 'FLUVOXAMINE MALEATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74801, 1212, 'FLUVOXAMINE MALEATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78867, 1212, 'FLUVOXAMINE MALEATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78869, 1212, 'FLUVOXAMINE MALEATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43285, 1215, 'BENAZEPRIL HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43286, 1215, 'BENAZEPRIL HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14273, 1215, 'BENAZEPRIL HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: BENAZEPRIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14274, 1215, 'BENAZEPRIL HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: BENAZEPRIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14276, 1215, 'BENAZEPRIL HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: BENAZEPRIL HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75937, 1215, 'BENAZEPRIL HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77563, 1215, 'BENAZEPRIL HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77564, 1215, 'BENAZEPRIL HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79077, 1215, 'BENAZEPRIL HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68801, 1216, 'MILRINONE (MILRINONE LACTATE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: MILRINONE LACTATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68844, 1216, 'MILRINONE (MILRINONE LACTATE)', 'I', 1.0, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68609, 1216, 'MILRINONE (MILRINONE LACTATE)', 'I', 1.0, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73466, 1216, 'MILRINONE (MILRINONE LACTATE)', 'I', 1.0, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78793, 1218, 'BISOPROLOL FUMARATE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71685, 1218, 'BISOPROLOL FUMARATE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71686, 1218, 'BISOPROLOL FUMARATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75288, 1218, 'BISOPROLOL FUMARATE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75289, 1218, 'BISOPROLOL FUMARATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74136, 1218, 'BISOPROLOL FUMARATE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74140, 1218, 'BISOPROLOL FUMARATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78794, 1218, 'BISOPROLOL FUMARATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79399, 1218, 'BISOPROLOL FUMARATE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79400, 1218, 'BISOPROLOL FUMARATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79267, 1218, 'BISOPROLOL FUMARATE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79268, 1218, 'BISOPROLOL FUMARATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80695, 1218, 'BISOPROLOL FUMARATE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80697, 1218, 'BISOPROLOL FUMARATE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49920, 1220, 'TENOXICAM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11944, 1227, 'FLUMAZENIL', 'I', 0.1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FLUMAZENIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75176, 1227, 'FLUMAZENIL', 'I', 0.1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73439, 1227, 'FLUMAZENIL', 'I', 0.1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77477, 1240, 'DIPHENHYDRAMINE CITRATE', 'I', 38, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43510, 1241, 'KETOROLAC TROMETHAMINE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: KETOROLAC TROMETHAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19348, 1241, 'KETOROLAC TROMETHAMINE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: KETOROLAC TROMETHAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48899, 1241, 'KETOROLAC TROMETHAMINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61273, 1241, 'KETOROLAC TROMETHAMINE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13121, 1241, 'KETOROLAC TROMETHAMINE', 'I', 0.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: KETOROLAC TROMETHAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69937, 1241, 'KETOROLAC TROMETHAMINE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71709, 1241, 'KETOROLAC TROMETHAMINE', 'I', 0.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: KETOROLAC TROMETHAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73086, 1241, 'KETOROLAC TROMETHAMINE', 'I', 0.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44090, 1241, 'KETOROLAC TROMETHAMINE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: KETOROLAC TROMETHAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63447, 1241, 'KETOROLAC TROMETHAMINE', 'I', 30, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67933, 1241, 'KETOROLAC TROMETHAMINE', 'I', 30, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: KETOROLAC TROMETHAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68945, 1241, 'KETOROLAC TROMETHAMINE', 'I', 30, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13022, 1185, 'ZIDOVUDINE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ZIDOVUDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83899, 12634, 'ENSULIZOLE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11300, 1185, 'ZIDOVUDINE', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ZIDOVUDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12839, 1185, 'ZIDOVUDINE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ZIDOVUDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62673, 1185, 'ZIDOVUDINE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68746, 1185, 'ZIDOVUDINE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11942, 1185, 'ZIDOVUDINE', 'I', 50, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ZIDOVUDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11342, 1185, 'ZIDOVUDINE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ZIDOVUDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70034, 1188, 'CARVEDILOL', 'I', 3.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70035, 1188, 'CARVEDILOL', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70036, 1188, 'CARVEDILOL', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70037, 1188, 'CARVEDILOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70711, 1188, 'CARVEDILOL', 'I', 3.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70712, 1188, 'CARVEDILOL', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70713, 1188, 'CARVEDILOL', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70714, 1188, 'CARVEDILOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72243, 1188, 'CARVEDILOL', 'I', 3.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72244, 1188, 'CARVEDILOL', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72245, 1188, 'CARVEDILOL', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72246, 1188, 'CARVEDILOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75344, 1188, 'CARVEDILOL', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75343, 1188, 'CARVEDILOL', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75342, 1188, 'CARVEDILOL', 'I', 3.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75345, 1188, 'CARVEDILOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73116, 1188, 'CARVEDILOL', 'I', 3.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73117, 1188, 'CARVEDILOL', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73118, 1188, 'CARVEDILOL', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73119, 1188, 'CARVEDILOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73120, 1188, 'CARVEDILOL', 'I', 3.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73121, 1188, 'CARVEDILOL', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73122, 1188, 'CARVEDILOL', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73123, 1188, 'CARVEDILOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73718, 1188, 'CARVEDILOL', 'I', 3.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73719, 1188, 'CARVEDILOL', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73720, 1188, 'CARVEDILOL', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73721, 1188, 'CARVEDILOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83013, 1188, 'CARVEDILOL', 'I', 3.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83014, 1188, 'CARVEDILOL', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83015, 1188, 'CARVEDILOL', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80995, 1188, 'CARVEDILOL', 'I', 3.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80996, 1188, 'CARVEDILOL', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80997, 1188, 'CARVEDILOL', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80998, 1188, 'CARVEDILOL', 'I', 25.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82370, 1188, 'CARVEDILOL', 'I', 3.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82371, 1188, 'CARVEDILOL', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82374, 1188, 'CARVEDILOL', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82375, 1188, 'CARVEDILOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83290, 1188, 'CARVEDILOL', 'I', 3.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83292, 1188, 'CARVEDILOL', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83294, 1188, 'CARVEDILOL', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83296, 1188, 'CARVEDILOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84979, 1188, 'CARVEDILOL', 'I', 3.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84980, 1188, 'CARVEDILOL', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84981, 1188, 'CARVEDILOL', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84982, 1188, 'CARVEDILOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85386, 1188, 'CARVEDILOL', 'I', 3.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85387, 1188, 'CARVEDILOL', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85388, 1188, 'CARVEDILOL', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85389, 1188, 'CARVEDILOL', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60542, 12633, 'FORMOTEROL FUMARATE DIHYDRATE', 'I', 12, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60543, 12633, 'FORMOTEROL FUMARATE DIHYDRATE', 'I', 6, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69428, 12633, 'FORMOTEROL FUMARATE DIHYDRATE', 'I', 6, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69429, 12633, 'FORMOTEROL FUMARATE DIHYDRATE', 'I', 6, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84679, 12633, 'FORMOTEROL FUMARATE DIHYDRATE', 'I', 5, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84680, 12633, 'FORMOTEROL FUMARATE DIHYDRATE', 'I', 5, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84681, 12633, 'FORMOTEROL FUMARATE DIHYDRATE', 'I', 5, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42377, 12634, 'ENSULIZOLE', 'I', 2.0, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PHENYL BENZIMIDAZOLE SULFONIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42376, 12634, 'ENSULIZOLE', 'I', 2.0, '%', '', '', 'N', '', 'Historic Freeform Text: PHENYL BENZIMIDAZOLE SULFONIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66106, 12634, 'ENSULIZOLE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69552, 12634, 'ENSULIZOLE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70253, 12634, 'ENSULIZOLE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70998, 12634, 'ENSULIZOLE', 'I', 1.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70999, 12634, 'ENSULIZOLE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76600, 12634, 'ENSULIZOLE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76707, 12634, 'ENSULIZOLE', 'I', 1.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75392, 12634, 'ENSULIZOLE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75594, 12634, 'ENSULIZOLE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74357, 12634, 'ENSULIZOLE', 'I', 1.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74358, 12634, 'ENSULIZOLE', 'I', 1.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74554, 12634, 'ENSULIZOLE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75869, 12634, 'ENSULIZOLE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76206, 12634, 'ENSULIZOLE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77484, 12634, 'ENSULIZOLE', 'I', 1.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77485, 12634, 'ENSULIZOLE', 'I', 1.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77540, 12634, 'ENSULIZOLE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77554, 12634, 'ENSULIZOLE', 'I', 1.7, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77606, 12634, 'ENSULIZOLE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77440, 12634, 'ENSULIZOLE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77619, 12634, 'ENSULIZOLE', 'I', 1.8, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78110, 12634, 'ENSULIZOLE', 'I', 1.7, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78240, 12634, 'ENSULIZOLE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80443, 12634, 'ENSULIZOLE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78955, 12634, 'ENSULIZOLE', 'I', 1.7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79216, 12634, 'ENSULIZOLE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80438, 12634, 'ENSULIZOLE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81450, 12634, 'ENSULIZOLE', 'I', 2.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78621, 12634, 'ENSULIZOLE', 'I', 1.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79252, 12634, 'ENSULIZOLE', 'I', 1.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79253, 12634, 'ENSULIZOLE', 'I', 1.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79255, 12634, 'ENSULIZOLE', 'I', 1.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78890, 12634, 'ENSULIZOLE', 'I', 1.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78891, 12634, 'ENSULIZOLE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79533, 12634, 'ENSULIZOLE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79068, 12634, 'ENSULIZOLE', 'I', 1.8, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78647, 12634, 'ENSULIZOLE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82382, 12634, 'ENSULIZOLE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84120, 12634, 'ENSULIZOLE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72549, 12634, 'ENSULIZOLE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74968, 12634, 'ENSULIZOLE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77288, 12634, 'ENSULIZOLE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79605, 12634, 'ENSULIZOLE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80398, 12634, 'ENSULIZOLE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80400, 12634, 'ENSULIZOLE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79595, 12634, 'ENSULIZOLE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80230, 12634, 'ENSULIZOLE', 'I', 1.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82270, 12634, 'ENSULIZOLE', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80425, 12634, 'ENSULIZOLE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80252, 12634, 'ENSULIZOLE', 'I', 1.8, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81034, 12634, 'ENSULIZOLE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80178, 12634, 'ENSULIZOLE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81066, 12634, 'ENSULIZOLE', 'I', 1.8, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83240, 12634, 'ENSULIZOLE', 'I', 1.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83494, 12634, 'ENSULIZOLE', 'I', 1.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84032, 12634, 'ENSULIZOLE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84033, 12634, 'ENSULIZOLE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84099, 12634, 'ENSULIZOLE', 'I', 1.7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50134, 12634, 'ENSULIZOLE', 'I', 2, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61380, 12634, 'ENSULIZOLE', 'I', 1.7, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62732, 12634, 'ENSULIZOLE', 'I', 1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60001, 12634, 'ENSULIZOLE', 'I', 2, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69490, 12683, 'NATEGLINIDE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69491, 12683, 'NATEGLINIDE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75881, 12684, 'TIPRANAVIR', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69524, 12688, 'SURFACTANT-ASSOCIATED PROTEINS SP-B AND SP-C', 'I', 500, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69657, 12699, 'ALFUZOSIN HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78993, 12699, 'ALFUZOSIN HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79984, 12699, 'ALFUZOSIN HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80137, 12699, 'ALFUZOSIN HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15889, 12708, 'CONJUGATED ESTROGENS', 'I', 1.25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CONJUGATED ESTROGENIC HORMONES');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15782, 12708, 'CONJUGATED ESTROGENS', 'I', 0.625, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CONJUGATED ESTROGENIC HORMONES');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15486, 12708, 'CONJUGATED ESTROGENS', 'I', 0.3, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CONJUGATED ESTROGENIC HORMONES');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10883, 12708, 'CONJUGATED ESTROGENS', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CONJUGATED ESTROGENIC HORMONES');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10884, 12708, 'CONJUGATED ESTROGENS', 'I', 1.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CONJUGATED ESTROGENIC HORMONES');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10885, 12708, 'CONJUGATED ESTROGENS', 'I', 0.9, 'MG', '', '', 'N', '', 'Historic Freeform Text: CONJUGATED ESTROGENIC HORMONES');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10886, 12708, 'CONJUGATED ESTROGENS', 'I', 0.625, 'MG', '', '', 'N', '', 'Historic Freeform Text: CONJUGATED ESTROGENIC HORMONES');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10887, 12708, 'CONJUGATED ESTROGENS', 'I', 0.3, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CONJUGATED ESTROGENIC HORMONES');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5311, 12708, 'CONJUGATED ESTROGENS', 'I', 0.625, 'MG', '', '', 'N', '', 'Historic Freeform Text: CONJUGATED ESTROGENIC HORMONES');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5312, 12708, 'CONJUGATED ESTROGENS', 'I', 1.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CONJUGATED ESTROGENIC HORMONES');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1657, 12708, 'CONJUGATED ESTROGENS', 'I', 0.625, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CONJUGATED ESTROGEN ((SODIUM ESTRONE SULFATE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1658, 12708, 'CONJUGATED ESTROGENS', 'I', 1.25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CONJUGATED ESTROGENIC HORMONES');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50169, 12708, 'CONJUGATED ESTROGENS', 'I', 0.3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50170, 12708, 'CONJUGATED ESTROGENS', 'I', 0.9, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63126, 12708, 'CONJUGATED ESTROGENS', 'I', 0.3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63127, 12708, 'CONJUGATED ESTROGENS', 'I', 0.9, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66710, 12708, 'CONJUGATED ESTROGENS', 'I', 0.625, 'MG', '', '', 'N', '', 'BLISTER CARD CONTAINING MAROON 0.625MG ''PREMARIN'' TABLETS.(TABLET #1). DIN 02043408-PREMARIN./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66711, 12708, 'CONJUGATED ESTROGENS', 'I', 0.625, 'MG', '', '', 'N', '', 'BLISTER CARD CONTAINING MAROON 0.625MG ''PREMARIN'' TABLETS.(TABLET #1)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16736, 12708, 'CONJUGATED ESTROGENS', 'I', 25, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: CONJUGATED ESTROGENIC HORMONES');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15704, 12708, 'CONJUGATED ESTROGENS', 'I', 0.625, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69741, 12713, 'GANIRELIX (GANIRELIX ACETATE)', 'I', 250, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3409, 12719, 'MODIFIED RAGWEED TYROSINE ADSORBATE', 'I', 210, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3409, 12719, 'MODIFIED RAGWEED TYROSINE ADSORBATE', 'I', 500, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3409, 12719, 'MODIFIED RAGWEED TYROSINE ADSORBATE', 'I', 1400, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3409, 12719, 'MODIFIED RAGWEED TYROSINE ADSORBATE', 'I', 4300, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69777, 12720, 'DOCOSANOL', 'I', 10, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69790, 12724, 'INSULIN GLARGINE', 'I', 100, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73683, 12724, 'INSULIN GLARGINE', 'I', 100, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77967, 12724, 'INSULIN GLARGINE', 'I', 100, 'UNIT', '', '', 'N', 'ML', 'RDNA ORIGIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15101, 2196, 'SODIUM CHLORITE', 'I', 0.64, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM CHLORITE ((BASE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10853, 2196, 'SODIUM CHLORITE', 'I', 0.64, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76528, 2196, 'SODIUM CHLORITE', 'I', 20.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78823, 2196, 'SODIUM CHLORITE', 'I', 30.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50130, 8826, 'WATER', 'I', 50, 'ML', '', '', 'N', '', 'WATER FOR INJECTION Q.S. UP TO 50ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62666, 8826, 'WATER', 'I', 0.5, 'ML', '', '', 'N', '', 'STERILE WATER FOR INJECTION: 0.5ML PER SYRINGE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64641, 8826, 'WATER', 'I', 0.5, 'ML', '', '', 'N', '', 'WATER FOR INJECTION: 0.5ML/SYRINGE OR AMPOULE/KIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76176, 8826, 'WATER', 'I', 1, 'ML', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31491, 8826, 'WATER', 'I', 100, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: WATER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19812, 8826, 'WATER', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: WATER ((STERILE FOR INJECTION))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20353, 8826, 'WATER', 'I', 99.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: WATER ((STERILE-.945%BENZYL ALC PRESERVAT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20354, 8826, 'WATER', 'I', 99.1, '%', '', '', 'N', '', 'Historic Freeform Text: WATER ((STERILE-.945%BENYZL ALC PRESERVAT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17402, 8826, 'WATER', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: WATER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13509, 8826, 'WATER', 'I', 100, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: WATER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9831, 8826, 'WATER', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: WATER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3822, 8826, 'WATER', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: WATER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3383, 8826, 'WATER', 'I', 100, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: WATER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1734, 8826, 'WATER', 'I', 100, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: WATER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (117, 8826, 'WATER', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: WATER FOR INJECTION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68381, 8826, 'WATER', 'I', 100, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: WATER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (229, 8826, 'WATER', 'I', 100, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75493, 8826, 'WATER', 'I', 100, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78457, 8826, 'WATER', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: WATER FOR INJECTION');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43361, 8826, 'WATER', 'I', 1, 'ML', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: WATER ((BACTERIOSTATIC, FOR INJECTION))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44257, 8826, 'WATER', 'I', 10, 'ML', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: WATER ((BACTERIOSTATIC))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43174, 8826, 'WATER', 'I', 10, 'ML', '', '', 'N', 'VIAL', 'Historic Freeform Text: WATER ((BACTERIOSTATIC USP FOR INJECTION))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42981, 8826, 'WATER', 'I', 20, 'ML', '', '', 'N', 'VIAL', 'Historic Freeform Text: STERILE WATER ((DILUENT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18250, 8826, 'WATER', 'I', 200, 'ML', '', '', 'N', 'VIAL', 'Historic Freeform Text: WATER ((STERILE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51025, 8826, 'WATER', 'I', 1, 'ML', '', '', 'N', 'VIAL', 'BACTERIOSTATIC WATER (AS DILUENT) FOR INJECTION, PRESERVED WITH BENZYL ALCOHOL (0.9%).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52240, 8826, 'WATER', 'I', 10, 'ML', '', '', 'N', 'VIAL', 'BACTERIOSTATIC WATER FOR INJECTION.  PRESERVED WITH 0.9% BENZYL ALCOHOL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52242, 8826, 'WATER', 'I', 20, 'ML', '', '', 'N', 'VIAL', 'BACTERIOSTATIC WATER FOR INJECTION.  PRESERVED WITH 0.9% BENZYL ALCOHOL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61169, 8826, 'WATER', 'I', 20, 'ML', '', '', 'N', 'VIAL', 'STERILE WATER FOR INJECTION.  20ML/VIAL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61170, 8826, 'WATER', 'I', 10, 'ML', '', '', 'N', 'VIAL', 'STERILE WATER FOR INJECTION.  10ML/VIAL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64277, 8826, 'WATER', 'I', 20, 'ML', '', '', 'N', 'VIAL', 'BACTERIOSTATIC WATER FOR INJ.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63758, 8826, 'WATER', 'I', 5, 'ML', '', '', 'N', 'VIAL', '5ML/VIAL/KIT.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65082, 8826, 'WATER (DILUENT)', 'I', 25, 'ML', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83498, 8826, 'WATER', 'I', 10, 'ML', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83912, 8826, 'WATER', 'I', 50, 'ML', '', '', 'N', 'VIAL', 'Historic Freeform Text: STERILE WATER ((DILUENT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15867, 8826, 'WATER', 'I', 100, '%', '', '', 'N', '%', 'Historic Freeform Text: WATER ((STERILE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13287, 8826, 'WATER', 'I', 100, '%', '', '', 'N', '%', 'Historic Freeform Text: WATER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7140, 8826, 'WATER', 'I', 100, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: WATER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63009, 8826, 'WATER', 'I', 1, 'L', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43443, 8826, 'WATER', 'I', 50, 'ML', '', '', 'N', 'KIT', 'Historic Freeform Text: WATER ((STERILE FOR INJECTION, DILUENT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20105, 8826, 'WATER', 'I', 100, 'ML', '', '', 'N', 'KIT', 'Historic Freeform Text: WATER ((STERILE FOR INJECTION))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62499, 8826, 'WATER', 'I', 1, 'ML', '', '', 'N', 'KIT', 'STERILE WATER FOR INJECTION.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62500, 8826, 'WATER', 'I', 1, 'ML', '', '', 'N', 'KIT', 'STERILE WATER FOR INJECTION.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61171, 8826, 'WATER', 'I', 30, 'ML', '', '', 'N', 'KIT', 'STERILE WATER FOR INJECTION.  30ML/VIAL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61332, 8826, 'WATER', 'I', 10, 'ML', '', '', 'N', 'KIT', 'BACTERIOSTATIC WATER FOR INJECTION: 10ML/VIAL. CONTAINS 0.9% BENZYL ALCOHOL AS A PRESERVATIVE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66735, 8826, 'WATER', 'I', 1, 'ML', '', '', 'N', 'KIT', 'BACTERIOSTATIC WATER FOR INJECTION: 1 ML/VIAL/KIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 10027, 'WOOL ALCOHOLS', 'I', 0.81, 'MG', '', '', 'N', 'PATCH', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75035, 13904, 'TRAMADOL HYDROCHLORIDE', 'I', 37.50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78172, 13904, 'TRAMADOL HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78173, 13904, 'TRAMADOL HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78174, 13904, 'TRAMADOL HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78458, 13904, 'TRAMADOL HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78459, 13904, 'TRAMADOL HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78460, 13904, 'TRAMADOL HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77188, 13904, 'TRAMADOL HYDROCHLORIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77189, 13904, 'TRAMADOL HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77190, 13904, 'TRAMADOL HYDROCHLORIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77191, 13904, 'TRAMADOL HYDROCHLORIDE', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82241, 13904, 'TRAMADOL HYDROCHLORIDE', 'I', 37.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83476, 13904, 'TRAMADOL HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84529, 13904, 'TRAMADOL HYDROCHLORIDE', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84531, 13904, 'TRAMADOL HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3629, 4362, 'SODIUM DODECYLBENZENESULFONATE', 'I', 2.028, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM DODECYL BENZENE SULFONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2802, 4362, 'SODIUM DODECYLBENZENESULFONATE', 'I', 2.75, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM DODECYL BENZENE SULFONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11016, 4362, 'SODIUM DODECYLBENZENESULFONATE', 'I', 3.5, '%', '', '', 'N', '%', 'Historic Freeform Text: SODIUM DODECYL BENZENE SULFONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47227, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42377, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42376, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42310, 12049, 'OCTINOXATE', 'I', 7.4, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41935, 12049, 'OCTINOXATE', 'I', 7, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42607, 12049, 'OCTINOXATE', 'I', 7.3, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37913, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37916, 12049, 'OCTINOXATE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (32792, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33490, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30927, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77461, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19330, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19037, 12049, 'OCTINOXATE', 'I', 8.5, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18691, 12049, 'OCTINOXATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15893, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15869, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75823, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13954, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13958, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13929, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13930, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47540, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48123, 12049, 'OCTINOXATE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50605, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50939, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51733, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50532, 12049, 'OCTINOXATE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53823, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61235, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60497, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61295, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61296, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60890, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62357, 12049, 'OCTINOXATE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60920, 12049, 'OCTINOXATE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60325, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62463, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63261, 12049, 'OCTINOXATE', 'I', 7.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63263, 12049, 'OCTINOXATE', 'I', 7.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63264, 12049, 'OCTINOXATE', 'I', 7.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64081, 12049, 'OCTINOXATE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63342, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63348, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63350, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64701, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64702, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64150, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64225, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64289, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63102, 12049, 'OCTINOXATE', 'I', 7.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65189, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67293, 12049, 'OCTINOXATE', 'I', 2.23, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65332, 12049, 'OCTINOXATE', 'I', 2.23, '%', '', '', 'N', '', '2.23%W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65907, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65423, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65424, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65425, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65427, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65426, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64877, 12049, 'OCTINOXATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64883, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66706, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66106, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66772, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66828, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66974, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68850, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69344, 12049, 'OCTINOXATE', 'I', 8.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69393, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69394, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69420, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67949, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67987, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68051, 12049, 'OCTINOXATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68570, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68594, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68595, 12049, 'OCTINOXATE', 'I', 7.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68117, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68186, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67743, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72102, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71359, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71382, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71383, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71384, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71386, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69963, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72269, 12049, 'OCTINOXATE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72271, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72270, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70085, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70087, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72290, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70111, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70113, 12049, 'OCTINOXATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70114, 12049, 'OCTINOXATE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71534, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71614, 12049, 'OCTINOXATE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71649, 12049, 'OCTINOXATE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70878, 12049, 'OCTINOXATE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70879, 12049, 'OCTINOXATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70880, 12049, 'OCTINOXATE', 'I', 8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70881, 12049, 'OCTINOXATE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70903, 12049, 'OCTINOXATE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70904, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71650, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70260, 12049, 'OCTINOXATE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70261, 12049, 'OCTINOXATE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70981, 12049, 'OCTINOXATE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70997, 12049, 'OCTINOXATE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70373, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71098, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71099, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71100, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71101, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69791, 12049, 'OCTINOXATE', 'I', 8.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71148, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69886, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70539, 12049, 'OCTINOXATE', 'I', 4.996, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72068, 12049, 'OCTINOXATE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76449, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76450, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76468, 12049, 'OCTINOXATE', 'I', 3.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76470, 12049, 'OCTINOXATE', 'I', 7.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72890, 12049, 'OCTINOXATE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73900, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75151, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75161, 12049, 'OCTINOXATE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75172, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76518, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72783, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75229, 12049, 'OCTINOXATE', 'I', 7.0, '%', '', '', 'N', '', 'V/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75235, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76600, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76619, 12049, 'OCTINOXATE', 'I', 7.49, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76634, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76635, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74004, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74039, 12049, 'OCTINOXATE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75271, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75277, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75296, 12049, 'OCTINOXATE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75298, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75350, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76383, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76707, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76711, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76743, 12049, 'OCTINOXATE', 'I', 3.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74106, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74176, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75392, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75404, 12049, 'OCTINOXATE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75425, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75450, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75777, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76744, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73042, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73044, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74215, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74217, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74229, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74244, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75512, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75513, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72332, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72336, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72339, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73106, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74271, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74321, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75531, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75565, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75596, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72406, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74357, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74358, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74363, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74408, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74412, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75641, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75676, 12049, 'OCTINOXATE', 'I', 7.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75677, 12049, 'OCTINOXATE', 'I', 7.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75697, 12049, 'OCTINOXATE', 'I', 7.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73157, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73158, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73159, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73161, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74430, 12049, 'OCTINOXATE', 'I', 3.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74434, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74441, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74447, 12049, 'OCTINOXATE', 'I', 7, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74448, 12049, 'OCTINOXATE', 'I', 7, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74455, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74458, 12049, 'OCTINOXATE', 'I', 7.50, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75752, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75755, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75756, 12049, 'OCTINOXATE', 'I', 7.2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75768, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72581, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72582, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72585, 12049, 'OCTINOXATE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74548, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74559, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74560, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74564, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74589, 12049, 'OCTINOXATE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74591, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75847, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75864, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75868, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75869, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74630, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74655, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75907, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75919, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75920, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75989, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75990, 12049, 'OCTINOXATE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73304, 12049, 'OCTINOXATE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73308, 12049, 'OCTINOXATE', 'I', 7.30, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73323, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73324, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74735, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76004, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76007, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73363, 12049, 'OCTINOXATE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73389, 12049, 'OCTINOXATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73391, 12049, 'OCTINOXATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73436, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75779, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76108, 12049, 'OCTINOXATE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76132, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76146, 12049, 'OCTINOXATE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72680, 12049, 'OCTINOXATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73488, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73522, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74880, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74916, 12049, 'OCTINOXATE', 'I', 8.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73587, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73606, 12049, 'OCTINOXATE', 'I', 6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73607, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73654, 12049, 'OCTINOXATE', 'I', 1.7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73657, 12049, 'OCTINOXATE', 'I', 6.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73674, 12049, 'OCTINOXATE', 'I', 3.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74918, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74955, 12049, 'OCTINOXATE', 'I', 4.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74992, 12049, 'OCTINOXATE', 'I', 7.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76247, 12049, 'OCTINOXATE', 'I', 7.9, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72724, 12049, 'OCTINOXATE', 'I', 7.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72726, 12049, 'OCTINOXATE', 'I', 7.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72727, 12049, 'OCTINOXATE', 'I', 5.9, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72737, 12049, 'OCTINOXATE', 'I', 2.9, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72739, 12049, 'OCTINOXATE', 'I', 6.9, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73755, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73756, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74998, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75061, 12049, 'OCTINOXATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76206, 12049, 'OCTINOXATE', 'I', 6, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76325, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76327, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76328, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76343, 12049, 'OCTINOXATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76349, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76379, 12049, 'OCTINOXATE', 'I', 7.50, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72761, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72762, 12049, 'OCTINOXATE', 'I', 3.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77484, 12049, 'OCTINOXATE', 'I', 4.9, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77485, 12049, 'OCTINOXATE', 'I', 4.9, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78091, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78108, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78164, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77065, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77531, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77533, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77540, 12049, 'OCTINOXATE', 'I', 5.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78385, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78402, 12049, 'OCTINOXATE', 'I', 4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76974, 12049, 'OCTINOXATE', 'I', 7.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77512, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77552, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77554, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77560, 12049, 'OCTINOXATE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77605, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77606, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77611, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77082, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77295, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77223, 12049, 'OCTINOXATE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77186, 12049, 'OCTINOXATE', 'I', 4.9, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76897, 12049, 'OCTINOXATE', 'I', 7.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76914, 12049, 'OCTINOXATE', 'I', 7.50, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76915, 12049, 'OCTINOXATE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77374, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77375, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77083, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77048, 12049, 'OCTINOXATE', 'I', 7.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77058, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77410, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77436, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77439, 12049, 'OCTINOXATE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77440, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77517, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77619, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77629, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77630, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77632, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77608, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76890, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77681, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77682, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77692, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77925, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77016, 12049, 'OCTINOXATE', 'I', 1.2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77812, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77820, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77883, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78110, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78157, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77254, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78256, 12049, 'OCTINOXATE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78278, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77076, 12049, 'OCTINOXATE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77441, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77434, 12049, 'OCTINOXATE', 'I', 7.75, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76869, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77299, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78301, 12049, 'OCTINOXATE', 'I', 7.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78304, 12049, 'OCTINOXATE', 'I', 8.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78310, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78311, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78317, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76910, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77768, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77926, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77927, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77928, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77581, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78023, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78024, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78025, 12049, 'OCTINOXATE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77321, 12049, 'OCTINOXATE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77322, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77323, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77324, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77325, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77326, 12049, 'OCTINOXATE', 'I', 7.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77411, 12049, 'OCTINOXATE', 'I', 4.1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78014, 12049, 'OCTINOXATE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78019, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78020, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78047, 12049, 'OCTINOXATE', 'I', 5.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77513, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77515, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77617, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77618, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78331, 12049, 'OCTINOXATE', 'I', 6.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78343, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78345, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77287, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79021, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79423, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79215, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70856, 12049, 'OCTINOXATE', 'I', 7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78658, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78680, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79081, 12049, 'OCTINOXATE', 'I', 6.32, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79082, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79181, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79182, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79221, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80443, 12049, 'OCTINOXATE', 'I', 7.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79262, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79263, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79420, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78990, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79271, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79387, 12049, 'OCTINOXATE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78955, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78957, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78958, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78959, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79216, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79415, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79416, 12049, 'OCTINOXATE', 'I', 7.3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79417, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79295, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79407, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80173, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80438, 12049, 'OCTINOXATE', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81450, 12049, 'OCTINOXATE', 'I', 8.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79256, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78605, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78606, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78890, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78891, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80565, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79240, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79321, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79322, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79276, 12049, 'OCTINOXATE', 'I', 7.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79913, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79982, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79067, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79068, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79225, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79227, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79228, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80110, 12049, 'OCTINOXATE', 'I', 7.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80111, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80641, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80828, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80045, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81860, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81861, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78578, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78646, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79026, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79168, 12049, 'OCTINOXATE', 'I', 6.4, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78901, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82382, 12049, 'OCTINOXATE', 'I', 8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82383, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79421, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79090, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79092, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79185, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79187, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79086, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80673, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78589, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79251, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82461, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81642, 12049, 'OCTINOXATE', 'I', 6.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81643, 12049, 'OCTINOXATE', 'I', 6.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80281, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80800, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82622, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80457, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80820, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80821, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82530, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66809, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83915, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83916, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84120, 12049, 'OCTINOXATE', 'I', 8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84130, 12049, 'OCTINOXATE', 'I', 4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84131, 12049, 'OCTINOXATE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84246, 12049, 'OCTINOXATE', 'I', 4.2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84266, 12049, 'OCTINOXATE', 'I', 4.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84268, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84342, 12049, 'OCTINOXATE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84347, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84348, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84353, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84379, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84443, 12049, 'OCTINOXATE', 'I', 6.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84553, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84603, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84818, 12049, 'OCTINOXATE', 'I', 5.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84903, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66753, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16229, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15968, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48991, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50232, 12049, 'OCTINOXATE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60006, 12049, 'OCTINOXATE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66357, 12049, 'OCTINOXATE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65475, 12049, 'OCTINOXATE', 'I', 7.50, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65639, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69095, 12049, 'OCTINOXATE', 'I', 7.50, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67685, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70086, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71503, 12049, 'OCTINOXATE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70588, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75370, 12049, 'OCTINOXATE', 'I', 7.50, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74228, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75591, 12049, 'OCTINOXATE', 'I', 7.50, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75634, 12049, 'OCTINOXATE', 'I', 6.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75689, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72583, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75934, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75980, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76030, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76139, 12049, 'OCTINOXATE', 'I', 1.3, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74849, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74883, 12049, 'OCTINOXATE', 'I', 5.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74884, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74885, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74999, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76351, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72764, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78398, 12049, 'OCTINOXATE', 'I', 6.50, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78399, 12049, 'OCTINOXATE', 'I', 6.50, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77462, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77463, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77390, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77392, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77473, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77288, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76894, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77470, 12049, 'OCTINOXATE', 'I', 6.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76892, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77633, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78222, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78297, 12049, 'OCTINOXATE', 'I', 5.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77340, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77341, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77394, 12049, 'OCTINOXATE', 'I', 8.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77395, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77396, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79440, 12049, 'OCTINOXATE', 'I', 7.4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80859, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81656, 12049, 'OCTINOXATE', 'I', 7.11, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81144, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81175, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81252, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82349, 12049, 'OCTINOXATE', 'I', 2, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82350, 12049, 'OCTINOXATE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80135, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81909, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79531, 12049, 'OCTINOXATE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79849, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79850, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81268, 12049, 'OCTINOXATE', 'I', 7.11, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81410, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82154, 12049, 'OCTINOXATE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79579, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79748, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82210, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80985, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82964, 12049, 'OCTINOXATE', 'I', 6.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79183, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79674, 12049, 'OCTINOXATE', 'I', 7.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79770, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80487, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80488, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79458, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80527, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80531, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80723, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79607, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79773, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80747, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80773, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79217, 12049, 'OCTINOXATE', 'I', 4.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82268, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82269, 12049, 'OCTINOXATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79044, 12049, 'OCTINOXATE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81707, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81714, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81715, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79460, 12049, 'OCTINOXATE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79466, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79468, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79470, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82602, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79747, 12049, 'OCTINOXATE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80026, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80027, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81451, 12049, 'OCTINOXATE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80484, 12049, 'OCTINOXATE', 'I', 5.994, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81017, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79971, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80049, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80052, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80960, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82987, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80720, 12049, 'OCTINOXATE', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81457, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81557, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82013, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82617, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80977, 12049, 'OCTINOXATE', 'I', 4.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79980, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80631, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80810, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82802, 12049, 'OCTINOXATE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79524, 12049, 'OCTINOXATE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79645, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79647, 12049, 'OCTINOXATE', 'I', 7.4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79648, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79989, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80226, 12049, 'OCTINOXATE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80112, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80114, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80580, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81301, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81661, 12049, 'OCTINOXATE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81830, 12049, 'OCTINOXATE', 'I', 6.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78652, 12049, 'OCTINOXATE', 'I', 3.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81378, 12049, 'OCTINOXATE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81379, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79618, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79620, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80230, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80070, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80696, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81352, 12049, 'OCTINOXATE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81829, 12049, 'OCTINOXATE', 'I', 7.11, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80878, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81145, 12049, 'OCTINOXATE', 'I', 6.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82305, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82315, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79169, 12049, 'OCTINOXATE', 'I', 6.4, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80775, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80776, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80858, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81635, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81931, 12049, 'OCTINOXATE', 'I', 7.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80309, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80312, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80313, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80314, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80315, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80319, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82270, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82380, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82415, 12049, 'OCTINOXATE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81984, 12049, 'OCTINOXATE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82283, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79484, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80382, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80392, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80424, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81912, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80252, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80515, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80516, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80517, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79546, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81033, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81034, 12049, 'OCTINOXATE', 'I', 4.9, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82368, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82372, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79871, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81007, 12049, 'OCTINOXATE', 'I', 3.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80669, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80670, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80671, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82621, 12049, 'OCTINOXATE', 'I', 7.12, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79249, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80707, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82244, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80537, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81638, 12049, 'OCTINOXATE', 'I', 4.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81639, 12049, 'OCTINOXATE', 'I', 6.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82060, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82062, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82066, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82067, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82128, 12049, 'OCTINOXATE', 'I', 7.0, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80177, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81066, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82610, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79705, 12049, 'OCTINOXATE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80864, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80865, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80879, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82484, 12049, 'OCTINOXATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80595, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81287, 12049, 'OCTINOXATE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82113, 12049, 'OCTINOXATE', 'I', 3.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82779, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79540, 12049, 'OCTINOXATE', 'I', 7.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82523, 12049, 'OCTINOXATE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82525, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82167, 12049, 'OCTINOXATE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83081, 12049, 'OCTINOXATE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83111, 12049, 'OCTINOXATE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83112, 12049, 'OCTINOXATE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83116, 12049, 'OCTINOXATE', 'I', 7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83120, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83121, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83146, 12049, 'OCTINOXATE', 'I', 7.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83240, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83278, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83317, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83494, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83580, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83677, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83705, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83706, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83710, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83728, 12049, 'OCTINOXATE', 'I', 4.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83737, 12049, 'OCTINOXATE', 'I', 2.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83877, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83899, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83900, 12049, 'OCTINOXATE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83903, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83908, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83964, 12049, 'OCTINOXATE', 'I', 4.09, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84038, 12049, 'OCTINOXATE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84040, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84042, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84055, 12049, 'OCTINOXATE', 'I', 4.09, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84099, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84118, 12049, 'OCTINOXATE', 'I', 4.9, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84119, 12049, 'OCTINOXATE', 'I', 4.9, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84151, 12049, 'OCTINOXATE', 'I', 7, '%', '', '', 'N', 'W/W', 'OCTINOXATE 7G/100G');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84209, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84244, 12049, 'OCTINOXATE', 'I', 5.99, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84257, 12049, 'OCTINOXATE', 'I', 7, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84292, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84344, 12049, 'OCTINOXATE', 'I', 6.34, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84378, 12049, 'OCTINOXATE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84398, 12049, 'OCTINOXATE', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84399, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84414, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84420, 12049, 'OCTINOXATE', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84425, 12049, 'OCTINOXATE', 'I', 0.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84465, 12049, 'OCTINOXATE', 'I', 6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84503, 12049, 'OCTINOXATE', 'I', 5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84519, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84520, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84530, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84574, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84576, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84579, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84580, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84640, 12049, 'OCTINOXATE', 'I', 5.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84664, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84713, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84761, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84853, 12049, 'OCTINOXATE', 'I', 6.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84858, 12049, 'OCTINOXATE', 'I', 6.00, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84886, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85096, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85098, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85099, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85135, 12049, 'OCTINOXATE', 'I', 3.4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85228, 12049, 'OCTINOXATE', 'I', 3.6, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85341, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85343, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85515, 12049, 'OCTINOXATE', 'I', 7, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42332, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42329, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18554, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15799, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16893, 12049, 'OCTINOXATE', 'I', 4.5, '%', '', '', 'N', '%', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16896, 12049, 'OCTINOXATE', 'I', 5, '%', '', '', 'N', '%', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50055, 12049, 'OCTINOXATE', 'I', 6, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50132, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50134, 12049, 'OCTINOXATE', 'I', 5.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53416, 12049, 'OCTINOXATE', 'I', 4.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53417, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53419, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53421, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53422, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53423, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53424, 12049, 'OCTINOXATE', 'I', 5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53425, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53426, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61886, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', 'Historic Freeform Text: OCTYL METHOXYCINNAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61896, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60506, 12049, 'OCTINOXATE', 'I', 5.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60302, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60326, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60327, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60328, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63346, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63347, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63349, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63351, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62732, 12049, 'OCTINOXATE', 'I', 6, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62743, 12049, 'OCTINOXATE', 'I', 6, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64334, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64341, 12049, 'OCTINOXATE', 'I', 3, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64736, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64737, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64738, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64739, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64740, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65601, 12049, 'OCTINOXATE', 'I', 7.5, '%', '', '', 'N', '%', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63661, 12049, 'OCTINOXATE', 'I', 75, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63662, 12049, 'OCTINOXATE', 'I', 75, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60001, 12049, 'OCTINOXATE', 'I', 7, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61299, 12049, 'OCTINOXATE', 'I', 4, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61313, 12049, 'OCTINOXATE', 'I', 6, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63515, 12049, 'OCTINOXATE', 'I', 6.5, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63516, 12049, 'OCTINOXATE', 'I', 6.5, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66124, 12049, 'OCTINOXATE', 'I', 6.5, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72236, 12049, 'OCTINOXATE', 'I', 7.5, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71227, 12049, 'OCTINOXATE', 'I', 7.5, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74459, 12049, 'OCTINOXATE', 'I', 4, 'G', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62885, 12049, 'OCTINOXATE', 'I', 60, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75367, 15411, 'SODIUM OXYBATE', 'I', 500, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11421, 1196, 'CLOZAPINE', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLOZAPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11422, 1196, 'CLOZAPINE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOZAPINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71485, 1196, 'CLOZAPINE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71486, 1196, 'CLOZAPINE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72354, 1196, 'CLOZAPINE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72355, 1196, 'CLOZAPINE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79038, 1196, 'CLOZAPINE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79039, 1196, 'CLOZAPINE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17222, 1197, 'TERCONAZOLE', 'I', 80, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TERCONAZOLE ((3 VAGINAL OVULES 80MG EACH))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17222, 1197, 'TERCONAZOLE', 'I', 0.8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TERCONAZOLE ((TERAZOL 3 VAGINAL CRM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71914, 1197, 'TERCONAZOLE', 'I', 0.4, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11460, 1197, 'TERCONAZOLE', 'I', 4, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: TERCONAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43478, 1200, 'ZOPICLONE', 'I', 7.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: ZOPICLONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43233, 1200, 'ZOPICLONE', 'I', 7.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: ZOPICLONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43171, 1200, 'ZOPICLONE', 'I', 5.0, 'MG', '', '', 'N', '', 'Historic Freeform Text: ZOPICLONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19922, 1200, 'ZOPICLONE', 'I', 7.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ZOPICLONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12426, 1200, 'ZOPICLONE', 'I', 7.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: ZOPICLONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62024, 1200, 'ZOPICLONE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64177, 1200, 'ZOPICLONE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64414, 1200, 'ZOPICLONE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66207, 1200, 'ZOPICLONE', 'I', 3.75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66208, 1200, 'ZOPICLONE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67334, 1200, 'ZOPICLONE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69081, 1200, 'ZOPICLONE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70717, 1200, 'ZOPICLONE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: ZOPICLONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70480, 1200, 'ZOPICLONE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75330, 1200, 'ZOPICLONE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75331, 1200, 'ZOPICLONE', 'I', 7.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: ZOPICLONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74282, 1200, 'ZOPICLONE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74283, 1200, 'ZOPICLONE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75747, 1200, 'ZOPICLONE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75748, 1200, 'ZOPICLONE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73639, 1200, 'ZOPICLONE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73638, 1200, 'ZOPICLONE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76363, 1200, 'ZOPICLONE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76362, 1200, 'ZOPICLONE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76809, 1200, 'ZOPICLONE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77941, 1200, 'ZOPICLONE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77942, 1200, 'ZOPICLONE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78196, 1200, 'ZOPICLONE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82952, 1200, 'ZOPICLONE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79861, 1200, 'ZOPICLONE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79862, 1200, 'ZOPICLONE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80693, 1200, 'ZOPICLONE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80694, 1200, 'ZOPICLONE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43329, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PRAVASTATIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11029, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PRAVASTATIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11030, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PRAVASTATIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68318, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68319, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68320, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67424, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67425, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67426, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67763, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67764, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67765, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72163, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72165, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72166, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71157, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71158, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71159, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71918, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71919, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71920, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71241, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71242, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71243, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74231, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74232, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74233, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75562, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75563, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75564, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75794, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', 'TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75795, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'N', '', 'TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75796, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'N', '', 'TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72518, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72519, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72520, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73456, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73457, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73458, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73459, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73460, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73461, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77000, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77001, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77002, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78713, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78714, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78715, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80298, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80299, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80300, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81669, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81670, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81671, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84168, 1201, 'PRAVASTATIN SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84169, 1201, 'PRAVASTATIN SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84170, 1201, 'PRAVASTATIN SODIUM', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17800, 1203, 'SODIUM IOXITALAMATE', 'I', 255, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM IOXITALAMATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17789, 1204, 'FLUCONAZOLE', 'I', 150, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUCONAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10952, 1204, 'FLUCONAZOLE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUCONAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10953, 1204, 'FLUCONAZOLE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUCONAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60693, 1204, 'FLUCONAZOLE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60694, 1204, 'FLUCONAZOLE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60273, 1204, 'FLUCONAZOLE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60274, 1204, 'FLUCONAZOLE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65565, 1204, 'FLUCONAZOLE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69316, 1204, 'FLUCONAZOLE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69317, 1204, 'FLUCONAZOLE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67573, 1204, 'FLUCONAZOLE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70808, 1204, 'FLUCONAZOLE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70245, 1204, 'FLUCONAZOLE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70246, 1204, 'FLUCONAZOLE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69743, 1204, 'FLUCONAZOLE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69744, 1204, 'FLUCONAZOLE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69798, 1204, 'FLUCONAZOLE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74071, 1204, 'FLUCONAZOLE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76691, 1204, 'FLUCONAZOLE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76692, 1204, 'FLUCONAZOLE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75698, 1204, 'FLUCONAZOLE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73413, 1204, 'FLUCONAZOLE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73414, 1204, 'FLUCONAZOLE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76799, 1204, 'FLUCONAZOLE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77940, 1204, 'FLUCONAZOLE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79630, 1204, 'FLUCONAZOLE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79631, 1204, 'FLUCONAZOLE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78725, 1204, 'FLUCONAZOLE', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78726, 1204, 'FLUCONAZOLE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78727, 1204, 'FLUCONAZOLE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79724, 1204, 'FLUCONAZOLE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80890, 1204, 'FLUCONAZOLE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83738, 1204, 'FLUCONAZOLE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18010, 1204, 'FLUCONAZOLE', 'I', 50, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: FLUCONAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10954, 1204, 'FLUCONAZOLE', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FLUCONAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72232, 1204, 'FLUCONAZOLE', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72035, 1204, 'FLUCONAZOLE', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72794, 1204, 'FLUCONAZOLE', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74685, 1204, 'FLUCONAZOLE', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FLUCONAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79728, 1204, 'FLUCONAZOLE', 'I', 150, 'MG', '', '', 'N', 'CAP', 'CANESORAL DIN 02311690 /JJ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13805, 1205, 'DICLOFENAC POTASSIUM', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DICLOFENAC POTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62824, 1205, 'DICLOFENAC POTASSIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63235, 1205, 'DICLOFENAC POTASSIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67343, 1205, 'DICLOFENAC POTASSIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74714, 1205, 'DICLOFENAC POTASSIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79703, 1205, 'DICLOFENAC POTASSIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83694, 1205, 'DICLOFENAC POTASSIUM', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84242, 12794, 'HYDROXYETHYL STARCH 130/0.4', 'I', 6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2002, 1073, 'SODIUM BISULFITE', 'I', 1.8, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: SODIUM BISULFITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1615, 1073, 'SODIUM BISULFITE', 'I', 1.8, 'G', '', '500', 'N', 'ML', 'Historic Freeform Text: SODIUM BISULFITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15493, 1073, 'SODIUM BISULFITE', 'I', 40, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM BISULFITE ((LESS THAN 0.05G))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11330, 1074, 'SODIUM LACTATE', 'I', 1.6, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70916, 1074, 'SODIUM LACTATE', 'I', 4.72, 'G', '', '1000', 'N', 'ML', 'SODIUM LACTATE ANHYDROUS - COMPARTMENT C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70917, 1074, 'SODIUM LACTATE', 'I', 4.72, 'G', '', '1000', 'N', 'ML', 'SODIUM LACTATE ANHYDROUS - COMPARTMENT C');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21756, 1074, 'SODIUM LACTATE', 'I', 160, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15769, 1074, 'SODIUM LACTATE', 'I', 448, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15772, 1074, 'SODIUM LACTATE', 'I', 448, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15778, 1074, 'SODIUM LACTATE', 'I', 392, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15768, 1074, 'SODIUM LACTATE', 'I', 448, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15763, 1074, 'SODIUM LACTATE', 'I', 392, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15764, 1074, 'SODIUM LACTATE', 'I', 392, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14250, 1074, 'SODIUM LACTATE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10512, 1074, 'SODIUM LACTATE', 'I', 392, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11197, 1074, 'SODIUM LACTATE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10936, 1074, 'SODIUM LACTATE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10937, 1074, 'SODIUM LACTATE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12186, 1074, 'SODIUM LACTATE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10861, 1074, 'SODIUM LACTATE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10863, 1074, 'SODIUM LACTATE', 'I', 448, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10864, 1074, 'SODIUM LACTATE', 'I', 448, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10865, 1074, 'SODIUM LACTATE', 'I', 448, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9830, 1074, 'SODIUM LACTATE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10143, 1074, 'SODIUM LACTATE', 'I', 392, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10144, 1074, 'SODIUM LACTATE', 'I', 392, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8601, 1074, 'SODIUM LACTATE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10009, 1074, 'SODIUM LACTATE', 'I', 392, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5373, 1074, 'SODIUM LACTATE', 'I', 7.842, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1749, 1074, 'SODIUM LACTATE', 'I', 3.1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1745, 1074, 'SODIUM LACTATE', 'I', 3.1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1673, 1074, 'SODIUM LACTATE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1628, 1074, 'SODIUM LACTATE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1548, 1074, 'SODIUM LACTATE', 'I', 3.1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 1074, 'SODIUM LACTATE', 'I', 448, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67329, 1074, 'SODIUM LACTATE', 'I', 310, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70277, 1074, 'SODIUM LACTATE', 'I', 310, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7143, 1074, 'SODIUM LACTATE', 'I', 3.1, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5663, 1074, 'SODIUM LACTATE', 'I', 3.1, 'G', '', '', 'N', 'L', 'Historic Freeform Text: SODIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49558, 1074, 'SODIUM LACTATE', 'I', 4.483, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49559, 1074, 'SODIUM LACTATE', 'I', 4.483, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49560, 1074, 'SODIUM LACTATE', 'I', 4.483, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64397, 1074, 'SODIUM LACTATE', 'I', 4.5, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63009, 1074, 'SODIUM LACTATE', 'I', 3.1, 'G', '', '', 'N', 'L', 'SODIUM LACTATE ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71993, 1074, 'SODIUM LACTATE', 'I', 2.63, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71997, 1074, 'SODIUM LACTATE', 'I', 2.63, 'G', '', '', 'N', 'L', 'BAG B.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71998, 1074, 'SODIUM LACTATE', 'I', 2.63, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74647, 1074, 'SODIUM LACTATE', 'I', 3.925, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74648, 1074, 'SODIUM LACTATE', 'I', 3.925, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74649, 1074, 'SODIUM LACTATE', 'I', 3.925, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15809, 1076, 'POTASSIUM ACETATE', 'I', 63, 'MG', '', '', 'N', '', 'Historic Freeform Text: POTASSIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15808, 1076, 'POTASSIUM ACETATE', 'I', 63, 'MG', '', '', 'N', '', 'Historic Freeform Text: POTASSIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5698, 1076, 'POTASSIUM ACETATE', 'I', 62.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: POTASSIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6202, 1076, 'POTASSIUM ACETATE', 'I', 38, 'MG', '', '', 'N', '', 'Historic Freeform Text: POTASSIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66863, 1076, 'POTASSIUM ACETATE', 'I', 38, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35667, 1076, 'POTASSIUM ACETATE', 'I', 11.59, '%', '', '', 'N', '%', 'Historic Freeform Text: POTASSIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21691, 1076, 'POTASSIUM ACETATE', 'I', 1.96, 'G', '', '20', 'N', 'ML', 'Historic Freeform Text: POTASSIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3407, 1076, 'POTASSIUM ACETATE', 'I', 1, 'G', '', '60', 'N', 'ML', 'Historic Freeform Text: POTASSIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7141, 1076, 'POTASSIUM ACETATE', 'I', 1, 'G', '', '1000', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36695, 1076, 'POTASSIUM ACETATE', 'I', 500, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: POTASSIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23184, 1076, 'POTASSIUM ACETATE', 'I', 690, 'MG', '', '25', 'N', 'ML', 'Historic Freeform Text: POTASSIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19078, 1076, 'POTASSIUM ACETATE', 'I', 392, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM ACETATE ((ANYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11038, 1076, 'POTASSIUM ACETATE', 'I', 128, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9429, 1076, 'POTASSIUM ACETATE', 'I', 392, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2002, 1076, 'POTASSIUM ACETATE', 'I', 900, 'MG', '', '500', 'N', 'ML', 'Historic Freeform Text: POTASSIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1739, 1076, 'POTASSIUM ACETATE', 'I', 1.28, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: POTASSIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1615, 1076, 'POTASSIUM ACETATE', 'I', 900, 'MG', '', '500', 'N', 'ML', 'Historic Freeform Text: POTASSIUM ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71771, 12754, 'EZETIMIBE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70433, 12755, '3-(TRIMETHOXYSILYL)PROPYL DIMETHYL OCTADECYL AMMONIUM CHLORIDE', 'I', 0.11, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69890, 12759, 'VALGANCICLOVIR (VALGANCICLOVIR HYDROCHLORIDE)', 'I', 450, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79164, 12759, 'VALGANCICLOVIR (VALGANCICLOVIR HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'N', 'ML', 'POWDER FOR ORAL SOLUTION 50MG/ML VALGANCICLOVIR (AS VALGANCICLOVIR HYDROCHLORIDE) WHEN RECONSTITUTED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70006, 12770, 'PALIVIZUMAB', 'I', 50, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70007, 12770, 'PALIVIZUMAB', 'I', 100, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72560, 12774, 'BUTANEDIOL', 'I', 5.7, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79508, 12787, 'MOROCTOCOG ALFA', 'I', 250, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79509, 12787, 'MOROCTOCOG ALFA', 'I', 500, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79510, 12787, 'MOROCTOCOG ALFA', 'I', 1000, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79511, 12787, 'MOROCTOCOG ALFA', 'I', 2000, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70142, 12790, 'THYROTROPIN ALFA', 'I', 0.9, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76364, 12794, 'HYDROXYETHYL STARCH 130/0.4', 'I', 6, '%', '', '', 'N', '', 'POLY (O-2 HYDROXYETHYL) STARCH 130/0.4. 130/04 ADDED TO PRODUCT NAME AS PER APPROVED PM. 2009.07.23.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1895, 5131, 'ETHYL ACETATE', 'I', 66.8, '%', '', '', 'N', '%', 'Historic Freeform Text: ETHYL ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5504, 6888, 'COCILLANA', 'I', 1.36, 'MG', '', '1', 'N', 'ML', 'Historic Freeform Text: COCILLANA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3666, 3457, 'OIL OF THYME', 'I', 0.28, '%', '', '', 'N', '%', 'Historic Freeform Text: OIL OF THYME');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4161, 3457, 'OIL OF THYME', 'I', 2.8, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: OIL OF THYME');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3669, 9122, 'EUCALYPTOL', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: EUCALYPTOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3621, 9122, 'EUCALYPTOL', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: EUCALYPTOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5754, 9122, 'EUCALYPTOL', 'I', 25, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: EUCALYPTOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66277, 4993, 'DEXPANTHENOL', 'I', 5, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 4993, 'DEXPANTHENOL', 'I', 0.05, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXPANTHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19369, 4993, 'DEXPANTHENOL', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXPANTHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16462, 4993, 'DEXPANTHENOL', 'I', 3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: D-PANTHENOL ((VIAL 1))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10470, 4993, 'DEXPANTHENOL', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXPANTHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12562, 4993, 'DEXPANTHENOL', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXPANTHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9254, 4993, 'DEXPANTHENOL', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9527, 4993, 'DEXPANTHENOL', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PANTOTHENYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7179, 4993, 'DEXPANTHENOL', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PANTOTHENYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6072, 4993, 'DEXPANTHENOL', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PANTOTHENYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 4993, 'DEXPANTHENOL', 'I', 5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PANTOTHENYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6071, 4993, 'DEXPANTHENOL', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PANTOTHENYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6341, 4993, 'DEXPANTHENOL', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PANTOTHENYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6339, 4993, 'DEXPANTHENOL', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PANTOTHENYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7329, 4993, 'DEXPANTHENOL', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXPANTHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3497, 4993, 'DEXPANTHENOL', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PANTOTHENYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2871, 4993, 'DEXPANTHENOL', 'I', 50, 'MG', '', '10', 'N', 'ML', 'Historic Freeform Text: PANTOTHENYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31, 4993, 'DEXPANTHENOL', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PANTOTHENYL ALCOHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68684, 4993, 'DEXPANTHENOL (PANTHENOL)', 'I', 3, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 4993, 'DEXPANTHENOL (CALCIUM D-PANTOTHENATE)', 'I', 5, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78915, 4993, 'DEXPANTHENOL', 'I', 15, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42161, 9358, 'CAFFEINE', 'I', 33, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35047, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31568, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33917, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23669, 9358, 'CAFFEINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23671, 9358, 'CAFFEINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23672, 9358, 'CAFFEINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19935, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19248, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19249, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15579, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15578, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13699, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14596, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14595, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14316, 9358, 'CAFFEINE', 'I', 65, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13259, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11741, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11158, 9358, 'CAFFEINE', 'I', 32, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11065, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5371, 9358, 'CAFFEINE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5372, 9358, 'CAFFEINE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6516, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6479, 9358, 'CAFFEINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6480, 9358, 'CAFFEINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5876, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6419, 9358, 'CAFFEINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5779, 9358, 'CAFFEINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6893, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6894, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6346, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7434, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6763, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6764, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1233, 9358, 'CAFFEINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2918, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1025, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (872, 9358, 'CAFFEINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (873, 9358, 'CAFFEINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47953, 9358, 'CAFFEINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47954, 9358, 'CAFFEINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47955, 9358, 'CAFFEINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47956, 9358, 'CAFFEINE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (413, 9358, 'CAFFEINE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62075, 9358, 'CAFFEINE (CAFFEINE CITRATE)', 'I', 15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CAFFEINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62101, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60750, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66118, 9358, 'CAFFEINE', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70220, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70240, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73935, 9358, 'CAFFEINE', 'I', 65, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75299, 9358, 'CAFFEINE', 'I', 65, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75534, 9358, 'CAFFEINE', 'I', 65, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73187, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75894, 9358, 'CAFFEINE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76086, 9358, 'CAFFEINE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73681, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75038, 9358, 'CAFFEINE', 'I', 65, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77631, 9358, 'CAFFEINE', 'I', 65, 'MG', '', '', 'N', '', 'ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78862, 9358, 'CAFFEINE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81810, 9358, 'CAFFEINE', 'I', 32, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81813, 9358, 'CAFFEINE', 'I', 32, 'MG', '', '', 'N', '', 'Historic Freeform Text: CAFFEINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2479, 244, 'CALCIUM LACTATE', 'I', 24, 'MG', '', '', 'N', '', 'Historic Freeform Text: CALCIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2191, 244, 'CALCIUM LACTATE', 'I', 24, 'MG', '', '', 'N', '', 'Historic Freeform Text: CALCIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1979, 244, 'CALCIUM LACTATE', 'I', 1.41, '%', '', '', 'N', '%', 'Historic Freeform Text: CALCIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2009, 244, 'CALCIUM LACTATE', 'I', 1.41, '%', '', '', 'N', '%', 'Historic Freeform Text: CALCIUM LACTATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47888, 244, 'CALCIUM LACTATE', 'I', 32.3, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61949, 6871, 'BETAINE', 'I', 1, 'G', '', '1.7', 'N', 'CC', 'BETAINE ANHYDROUS.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16486, 7281, 'COPPER GLUCONATE', 'I', 5, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: CUPRIC GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36697, 7281, 'COPPER GLUCONATE', 'I', 0.195, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: COPPER GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19369, 7281, 'COPPER GLUCONATE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CUPRIC GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10470, 7281, 'COPPER GLUCONATE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CUPRIC GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12562, 7281, 'COPPER GLUCONATE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CUPRIC GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9254, 7281, 'COPPER GLUCONATE', 'I', 0.2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9527, 7281, 'COPPER GLUCONATE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: COPPER GLUCONATE ((GLUCONATE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7179, 7281, 'COPPER GLUCONATE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CUPRIC GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6071, 7281, 'COPPER GLUCONATE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CUPRIC GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6339, 7281, 'COPPER GLUCONATE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CUPRIC GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5655, 7281, 'COPPER GLUCONATE', 'I', 0.195, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CUPRIC GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7329, 7281, 'COPPER GLUCONATE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CUPRIC GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3190, 7281, 'COPPER GLUCONATE', 'I', 0.975, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CUPRIC GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4718, 7281, 'COPPER GLUCONATE', 'I', 1, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CUPRIC GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3104, 7281, 'COPPER GLUCONATE', 'I', 0.975, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CUPRIC GLUCONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78915, 7281, 'COPPER GLUCONATE', 'I', 0.2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13167, 9969, 'DEXTRAN (DEXTRAN 70)', 'I', 0.1, '%', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DEXTRAN ((70))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10032, 9969, 'DEXTRAN (DEXTRAN 70)', 'I', 0.1, '%', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DEXTRAN ((AS DEXTRAN 70))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1743, 9969, 'DEXTRAN', 'I', 10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DEXTRAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2682, 9969, 'DEXTRAN', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DEXTRAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70567, 9969, 'DEXTRAN', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1744, 9969, 'DEXTRAN', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTRAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1732, 9969, 'DEXTRAN', 'I', 60, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTRAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1733, 9969, 'DEXTRAN', 'I', 60, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTRAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75968, 17147, 'PALIFERMIN', 'I', 6.25, 'MG', '', '', 'N', 'VIAL', 'EQUIV. TO 5MG/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82408, 19793, 'DARUNAVIR (DARUNAVIR ETHANOLATE)', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80949, 19793, 'DARUNAVIR (DARUNAVIR ETHANOLATE)', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80950, 19793, 'DARUNAVIR (DARUNAVIR ETHANOLATE)', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6345, 6400, 'ALUMINUM DIACETATE', 'I', 0.35, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALUMINUM DIACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2015, 8143, 'SULFAPYRIDINE', 'I', 13, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFAPYRIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2262, 8143, 'SULFAPYRIDINE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFAPYRIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63847, 8143, 'SULFAPYRIDINE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFAPYRIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3991, 9558, 'NITRAZEPAM', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NITRAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3992, 9558, 'NITRAZEPAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: NITRAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47629, 9558, 'NITRAZEPAM', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47630, 9558, 'NITRAZEPAM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53893, 9558, 'NITRAZEPAM', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53896, 9558, 'NITRAZEPAM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69245, 9558, 'NITRAZEPAM', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: NITRAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69246, 9558, 'NITRAZEPAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: NITRAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16473, 'N-ISOPROPYL-N''-PHENYL-PARA-PHENYLENEDIAMINE', 'I', 0.01, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS BLACK RUBBER MIX 0.06MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16474, 'N-CYCLOHEXYL-N''-PHENYL-PARA-PHENYLENEDIAMINE', 'I', 0.025, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS BLACK RUBBER MIX 0.06MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16475, 'N,N''-DIPHENYL-PARA-PHENYLENEDIAMINE', 'I', 0.025, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS BLACK RUBBER MIX 0.06MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16476, 'MERCAPTOBENZOTHIAZOLE', 'I', 0.061, 'MG', '', '', 'N', 'PATCH', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16477, 'N-HYDROXYMETHYLSUCCINIMIDE', 'I', 0.15, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS FORMALDEHYDE 0.15MG/PATCH  - HMS IS A FORMALDEHYDE-RELEASING COMPOUND DEVELOPED TO OVERCOM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16478, '(MORPHOLINOTHIO)BENZOTHIAZOLE', 'I', 0.02, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS MERCAPTO MIX 0.06MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16479, 'N-CYCLOHEXYL-2-BENZOTHIAZOLESULFENAMIDE', 'I', 0.02, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS MERCAPTO MIX 0.06MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16480, 'DITHIOBIS(BENZOTHIAZOLE)', 'I', 0.02, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS MERCAPTO MIX 0.06MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16481, 'TETRAMETHYLTHIURAM MONOSULFIDE', 'I', 0.005, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS THIURAM MIX 0.02MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16482, 'THIRAM', 'I', 0.005, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS THIURAM MIX 0.02MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16483, 'BIS(1-PIPERIDYLTHIOCARBONYL)DISULFIDE', 'I', 0.005, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS THIURAM MIX 0.02MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11545, 5983, 'POLOXALENE', 'I', 530, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: POLOXALENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70837, 9921, 'CALCIUM POLYCARBOPHIL', 'I', 625, 'MG', '', '', 'N', '', 'EQUIVALENT TO 500MG POLYCARBOPHIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14249, 3054, 'DEXTRAN 40', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: DEXTRAN 40');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21688, 3054, 'DEXTRAN 40', 'I', 10, '%', '', '', 'N', '%', 'Historic Freeform Text: DEXTRAN 40');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24615, 4832, 'IRON DEXTRAN COMPLEX', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: IRON DEXTRAN COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4720, 4832, 'IRON DEXTRAN COMPLEX', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: IRON DEXTRAN COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (519, 4832, 'IRON DEXTRAN COMPLEX', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: IRON DEXTRAN COMPLEX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67195, 12072, 'GLUCAGON (RECOMBINANT DNA ORIGIN)', 'I', 1, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81923, 12072, 'GLUCAGON (RECOMBINANT DNA ORIGIN) (GLUCAGON HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'N', 'VIAL', 'RECOMBINANT DNA ORIGIN AS PER THE PRODUCT LABEL. NOT LISTED ON PM. BGTD ADVISED OF THIS DISCREPANCY.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81924, 12072, 'GLUCAGON (RECOMBINANT DNA ORIGIN) (GLUCAGON HYDROCHLORIDE)', 'I', 1, 'MG', '', '', 'N', 'VIAL', 'RECOMBINANT DNA ORIGIN AS PER THE PRODUCT LABEL. NOT LISTED ON PM. BGTD ADVISED OF THIS DISCREPANCY.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76550, 19042, 'MENINGOCOCCAL POLYSACCHARIDE-DIPHTHERIA TOXOID CONJUGATE, GROUP A', 'I', 4.0, 'µG', '', '0.5', 'N', 'ML', 'THERE IS A TOTAL OF APPROX. 48 MCG OF CONJUGATED DIPHTHERIA TOXOID PER 0.5ML HUMAN DOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76550, 19043, 'MENINGOCOCCAL POLYSACCHARIDE-DIPHTHERIA TOXOID CONJUGATE, GROUP C', 'I', 4.0, 'µG', '', '0.5', 'N', 'ML', 'THERE IS A TOTAL OF APPROX. 48 MCG OF CONJUGATED DIPHTHERIA TOXOID PER 0.5ML HUMAN DOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76550, 19044, 'MENINGOCOCCAL POLYSACCHARIDE-DIPHTHERIA TOXOID CONJUGATE, GROUP Y', 'I', 4.0, 'µG', '', '0.5', 'N', 'ML', 'THERE IS A TOTAL OF APPROX. 48 MCG OF CONJUGATED DIPHTHERIA TOXOID PER 0.5ML HUMAN DOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76550, 19045, 'MENINGOCOCCAL POLYSACCHARIDE-DIPHTHERIA TOXOID CONJUGATE, GROUP W 135', 'I', 4.0, 'µG', '', '0.5', 'N', 'ML', 'THERE IS A TOTAL OF APPROX. 48 MCG OF CONJUGATED DIPHTHERIA TOXOID PER 0.5ML HUMAN DOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13132, 20371, 'YOHIMBINE HYDROCHLORIDE', 'I', 6, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: YOHIMBINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47429, 1838, 'NORFLOXACIN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12016, 20371, 'YOHIMBINE HYDROCHLORIDE', 'I', 5.4, 'MG', '', '', 'N', '', 'Historic Freeform Text: YOHIMBINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12575, 20371, 'YOHIMBINE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: YOHIMBINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80596, 20420, 'PNEUMOCOCCAL POLYSACC. SEROT. 18C CONJUG. TO TETANUS TOXOID CARRIER PROT.', 'I', 3, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80596, 20421, 'PNEUMOCOCCAL POLYSACCHARID SEROT. 19F CONJUG. TO DIPHTHERIA TOXOID CARRIER PROT.', 'I', 3, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70150, 20505, 'HETASTARCH', 'I', 6, 'G', '', '100', 'N', 'ML', '6% HETASTARCH IN LACTATED ELECTROLYTE INJECTION. 2009.07.23. ACTIVE INGREDIENT NAME REVISED TO HETAS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82897, 20570, 'DENOSUMAB', 'I', 60, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85304, 20570, 'DENOSUMAB', 'I', 120, 'MG', '', '1.7', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16632, 5843, 'TROPICAMIDE', 'I', 0.8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TROPICAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6057, 5843, 'TROPICAMIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: TROPICAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (260, 5843, 'TROPICAMIDE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: TROPICAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18758, 5843, 'TROPICAMIDE', 'I', 1, '%', '', '', 'N', 'W/V', 'HISTORIC FREEFORM TEXT: TROPICAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16255, 5843, 'TROPICAMIDE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: TROPICAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16634, 5843, 'TROPICAMIDE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: TROPICAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6054, 5843, 'TROPICAMIDE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: TROPICAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6056, 5843, 'TROPICAMIDE', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: TROPICAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (780, 5843, 'TROPICAMIDE', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: TROPICAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10785, 8553, 'LINCOMYCIN (LINCOMYCIN HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LINCOMYCIN HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10224, 8553, 'LINCOMYCIN (LINCOMYCIN HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LINCOMYCIN HCL ((LINCOMYCIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (425, 8553, 'LINCOMYCIN (LINCOMYCIN HYDROCHLORIDE)', 'I', 300, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LINCOMYCIN HYDROCHLORIDE ((LINCOMYCIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20102, 8553, 'LINCOMYCIN (LINCOMYCIN HYDROCHLORIDE)', 'I', 22, 'G', '', '', 'Y', 'KG', 'HISTORIC FREEFORM TEXT: LINCOMYCIN ((AS LINCOMYCIN HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17248, 8553, 'LINCOMYCIN (LINCOMYCIN HYDROCHLORIDE)', 'I', 44, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: LINCOMYCIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15877, 8553, 'LINCOMYCIN (LINCOMYCIN HYDROCHLORIDE)', 'I', 44, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: LINCOMYCIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16467, 8553, 'LINCOMYCIN (LINCOMYCIN HYDROCHLORIDE)', 'I', 110, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: LINCOMYCIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10168, 8553, 'LINCOMYCIN (LINCOMYCIN HYDROCHLORIDE)', 'I', 22, 'G', '', '', 'Y', 'KG', 'HISTORIC FREEFORM TEXT: LINCOMYCIN HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10165, 8553, 'LINCOMYCIN (LINCOMYCIN HYDROCHLORIDE)', 'I', 44, 'G', '', '', 'Y', 'KG', 'HISTORIC FREEFORM TEXT: LINCOMYCIN ((HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10166, 8553, 'LINCOMYCIN (LINCOMYCIN HYDROCHLORIDE)', 'I', 110, 'G', '', '', 'Y', 'KG', 'HISTORIC FREEFORM TEXT: LINCOMYCIN HCL ((LINCOMYCIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13676, 8553, 'LINCOMYCIN (LINCOMYCIN HYDROCHLORIDE)', 'I', 33.3, 'G', '', '150', 'N', 'G', 'HISTORIC FREEFORM TEXT: LINCOMYCIN HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10030, 8553, 'LINCOMYCIN (LINCOMYCIN HYDROCHLORIDE)', 'I', 33.3, 'G', '', '150', 'N', 'G', 'Historic Freeform Text: LINCOMYCIN HCL ((LINCOMYCIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10000, 8553, 'LINCOMYCIN (LINCOMYCIN HYDROCHLORIDE)', 'I', 400, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50578, 8553, 'LINCOMYCIN (LINCOMYCIN HYDROCHLORIDE)', 'I', 400, 'MG', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50225, 8553, 'LINCOMYCIN (LINCOMYCIN HYDROCHLORIDE)', 'I', 222, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15118, 11107, 'DOXEPIN (DOXEPIN HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: DOXEPIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15104, 11107, 'DOXEPIN (DOXEPIN HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DOXEPIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15105, 11107, 'DOXEPIN (DOXEPIN HYDROCHLORIDE)', 'I', 150, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DOXEPIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15106, 11107, 'DOXEPIN (DOXEPIN HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DOXEPIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15107, 11107, 'DOXEPIN (DOXEPIN HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DOXEPIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15108, 11107, 'DOXEPIN (DOXEPIN HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DOXEPIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (944, 11107, 'DOXEPIN (DOXEPIN HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DOXEPIN HYDROCHLORIDE ((DOXEPIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (945, 11107, 'DOXEPIN (DOXEPIN HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', '', 'Historic Freeform Text: DOXEPIN HYDROCHLORIDE ((DOXEPIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (946, 11107, 'DOXEPIN (DOXEPIN HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', 'Historic Freeform Text: DOXEPIN HYDROCHLORIDE ((DOXEPIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2780, 11107, 'DOXEPIN (DOXEPIN HYDROCHLORIDE)', 'I', 75, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DOXEPIN HCL ((DOXEPIN 75MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2049, 11107, 'DOXEPIN (DOXEPIN HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', 'Historic Freeform Text: DOXEPIN HCL ((BASE 100MG))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4516, 6714, 'QUINIDINE SULFATE', 'I', 190, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: QUINIDINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44184, 8092, 'IOHEXOL', 'I', 388, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: IOHEXOL ((ORGANIC.BOUND IODINE 180MG/ML))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44185, 8092, 'IOHEXOL', 'I', 518, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: IOHEXOL ((ORGANIC.BOUND IODINE 240MG/ML))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44186, 8092, 'IOHEXOL', 'I', 647, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: IOHEXOL ((ORGANIC.BOUND IODINE 300MG/ML))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44187, 8092, 'IOHEXOL', 'I', 755, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: IOHEXOL ((ORGANIC.BOUND IODINE 350MG/ML))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43886, 9905, 'AMANTADINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMANTADINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17975, 9905, 'AMANTADINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMANTADINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13464, 9905, 'AMANTADINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMANTADINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14393, 9905, 'AMANTADINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: AMANTADINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74802, 9905, 'AMANTADINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: AMANTADINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13917, 7555, 'HALOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HALOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13909, 7555, 'HALOBETASOL PROPIONATE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: HALOBETASOL PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6639, 10161, 'FURAZOLIDONE', 'I', 0.2, '%', '', '', 'N', '', 'Historic Freeform Text: FURAZOLIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7144, 4950, 'CHOLINE CHLORIDE', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CHOLINE CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10470, 4950, 'CHOLINE CHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHOLINE CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12562, 4950, 'CHOLINE CHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHOLINE CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6071, 4950, 'CHOLINE CHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHOLINE CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5925, 4950, 'CHOLINE CHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHOLINE CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5147, 4950, 'CHOLINE CHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHOLINE CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78915, 4950, 'CHOLINE CHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 4950, 'CHOLINE CHLORIDE', 'I', 88, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: CHOLINE CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18635, 4950, 'CHOLINE CHLORIDE', 'I', 500, 'MG', '', '19', 'N', 'G', 'Historic Freeform Text: CHOLINE CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20258, 7578, 'FLUOCINOLONE ACETONIDE', 'I', 0.025, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUOCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20009, 7578, 'FLUOCINOLONE ACETONIDE', 'I', 0.01, '%', '', '', 'N', '', 'Historic Freeform Text: FLUOCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13875, 7578, 'FLUOCINOLONE ACETONIDE', 'I', 0.01, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUOCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60664, 7578, 'FLUOCINOLONE ACETONIDE', 'I', 0.01, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66546, 7578, 'FLUOCINOLONE ACETONIDE', 'I', 0.01, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78584, 7578, 'FLUOCINOLONE ACETONIDE', 'I', 0.01, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9273, 7578, 'FLUOCINOLONE ACETONIDE', 'I', 0.01, '%', '', '', 'N', '%', 'Historic Freeform Text: FLUOCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8975, 7578, 'FLUOCINOLONE ACETONIDE', 'I', 0.025, '%', '', '', 'N', '%', 'Historic Freeform Text: FLUOCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9447, 7578, 'FLUOCINOLONE ACETONIDE', 'I', 0.25, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: FLUOCINOLONE ACETONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14049, 763, 'ENOXAPARIN SODIUM', 'I', 100, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: ENOXAPARIN AI STRENGTH UPDATED FROM 30MG/0.3ML TO 100MG/ML AS PER NATASHA TH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59932, 763, 'ENOXAPARIN SODIUM', 'I', 100, 'MG', '', '', 'N', 'ML', 'ALSO CONTAINS 1.5% BENZYL ALCOHOL AS A PRESERVATIVE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60174, 763, 'ENOXAPARIN SODIUM', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66484, 763, 'ENOXAPARIN SODIUM', 'I', 150, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53282, 11246, 'FACTOR XIII', 'I', 50, 'UNIT', '', '1', 'N', 'ML', 'FACTOR X111  10 - 50 U PER KIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53284, 11246, 'FACTOR XIII', 'I', 250, 'UNIT', '', '5', 'N', 'ML', 'FACTOR X111 50  - 250 U PER KIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12995, 2433, 'ASPARAGINASE', 'I', 10000, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: ASPARAGINASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61174, 2433, 'ASPARAGINASE', 'I', 10000, 'UNIT', '', '', 'N', 'VIAL', 'SOURCE OF ASPARAGINASE: ERWINIA CHRYSANTHEMI (E.CARROTOVARA)/KK.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19647, 141, 'BICALUTAMIDE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BICALUTAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76331, 141, 'BICALUTAMIDE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BICALUTAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76679, 141, 'BICALUTAMIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BICALUTAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76683, 141, 'BICALUTAMIDE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BICALUTAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75561, 141, 'BICALUTAMIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BICALUTAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75978, 141, 'BICALUTAMIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76122, 141, 'BICALUTAMIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BICALUTAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76175, 141, 'BICALUTAMIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BICALUTAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78142, 141, 'BICALUTAMIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81064, 141, 'BICALUTAMIDE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BICALUTAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79663, 141, 'BICALUTAMIDE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BICALUTAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81133, 141, 'BICALUTAMIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78772, 141, 'BICALUTAMIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84234, 141, 'BICALUTAMIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18306, 269, 'DALTEPARIN SODIUM', 'I', 5000, 'UNIT', '', '0.2', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DALTEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18307, 269, 'DALTEPARIN SODIUM', 'I', 2500, 'UNIT', '', '0.2', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DALTEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18235, 269, 'DALTEPARIN SODIUM', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50478, 269, 'DALTEPARIN SODIUM', 'I', 25000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83790, 269, 'DALTEPARIN SODIUM', 'I', 7500, 'UNIT', '', '0.3', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DALTEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83791, 269, 'DALTEPARIN SODIUM', 'I', 10000, 'UNIT', '', '0.4', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DALTEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83792, 269, 'DALTEPARIN SODIUM', 'I', 12500, 'UNIT', '', '0.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DALTEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83793, 269, 'DALTEPARIN SODIUM', 'I', 15000, 'UNIT', '', '0.6', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DALTEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83794, 269, 'DALTEPARIN SODIUM', 'I', 18000, 'UNIT', '', '0.72', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DALTEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19202, 619, 'TINZAPARIN SODIUM', 'I', 10000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: TINZAPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47420, 619, 'TINZAPARIN SODIUM', 'I', 20000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47983, 619, 'TINZAPARIN SODIUM', 'I', 10000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: TINZAPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50802, 619, 'TINZAPARIN SODIUM', 'I', 20000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (45892, 9060, 'HEPARIN SODIUM', 'I', 10, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: HEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36794, 9060, 'HEPARIN SODIUM', 'I', 4000, 'UNIT', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HEPARIN SODIUM  SOURCED FROM THE INTESTINE OF PIG. CONTACTED THE SPONSOR REG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36795, 9060, 'HEPARIN SODIUM', 'I', 10000, 'UNIT', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HEPARIN SODIUM  SOURCED FROM THE INTESTINE OF PIG. CONTACTED THE SPONSOR REG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21993, 9060, 'HEPARIN SODIUM', 'I', 200, 'UNIT', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HEPARIN SODIUM  SOURCED FROM THE INTESTINE OF PIG. CONTACTED THE SPONSOR REG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18721, 9060, 'HEPARIN SODIUM', 'I', 25000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: HEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17227, 9060, 'HEPARIN SODIUM', 'I', 2, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16794, 9060, 'HEPARIN SODIUM', 'I', 5000, 'UNIT', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HEPARIN SODIUM  SOURCED FROM THE INTESTINE OF PIG. CONTACTED THE SPONSOR REG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77250, 1327, 'GLICLAZIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10526, 9060, 'HEPARIN SODIUM', 'I', 1000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12646, 9060, 'HEPARIN SODIUM', 'I', 50, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: HEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12647, 9060, 'HEPARIN SODIUM', 'I', 40, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9790, 9060, 'HEPARIN SODIUM', 'I', 10, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: HEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9791, 9060, 'HEPARIN SODIUM', 'I', 100, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: HEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9470, 9060, 'HEPARIN SODIUM', 'I', 1000, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: HEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9471, 9060, 'HEPARIN SODIUM', 'I', 10000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9400, 9060, 'HEPARIN SODIUM', 'I', 100, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: HEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8041, 9060, 'HEPARIN SODIUM', 'I', 25000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8042, 9060, 'HEPARIN SODIUM', 'I', 100, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: HEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8043, 9060, 'HEPARIN SODIUM', 'I', 10000, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6627, 9060, 'HEPARIN SODIUM', 'I', 10, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: HEPARIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74973, 9060, 'HEPARIN SODIUM', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74976, 9060, 'HEPARIN SODIUM', 'I', 1000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78841, 9060, 'HEPARIN SODIUM', 'I', 1000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78842, 9060, 'HEPARIN SODIUM', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78843, 9060, 'HEPARIN SODIUM', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81672, 20511, 'DRONEDARONE (DRONEDARONE HYDROCHLORIDE)', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18936, 18176, 'CALCIUM SACCHARATE', 'I', 4.5, 'MG', '', '', 'N', 'ML', 'CALCIUM SACCHARATE TETRAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63418, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63419, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63420, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63421, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50116, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50115, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50117, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50120, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60871, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60872, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60873, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60874, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60994, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60995, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60996, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60997, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60236, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60237, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60238, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60239, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66699, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74061, 2189, 'LOXAPINE (LOXAPINE SUCCINATE)', 'I', 2.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34560, 2189, 'LOXAPINE (LOXAPINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LOXAPINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62556, 2189, 'LOXAPINE (LOXAPINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74062, 2189, 'LOXAPINE (LOXAPINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12921, 8185, 'SULFAMETHAZINE SODIUM', 'I', 25, '%', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (676, 8185, 'SULFAMETHAZINE SODIUM', 'I', 25, '%', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1869, 8185, 'SULFAMETHAZINE SODIUM', 'I', 100, '%', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2194, 8185, 'SULFAMETHAZINE SODIUM', 'I', 25, '%', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (133, 8185, 'SULFAMETHAZINE SODIUM', 'I', 12.5, '%', '', '', 'N', '', 'Historic Freeform Text: SULFAMETHAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2001, 8185, 'SULFAMETHAZINE SODIUM', 'I', 0, 'NIL', '', '', 'N', 'NIL', 'HISTORIC FREEFORM TEXT: SULFAMETHAZINE SODIUM  CONTACTED THE COMPANY SEVERAL TIMES TO UPDATE THE CON');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5692, 8185, 'SULFAMETHAZINE SODIUM', 'I', 25, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: SULFAMETHAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (23683, 8185, 'SULFAMETHAZINE SODIUM', 'I', 66, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: SULFAMETHAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14165, 8185, 'SULFAMETHAZINE SODIUM', 'I', 170.5, 'G', '', '450', 'N', 'G', 'Historic Freeform Text: SULFAMETHAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8101, 8185, 'SULFAMETHAZINE SODIUM', 'I', 150, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: SULFAMETHAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3926, 8185, 'SULFAMETHAZINE SODIUM', 'I', 170.5, 'G', '', '450', 'N', 'G', 'Historic Freeform Text: SULFAMETHAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1143, 8185, 'SULFAMETHAZINE SODIUM', 'I', 378, 'G', '', '590', 'N', 'G', 'Historic Freeform Text: SULFAMETHAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1613, 8185, 'SULFAMETHAZINE SODIUM', 'I', 20, 'G', '', '454', 'N', 'G', 'Historic Freeform Text: SULFAMETHAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2126, 8185, 'SULFAMETHAZINE SODIUM', 'I', 302, 'G', '', '454', 'N', 'G', 'Historic Freeform Text: SULFAMETHAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26617, 8185, 'SULFAMETHAZINE SODIUM', 'I', 630, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: SULFAMETHAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7178, 8185, 'SULFAMETHAZINE SODIUM', 'I', 667, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SULFAMETHAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1970, 8185, 'SULFAMETHAZINE SODIUM', 'I', 630, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: SULFAMETHAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47385, 8185, 'SULFAMETHAZINE SODIUM', 'I', 630, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (631, 7568, 'FLUMETHASONE PIVALATE', 'I', 0.02, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUMETHASONE PIVALATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (868, 7568, 'FLUMETHASONE PIVALATE', 'I', 0.02, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUMETHASONE PIVALATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66032, 6731, 'DIGOXIN', 'I', 0.0625, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66033, 6731, 'DIGOXIN', 'I', 0.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66034, 6731, 'DIGOXIN', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69479, 6731, 'DIGOXIN', 'I', 0.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69478, 6731, 'DIGOXIN', 'I', 0.0625, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69480, 6731, 'DIGOXIN', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76686, 6731, 'DIGOXIN', 'I', 0.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76687, 6731, 'DIGOXIN', 'I', 0.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76688, 6731, 'DIGOXIN', 'I', 0.0625, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82129, 6731, 'DIGOXIN', 'I', 0.0625, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82130, 6731, 'DIGOXIN', 'I', 0.125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82131, 6731, 'DIGOXIN', 'I', 0.250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15757, 6731, 'DIGOXIN', 'I', 0.25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIGOXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15756, 6731, 'DIGOXIN', 'I', 0.05, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIGOXIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66031, 6731, 'DIGOXIN', 'I', 0.05, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44051, 1327, 'GLICLAZIDE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLICLAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10918, 1327, 'GLICLAZIDE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: GLICLAZIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47424, 1327, 'GLICLAZIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61497, 1327, 'GLICLAZIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66827, 1327, 'GLICLAZIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69269, 1327, 'GLICLAZIDE', 'I', 80, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72804, 1327, 'GLICLAZIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77975, 1327, 'GLICLAZIDE', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78313, 1327, 'GLICLAZIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84157, 1327, 'GLICLAZIDE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44191, 11259, 'CEPHAPIRIN (CEPHAPIRIN BENZATHINE)', 'I', 300, 'MG', '', '10', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CEPHAPIRIN ((AS CEPHAPIRIN BENZATHINE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44192, 11259, 'CEPHAPIRIN (CEPHAPIRIN SODIUM)', 'I', 200, 'MG', '', '10', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CEPHAPIRIN ((AS CEPHAPIRIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61025, 11259, 'CEPHAPIRIN (CEPHAPIRIN BENZATHINE)', 'I', 500, 'MG', '', '19', 'N', 'G', '19GM SYRINGE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18999, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19000, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19001, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9126, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9347, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9348, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8057, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8058, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8059, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7442, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7443, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7444, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7391, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7392, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7393, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64798, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64799, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64800, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8118, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8566, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 10, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (316, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HYDROXYZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50516, 8008, 'HYDROXYZINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3330, 11217, 'FLUNIXIN (FLUNIXIN MEGLUMINE)', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FLUXAMINE MEGLUMINE ((FLUNIXIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49911, 11217, 'FLUNIXIN (FLUNIXIN MEGLUMINE)', 'I', 50, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (54227, 11217, 'FLUNIXIN (FLUNIXIN MEGLUMINE)', 'I', 50, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62605, 11217, 'FLUNIXIN (FLUNIXIN MEGLUMINE)', 'I', 50, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64080, 11217, 'FLUNIXIN (FLUNIXIN MEGLUMINE)', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73176, 11217, 'FLUNIXIN (FLUNIXIN MEGLUMINE)', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81673, 11217, 'FLUNIXIN (FLUNIXIN MEGLUMINE)', 'I', 16.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20239, 2370, 'CARBIDOPA', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBIDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20189, 2370, 'CARBIDOPA', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBIDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20190, 2370, 'CARBIDOPA', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBIDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19758, 2370, 'CARBIDOPA', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBIDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19766, 2370, 'CARBIDOPA', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBIDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19767, 2370, 'CARBIDOPA', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBIDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14082, 2370, 'CARBIDOPA', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBIDOPA Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11481, 2370, 'CARBIDOPA', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBIDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4008, 2370, 'CARBIDOPA', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBIDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3331, 2370, 'CARBIDOPA', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBIDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2142, 2370, 'CARBIDOPA', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBIDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68470, 2370, 'CARBIDOPA', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBIDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68471, 2370, 'CARBIDOPA', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBIDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68472, 2370, 'CARBIDOPA', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBIDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69226, 2370, 'CARBIDOPA', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71866, 2370, 'CARBIDOPA', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBIDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75839, 2370, 'CARBIDOPA', 'I', 25, 'MG', '', '', 'N', '', 'CARBIDOPA USP 27 MG USED THAT IS EQUIVALENT TO 25 MG CARBIDOPA ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82347, 2370, 'CARBIDOPA', 'I', 18.75, 'MG', '', '', 'N', '', 'CARBIDOPA MONOHYDRATE 20.25 MG/TAB.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82348, 2370, 'CARBIDOPA', 'I', 31.25, 'MG', '', '', 'N', '', 'CARBIDOPA MONOHYDRATE 33.8 MG/TAB.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79150, 2370, 'CARBIDOPA', 'I', 12.5, 'MG', '', '', 'N', '', 'CARBIDOPA MONOHYDRATE 13.5 MG PER TAB.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79151, 2370, 'CARBIDOPA', 'I', 25, 'MG', '', '', 'N', '', 'CARBIDOPA MONOHYDRATE 27MG PER TAB.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79152, 2370, 'CARBIDOPA', 'I', 37.5, 'MG', '', '', 'N', '', 'CARBIDOPA MONOHYDRATE 40.5 MG/TAB.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79676, 2370, 'CARBIDOPA', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77753, 2370, 'CARBIDOPA (CARBIDOPA MONOHYDRATE)', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77283, 20022, 'DEFERASIROX', 'I', 125.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77284, 20022, 'DEFERASIROX', 'I', 250.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77285, 20022, 'DEFERASIROX', 'I', 500.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43987, 8199, 'SULFADIAZINE (SULFADIAZINE SODIUM)', 'I', 400, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: SULFADIAZINE ((AS SODIUM SULFADIAZINE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43988, 8199, 'SULFADIAZINE (SULFADIAZINE SODIUM)', 'I', 200, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: SULFADIAZINE ((AS SODIUM SULFADIAZINE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43986, 8199, 'SULFADIAZINE', 'I', 333.3, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: SULFADIAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65007, 8199, 'SULFADIAZINE', 'I', 333, 'MG', '', '', 'Y', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80624, 8199, 'SULFADIAZINE', 'I', 333, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3884, 2239, 'DODICIN', 'I', 0.4, '%', '', '', 'N', '', 'Historic Freeform Text: DODICINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74044, 541, 'SOFT WAX (PETROLATUM)', 'I', 274, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81380, 2134, 'OXANTEL PAMOATE', 'I', 111.8, 'MG', '', '', 'N', '', 'OXANTEL PAMOATE 111.8MG (40MG BASE) PER TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81381, 2134, 'OXANTEL PAMOATE', 'I', 559.0, 'MG', '', '', 'N', '', 'OXANTEL PAMOATE 559.0MG (200MG BASE) PER TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81382, 2134, 'OXANTEL PAMOATE', 'I', 1397.5, 'MG', '', '', 'N', '', 'OXANTEL PAMOATE 1397.5MG (500MG BASE) PER TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2014, 9368, 'DIPYRONE', 'I', 50, '%', '', '', 'N', '%', 'Historic Freeform Text: DIPYRONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11172, 8450, 'AMPICILLIN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMPICILLIN ((AS TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11173, 8450, 'AMPICILLIN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMPICILLIN ((AS TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5595, 8450, 'AMPICILLIN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMPICILLIN ((TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5596, 8450, 'AMPICILLIN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMPICILLIN ((TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1124, 8450, 'AMPICILLIN', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMPICILLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1125, 8450, 'AMPICILLIN', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMPICILLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37491, 8450, 'AMPICILLIN (AMPICILLIN SODIUM)', 'I', 2, 'G', '', '', 'Y', 'VIAL', 'Historic Freeform Text: AMPICILLIN ((AS AMPICILLIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37492, 8450, 'AMPICILLIN (AMPICILLIN SODIUM)', 'I', 1, 'G', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: AMPICILLIN ((AS AMPICILLIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11825, 8450, 'AMPICILLIN (AMPICILLIN TRIHYDRATE)', 'I', 25, 'G', '', '', 'N', 'VIAL', 'AMPICILLIN (AS AMPICILLIN TRIHYDRATE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10510, 8450, 'AMPICILLIN (AMPICILLIN TRIHYDRATE)', 'I', 10, 'G', '', '', 'N', 'VIAL', 'AMPICILLIN (AS AMPICILLIN TRIHYDRATE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12267, 8450, 'AMPICILLIN (AMPICILLIN SODIUM)', 'I', 1, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: AMPICILLIN SODIUM ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12268, 8450, 'AMPICILLIN (AMPICILLIN SODIUM)', 'I', 2, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: AMPICILLIN SODIUM ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37493, 8450, 'AMPICILLIN (AMPICILLIN SODIUM)', 'I', 500, 'MG', '', '', 'Y', 'VIAL', 'Historic Freeform Text: AMPICILLIN ((AS AMPICILLIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37494, 8450, 'AMPICILLIN (AMPICILLIN SODIUM)', 'I', 250, 'MG', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: AMPICILLIN ((AS AMPICILLIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16990, 8450, 'AMPICILLIN (AMPICILLIN SODIUM)', 'I', 250, 'MG', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: AMPICILLIN ((AS AMPICILLIN SODIUM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12261, 8450, 'AMPICILLIN (AMPICILLIN SODIUM)', 'I', 250, 'MG', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: AMPICILLIN SOD ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12262, 8450, 'AMPICILLIN (AMPICILLIN SODIUM)', 'I', 500, 'MG', '', '', 'Y', 'VIAL', 'Historic Freeform Text: AMPICILLIN SOD ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11170, 8450, 'AMPICILLIN', 'I', 250, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: AMPICILLIN ((AS TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11171, 8450, 'AMPICILLIN', 'I', 125, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: AMPICILLIN ((AS TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5827, 8450, 'AMPICILLIN', 'I', 125, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: AMPICILLIN ((TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5828, 8450, 'AMPICILLIN', 'I', 250, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: AMPICILLIN ((TRIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1270, 8450, 'AMPICILLIN', 'I', 500, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: AMPICILLIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8203, 1923, 'TRIFLURIDINE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: TRIFLURIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72882, 1923, 'TRIFLURIDINE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43244, 1262, 'TERAZOSIN HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: TERAZOSIN HCL ((AS DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43245, 1262, 'TERAZOSIN HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: TERAZOSIN HCL ((AS DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43246, 1262, 'TERAZOSIN HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: TERAZOSIN HCL ((AS DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43247, 1262, 'TERAZOSIN HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: TERAZOSIN HCL ((AS DIHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12778, 1262, 'TERAZOSIN HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TERAZOSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9618, 1262, 'TERAZOSIN HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: TERAZOSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9619, 1262, 'TERAZOSIN HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TERAZOSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9542, 1262, 'TERAZOSIN HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: TERAZOSINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16734, 9751, 'HEXACHLOROPHENE', 'I', 3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HEXACHLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61027, 1838, 'NORFLOXACIN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65123, 1838, 'NORFLOXACIN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70783, 1838, 'NORFLOXACIN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75498, 1838, 'NORFLOXACIN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78683, 1838, 'NORFLOXACIN', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5674, 8411, 'CLOXACILLIN SODIUM', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOXACILLIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5673, 8411, 'CLOXACILLIN SODIUM', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOXACILLIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13134, 8411, 'CLOXACILLIN SODIUM', 'I', 1, 'G', '', '', 'N', 'VIAL', 'Historic Freeform Text: CLOXACILLIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12434, 8411, 'CLOXACILLIN SODIUM', 'I', 2, 'G', '', '', 'N', 'VIAL', 'Historic Freeform Text: CLOXACILLIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12435, 8411, 'CLOXACILLIN SODIUM', 'I', 500, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: CLOXACILLIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6424, 8411, 'CLOXACILLIN SODIUM', 'I', 125, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: CLOXACILLIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3794, 8411, 'CLOXACILLIN SODIUM', 'I', 125, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CLOXACILLIN SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18969, 7943, 'MOCLOBEMIDE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: MOCLOBEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13256, 7943, 'MOCLOBEMIDE', 'I', 150, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MOCLOBEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51594, 7943, 'MOCLOBEMIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51595, 7943, 'MOCLOBEMIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60426, 7943, 'MOCLOBEMIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60425, 7943, 'MOCLOBEMIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64019, 7943, 'MOCLOBEMIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63228, 7943, 'MOCLOBEMIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63229, 7943, 'MOCLOBEMIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63230, 7943, 'MOCLOBEMIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67255, 7943, 'MOCLOBEMIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67256, 7943, 'MOCLOBEMIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67101, 7943, 'MOCLOBEMIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67102, 7943, 'MOCLOBEMIDE', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6770, 8249, 'THIOPENTAL SODIUM', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: THIOPENTAL SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18250, 8249, 'THIOPENTAL SODIUM', 'I', 5, 'G', '', '', 'N', 'VIAL', 'Historic Freeform Text: THIOPENTAL SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (224, 8249, 'THIOPENTAL SODIUM', 'I', 1, 'G', '', '', 'N', 'VIAL', 'Historic Freeform Text: THIOPENTAL SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67249, 8249, 'THIOPENTAL SODIUM', 'I', 1, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: THIOPENTAL SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6771, 8249, 'THIOPENTAL SODIUM', 'I', 250, 'MG', '', '', 'N', 'SYR', 'Historic Freeform Text: THIOPENTAL SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8600, 8249, 'THIOPENTAL SODIUM', 'I', 25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: THIOPENTAL SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2315, 8249, 'THIOPENTAL SODIUM', 'I', 5, 'G', '', '', 'N', 'BOTTLE', 'Historic Freeform Text: THIOPENTAL SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5698, 8132, 'SULFATHIAZOLE (SULFATHIAZOLE SODIUM)', 'I', 1, 'G', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SULFATHIAZOLE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1616, 8132, 'SULFATHIAZOLE', 'I', 5.85, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFATHIAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2006, 8132, 'SULFATHIAZOLE', 'I', 5.85, 'G', '', '', 'N', '', 'Historic Freeform Text: SULFATHIAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2005, 8132, 'SULFATHIAZOLE', 'I', 668.85, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFATHIAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1343, 8132, 'SULFATHIAZOLE', 'I', 320, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFATHIAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1612, 8132, 'SULFATHIAZOLE', 'I', 668.85, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFATHIAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2046, 8132, 'SULFATHIAZOLE', 'I', 320, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFATHIAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2181, 8132, 'SULFATHIAZOLE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: SULFATHIAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12797, 8132, 'SULFATHIAZOLE', 'I', 26.4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFATHIAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3404, 8132, 'SULFATHIAZOLE', 'I', 26.4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFATHIAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2262, 8132, 'SULFATHIAZOLE', 'I', 45, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFATHIAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63847, 8132, 'SULFATHIAZOLE', 'I', 45, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SULFATHIAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3830, 8132, 'SULFATHIAZOLE', 'I', 38.8, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SULFATHIAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3773, 8132, 'SULFATHIAZOLE', 'I', 38.8, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: SULFATHIAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78561, 20163, 'PALIPERIDONE', 'I', 9, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16733, 5776, 'PRILOCAINE', 'I', 2.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PRILOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81134, 5776, 'PRILOCAINE', 'I', 2.5, '%', '', '', 'N', '', 'Historic Freeform Text: PRILOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11440, 5776, 'PRILOCAINE', 'I', 25, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PRILOCAINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 939, 'L-VALINE', 'I', 212, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20278, 939, 'L-VALINE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20279, 939, 'L-VALINE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20276, 939, 'L-VALINE', 'I', 246.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19306, 939, 'L-VALINE', 'I', 750, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19610, 939, 'L-VALINE', 'I', 230, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20303, 939, 'L-VALINE', 'I', 246.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20302, 939, 'L-VALINE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20292, 939, 'L-VALINE', 'I', 246.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20291, 939, 'L-VALINE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20290, 939, 'L-VALINE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20289, 939, 'L-VALINE', 'I', 246.5, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20288, 939, 'L-VALINE', 'I', 145, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20282, 939, 'L-VALINE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20281, 939, 'L-VALINE', 'I', 290, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18729, 939, 'L-VALINE', 'I', 212, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18727, 939, 'L-VALINE', 'I', 212, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18703, 939, 'L-VALINE', 'I', 175, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18702, 939, 'L-VALINE', 'I', 212, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 939, 'L-VALINE', 'I', 212, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19143, 939, 'L-VALINE', 'I', 230, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 939, 'L-VALINE', 'I', 175, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18699, 939, 'L-VALINE', 'I', 230, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18698, 939, 'L-VALINE', 'I', 175, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18697, 939, 'L-VALINE', 'I', 212, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18646, 939, 'L-VALINE', 'I', 452, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18644, 939, 'L-VALINE', 'I', 500, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18645, 939, 'L-VALINE', 'I', 175, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18628, 939, 'L-VALINE', 'I', 500, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18608, 939, 'L-VALINE', 'I', 350, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18607, 939, 'L-VALINE', 'I', 425, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18606, 939, 'L-VALINE', 'I', 673, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18550, 939, 'L-VALINE', 'I', 230, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 939, 'L-VALINE', 'I', 230, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14077, 939, 'L-VALINE', 'I', 230, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 939, 'L-VALINE', 'I', 230, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 939, 'L-VALINE', 'I', 230, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14073, 939, 'L-VALINE', 'I', 195, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 939, 'L-VALINE', 'I', 195, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14071, 939, 'L-VALINE', 'I', 195, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 939, 'L-VALINE', 'I', 115, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14067, 939, 'L-VALINE', 'I', 230, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 939, 'L-VALINE', 'I', 230, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 939, 'L-VALINE', 'I', 195, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5890, 939, 'L-VALINE', 'I', 680, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3468, 939, 'L-VALINE', 'I', 800, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4560, 939, 'L-VALINE', 'I', 560, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2776, 939, 'L-VALINE', 'I', 400, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: VALINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60165, 939, 'L-VALINE', 'I', 760, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 939, 'L-VALINE', 'I', 1.62, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 939, 'L-VALINE', 'I', 2.83, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 939, 'L-VALINE', 'I', 3.64, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83780, 939, 'L-VALINE', 'I', 3.64, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43080, 8344, 'CEFTAZIDIME (CEFTAZIDIME PENTAHYDRATE)', 'I', 1, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: CEFTAZIDIME ((AS PENTAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43081, 8344, 'CEFTAZIDIME (CEFTAZIDIME PENTAHYDRATE)', 'I', 2, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: CEFTAZIDIME ((AS PENTAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43082, 8344, 'CEFTAZIDIME (CEFTAZIDIME PENTAHYDRATE)', 'I', 6, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: CEFTAZIDIME ((AS PENTAHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11371, 8344, 'CEFTAZIDIME', 'I', 6, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11372, 8344, 'CEFTAZIDIME', 'I', 2, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11370, 8344, 'CEFTAZIDIME', 'I', 1, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75762, 16516, 'EMTRICITABINE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76043, 16516, 'EMTRICITABINE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78602, 16516, 'EMTRICITABINE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76057, 17368, 'TROSPIUM CHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82529, 17368, 'TROSPIUM CHLORIDE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76603, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 3.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76604, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 3.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77476, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78218, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 0.75, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78220, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78221, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 3, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77122, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77123, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78154, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77383, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 2.00, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78156, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 0.75, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78656, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 1.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78813, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 2.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78893, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78894, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78895, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 4.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78604, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 3.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78646, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79098, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 4.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76605, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 3.00, '%', '', '', 'N', 'W/W', '(MEXORYL XL)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81654, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82930, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 0.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82931, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80435, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81660, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 1.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81661, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80393, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82270, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80383, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79784, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84715, 19130, 'DROMETRIZOLE TRISILOXANE', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78159, 20139, 'OXALIPLATIN', 'I', 50, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78160, 20139, 'OXALIPLATIN', 'I', 100, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78161, 20139, 'OXALIPLATIN', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79016, 20185, 'LENALIDOMIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79017, 20185, 'LENALIDOMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80322, 20185, 'LENALIDOMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80324, 20185, 'LENALIDOMIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75871, 17051, 'DARIFENACIN (DARIFENACIN HYDROBROMIDE)', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75872, 17051, 'DARIFENACIN (DARIFENACIN HYDROBROMIDE)', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76882, 19707, 'RECOMBINANT HUMAN PAPILLOMAVIRUS TYPE 6 L1 PROTEIN', 'I', 20, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76882, 19708, 'RECOMBINANT HUMAN PAPILLOMAVIRUS TYPE 11 L1 PROTEIN', 'I', 40, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76882, 19709, 'RECOMBINANT HUMAN PAPILLOMAVIRUS TYPE 16 L1 PROTEIN', 'I', 40, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82773, 19709, 'RECOMBINANT HUMAN PAPILLOMAVIRUS TYPE 16 L1 PROTEIN', 'I', 20, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76882, 19710, 'RECOMBINANT HUMAN PAPILLOMAVIRUS TYPE 18 L1 PROTEIN', 'I', 20, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82773, 19710, 'RECOMBINANT HUMAN PAPILLOMAVIRUS TYPE 18 L1 PROTEIN', 'I', 20, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80860, 5656, 'CALCIUM PROPIONATE', 'I', 200, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26536, 5656, 'CALCIUM PROPIONATE', 'I', 30, 'G', '', '95', 'N', 'G', 'Historic Freeform Text: CALCIUM PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10527, 5656, 'CALCIUM PROPIONATE', 'I', 1.75, 'G', '', '75', 'N', 'G', 'Historic Freeform Text: CALCIUM PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11889, 5656, 'CALCIUM PROPIONATE', 'I', 30, 'G', '', '95', 'N', 'G', 'Historic Freeform Text: CALCIUM PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1765, 5656, 'CALCIUM PROPIONATE', 'I', 320.0, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: CALCIUM PROPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51745, 1880, 'ETODOLAC', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51746, 1880, 'ETODOLAC', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66748, 1880, 'ETODOLAC', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66749, 1880, 'ETODOLAC', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11167, 10295, 'METHYLDOPA', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11168, 10295, 'METHYLDOPA', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11169, 10295, 'METHYLDOPA', 'I', 125, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5862, 10295, 'METHYLDOPA', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5820, 10295, 'METHYLDOPA', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5821, 10295, 'METHYLDOPA', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6163, 10295, 'METHYLDOPA', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2470, 10295, 'METHYLDOPA', 'I', 125, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2471, 10295, 'METHYLDOPA', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2909, 10295, 'METHYLDOPA', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2251, 10295, 'METHYLDOPA', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2232, 10295, 'METHYLDOPA', 'I', 125, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2188, 10295, 'METHYLDOPA', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: METHYLDOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6675, 1972, 'PHENOXYISOPROPANOL', 'I', 0.84, '%', '', '', 'N', '', 'Historic Freeform Text: PHENOXYISOPROPANOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83587, 10075, 'FENTANYL (FENTANYL CITRATE)', 'I', 200, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FENTANYL CITRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83588, 10075, 'FENTANYL (FENTANYL CITRATE)', 'I', 400, 'µG', '', '', 'N', '', 'Historic Freeform Text: FENTANYL CITRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83589, 10075, 'FENTANYL (FENTANYL CITRATE)', 'I', 600, 'µG', '', '', 'N', '', 'Historic Freeform Text: FENTANYL CITRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83590, 10075, 'FENTANYL (FENTANYL CITRATE)', 'I', 800, 'µG', '', '', 'N', '', 'Historic Freeform Text: FENTANYL CITRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83591, 10075, 'FENTANYL (FENTANYL CITRATE)', 'I', 1200, 'µG', '', '', 'N', '', 'Historic Freeform Text: FENTANYL CITRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84910, 10075, 'FENTANYL (FENTANYL CITRATE)', 'I', 100, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84911, 10075, 'FENTANYL (FENTANYL CITRATE)', 'I', 200, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84912, 10075, 'FENTANYL (FENTANYL CITRATE)', 'I', 300, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84913, 10075, 'FENTANYL (FENTANYL CITRATE)', 'I', 400, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84914, 10075, 'FENTANYL (FENTANYL CITRATE)', 'I', 600, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84915, 10075, 'FENTANYL (FENTANYL CITRATE)', 'I', 800, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76148, 10075, 'FENTANYL', 'I', 25, 'µG', '', '', 'N', 'HOUR', '2009.09.25. STRENGTH EXPRESSED IN MCG PER HOUR FOR CONSISTENCY WITH OTHER FENTANYL TRANSDERMAL PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76149, 10075, 'FENTANYL', 'I', 50, 'µG', '', '', 'N', 'HOUR', '2009.09.25. STRENGTH EXPRESSED IN MCG PER HOUR FOR CONSISTENCY WITH OTHER FENTANYL TRANSDERMAL PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76150, 10075, 'FENTANYL', 'I', 75, 'µG', '', '', 'N', 'HOUR', '2009.09.25. STRENGTH EXPRESSED IN MCG PER HOUR FOR CONSISTENCY WITH OTHER FENTANYL TRANSDERMAL PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76857, 10075, 'FENTANYL', 'I', 25, 'µG', '', '', 'N', 'HOUR', 'DELIVERING 25MCG/H FENTANYL RESPECTIVELY FOR 72 HOURS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76858, 10075, 'FENTANYL', 'I', 50, 'µG', '', '', 'N', 'HOUR', 'DELIVERING 50MCG/H FENTANYL RESPECTIVELY FOR 72 HOURS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76859, 10075, 'FENTANYL', 'I', 75, 'µG', '', '', 'N', 'HOUR', 'DELIVERING 75MCG/H FENTANYL RESPECTIVELY FOR 72 HOURS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76860, 10075, 'FENTANYL', 'I', 100, 'µG', '', '', 'N', 'HOUR', 'DELIVERING 100MCG/H FENTANYL RESPECTIVELY FOR 72 HOURS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76151, 10075, 'FENTANYL', 'I', 100, 'µG', '', '', 'N', 'HOUR', '2009.09.25. STRENGTH EXPRESSED IN MCG PER HOUR FOR CONSISTENCY WITH OTHER FENTANYL TRANSDERMAL PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81986, 10075, 'FENTANYL', 'I', 12.0, 'µG', '', '', 'N', 'HOUR', '12MCG/HOUR FOR 72 HOURS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79746, 10075, 'FENTANYL', 'I', 12, 'µG', '', '', 'N', 'HOUR', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82689, 10075, 'FENTANYL', 'I', 12, 'µG', '', '', 'N', 'HOUR', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82690, 10075, 'FENTANYL', 'I', 25, 'µG', '', '', 'N', 'HOUR', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82691, 10075, 'FENTANYL', 'I', 50, 'µG', '', '', 'N', 'HOUR', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82692, 10075, 'FENTANYL', 'I', 75, 'µG', '', '', 'N', 'HOUR', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82693, 10075, 'FENTANYL', 'I', 100, 'µG', '', '', 'N', 'HOUR', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80018, 10075, 'FENTANYL', 'I', 25, 'µG', '', '', 'N', 'HOUR', '2.76MG/PATCH 25MCG/HR FOR 72 HRS./JJ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80019, 10075, 'FENTANYL', 'I', 50, 'µG', '', '', 'N', 'HOUR', '5.52MG/PATCH 50MCG/HR FOR 72 HRS./JJ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80020, 10075, 'FENTANYL', 'I', 75, 'µG', '', '', 'N', 'HOUR', '8.28MG/PATCH 75MCG/HR FOR 72 HRS./JJ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80021, 10075, 'FENTANYL', 'I', 100, 'µG', '', '', 'N', 'HOUR', '11.04MG/PATCH 100MCG/HR FOR 72 HRS./JJ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81586, 10075, 'FENTANYL', 'I', 12, 'µG', '', '', 'N', 'HOUR', 'FENTANYL CONTENT IN 5.25 SQUARE CM: 2.1 MG.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81587, 10075, 'FENTANYL', 'I', 25, 'µG', '', '', 'N', 'HOUR', 'FENTANYL CONTENT IN 10.5 SQUARE CM: 4.2 MG.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81588, 10075, 'FENTANYL', 'I', 50, 'µG', '', '', 'N', 'HOUR', 'FENTANYL CONTENT IN 21 SQUARE CM: 8.4 MG.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81589, 10075, 'FENTANYL', 'I', 75, 'µG', '', '', 'N', 'HOUR', 'FENTANYL CONTENT IN 31.5 SQUARE CM: 12.6 MG.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81590, 10075, 'FENTANYL', 'I', 100, 'µG', '', '', 'N', 'HOUR', 'FENTANYL CONTENT IN 42 SQUARE CM: 16.8 MG.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81243, 10075, 'FENTANYL', 'I', 12, 'µG', '', '', 'N', 'HOUR', 'FENTANYL CONTENT IN 5.25 SQUARE CM: 2.1 MG.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81244, 10075, 'FENTANYL', 'I', 25, 'µG', '', '', 'N', 'HOUR', 'FENTANYL CONTENT IN 10.5 SQUARE CM: 4.2 MG.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81245, 10075, 'FENTANYL', 'I', 37, 'µG', '', '', 'N', 'HOUR', 'FENTANYL CONTENT IN 15.75 SQUARE CM: 6.3 MG.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81246, 10075, 'FENTANYL', 'I', 50, 'µG', '', '', 'N', 'HOUR', 'FENTANYL CONTENT IN 21 SQUARE CM: 8.4 MG.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81247, 10075, 'FENTANYL', 'I', 75, 'µG', '', '', 'N', 'HOUR', 'FENTANYL CONTENT IN 31.5 SQUARE CM: 12.6 MG.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81248, 10075, 'FENTANYL', 'I', 100, 'µG', '', '', 'N', 'HOUR', 'FENTANYL CONTENT IN 42 SQUARE CM: 16.8 MG.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12664, 10075, 'FENTANYL (FENTANYL CITRATE)', 'I', 50, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: FENTANYL CITRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63983, 10075, 'FENTANYL (FENTANYL CITRATE)', 'I', 50, 'µG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 1362, 'DL-ISOLEUCINE', 'I', 0.02, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DL-ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4894, 10278, 'OXTRIPHYLLINE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXTRIPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4895, 10278, 'OXTRIPHYLLINE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXTRIPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4898, 10278, 'OXTRIPHYLLINE', 'I', 300, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXTRIPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20293, 10278, 'OXTRIPHYLLINE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHOLINE THEOPHYLLINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12803, 10278, 'OXTRIPHYLLINE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHOLINE THEOPHYLLINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4258, 10278, 'OXTRIPHYLLINE', 'I', 100, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: OXTRIPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3966, 10278, 'OXTRIPHYLLINE', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: OXTRIPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18005, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', '', 'Historic Freeform Text: SERTRALINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13392, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', 'Historic Freeform Text: SERTRALINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12662, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', 'Historic Freeform Text: SERTRALINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61676, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61677, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61678, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64051, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64054, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64055, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64918, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 25.0, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64919, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 50.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64920, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 100.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66267, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66268, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66269, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68828, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68829, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68830, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69170, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69172, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69174, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69940, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69941, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69942, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69856, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69857, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69858, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69900, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69901, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69902, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71283, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71284, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71285, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72848, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72849, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72850, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75917, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', 'Historic Freeform Text: SERTRALINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75918, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'Y', '', 'Historic Freeform Text: SERTRALINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77280, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77281, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77282, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78908, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78910, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78911, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83874, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83875, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83876, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75916, 11168, 'SERTRALINE (SERTRALINE HYDROCHLORIDE)', 'I', 25, 'MG', '', '', 'Y', 'CAP', 'Historic Freeform Text: SERTRALINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18754, 7490, 'LEVONORGESTREL', 'I', 150, 'µG', '', '', 'N', '', 'Historic Freeform Text: LEVONORGESTREL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18755, 7490, 'LEVONORGESTREL', 'I', 150, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LEVONORGESTREL WHITE TABS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8123, 7490, 'LEVONORGESTREL', 'I', 125, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LEVONORGESTREL ((OCHREOUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8124, 7490, 'LEVONORGESTREL', 'I', 50, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LEVONORGESTREL ((LIGHT BRN))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8124, 7490, 'LEVONORGESTREL', 'I', 75, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LEVONORGESTREL ((WHITE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8124, 7490, 'LEVONORGESTREL', 'I', 125, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LEVONORGESTREL ((OCHREOUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8123, 7490, 'LEVONORGESTREL', 'I', 50, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LEVONORGESTREL ((LIGHT BRN))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8123, 7490, 'LEVONORGESTREL', 'I', 75, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LEVONORGESTREL ((WHITE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60269, 7490, 'LEVONORGESTREL', 'I', 100, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60270, 7490, 'LEVONORGESTREL', 'I', 100, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78383, 7490, 'LEVONORGESTREL', 'I', 100, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78384, 7490, 'LEVONORGESTREL', 'I', 100, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65334, 7490, 'LEVONORGESTREL', 'I', 0.75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66845, 7490, 'LEVONORGESTREL', 'I', 52, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73542, 7490, 'LEVONORGESTREL', 'I', 1.39, 'MG', '', '', 'N', '', 'PROVIDES CONTROLLED DELIVERY OF 0.015MG/DAY');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78129, 7490, 'LEVONORGESTREL', 'I', 0.15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78130, 7490, 'LEVONORGESTREL', 'I', 0.15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77107, 7490, 'LEVONORGESTREL', 'I', 0.75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78201, 7490, 'LEVONORGESTREL', 'I', 0.15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83160, 7490, 'LEVONORGESTREL', 'I', 0.15, 'MG', '', '', 'N', '', 'LIGHT BLUE TABLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84978, 7490, 'LEVONORGESTREL', 'I', 0.75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46718, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16473, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10947, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11337, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63871, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72122, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72123, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72126, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72128, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72129, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71463, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71464, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71465, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71466, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70769, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70770, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70771, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70772, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71540, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71541, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71542, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71543, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71544, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70934, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71245, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71246, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71247, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71248, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71249, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71302, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71303, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71304, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71305, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71306, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71307, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71310, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71311, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71312, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71313, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73865, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73866, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73867, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73868, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73869, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73870, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73871, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73872, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73873, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75133, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75134, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75135, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76721, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76722, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76723, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76724, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76725, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76728, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76729, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76730, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76731, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76732, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75463, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75464, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75465, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75466, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75467, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72430, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72429, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72431, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72432, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72433, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73495, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73496, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73497, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73498, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73499, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73750, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73751, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73752, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73753, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73754, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73864, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77028, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77029, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77030, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77031, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77032, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78626, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78627, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78628, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78630, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78632, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82862, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82863, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82864, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82861, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82865, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81676, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81677, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81678, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81679, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81680, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81483, 1221, 'SIMVASTATIN', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81484, 1221, 'SIMVASTATIN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81485, 1221, 'SIMVASTATIN', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81486, 1221, 'SIMVASTATIN', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81487, 1221, 'SIMVASTATIN', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53282, 17119, 'FIBRINOGEN (HUMAN)', 'I', 110, 'MG', '', '1', 'N', 'ML', 'FIBRINOGEN 70 - 110MG PER KIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53284, 17119, 'FIBRINOGEN (HUMAN)', 'I', 550, 'MG', '', '5', 'N', 'ML', 'FIBRINOGEN 350 - 550MG PER KIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78184, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83385, 17119, 'FIBRINOGEN (HUMAN)', 'I', 90, 'MG', '', '', 'N', 'ML', 'COMPONENT 1 HUMAN CLOTTABLE FIBRINOGEN: 50-90 MG/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76292, 18175, 'SOLIFENACIN SUCCINATE', 'I', 5, 'MG', '', '', 'N', '', 'EQUIVALENT TO SOLIFENACIN 3.8MG.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76293, 18175, 'SOLIFENACIN SUCCINATE', 'I', 10, 'MG', '', '', 'N', '', 'EQUIVALENT TO SOLIFENACIN 7.5 MG.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48212, 20143, 'DIPYRONE MONOHYDRATE', 'I', 50, '%', '', '', 'N', 'W/V', '.H20');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5957, 20143, 'DIPYRONE MONOHYDRATE', 'I', 500, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DIPYRONE REVISED TO DIPYRONE MONOHYDRATE FROM DIPYRONE AS REQUESTED BY VDD (');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (231, 6991, 'GAMBIR', 'I', 29.25, 'MG', '', '2.9', 'N', 'G', 'Historic Freeform Text: GAMBIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46352, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44478, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (45490, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41219, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41220, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41221, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37812, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34197, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (29437, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (29438, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (29436, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25675, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21701, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19411, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL DIMETHYL ETHYL BENZYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19346, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20341, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19504, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18892, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17969, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 3.15, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18799, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18782, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18771, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18329, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.09, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19113, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18900, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17241, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17242, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17243, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16773, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15830, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16719, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16720, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16238, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.125, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16184, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.09, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15690, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15557, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15507, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15508, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1.43, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14705, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13705, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.115, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13656, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.115, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14632, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14617, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13553, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13394, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13373, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13352, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13868, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14321, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14211, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14213, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14215, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10490, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10491, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10471, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10425, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10429, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11066, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12289, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.125, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12255, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.125, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11453, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12556, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11431, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8428, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8429, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9224, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.08, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9223, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8354, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1.28, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8606, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10010, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8044, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8045, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8046, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7139, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7071, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6535, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7041, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7022, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6466, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6469, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6464, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6465, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7457, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5699, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.35, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6268, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6263, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 3.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7322, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1.29, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7320, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6667, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 3.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6666, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3824, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3826, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4199, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1.75, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4200, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.35, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3619, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3592, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3594, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.85, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5240, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4612, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3471, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3470, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5088, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3924, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4494, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3307, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2545, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1.75, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2298, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2932, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 3.12, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2196, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48111, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49187, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49430, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50061, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50646, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.84, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50866, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'ALSO CALLED:  N-ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51889, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53825, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62048, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.44, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61358, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61471, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1, '%', '', '', 'N', '', '(40%C12, 50% C14, 10% C16)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60867, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61030, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62389, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62391, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63262, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64703, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62730, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64461, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67128, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65738, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67182, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65270, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.106, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65846, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66387, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.125, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64771, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 7.95, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64770, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 7.95, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65998, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.86, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66666, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64939, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66126, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65628, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.106, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65645, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68306, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68862, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68930, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68931, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67324, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67373, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67389, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.125, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67406, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67435, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67464, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67597, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67640, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69936, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70067, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70765, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72292, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72294, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72295, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70135, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70143, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70144, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70805, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70804, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71528, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71597, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71598, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70165, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.115, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70197, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70199, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69698, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69699, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70392, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.145, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70410, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70433, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.11, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70460, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71966, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71987, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70599, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75171, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.024, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76460, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76479, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.0240, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76537, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72822, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72823, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72834, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.11, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72860, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75223, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.74, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75231, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76592, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72930, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72931, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74028, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 6.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74065, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74069, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.15, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74338, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74344, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75554, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75555, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72428, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75729, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72572, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72493, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72494, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72496, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72497, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72614, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72615, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.11, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73297, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73358, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.175, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74753, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.09, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74808, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73631, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73675, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.125, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76314, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.11, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76315, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.11, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73723, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73722, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73726, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73838, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77369, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77370, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78416, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78430, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77307, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77126, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77546, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77547, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77801, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77802, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77829, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77845, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77869, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77870, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77871, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77382, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.00, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78183, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81685, 932, 'RAMIPRIL', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77175, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78260, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77591, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77649, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.37, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78326, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76819, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77965, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.1375, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77966, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.1375, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81582, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82831, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82279, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78729, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78730, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82833, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79876, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80991, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.115, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81854, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83037, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78563, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.85, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79842, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79844, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80719, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78918, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.37, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80171, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82556, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80303, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80305, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80458, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79860, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81121, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.025, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81653, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81844, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81845, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.59, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80495, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.145, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82428, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81305, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81992, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81995, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80336, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82417, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80541, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80464, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80630, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82544, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79832, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82115, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82120, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83084, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83511, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83623, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83682, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83946, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.125, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83957, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83962, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84220, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84223, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', '', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84358, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84366, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 7.95, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84373, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.14, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84440, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1.6, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84554, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84566, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84768, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85170, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 5.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14193, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81274, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81277, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82413, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82414, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80990, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 2.25, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80403, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79976, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79901, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81686, 932, 'RAMIPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81013, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81014, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81303, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82416, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.145, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80465, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.8, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82548, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.105, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84145, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85444, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80304, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', 'W/V', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83956, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.154, '%', '', '', 'N', 'W/V', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18082, 196, 'ALKYL DIMETHYL ETHYLBENZYL AMMONIUM CHLORIDE', 'I', 0.05, '%', '', '', 'N', '%', 'Historic Freeform Text: ALKYL ETHYLBENZYL DIMETHYL AMMONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3926, 20188, 'SULFATHIAZOLE SODIUM PENTAHYDRATE', 'I', 136.3, 'G', '', '450', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 9085, 'CHLOROQUINALDOL', 'I', 0.08, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS QUINOLINE MIX 0.154MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16824, 4601, 'ESTROPIPATE', 'I', 0.75, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: ESTROPIPATE (CALC.AS.625MG NA ESTR.SULPH.)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16827, 4601, 'ESTROPIPATE', 'I', 3.0, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: ESTROPIPATE (CALC.AS NA ESTR.SULP.2.5MG)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16816, 4601, 'ESTROPIPATE', 'I', 1.5, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: ESTROPIPATE (CALC.AS NA ESTR.SULP.1.25MG)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2047, 9929, 'ISOLEUCINE', 'I', 515, 'MG', '', '', 'N', '', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43947, 9929, 'ISOLEUCINE', 'I', 1.08, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44068, 9929, 'ISOLEUCINE', 'I', 590, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15493, 9929, 'ISOLEUCINE', 'I', 560, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11329, 9929, 'ISOLEUCINE', 'I', 600, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 9929, 'ISOLEUCINE', 'I', 3.3, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7163, 9929, 'ISOLEUCINE', 'I', 462, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5891, 9929, 'ISOLEUCINE', 'I', 620, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 9929, 'ISOLEUCINE', 'I', 1.6, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4661, 9929, 'ISOLEUCINE', 'I', 480, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1888, 9929, 'ISOLEUCINE', 'I', 480, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 9929, 'ISOLEUCINE', 'I', 2, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 9929, 'ISOLEUCINE', 'I', 2, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ISOLEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50094, 9929, 'ISOLEUCINE', 'I', 85, 'MG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16178, 521, 'IOPROMIDE', 'I', 50, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IOPROMIDE 499MG/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16179, 521, 'IOPROMIDE', 'I', 62, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IOPROMIDE 623MG/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16180, 521, 'IOPROMIDE', 'I', 77, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IOPROMIDE 769MG/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37570, 10133, 'DIATRIZOATE SODIUM', 'I', 10, '%', '', '', 'N', '', 'Historic Freeform Text: DIATRIZOATE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12455, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 1, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DOXAZOSIN MESYLATE ((DOXAZOSIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12456, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 2, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DOXAZOSIN MESYLATE ((DOXAZOXIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12457, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 4, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DOXAZOSIN MESYLATE ((DOXAZOSIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64067, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 1, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64068, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 2, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64069, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 4, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64570, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 1, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DOXAZOSIN MESYLATE ((DOXAZOSIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64571, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DOXAZOSIN MESYLATE ((DOXAZOSIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64572, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 4, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DOXAZOSIN MESYLATE ((DOXAZOSIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66535, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66536, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 2, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66537, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 4, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68508, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 1, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DOXAZOSIN MESYLATE ((DOXAZOSIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68509, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 2, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DOXAZOSIN MESYLATE ((DOXAZOSIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68510, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 4, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DOXAZOSIN MESYLATE ((DOXAZOSIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70496, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 1, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DOXAZOSIN MESYLATE ((DOXAZOSIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70497, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 2, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DOXAZOSIN MESYLATE ((DOXAZOSIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70498, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 4, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: DOXAZOSIN MESYLATE ((DOXAZOSIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64159, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 1, 'MG', '', '', 'N', 'TAB', 'HISTORIC FREEFORM TEXT: DOXAZOSIN MESYLATE ((DOXAZOSIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64160, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 2, 'MG', '', '', 'N', 'TAB', 'HISTORIC FREEFORM TEXT: DOXAZOSIN MESYLATE ((DOXAZOSIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64161, 11258, 'DOXAZOSIN (DOXAZOSIN MESYLATE)', 'I', 4, 'MG', '', '', 'N', 'TAB', 'HISTORIC FREEFORM TEXT: DOXAZOSIN MESYLATE ((DOXAZOSIN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6404, 5951, 'INVERT SUGAR', 'I', 50, 'G', '', '', 'N', 'L', 'Historic Freeform Text: INVERT SUGAR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44019, 7655, 'INACTIVATED POLIOMYELITIS VACCINE (V.C.O.) TYPE 1 MAHONEY', 'I', 40, 'UNIT', '', '0.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: INACTIV.POLIOM.VAC.(V.C.O.)TYPE 1(MAHONEY) UNIT IS D ANTIGEN UNITS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83726, 7655, 'INACTIVATED POLIOMYELITIS VACCINE (V.C.O.) TYPE 1 MAHONEY', 'I', 40, 'UNIT', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44019, 7653, 'INACTIVATED POLIOMYELITIS VACCINE (V.C.O.) TYPE 3 SAUKETT', 'I', 32, 'UNIT', '', '0.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: INACTIV.POLIOM.VAC.(V.C.O.) TYPE 3 (SAUKETT) UNIT IS D ANTIGEN UNITS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83726, 7653, 'INACTIVATED POLIOMYELITIS VACCINE (V.C.O.) TYPE 3 SAUKETT', 'I', 32, 'UNIT', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (236, 11441, 'PHOSPHATIDYL CHOLINE', 'I', 0.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: LECITHIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75584, 16096, 'TOSITUMOMAB', 'I', 14, 'MG', '', '', 'N', 'ML', 'KIT CONTAINING 35MG/2.5ML AND 225MG/16.1ML. SAME STRENGTH.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9522, 16112, 'CHLORAMPHENICOL', 'I', 1000, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORAMPHENICOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9431, 16112, 'CHLORAMPHENICOL', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORAMPHENICOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6363, 16112, 'CHLORAMPHENICOL', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: CHLORAMPHENICOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2789, 16112, 'CHLORAMPHENICOL (CHLORAMPHENICOL SODIUM SUCCINATE)', 'I', 1, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: CHLORAMPHENICOL SODIUM SUCCINATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16628, 16112, 'CHLORAMPHENICOL', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORAMPHENICOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16630, 16112, 'CHLORAMPHENICOL', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORAMPHENICOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13141, 16112, 'CHLORAMPHENICOL', 'I', 1, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORAMPHENICOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12644, 16112, 'CHLORAMPHENICOL', 'I', 0.5, '%', '', '', 'N', '%', 'Historic Freeform Text: CHLORAMPHENICOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19243, 16112, 'CHLORAMPHENICOL', 'I', 5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CHLORAMPHENICOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13116, 16112, 'CHLORAMPHENICOL', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CHLORAMPHENICOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13383, 16112, 'CHLORAMPHENICOL', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHLORAMPHENICOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9521, 16112, 'CHLORAMPHENICOL (CHLORAMPHENICOL PALMITATE)', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHLORAMPHENICOL PALMITATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1386, 16112, 'CHLORAMPHENICOL', 'I', 4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHLORAMPHENICOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13117, 16112, 'CHLORAMPHENICOL', 'I', 10, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: CHLORAMPHENICOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13682, 16112, 'CHLORAMPHENICOL', 'I', 10, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: CHLORAMPHENICOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3976, 16112, 'CHLORAMPHENICOL', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: CHLORAMPHENICOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78681, 20171, 'DULOXETINE (DULOXETINE HYDROCHLORIDE)', 'I', 30, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78682, 20171, 'DULOXETINE (DULOXETINE HYDROCHLORIDE)', 'I', 60, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78747, 20177, 'ANIDULAFUNGIN', 'I', 100, 'MG', '', '', 'N', 'VIAL', '122MG/VIAL, EQUIVALENT TO 100MG ACTIVE ANIDULAFUNGIN. DILUENT: 30ML PER VIAL./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81644, 20177, 'ANIDULAFUNGIN', 'I', 100, 'MG', '', '', 'N', 'VIAL', '122MG/VIAL, EQUIVALENT TO 100MG ACTIVE ANIDULAFUNGIN. DILUENT: 30ML PER VIAL./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 10194, 'MANGANESE (MANGANESE GLUCONATE)', 'I', 0.5, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81317, 10194, 'MANGANESE (MANGANESE SULFATE)', 'I', 8768, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20314, 10194, 'MANGANESE (MANGANESE SULFATE)', 'I', 0.1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: MN ((AS MANGANESE SULFATE.H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19923, 10194, 'MANGANESE (MANGANESE SULFATE)', 'I', 0.1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: MN ((AS MANGANESE SULFATE.H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16225, 10194, 'MANGANESE (MANGANESE SULFATE)', 'I', 0.5, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: MN ((AS MANGANESE SULFATE.H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16226, 10194, 'MANGANESE (MANGANESE SULFATE)', 'I', 0.1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: MN ((AS MANGANESE SULFATE.H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16227, 10194, 'MANGANESE (MANGANESE SULFATE)', 'I', 0.5, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: MN ((AS MANGANESE SULFATE.H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16224, 10194, 'MANGANESE (MANGANESE SULFATE)', 'I', 0.5, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: MN ((AS MANGANESE SULFATE.H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13489, 10194, 'MANGANESE (MANGANESE SULFATE)', 'I', 0.5, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: MANGANESE SULFATE ((MN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13486, 10194, 'MANGANESE (MANGANESE SULFATE)', 'I', 0.1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: MANGANESE SULFATE ((MN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 10194, 'MANGANESE (MANGANESE OXIDE)', 'I', 435, 'MG', '', '', 'Y', 'KG', 'HISTORIC FREEFORM TEXT: MANG. OXIDE ((MANG. EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (560, 9671, 'MERCURY', 'I', 0.005, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MERCURY ((FROM ETHYLATED MERCURY STEROLS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75618, 16163, 'NITRIC OXIDE', 'I', 100, 'PPM', '', '', 'N', 'CYLR', 'CYLR STANDS FOR CYLINDER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75619, 16163, 'NITRIC OXIDE', 'I', 800, 'PPM', '', '', 'N', 'CYLR', 'CYLR STANDS FOR CYLINDER');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 16199, 'HISTIDINE MONOHYDROCHLORIDE', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: L-HISTIDINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75642, 16200, 'BEVACIZUMAB', 'I', 25, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46832, 16202, 'RABIES VACCINE INACTIVATED (HUMAN DIPLOID-CELL CULTURE)', 'I', 2.5, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: RABIES VACCINE DRIED HUMAN DIPLOID CELL RABIES VACCINE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64083, 10267, 'FENUGREEK', 'I', 0.2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11136, 20170, 'ENALAPRIL SODIUM', 'I', 2, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 2.5MG OF ENALAPRIL MALEATE THAT APPEARS AS 2MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10913, 20170, 'ENALAPRIL SODIUM', 'I', 8, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 10MG OF ENALAPRIL MALEATE  THAT APPEARS AS ENALAPRIL SODIUM 8MG (SEE PM, IN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8111, 20170, 'ENALAPRIL SODIUM', 'I', 4, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 5MG OF ENALAPRIL MALEATE THAT APPEARS AS 4MG OF ENALAPRIL SODIUM IN THE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8102, 20170, 'ENALAPRIL SODIUM', 'I', 8, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 10MG OF ENALAPRIL MALEATE THAT APPEARS AS 8MG OF ENALAPRIL SODIUM IN THE TA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8103, 20170, 'ENALAPRIL SODIUM', 'I', 16, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 20MG OF ENALAPRIL MALEATE THAT APPEARS AS 16MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52490, 20170, 'ENALAPRIL SODIUM', 'I', 4, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 5MG OF ENALAPRIL MALEATE THAT APPEARS AS 4MG OF ENALAPRIL SODIUM IN THE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52491, 20170, 'ENALAPRIL SODIUM', 'I', 8, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 10MG OF ENALAPRIL MALEATE THAT APPEARS AS 8MG OF ENALAPRIL SODIUM IN THE TA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52492, 20170, 'ENALAPRIL SODIUM', 'I', 16, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 20MG OF ENALAPRIL MALEATE THAT APPEARS AS 16MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78601, 20170, 'ENALAPRIL SODIUM', 'I', 2.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 2.5MG OF ENALAPRIL MALEATE THAT APPEARS AS 2MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77724, 20170, 'ENALAPRIL SODIUM', 'I', 2.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 2.5MG OF ENALAPRIL MALEATE THAT APPEARS AS 2MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77725, 20170, 'ENALAPRIL SODIUM', 'I', 4.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 5MG OF ENALAPRIL MALEATE THAT APPEARS AS 4MG OF ENALAPRIL SODIUM IN THE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77726, 20170, 'ENALAPRIL SODIUM', 'I', 8.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 10MG OF ENALAPRIL MALEATE THAT APPEARS AS 8MG OF ENALAPRIL SODIUM IN THE TA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77727, 20170, 'ENALAPRIL SODIUM', 'I', 16, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 20MG OF ENALAPRIL MALEATE THAT APPEARS AS 16MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78528, 20170, 'ENALAPRIL SODIUM', 'I', 2.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 2.5MG OF ENALAPRIL MALEATE THAT APPEARS AS 2MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78529, 20170, 'ENALAPRIL SODIUM', 'I', 4.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 5MG OF ENALAPRIL MALEATE THAT APPEARS AS 4MG OF ENALAPRIL SODIUM IN THE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78530, 20170, 'ENALAPRIL SODIUM', 'I', 8.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 10MG OF ENALAPRIL MALEATE THAT APPEARS AS 8MG OF ENALAPRIL SODIUM IN THE TA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78531, 20170, 'ENALAPRIL SODIUM', 'I', 16, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 20MG OF ENALAPRIL MALEATE THAT APPEARS AS 16MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78532, 20170, 'ENALAPRIL SODIUM', 'I', 2.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 2.5MG OF ENALAPRIL MALEATE THAT APPEARS AS 2MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78533, 20170, 'ENALAPRIL SODIUM', 'I', 4.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 5MG OF ENALAPRIL MALEATE THAT APPEARS AS 4MG OF ENALAPRIL SODIUM IN THE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78534, 20170, 'ENALAPRIL SODIUM', 'I', 8.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 10MG OF ENALAPRIL MALEATE THAT APPEARS AS 8MG OF ENALAPRIL SODIUM IN THE TA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78535, 20170, 'ENALAPRIL SODIUM', 'I', 16, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 20MG OF ENALAPRIL MALEATE THAT APPEARS AS 16MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78614, 20170, 'ENALAPRIL SODIUM', 'I', 2.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 2.5MG OF ENALAPRIL MALEATE THAT APPEARS AS 2MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78615, 20170, 'ENALAPRIL SODIUM', 'I', 4.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 5.0 MG OF ENALAPRIL MALEATE THAT APPEARS AS 4MG OF ENALAPRIL SODIUM IN THE ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78616, 20170, 'ENALAPRIL SODIUM', 'I', 8.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 10MG OF ENALAPRIL MALEATE THAT APPEARS AS 8MG OF ENALAPRIL SODIUM IN THE TA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78485, 1255, 'OCTREOTIDE (OCTREOTIDE ACETATE)', 'I', 500, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78617, 20170, 'ENALAPRIL SODIUM', 'I', 16, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 20MG OF ENALAPRIL MALEATE THAT APPEARS AS 16MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78536, 20170, 'ENALAPRIL SODIUM', 'I', 2.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 2.5MG OF ENALAPRIL MALEATE THAT APPEARS AS 2MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78537, 20170, 'ENALAPRIL SODIUM', 'I', 4, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 5MG OF ENALAPRIL MALEATE THAT APPEARS AS 4MG OF ENALAPRIL SODIUM IN THE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78538, 20170, 'ENALAPRIL SODIUM', 'I', 8, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 10MG OF ENALAPRIL MALEATE THAT APPEARS AS 8MG OF ENALAPRIL SODIUM IN THE TA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78539, 20170, 'ENALAPRIL SODIUM', 'I', 16, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 20MG OF ENALAPRIL MALEATE THAT APPEARS AS 16MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78540, 20170, 'ENALAPRIL SODIUM', 'I', 2.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 2.5MG OF ENALAPRIL MALEATE THAT APPEARS AS 2MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78541, 20170, 'ENALAPRIL SODIUM', 'I', 4, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 5MG OF ENALAPRIL MALEATE THAT APPEARS AS 4MG OF ENALAPRIL SODIUM IN THE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78542, 20170, 'ENALAPRIL SODIUM', 'I', 8, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 10MG OF ENALAPRIL MALEATE THAT APPEARS AS 8MG OF ENALAPRIL SODIUM IN THE TA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78543, 20170, 'ENALAPRIL SODIUM', 'I', 16, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 20MG OF ENALAPRIL MALEATE THAT APPEARS AS 16MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78544, 20170, 'ENALAPRIL SODIUM', 'I', 2.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 2.5MG OF ENALAPRIL MALEATE THAT APPEARS AS 2MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78545, 20170, 'ENALAPRIL SODIUM', 'I', 4, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 5MG OF ENALAPRIL MALEATE THAT APPEARS AS 4MG OF ENALAPRIL SODIUM IN THE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78546, 20170, 'ENALAPRIL SODIUM', 'I', 8, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 10MG OF ENALAPRIL MALEATE THAT APPEARS AS 8MG OF ENALAPRIL SODIUM IN THE TA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78547, 20170, 'ENALAPRIL SODIUM', 'I', 16, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 20MG OF ENALAPRIL MALEATE THAT APPEARS AS 16MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80898, 20170, 'ENALAPRIL SODIUM', 'I', 2.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 2.5MG OF ENALAPRIL MALEATE THAT APPEARS AS 2MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80899, 20170, 'ENALAPRIL SODIUM', 'I', 4.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 5MG OF ENALAPRIL MALEATE THAT APPEARS AS 4MG OF ENALAPRIL SODIUM IN THE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80900, 20170, 'ENALAPRIL SODIUM', 'I', 8.0, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 10MG OF ENALAPRIL MALEATE THAT APPEARS AS 8MG OF ENALAPRIL SODIUM IN THE TA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80901, 20170, 'ENALAPRIL SODIUM', 'I', 16, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 20MG OF ENALAPRIL MALEATE THAT APPEARS AS 16MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81632, 20170, 'ENALAPRIL SODIUM', 'I', 32, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 40 MG OF ENALAPRIL MALEATE THAT APPEARS AS 32 MG OF ENALAPRIL SODIUM IN THE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78554, 20170, 'ENALAPRIL SODIUM', 'I', 4, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 5MG OF ENALAPRIL MALEATE THAT APPEARS AS 4MG OF ENALAPRIL SODIUM IN THE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78555, 20170, 'ENALAPRIL SODIUM', 'I', 8, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 10MG OF ENALAPRIL MALEATE THAT APPEARS AS 8MG OF ENALAPRIL SODIUM IN THE TA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83747, 20170, 'ENALAPRIL SODIUM', 'I', 2, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 2.5MG OF ENALAPRIL MALEATE THAT APPEARS AS 2MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83748, 20170, 'ENALAPRIL SODIUM', 'I', 4, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 5MG OF ENALAPRIL MALEATE THAT APPEARS AS 4MG OF ENALAPRIL SODIUM IN THE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83749, 20170, 'ENALAPRIL SODIUM', 'I', 8, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 10MG OF ENALAPRIL MALEATE THAT APPEARS AS 8MG OF ENALAPRIL SODIUM IN THE TA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83750, 20170, 'ENALAPRIL SODIUM', 'I', 16, 'MG', '', '', 'N', '', 'EACH TABLET IS MADE WITH 20MG OF ENALAPRIL MALEATE THAT APPEARS AS 16MG OF ENALAPRIL SODIUM IN THE T');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11257, 6897, 'OPIUM', 'I', 65, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OPIUM ((POWDER))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11124, 6897, 'OPIUM', 'I', 65, 'MG', '', '', 'N', '', 'Historic Freeform Text: OPIUM ((PWR))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3621, 7114, 'BEECHWOOD CREOSOTE', 'I', 0.2, '%', '', '', 'N', '%', 'Historic Freeform Text: CREOSOTE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13090, 8589, 'SPIRAMYCIN', 'I', 750000, 'UNIT', '', '', 'N', '', 'Historic Freeform Text: SPIRAMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12601, 8589, 'SPIRAMYCIN', 'I', 1500000, 'UNIT', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SPIRAMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (41578, 6944, 'STORAX', 'I', 8, 'G', '', '100', 'N', 'ML', 'Historic Freeform Text: STORAX');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60180, 8814, 'CASCARA SAGRADA', 'I', 100, 'MG', '', '', 'N', '', 'BARK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (623, 3453, 'ACRIFLAVINE', 'I', 0.03, '%', '', '', 'N', '', 'Historic Freeform Text: ACRIFLAVINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (620, 3453, 'ACRIFLAVINE', 'I', 0.2, '%', '', '', 'N', '', 'Historic Freeform Text: ACRIFLAVINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1593, 3453, 'ACRIFLAVINE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: ACRIFLAVINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1500, 3453, 'ACRIFLAVINE', 'I', 0.0034, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: ACRIFLAVINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 11169, 'VITAMIN B6 (PYRIDOXINE HYDROCHLORIDE)', 'I', 15, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70202, 11169, 'VITAMIN B6 (PYRIDOXINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', 'PINK TABLET A.M.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76186, 11169, 'VITAMIN B6 (PYRIDOXINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', 'PINK TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6716, 11169, 'VITAMIN B6 (PYRIDOXINE HYDROCHLORIDE)', 'I', 740, 'µG', '', '7.5', 'N', 'ML', 'Historic Freeform Text: VIT B6 ((HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82159, 11169, 'VITAMIN B6 (PYRIDOXINE HYDROCHLORIDE)', 'I', 800, 'µG', '', '8', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9527, 11169, 'VITAMIN B6 (PYRIDOXINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT B6 ((HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5613, 11169, 'VITAMIN B6 (PYRIDOXINE HYDROCHLORIDE)', 'I', 1.2, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: PYRIDOXINE ((HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 11169, 'VITAMIN B6', 'I', 10, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 11169, 'VITAMIN B6', 'I', 10, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: PYRIDOXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33790, 11169, 'VITAMIN B6 (PYRIDOXINE HYDROCHLORIDE)', 'I', 1.3, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15001, 11169, 'VITAMIN B6 (PYRIDOXINE HYDROCHLORIDE)', 'I', 1.3, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: PYRIDOXINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5322, 11169, 'VITAMIN B6', 'I', 1.32, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PYRIDOXINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (690, 1411, 'ERGOLOID MESYLATES', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT:  DIHYDROERGOCORNINE METHANESULFONATE 0.333MG; DIHYDROERGOCRISTINE METHANESUL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62792, 1255, 'OCTREOTIDE (OCTREOTIDE ACETATE)', 'I', 10, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62793, 1255, 'OCTREOTIDE (OCTREOTIDE ACETATE)', 'I', 20, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62794, 1255, 'OCTREOTIDE (OCTREOTIDE ACETATE)', 'I', 30, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19627, 1255, 'OCTREOTIDE (OCTREOTIDE ACETATE)', 'I', 200, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: OCTREOTIDE ((AS ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9915, 1255, 'OCTREOTIDE (OCTREOTIDE ACETATE)', 'I', 50, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: OCTREOTIDE (AS ACETATE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9916, 1255, 'OCTREOTIDE (OCTREOTIDE ACETATE)', 'I', 100, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: OCTREOTIDE (AS ACETATE).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9917, 1255, 'OCTREOTIDE (OCTREOTIDE ACETATE)', 'I', 500, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: OCTREOTIDE (AS ACETATE).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72996, 1255, 'OCTREOTIDE (OCTREOTIDE ACETATE)', 'I', 50, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72997, 1255, 'OCTREOTIDE (OCTREOTIDE ACETATE)', 'I', 100, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72998, 1255, 'OCTREOTIDE (OCTREOTIDE ACETATE)', 'I', 500, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72999, 1255, 'OCTREOTIDE (OCTREOTIDE ACETATE)', 'I', 200, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78483, 1255, 'OCTREOTIDE (OCTREOTIDE ACETATE)', 'I', 100, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78484, 1255, 'OCTREOTIDE (OCTREOTIDE ACETATE)', 'I', 200, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5276, 6906, 'DEOXYCHOLIC ACID', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEOXYCHOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46803, 7942, 'CETIRIZINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CETIRIZINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43369, 7942, 'CETIRIZINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CETIRIZINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43370, 7942, 'CETIRIZINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CETIRIZINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50975, 7942, 'CETIRIZINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63802, 7942, 'CETIRIZINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63803, 7942, 'CETIRIZINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64501, 7942, 'CETIRIZINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70312, 7942, 'CETIRIZINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: CETIRIZINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80148, 7942, 'CETIRIZINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80149, 7942, 'CETIRIZINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84957, 7942, 'CETIRIZINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61744, 7942, 'CETIRIZINE HYDROCHLORIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11196, 7504, 'MOMETASONE FUROATE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: MOMETASONE FUROATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11444, 7504, 'MOMETASONE FUROATE', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MOMETASONE FUROATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68758, 7504, 'MOMETASONE FUROATE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75622, 7504, 'MOMETASONE FUROATE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72459, 7504, 'MOMETASONE FUROATE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75025, 7504, 'MOMETASONE FUROATE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75180, 7504, 'MOMETASONE FUROATE', 'I', 0.1, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85196, 7504, 'MOMETASONE FUROATE', 'I', 0.1, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: MOMETASONE FUROATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61885, 7504, 'MOMETASONE FUROATE', 'I', 50, 'µG', '', '', 'N', 'SPRAY', 'NOMETASONE FUROATE 52MCG/ACT CHANGED TO MOMETASONE FUROATE 50MCG/SPRAY AS PER GARY CONDRAN''S AND SHA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84679, 7504, 'MOMETASONE FUROATE', 'I', 50, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84680, 7504, 'MOMETASONE FUROATE', 'I', 100, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84681, 7504, 'MOMETASONE FUROATE', 'I', 200, 'µG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11443, 7504, 'MOMETASONE FUROATE', 'I', 1, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: MOMETASONE FUROATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43438, 2014, 'TEMAZEPAM', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: TEMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43439, 2014, 'TEMAZEPAM', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: TEMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43372, 2014, 'TEMAZEPAM', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: TEMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43373, 2014, 'TEMAZEPAM', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: TEMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5616, 2014, 'TEMAZEPAM', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: TEMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5618, 2014, 'TEMAZEPAM', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: TEMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48627, 2014, 'TEMAZEPAM', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48634, 2014, 'TEMAZEPAM', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47984, 2014, 'TEMAZEPAM', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47986, 2014, 'TEMAZEPAM', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47988, 2014, 'TEMAZEPAM', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47989, 2014, 'TEMAZEPAM', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66885, 2014, 'TEMAZEPAM', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66886, 2014, 'TEMAZEPAM', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68805, 2014, 'TEMAZEPAM', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: TEMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68804, 2014, 'TEMAZEPAM', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: TEMAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75853, 2014, 'TEMAZEPAM', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75854, 2014, 'TEMAZEPAM', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78328, 2014, 'TEMAZEPAM', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78329, 2014, 'TEMAZEPAM', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16522, 10058, 'ORPHENADRINE CITRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ORPHENADRINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14325, 10058, 'ORPHENADRINE CITRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ORPHENADRINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67477, 10058, 'ORPHENADRINE CITRATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14003, 10058, 'ORPHENADRINE CITRATE', 'I', 30, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ORPHENADRINE CITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47910, 10058, 'ORPHENADRINE CITRATE', 'I', 30, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78097, 20135, 'CEFOVECIN (CEFOVECIN SODIUM)', 'I', 80, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78519, 20160, 'MARAVIROC', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78520, 20160, 'MARAVIROC', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78924, 20179, 'SITAGLIPTIN (SITAGLIPTIN PHOSPHATE MONOHYDRATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81954, 20179, 'SITAGLIPTIN (SITAGLIPTIN PHOSPHATE MONOHYDRATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81956, 20179, 'SITAGLIPTIN (SITAGLIPTIN PHOSPHATE MONOHYDRATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81955, 20179, 'SITAGLIPTIN (SITAGLIPTIN PHOSPHATE MONOHYDRATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 6485, 'POTASSIUM (POTASSIUM CHLORIDE, POTASSIUM CITRATE)', 'I', 40, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7388, 6485, 'POTASSIUM (POTASSIUM PHOSPHATE DIBASIC)', 'I', 1.74, '%', '', '', 'Y', '%', 'HISTORIC FREEFORM TEXT: POT. PHOSPHATE ((POT. EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 6485, 'POTASSIUM', 'I', 2.7, 'MEQ', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 6485, 'POTASSIUM', 'I', 2.7, 'MEQ', '', '100', 'N', 'ML', 'Historic Freeform Text: POTASSIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6404, 6485, 'POTASSIUM (POTASSIUM CHLORIDE)', 'I', 10, 'MEQ', '', '', 'N', 'L', 'Historic Freeform Text: POTASS CHLORIDE ((POTASS EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17121, 6485, 'POTASSIUM (POTASSIUM CHLORIDE)', 'I', 7.48, 'G', '', '400', 'Y', 'G', 'HISTORIC FREEFORM TEXT: K ((AS KCL 14.28GM))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27514, 6410, 'SILICONE', 'I', 20, '%', '', '', 'N', '', 'Historic Freeform Text: SILICONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15975, 145, 'GOLD', 'I', 1.4, 'µG', '', '2', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GOLD ((COLLOIDAL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 331, 'ZINC (ZINC GLUCONATE)', 'I', 3, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70202, 331, 'ZINC (ZINC OXIDE)', 'I', 15, 'MG', '', '', 'N', '', 'PINK TABLET A.M.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76186, 331, 'ZINC (ZINC OXIDE)', 'I', 15, 'MG', '', '', 'N', '', 'PINK TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81317, 331, 'ZINC (ZINC OXIDE, ZINC SULFATE)', 'I', 13326, 'MG', '', '', 'N', '', 'ZINC SULFATE 2879MG ZINC OXIDE 10447MG ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7388, 331, 'ZINC (ZINC SULFATE)', 'I', 1.18, '%', '', '', 'Y', '%', 'HISTORIC FREEFORM TEXT: ZINC SULFATE ((ZINC EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20314, 331, 'ZINC (ZINC SULFATE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: ZN ((AS ZINC SULFATE.7H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19923, 331, 'ZINC (ZINC SULFATE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: ZN ((AS ZINC SULFATE.7H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16226, 331, 'ZINC (ZINC SULFATE)', 'I', 3, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: ZN ((AS ZINC SULFATE.7H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16227, 331, 'ZINC (ZINC SULFATE)', 'I', 5, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: ZN ((AS ZINC SULFATE.7H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16224, 331, 'ZINC (ZINC SULFATE)', 'I', 5, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: ZN ((AS ZINC SULFATE.7H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16225, 331, 'ZINC (ZINC SULFATE)', 'I', 5, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: ZN ((AS ZINC SULFATE.7H20))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13451, 331, 'ZINC (ZINC SULFATE)', 'I', 1, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: ZINC SULFATE ((ZINC EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13416, 331, 'ZINC (ZINC SULFATE)', 'I', 5, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: ZINC SULFATE ((ZN EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82159, 331, 'ZINC (ZINC SULFATE)', 'I', 16.8, 'MG', '', '8', 'N', 'ML', 'SUPPLIED AS ZINC SULFATE PART MISSING FROM LABEL GIVEN TO DIN UNIT, E-MAIL TO VDD. EW');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 331, 'ZINC (ZINC SULFATE)', 'I', 2.1, 'G', '', '', 'Y', 'KG', 'HISTORIC FREEFORM TEXT: ZINC SULF. ((ZINC EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84256, 1390, 'IMIPENEM', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78560, 20163, 'PALIPERIDONE', 'I', 6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8348, 1390, 'IMIPENEM', 'I', 250, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: IMIPENEM MONOHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8054, 1390, 'IMIPENEM', 'I', 500, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: IMIPENEM MONOHYDRATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83695, 1390, 'IMIPENEM', 'I', 250, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83696, 1390, 'IMIPENEM', 'I', 500, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84339, 1390, 'IMIPENEM', 'I', 250, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84340, 1390, 'IMIPENEM', 'I', 500, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62021, 7335, 'ALPROSTADIL', 'I', 250, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62022, 7335, 'ALPROSTADIL', 'I', 500, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62023, 7335, 'ALPROSTADIL', 'I', 1000, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43155, 7335, 'ALPROSTADIL', 'I', 23.2, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: ALPROSTADIL ((RECONSTITUTED  20MCG/ML))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20353, 7335, 'ALPROSTADIL', 'I', 23.2, 'µG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: ALPROSTADIL ((RECONSTITUTED 20MCG/ML))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4802, 7335, 'ALPROSTADIL', 'I', 500, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65340, 7335, 'ALPROSTADIL', 'I', 500, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77079, 7335, 'ALPROSTADIL', 'I', 500, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12955, 8942, 'PSEUDOEPHEDRINE SULFATE', 'I', 120, 'MG', '', '', 'N', '', 'Historic Freeform Text: D-PSEUDOEPHEDRINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3717, 8942, 'PSEUDOEPHEDRINE SULFATE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: D-PSEUDOEPHEDRINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33922, 773, 'PSEUDOEPHEDRINE SULFATE', 'I', 60, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PSEUDOEPHEDRINE SULPHATE ((WH. NIGHT TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33922, 773, 'PSEUDOEPHEDRINE SULFATE', 'I', 120, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PSEUDOEPHEDRINE SULPHATE ((YELLOW DAY SRT))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11974, 773, 'PSEUDOEPHEDRINE SULFATE', 'I', 120, 'MG', '', '', 'N', '', 'COMPANY INFORMED US THAT THIS AI WAS INCORRECTLY ENTERED IN DPD. WAS ENTERED AS PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2048, 773, 'PSEUDOEPHEDRINE SULFATE', 'I', 120, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: D-PSEUDOEPHEDRINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68939, 773, 'PSEUDOEPHEDRINE SULFATE', 'I', 240, 'MG', '', '', 'N', '', 'Historic Freeform Text: PSEUDOEPHEDRINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74601, 773, 'PSEUDOEPHEDRINE SULFATE', 'I', 240, 'MG', '', '', 'N', '', '(TABLET CORE)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79491, 773, 'PSEUDOEPHEDRINE SULFATE', 'I', 120, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20066, 773, 'PSEUDOEPHEDRINE SULFATE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: PSEUDOEPHEDRINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60122, 2210, 'POLYQUATERNIUM-1', 'I', 0.001, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78302, 2210, 'POLYQUATERNIUM-1', 'I', 0.001, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (622, 10011, 'IODOFORM', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: IODOFORM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74399, 10011, 'IODOFORM', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4875, 10011, 'IODOFORM', 'I', 15.8, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: IODOFORM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19610, 751, 'L-LEUCINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19143, 751, 'L-LEUCINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'HISTORIC FREEFORM TEXT: L-LEUCINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18550, 751, 'L-LEUCINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15868, 751, 'L-LEUCINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14077, 751, 'L-LEUCINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14076, 751, 'L-LEUCINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14075, 751, 'L-LEUCINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14073, 751, 'L-LEUCINE HYDROCHLORIDE', 'I', 263, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14072, 751, 'L-LEUCINE HYDROCHLORIDE', 'I', 263, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14071, 751, 'L-LEUCINE HYDROCHLORIDE', 'I', 263, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14069, 751, 'L-LEUCINE HYDROCHLORIDE', 'I', 155, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14068, 751, 'L-LEUCINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14067, 751, 'L-LEUCINE HYDROCHLORIDE', 'I', 310, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14066, 751, 'L-LEUCINE HYDROCHLORIDE', 'I', 263, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: L-LEUCINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12650, 1776, 'ENALAPRILAT', 'I', 1.25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ENALAPRILAT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 4819, 'COBALTOUS CHLORIDE', 'I', 0.016, 'MG', '', '', 'N', 'PATCH', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19050, 6750, 'CODEINE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CODEINE QTY UNIT: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19050, 6750, 'CODEINE (CODEINE SULFATE)', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: CODEINE ((AS SULFATE)) Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49057, 6750, 'CODEINE (CODEINE MONOHYDRATE)', 'I', 25, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49057, 6750, 'CODEINE (CODEINE SULFATE)', 'I', 25, 'MG', '', '', 'Y', '', 'AS CODEINE SULFATE TRIHYDRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19049, 6750, 'CODEINE', 'I', 100, 'MG', '', '', 'N', 'SRT', 'Historic Freeform Text: CODEINE Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19049, 6750, 'CODEINE (CODEINE SULFATE)', 'I', 100, 'MG', '', '', 'N', 'SRT', 'Historic Freeform Text: CODEINE ((AS SULFATE)) Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19051, 6750, 'CODEINE', 'I', 75, 'MG', '', '', 'N', 'SRT', 'Historic Freeform Text: CODEINE Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19051, 6750, 'CODEINE (CODEINE SULFATE)', 'I', 75, 'MG', '', '', 'N', 'SRT', 'Historic Freeform Text: CODEINE ((AS SULFATE)) Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7439, 5246, 'MEBEZONIUM IODIDE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MEBEZONIUM IODIDE ------------------------------------------------------AS P');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42865, 8609, 'ERYTHROMYCIN THIOCYANATE', 'I', 110, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: ERYTHROMYCIN THIOCYANATE ((ERYTH.EQ.102G))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13476, 17056, 'BOTULINUM TOXIN TYPE A', 'I', 100, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: CLOSTRIDIUM BOTULINUM TOXIN TYPE A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67653, 17056, 'BOTULINUM TOXIN TYPE A', 'I', 100, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: CLOSTRIDIUM BOTULINUM TOXIN TYPE A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77258, 20021, 'LANTHANUM (LANTHANUM CARBONATE HYDRATE)', 'I', 250, 'MG', '', '', 'N', '', 'LANTHANUM CARBONATE HYDRATE 477.0 MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77259, 20021, 'LANTHANUM (LANTHANUM CARBONATE HYDRATE)', 'I', 500, 'MG', '', '', 'N', '', 'LANTHANUM CARBONATE HYDRATE 954 MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77260, 20021, 'LANTHANUM (LANTHANUM CARBONATE HYDRATE)', 'I', 750, 'MG', '', '', 'N', '', 'LANTHANUM CARBONATE HYDRATE 1431 MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77261, 20021, 'LANTHANUM (LANTHANUM CARBONATE HYDRATE)', 'I', 1000, 'MG', '', '', 'N', '', 'LANTHANUM CARBONATE HYDRATE 1908 MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61235, 20039, 'ENZACAMENE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77540, 20039, 'ENZACAMENE', 'I', 2.0, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80438, 20039, 'ENZACAMENE', 'I', 3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77394, 20039, 'ENZACAMENE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77395, 20039, 'ENZACAMENE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77396, 20039, 'ENZACAMENE', 'I', 4, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50134, 20039, 'ENZACAMENE', 'I', 2, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78165, 20141, 'IDURSULFASE', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78388, 20155, 'FLUTICASONE FUROATE', 'I', 27.5, 'µG', '', '', 'N', 'ACT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78488, 20158, 'MAROPITANT (MAROPITANT CITRATE)', 'I', 16, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78489, 20158, 'MAROPITANT (MAROPITANT CITRATE)', 'I', 24, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78490, 20158, 'MAROPITANT (MAROPITANT CITRATE)', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78491, 20158, 'MAROPITANT (MAROPITANT CITRATE)', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78492, 20158, 'MAROPITANT (MAROPITANT CITRATE)', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78559, 20163, 'PALIPERIDONE', 'I', 3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83941, 20163, 'PALIPERIDONE (Paliperidone Palmitate)', 'I', 50, 'MG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83942, 20163, 'PALIPERIDONE (Paliperidone Palmitate)', 'I', 75, 'MG', '', '0.75', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83943, 20163, 'PALIPERIDONE (Paliperidone Palmitate)', 'I', 100, 'MG', '', '1', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83944, 20163, 'PALIPERIDONE (Paliperidone Palmitate)', 'I', 150, 'MG', '', '1.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78941, 20180, 'TEMSIROLIMUS', 'I', 25, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75090, 20190, 'INSULIN ASPART PROTAMINE', 'I', 70, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79388, 20208, 'METHYLNALTREXONE BROMIDE', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79412, 20210, 'PANITUMUMAB', 'I', 100, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6566, 10065, 'ETHOXYQUIN', 'I', 353, 'µG', '', '', 'N', 'G', 'Historic Freeform Text: ETHOXYQUIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50269, 11411, 'FOSPHENYTOIN SODIUM', 'I', 75, 'MG', '', '', 'N', 'ML', 'FOSPHENYTOIN SODIUM INJECTION 75MG/ML (EQUIVALENT TO 50MG/ML PHENYTOIN SODIUM)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18685, 250, 'IODIXANOL', 'I', 550, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: IODIXANOL ((ORG.BOUND IODINE 270MG/ML))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18694, 250, 'IODIXANOL', 'I', 652, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: IODIXANOL ((ORG.BOUND IODINE 320MG/ML))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44129, 8328, 'ENROFLOXACIN', 'I', 22.7, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ENROFLOXACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44130, 8328, 'ENROFLOXACIN', 'I', 68, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ENROFLOXACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63001, 8328, 'ENROFLOXACIN', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63002, 8328, 'ENROFLOXACIN', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63000, 8328, 'ENROFLOXACIN', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44127, 8328, 'ENROFLOXACIN', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ENROFLOXACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70910, 8328, 'ENROFLOXACIN', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73409, 8328, 'ENROFLOXACIN', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ENROFLOXACIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50027, 9350, 'METHYL NICOTINATE', 'I', 0.75, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2091, 9406, 'CHLORPROPAMIDE', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPROPAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2658, 9406, 'CHLORPROPAMIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORPROPAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26564, 5954, 'BUTAMBEN', 'I', 2, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BUTAMBEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16688, 5954, 'BUTAMBEN', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: BUTAMBEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4875, 5954, 'BUTAMBEN', 'I', 25.7, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: BUTAMBEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3778, 4991, 'FOLIC ACID', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (578, 4991, 'FOLIC ACID', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3002, 4991, 'FOLIC ACID', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2283, 4991, 'FOLIC ACID', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 4991, 'FOLIC ACID', 'I', 0.04, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70202, 4991, 'FOLIC ACID', 'I', 1.1, 'MG', '', '', 'N', '', 'BLUE TABLET P.M.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76186, 4991, 'FOLIC ACID', 'I', 5, 'MG', '', '', 'N', '', 'BLUE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77118, 4991, 'FOLIC ACID', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85094, 4991, 'FOLIC ACID', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66277, 4991, 'FOLIC ACID', 'I', 140, 'µG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16462, 4991, 'FOLIC ACID', 'I', 80, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: FOLIC ACID ((VIAL 2))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68684, 4991, 'FOLIC ACID', 'I', 80, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10312, 4991, 'FOLIC ACID', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 4991, 'FOLIC ACID', 'I', 0.99, 'MG', '', '', 'N', 'KG', 'Historic Freeform Text: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 4991, 'FOLIC ACID', 'I', 11.6, 'MG', '', '', 'N', 'KG', 'Historic Freeform Text: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36843, 4991, 'FOLIC ACID', 'I', 150, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33790, 4991, 'FOLIC ACID', 'I', 0.165, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24471, 4991, 'FOLIC ACID', 'I', 112.2, 'MG', '', '170', 'N', 'G', 'Historic Freeform Text: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24400, 4991, 'FOLIC ACID', 'I', 110, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17818, 4991, 'FOLIC ACID', 'I', 150, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17121, 4991, 'FOLIC ACID', 'I', 150, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 4991, 'FOLIC ACID', 'I', 112.2, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14119, 4991, 'FOLIC ACID', 'I', 150, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14113, 4991, 'FOLIC ACID', 'I', 112.2, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15001, 4991, 'FOLIC ACID', 'I', 0.165, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10527, 4991, 'FOLIC ACID', 'I', 14, 'MG', '', '75', 'N', 'G', 'Historic Freeform Text: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5322, 4991, 'FOLIC ACID', 'I', 0.165, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: FOLIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66631, 4991, 'FOLIC ACID', 'I', 12, 'MG', '', '300', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 781, 'VITAMIN B12 (CYANOCOBALAMIN)', 'I', 25, 'µG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70202, 781, 'VITAMIN B12 (CYANOCOBALAMIN)', 'I', 12, 'µG', '', '', 'N', '', 'BLUE TABLET P.M.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76186, 781, 'VITAMIN B12 (CYANOCOBALAMIN)', 'I', 12, 'µG', '', '', 'N', '', 'BLUE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66277, 781, 'VITAMIN B12 (CYANOCOBALAMIN)', 'I', 1, 'µG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25433, 781, 'VITAMIN B12', 'I', 0.05, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22007, 781, 'VITAMIN B12', 'I', 0.88, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19369, 781, 'VITAMIN B12', 'I', 100, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17796, 781, 'VITAMIN B12', 'I', 1000, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16486, 781, 'VITAMIN B12', 'I', 25, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VITAMIN B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16465, 781, 'VITAMIN B12 (CYANOCOBALAMIN)', 'I', 5000, 'µG', '', '', 'N', 'ML', 'CYANOCOBALAMIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16462, 781, 'VITAMIN B12 (VITAMIN B12)', 'I', 1, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: CYANOCOBALAMIN ((VIAL 2))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14271, 781, 'VITAMIN B12', 'I', 5000, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10470, 781, 'VITAMIN B12', 'I', 150, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12562, 781, 'VITAMIN B12', 'I', 150, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9254, 781, 'VITAMIN B12', 'I', 100, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9527, 781, 'VITAMIN B12', 'I', 150, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9372, 781, 'VITAMIN B12', 'I', 0.88, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7179, 781, 'VITAMIN B12', 'I', 100, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6071, 781, 'VITAMIN B12', 'I', 150, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5902, 781, 'VITAMIN B12', 'I', 150, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6341, 781, 'VITAMIN B12', 'I', 2, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6339, 781, 'VITAMIN B12', 'I', 100, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7329, 781, 'VITAMIN B12', 'I', 100, 'µG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7298, 781, 'VITAMIN B12 (CYANOCOBALAMIN)', 'I', 1000, 'µG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 781, 'VITAMIN B12', 'I', 5, 'µG', '', '100', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4268, 781, 'VITAMIN B12 (CYANOCOBALAMIN)', 'I', 100, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3497, 781, 'VITAMIN B12', 'I', 100, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2631, 781, 'VITAMIN B12', 'I', 5, 'µG', '', '100', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2011, 781, 'VITAMIN B12', 'I', 5, 'µG', '', '100', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65140, 781, 'VITAMIN B12', 'I', 100, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68684, 781, 'VITAMIN B12 (CYANOCOBALAMIN)', 'I', 1, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3870, 781, 'VITAMIN B12', 'I', 5, 'µG', '', '100', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71746, 781, 'VITAMIN B12', 'I', 1000, 'µG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VITAMIN B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78915, 781, 'VITAMIN B12', 'I', 150, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16909, 781, 'VITAMIN B12', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VITAMIN B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13324, 781, 'VITAMIN B12', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: VITAMIN B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6070, 781, 'VITAMIN B12', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6563, 781, 'VITAMIN B12', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6340, 781, 'VITAMIN B12', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6306, 781, 'VITAMIN B12', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6262, 781, 'VITAMIN B12', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4432, 781, 'VITAMIN B12', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4269, 781, 'VITAMIN B12 (CYANOCOBALAMIN)', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3500, 781, 'VITAMIN B12', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2871, 781, 'VITAMIN B12', 'I', 10, 'MG', '', '10', 'N', 'ML', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 781, 'VITAMIN B12', 'I', 6.6, 'MG', '', '', 'N', 'KG', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 781, 'VITAMIN B12', 'I', 1.335, 'MG', '', '', 'N', 'KG', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 781, 'VITAMIN B12', 'I', 13.2, 'MG', '', '', 'N', 'KG', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36843, 781, 'VITAMIN B12', 'I', 2560, 'µG', '', '400', 'N', 'G', 'Historic Freeform Text: VITAMIN B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33790, 781, 'VITAMIN B12', 'I', 6.6, 'µG', '', '', 'N', 'G', 'Historic Freeform Text: VITAMIN B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24400, 781, 'VITAMIN B12', 'I', 3155, 'µG', '', '100', 'N', 'G', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17818, 781, 'VITAMIN B12', 'I', 2560, 'µG', '', '400', 'N', 'G', 'Historic Freeform Text: VITAMIN B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 781, 'VITAMIN B12', 'I', 3740, 'µG', '', '100', 'N', 'G', 'Historic Freeform Text: VITAMIN B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14115, 781, 'VITAMIN B12 (CYANOCOBALAMIN)', 'I', 241, 'µG', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12923, 781, 'VITAMIN B12', 'I', 2.7, 'µG', '', '', 'N', 'G', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15001, 781, 'VITAMIN B12', 'I', 6.6, 'µG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: VITAMIN B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5322, 781, 'VITAMIN B12', 'I', 6.6, 'µG', '', '', 'N', 'G', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5144, 781, 'VITAMIN B12', 'I', 241, 'µG', '', '100', 'N', 'G', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5125, 781, 'VITAMIN B12', 'I', 241, 'µG', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1617, 781, 'VITAMIN B12', 'I', 1340, 'µG', '', '100', 'N', 'G', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50391, 781, 'VITAMIN B12', 'I', 3.5, 'µG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64903, 781, 'VITAMIN B12', 'I', 100, 'µG', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66631, 781, 'VITAMIN B12 (CYANOCOBALAMIN)', 'I', 500, 'µG', '', '300', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66864, 781, 'VITAMIN B12 (CYANOCOBALAMIN)', 'I', 200, 'µG', '', '400', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80280, 781, 'VITAMIN B12', 'I', 0.083, 'µG', '', '', 'N', 'G', 'CYANOCOBALAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24471, 781, 'VITAMIN B12', 'I', 3.74, 'MG', '', '170', 'N', 'G', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17121, 781, 'VITAMIN B12', 'I', 2.56, 'MG', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: VITAMIN B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14165, 781, 'VITAMIN B12', 'I', 2.3, 'MG', '', '450', 'N', 'G', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14119, 781, 'VITAMIN B12', 'I', 2.56, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14113, 781, 'VITAMIN B12', 'I', 3.74, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12922, 781, 'VITAMIN B12', 'I', 1.44, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8101, 781, 'VITAMIN B12', 'I', 2, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3926, 781, 'VITAMIN B12', 'I', 2.3, 'MG', '', '450', 'N', 'G', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1613, 781, 'VITAMIN B12', 'I', 4, 'MG', '', '454', 'N', 'G', 'Historic Freeform Text: VIT. B12');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78548, 20162, 'FIROCOXIB', 'I', 57, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78549, 20162, 'FIROCOXIB', 'I', 227, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78739, 20175, 'ALISKIREN (ALISKIREN FUMARATE)', 'I', 150, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78740, 20175, 'ALISKIREN (ALISKIREN FUMARATE)', 'I', 300, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81838, 20175, 'ALISKIREN (ALISKIREN FUMARATE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81839, 20175, 'ALISKIREN (ALISKIREN FUMARATE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81840, 20175, 'ALISKIREN (ALISKIREN FUMARATE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81841, 20175, 'ALISKIREN (ALISKIREN FUMARATE)', 'I', 300, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43440, 1381, 'FENOFIBRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: FENOFIBRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43375, 1381, 'FENOFIBRATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: FENOFIBRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17849, 1381, 'FENOFIBRATE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: FENOFIBRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51210, 1381, 'FENOFIBRATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63352, 1381, 'FENOFIBRATE', 'I', 200, 'MG', '', '', 'N', '', '(MICRONISED FORMULATION).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63736, 1381, 'FENOFIBRATE', 'I', 200, 'MG', '', '', 'N', '', 'MICRONIZED FENOFIBRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63876, 1381, 'FENOFIBRATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63903, 1381, 'FENOFIBRATE', 'I', 200, 'MG', '', '', 'N', '', '(MICRONISED FORMULATION).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65258, 1381, 'FENOFIBRATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65259, 1381, 'FENOFIBRATE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67060, 1381, 'FENOFIBRATE', 'I', 67, 'MG', '', '', 'N', '', '(MICRONISED FORMULATION).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67469, 1381, 'FENOFIBRATE', 'I', 67, 'MG', '', '', 'N', '', 'Historic Freeform Text: FENOFIBRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67470, 1381, 'FENOFIBRATE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: FENOFIBRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71549, 1381, 'FENOFIBRATE', 'I', 200, 'MG', '', '', 'N', '', 'MICRONIZED FENOFIBRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71739, 1381, 'FENOFIBRATE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: FENOFIBRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71082, 1381, 'FENOFIBRATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71083, 1381, 'FENOFIBRATE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75447, 1381, 'FENOFIBRATE', 'I', 48, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75448, 1381, 'FENOFIBRATE', 'I', 145, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75904, 1381, 'FENOFIBRATE', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FENOFIBRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73482, 1381, 'FENOFIBRATE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73485, 1381, 'FENOFIBRATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77447, 1381, 'FENOFIBRATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77448, 1381, 'FENOFIBRATE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77343, 1381, 'FENOFIBRATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77344, 1381, 'FENOFIBRATE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77156, 1381, 'FENOFIBRATE', 'I', 200, 'MG', '', '', 'N', '', 'MICRONIZED FENOFIBRATE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79587, 1381, 'FENOFIBRATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79588, 1381, 'FENOFIBRATE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84171, 1381, 'FENOFIBRATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84172, 1381, 'FENOFIBRATE', 'I', 160, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44105, 187, 'RIMEXOLONE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: RIMEXOLONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37335, 7532, 'HYDROCORTISONE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37455, 7532, 'HYDROCORTISONE (HYDROCORTISONE ACETATE)', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE ((AS ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51068, 2098, 'CEFACLOR', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (432, 7532, 'HYDROCORTISONE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (433, 7532, 'HYDROCORTISONE', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66276, 7532, 'HYDROCORTISONE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72190, 7532, 'HYDROCORTISONE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28281, 7532, 'HYDROCORTISONE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19238, 7532, 'HYDROCORTISONE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18722, 7532, 'HYDROCORTISONE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15948, 7532, 'HYDROCORTISONE (HYDROCORTISONE ACETATE)', 'I', 1, '%', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE ACETATE ((HYDROCORTISONE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10844, 7532, 'HYDROCORTISONE', 'I', 2.5, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10052, 7532, 'HYDROCORTISONE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9928, 7532, 'HYDROCORTISONE', 'I', 1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5472, 7532, 'HYDROCORTISONE', 'I', 2.5, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5413, 7532, 'HYDROCORTISONE', 'I', 2.5, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7035, 7532, 'HYDROCORTISONE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5634, 7532, 'HYDROCORTISONE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5635, 7532, 'HYDROCORTISONE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6695, 7532, 'HYDROCORTISONE', 'I', 2.5, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3269, 7532, 'HYDROCORTISONE', 'I', 0.032, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3370, 7532, 'HYDROCORTISONE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3347, 7532, 'HYDROCORTISONE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1938, 7532, 'HYDROCORTISONE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1686, 7532, 'HYDROCORTISONE', 'I', 0.1, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (410, 7532, 'HYDROCORTISONE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (411, 7532, 'HYDROCORTISONE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (810, 7532, 'HYDROCORTISONE', 'I', 1, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15605, 7532, 'HYDROCORTISONE (HYDROCORTISONE SODIUM SUCCINATE)', 'I', 1, 'G', '', '', 'N', 'VIAL', 'Historic Freeform Text: HYDROCORTISONE SOD SUCC ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14755, 7532, 'HYDROCORTISONE (HYDROCORTISONE SODIUM SUCCINATE)', 'I', 1, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE SOD SUCCINATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2222, 7532, 'HYDROCORTISONE (HYDROCORTISONE SODIUM SUCCINATE)', 'I', 1, 'G', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15608, 7532, 'HYDROCORTISONE (HYDROCORTISONE SODIUM SUCCINATE)', 'I', 100, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE SOD SUCC ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15607, 7532, 'HYDROCORTISONE (HYDROCORTISONE SODIUM SUCCINATE)', 'I', 250, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: HYDROCORTISONE SOD SUCC ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15606, 7532, 'HYDROCORTISONE (HYDROCORTISONE SODIUM SUCCINATE)', 'I', 500, 'MG', '', '', 'N', 'VIAL', 'Historic Freeform Text: HYDROCORTISONE SOD SUCC ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12346, 7532, 'HYDROCORTISONE (HYDROCORTISONE SODIUM SUCCINATE)', 'I', 100, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE SOD SUCCINATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12229, 7532, 'HYDROCORTISONE (HYDROCORTISONE SODIUM SUCCINATE)', 'I', 250, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE SOD SUCCINATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12703, 7532, 'HYDROCORTISONE (HYDROCORTISONE SODIUM SUCCINATE)', 'I', 500, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE SOD SUCCINATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2221, 7532, 'HYDROCORTISONE (HYDROCORTISONE SODIUM SUCCINATE)', 'I', 500, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2219, 7532, 'HYDROCORTISONE (HYDROCORTISONE SODIUM SUCCINATE)', 'I', 100, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2220, 7532, 'HYDROCORTISONE (HYDROCORTISONE SODIUM SUCCINATE)', 'I', 250, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10186, 7532, 'HYDROCORTISONE', 'I', 200, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2442, 7532, 'HYDROCORTISONE (ADRENAL CORTICAL EXTRACT)', 'I', 200, 'µG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ADRENAL CORTEX ((HYDROCORTISONE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18968, 7532, 'HYDROCORTISONE', 'I', 100, 'MG', '', '60', 'N', 'ML', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11287, 7532, 'HYDROCORTISONE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12843, 7532, 'HYDROCORTISONE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7265, 7532, 'HYDROCORTISONE', 'I', 100, 'MG', '', '60', 'N', 'ML', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49184, 7532, 'HYDROCORTISONE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37334, 7532, 'HYDROCORTISONE', 'I', 5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37454, 7532, 'HYDROCORTISONE (HYDROCORTISONE ACETATE)', 'I', 5, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: HYDROCORTISONE ((AS ACETATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9272, 7532, 'HYDROCORTISONE', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7030, 7532, 'HYDROCORTISONE', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3880, 7532, 'HYDROCORTISONE', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3881, 7532, 'HYDROCORTISONE', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1218, 7532, 'HYDROCORTISONE', 'I', 10, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: HYDROCORTISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61368, 7532, 'HYDROCORTISONE', 'I', 10, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66223, 7532, 'HYDROCORTISONE', 'I', 10, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66275, 7532, 'HYDROCORTISONE', 'I', 5, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71565, 7532, 'HYDROCORTISONE', 'I', 5, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1079, 7630, 'PREDNISOLONE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: PREDNISOLONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (457, 7630, 'PREDNISOLONE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: PREDNISOLONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70215, 7630, 'PREDNISOLONE (PREDNISOLONE ACETATE)', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PREDNISOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14154, 7630, 'PREDNISOLONE (PREDNISOLONE 21-SUCCINATE SODIUM)', 'I', 100, 'MG', '', '10', 'Y', 'ML', 'Historic Freeform Text: PREDNISOLONE BASE ((AS NA SUCCINATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13454, 7630, 'PREDNISOLONE', 'I', 100, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: PREDNISOLONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4719, 7630, 'PREDNISOLONE (PREDNISOLONE 21-SUCCINATE SODIUM)', 'I', 10, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: PREDNISOLONE SOD SUCCINATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49795, 7630, 'PREDNISOLONE (PREDNISOLONE SODIUM PHOSPHATE)', 'I', 5, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69619, 7630, 'PREDNISOLONE (PREDNISOLONE SODIUM PHOSPHATE)', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76309, 7630, 'PREDNISOLONE', 'I', 2.5, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: PREDNISOLONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (56852, 8348, 'CEFADROXIL', 'I', 500, 'MG', '', '', 'N', '', 'CEFADROXIL 500MG AS CEFADROXIL MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64363, 8348, 'CEFADROXIL', 'I', 500, 'MG', '', '', 'N', '', 'SUPPLIED AS CEFADROXIL MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79666, 8348, 'CEFADROXIL', 'I', 500, 'MG', '', '', 'N', '', 'SUPPLIED AS CEFADROXIL MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42947, 8348, 'CEFADROXIL (CEFADROXIL MONOHYDRATE)', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CEFADROXIL ((AS CEFADROXIL MONOHYDRATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (46520, 7423, 'ESTRADIOL BENZOATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: ESTRADIOL BENZOATE Qty Unit: IMP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13412, 6436, 'HYDRALAZINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDRALAZINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19977, 7423, 'ESTRADIOL BENZOATE', 'I', 28, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ESTRADIOL BENZOATE QTY UNIT: IMP  ONE IMPLANT (8 PELLETS) CONTAINS: 200MG TR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13291, 7423, 'ESTRADIOL BENZOATE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: ESTRADIOL BENZOATE Qty Unit: IMP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12840, 7423, 'ESTRADIOL BENZOATE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: ESTRADIOL BENZOATE Qty Unit: IMP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71354, 7423, 'ESTRADIOL BENZOATE', 'I', 14, 'MG', '', '', 'N', '', '14MG/IMPLANT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6075, 7423, 'ESTRADIOL BENZOATE', 'I', 10, 'MG', '', '', 'N', 'IMP', 'Historic Freeform Text: ESTRADIOL BENZOATE Qty Unit: IMP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4594, 7423, 'ESTRADIOL BENZOATE', 'I', 20, 'MG', '', '', 'N', 'IMP', '2.5MG/PELLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1639, 7423, 'ESTRADIOL BENZOATE', 'I', 20, 'MG', '', '', 'N', 'IMP', 'Historic Freeform Text: ESTRADIOL BENZOATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69850, 7423, 'ESTRADIOL BENZOATE', 'I', 20, 'MG', '', '', 'N', 'DOSE', 'Historic Freeform Text: ESTRADIOL BENZOATE Qty Unit: IMP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69853, 7423, 'ESTRADIOL BENZOATE', 'I', 20, 'MG', '', '', 'N', 'DOSE', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11012, 7423, 'ESTRADIOL BENZOATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ESTRADIOL BENZOATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1293, 8017, 'CHLORPROMAZINE (CHLORPROMAZINE HYDROCHLORIDE)', 'I', 50.0, 'MG', '', '', 'N', '', 'CHLORPROMAZINE HYDROCHLORIDE 55.8 MG CHANGED TO CHLORPROMAZINE 50MG INFORMATION FROM MICROFICHE DURI');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1294, 8017, 'CHLORPROMAZINE (CHLORPROMAZINE HYDROCHLORIDE)', 'I', 25.0, 'MG', '', '', 'N', '', 'CHLORPROMAZINE HYDROCHLORIDE 27.9 MG CHANGED TO CHLORPROMAZINE 25MG INFORMATION FROM MICROFICHE DURI');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1295, 8017, 'CHLORPROMAZINE (CHLORPROMAZINE HYDROCHLORIDE)', 'I', 100, 'MG', '', '', 'N', '', 'CHLORPROMAZINE HYDROCHLORIDE 111.6 MG CHANGED TO CHLORPROMAZINE 1000MG INFORMATION FROM MICROFICHE D');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65176, 1777, 'VECURONIUM BROMIDE', 'I', 10.00, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65177, 1777, 'VECURONIUM BROMIDE', 'I', 20.00, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35664, 7508, 'AMCINONIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35665, 7508, 'AMCINONIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35663, 7508, 'AMCINONIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71333, 7508, 'AMCINONIDE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: AMCINONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71334, 7508, 'AMCINONIDE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: AMCINONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71335, 7508, 'AMCINONIDE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: AMCINONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70909, 7508, 'AMCINONIDE', 'I', 0.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16514, 1914, 'FLURBIPROFEN', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLURBIPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16515, 1914, 'FLURBIPROFEN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLURBIPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14092, 1914, 'FLURBIPROFEN', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLURBIPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14093, 1914, 'FLURBIPROFEN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLURBIPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11465, 1914, 'FLURBIPROFEN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLURBIPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11466, 1914, 'FLURBIPROFEN', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLURBIPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6276, 1914, 'FLURBIPROFEN', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLURBIPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6167, 1914, 'FLURBIPROFEN', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLURBIPROFEN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2138, 6311, 'FLUOROURACIL', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: FLUOROURACIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42841, 6311, 'FLUOROURACIL', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FLUOROURACIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10015, 6311, 'FLUOROURACIL', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: FLUOROURACIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1320, 4839, 'FERROUS SULFATE', 'I', 84, '%', '', '', 'N', '%', 'Historic Freeform Text: FERROUS SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21328, 4839, 'FERROUS SULFATE', 'I', 45, 'G', '', '', 'N', 'KG', 'HISTORIC FREEFORM TEXT: FERROUS SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4394, 4839, 'FERROUS SULFATE', 'I', 0.5, 'G', '', '', 'N', 'KG', 'ADDED 2010.04.14 AS PER VDD REQUEST./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10527, 4839, 'FERROUS SULFATE', 'I', 240, 'MG', '', '75', 'N', 'G', 'Historic Freeform Text: FERROUS SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8567, 4839, 'FERROUS SULFATE', 'I', 840, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: FERROUS SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8529, 4839, 'FERROUS SULFATE', 'I', 840, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: FERROUS SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47888, 4839, 'FERROUS SULFATE', 'I', 5, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17904, 10135, 'CHLORTHALIDONE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORTHALIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18139, 10135, 'CHLORTHALIDONE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORTHALIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2467, 10135, 'CHLORTHALIDONE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORTHALIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2468, 10135, 'CHLORTHALIDONE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORTHALIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73131, 10135, 'CHLORTHALIDONE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORTHALIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73132, 10135, 'CHLORTHALIDONE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORTHALIDONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78821, 10135, 'CHLORTHALIDONE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78822, 10135, 'CHLORTHALIDONE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 9278, 'POTASSIUM DICHROMATE', 'I', 0.019, 'MG', '', '', 'N', 'PATCH', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64976, 2295, 'SELENIUM (SELENIUM HVP CHELATE)', 'I', 25, 'µG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81317, 2295, 'SELENIUM (SODIUM SELENITE)', 'I', 247, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20314, 2295, 'SELENIUM (SELENIOUS ACID)', 'I', 20, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: SE ((AS SELENIUM DIOXIDE  MONOHYDRATED))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16225, 2295, 'SELENIUM (SELENIOUS ACID)', 'I', 60, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: SE ((AS SELENIUM DIOXIDE  MONOHYDRATED))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16226, 2295, 'SELENIUM (SELENIOUS ACID)', 'I', 20, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: SE ((AS SELENIUM DIOXIDE  MONOHYDRATED))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16227, 2295, 'SELENIUM (SELENIOUS ACID)', 'I', 60, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: SE ((AS SELENIUM DIOXIDE  MONOHYDRATED))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13559, 2295, 'SELENIUM (SELENIOUS ACID)', 'I', 40, 'µG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: SELENIUM ((AS SELENIOUS ACID))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13020, 2295, 'SELENIUM (SODIUM SELENITE)', 'I', 3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM SELENITE ((SE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12954, 2295, 'SELENIUM (SODIUM SELENITE)', 'I', 3, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: SELENIUM ((AS SOD. SELENITE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6646, 2295, 'SELENIUM (SODIUM SELENITE)', 'I', 6, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SOD SELENITE ((SELENIUM EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4714, 2295, 'SELENIUM (SODIUM SELENITE)', 'I', 5, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM SELENITE ((SELENIUM 5MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4517, 2295, 'SELENIUM (SODIUM SELENITE)', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM SELENITE ((SELENIUM 2.5MG EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2473, 2295, 'SELENIUM (SODIUM SELENITE)', 'I', 3, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: SODIUM SELENITE ((SELENIUM EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (870, 2295, 'SELENIUM (SODIUM SELENITE)', 'I', 3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: SODIUM SELENITE ((SELENIUM EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61485, 4608, 'CHLORINE (SODIUM DICHLORO-S-TRIAZINETRIONE)', 'I', 3.1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49958, 3540, 'ALUMINUM AMMONIUM SULFATE DODECAHYDRATE', 'I', 20, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76196, 3540, 'ALUMINUM AMMONIUM SULFATE DODECAHYDRATE', 'I', 20, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1320, 3540, 'ALUMINUM AMMONIUM SULFATE DODECAHYDRATE', 'I', 5, '%', '', '', 'N', '%', 'Historic Freeform Text: ALUMINUM AMMONIUM SULFATE DODECAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8567, 3540, 'ALUMINUM AMMONIUM SULFATE DODECAHYDRATE', 'I', 50, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: ALUMINUM AMMONIUM SULFATE DODECAHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10525, 1236, 'CEFIXIME', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEFIXIME');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10523, 1236, 'CEFIXIME', 'I', 100, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CEFIXIME');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12959, 6436, 'HYDRALAZINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDRALAZINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13413, 6436, 'HYDRALAZINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDRALAZINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11047, 6436, 'HYDRALAZINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDRALAZINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11626, 6436, 'HYDRALAZINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDRALAZINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11627, 6436, 'HYDRALAZINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDRALAZINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10026, 10146, 'HALOPERIDOL', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HALOPERIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12691, 6436, 'HYDRALAZINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDRALAZINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8475, 6436, 'HYDRALAZINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDRALAZINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8476, 6436, 'HYDRALAZINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDRALAZINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12237, 6436, 'HYDRALAZINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'AMP', 'HISTORIC FREEFORM TEXT: HYDRALAZINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1193, 10153, 'CHLORAMBUCIL', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CHLORAMBUCIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36396, 20154, 'PHENOLATE SODIUM', 'I', 0.06, '%', '', '', 'N', '', 'Historic Freeform Text: SODIUM PHENOLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36398, 20154, 'PHENOLATE SODIUM', 'I', 0.06, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: SODIUM PHENOLATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78965, 20181, 'DESMOPRESSIN ACETATE TRIHYDRATE', 'I', 0.1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78966, 20181, 'DESMOPRESSIN ACETATE TRIHYDRATE', 'I', 0.2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83219, 20181, 'DESMOPRESSIN ACETATE TRIHYDRATE', 'I', 0.1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83220, 20181, 'DESMOPRESSIN ACETATE TRIHYDRATE', 'I', 0.2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49070, 11262, 'GEMCITABINE (GEMCITABINE HYDROCHLORIDE)', 'I', 1, 'G', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78409, 11262, 'GEMCITABINE (GEMCITABINE HYDROCHLORIDE)', 'I', 1, 'G', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79108, 11262, 'GEMCITABINE (GEMCITABINE HYDROCHLORIDE)', 'I', 1, 'G', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80969, 11262, 'GEMCITABINE (GEMCITABINE HYDROCHLORIDE)', 'I', 1, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78742, 11262, 'GEMCITABINE (GEMCITABINE HYDROCHLORIDE)', 'I', 1, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80422, 11262, 'GEMCITABINE (GEMCITABINE HYDROCHLORIDE)', 'I', 2, 'G', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49068, 11262, 'GEMCITABINE (GEMCITABINE HYDROCHLORIDE)', 'I', 200, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78408, 11262, 'GEMCITABINE (GEMCITABINE HYDROCHLORIDE)', 'I', 200, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79107, 11262, 'GEMCITABINE (GEMCITABINE HYDROCHLORIDE)', 'I', 200, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78741, 11262, 'GEMCITABINE (GEMCITABINE HYDROCHLORIDE)', 'I', 200, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50230, 7044, 'DICHLOROPHENE', 'I', 400, 'MG', '', '', 'N', '', 'FAWN TABLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50331, 7044, 'DICHLOROPHENE', 'I', 250, 'MG', '', '', 'N', '', 'FAWN TABLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3667, 7044, 'DICHLOROPHENE', 'I', 8.3, '%', '', '', 'N', '%', 'Historic Freeform Text: DICHLOROPHENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63399, 11384, 'TOPIRAMATE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63400, 11384, 'TOPIRAMATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76522, 11384, 'TOPIRAMATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50171, 11384, 'TOPIRAMATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50172, 11384, 'TOPIRAMATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50174, 11384, 'TOPIRAMATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76524, 11384, 'TOPIRAMATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76525, 11384, 'TOPIRAMATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75324, 11384, 'TOPIRAMATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74206, 11384, 'TOPIRAMATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74207, 11384, 'TOPIRAMATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74208, 11384, 'TOPIRAMATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75663, 11384, 'TOPIRAMATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75664, 11384, 'TOPIRAMATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75665, 11384, 'TOPIRAMATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75666, 11384, 'TOPIRAMATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75667, 11384, 'TOPIRAMATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75668, 11384, 'TOPIRAMATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74529, 11384, 'TOPIRAMATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74530, 11384, 'TOPIRAMATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73232, 11384, 'TOPIRAMATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73233, 11384, 'TOPIRAMATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73234, 11384, 'TOPIRAMATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74840, 11384, 'TOPIRAMATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74841, 11384, 'TOPIRAMATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74842, 11384, 'TOPIRAMATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74874, 11384, 'TOPIRAMATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74875, 11384, 'TOPIRAMATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74876, 11384, 'TOPIRAMATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77316, 11384, 'TOPIRAMATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77317, 11384, 'TOPIRAMATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77318, 11384, 'TOPIRAMATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81053, 11384, 'TOPIRAMATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81054, 11384, 'TOPIRAMATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81055, 11384, 'TOPIRAMATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79760, 11384, 'TOPIRAMATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80117, 11384, 'TOPIRAMATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80118, 11384, 'TOPIRAMATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80119, 11384, 'TOPIRAMATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79915, 11384, 'TOPIRAMATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79916, 11384, 'TOPIRAMATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79917, 11384, 'TOPIRAMATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83087, 11384, 'TOPIRAMATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83085, 11384, 'TOPIRAMATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83088, 11384, 'TOPIRAMATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84197, 11384, 'TOPIRAMATE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84198, 11384, 'TOPIRAMATE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84199, 11384, 'TOPIRAMATE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 5805, 'DISULFIRAM', 'I', 0.005, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS THIURAM MIX 0.02MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9615, 7420, 'ESTRADIOL VALERATE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ESTRADIOL VALERATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76288, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67912, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67924, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68031, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68034, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68035, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69079, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69080, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75162, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75163, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75189, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75190, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75283, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 2.0, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75285, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 2.0, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75286, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 4.0, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81416, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 1.0, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80101, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80102, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 2, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80103, 10205, 'BROMPHENIRAMINE MALEATE', 'I', 4, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13370, 768, 'FINASTERIDE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FINASTERIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61606, 768, 'FINASTERIDE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79259, 768, 'FINASTERIDE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FINASTERIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79578, 768, 'FINASTERIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82509, 768, 'FINASTERIDE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80561, 768, 'FINASTERIDE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80802, 768, 'FINASTERIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83386, 768, 'FINASTERIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83421, 768, 'FINASTERIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83549, 768, 'FINASTERIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83963, 768, 'FINASTERIDE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FINASTERIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84031, 768, 'FINASTERIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84122, 768, 'FINASTERIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84235, 768, 'FINASTERIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5748, 6462, 'ARSANILIC ACID', 'I', 200, 'G', '', '', 'N', 'KG', 'Historic Freeform Text: ARSANILIC ACID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (134, 5257, 'NITROBENZENE', 'I', 360, 'G', '', '11.35', 'N', 'KG', 'Historic Freeform Text: NITROBENZENE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82603, 11834, 'IMIQUIMOD', 'I', 3.75, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85046, 11834, 'IMIQUIMOD', 'I', 3.75, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62979, 11834, 'IMIQUIMOD', 'I', 50, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79459, 20215, 'NEPAFENAC', 'I', 0.1, '%', '', '', 'N', 'W/V', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79490, 6777, 'LACTIC ACID', 'I', 0.18, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80740, 6777, 'LACTIC ACID', 'I', 0.18, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76308, 6777, 'LACTIC ACID', 'I', 5.400, 'G', '', '1000', 'N', 'ML', 'SOLUTION A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76310, 6777, 'LACTIC ACID', 'I', 5.400, 'G', '', '1000', 'N', 'ML', 'SOLUTION A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12181, 6289, 'EDROPHONIUM CHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EDROPHONIUM CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10494, 20230, 'AMILORIDE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMILORIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12430, 20230, 'AMILORIDE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMILORIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10806, 20230, 'AMILORIDE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMILORIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11966, 20230, 'AMILORIDE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMILORIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74257, 20230, 'AMILORIDE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMILORIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73433, 20230, 'AMILORIDE HYDROCHLORIDE', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75772, 16581, 'PEGVISOMANT', 'I', 10, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75774, 16581, 'PEGVISOMANT', 'I', 15, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75775, 16581, 'PEGVISOMANT', 'I', 20, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76514, 18848, 'TRYPAN BLUE', 'I', 0.06, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65585, 8923, 'EPINEPHRINE BITARTRATE', 'I', 9.1, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65586, 8923, 'EPINEPHRINE BITARTRATE', 'I', 9.1, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75640, 8923, 'EPINEPHRINE BITARTRATE', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75645, 8923, 'EPINEPHRINE BITARTRATE', 'I', 0.02, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79742, 8923, 'EPINEPHRINE BITARTRATE', 'I', 0.0091, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79063, 8923, 'EPINEPHRINE BITARTRATE', 'I', 0.0091, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82513, 8923, 'EPINEPHRINE BITARTRATE', 'I', 0.009, 'MG', '', '', 'N', 'ML', 'EPINEPHRINE 1:200000');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82514, 8923, 'EPINEPHRINE BITARTRATE', 'I', 0.018, 'MG', '', '', 'N', 'ML', 'EPINEPHRINE 1:100000');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19460, 7526, 'FLUDROCORTISONE 21-ACETATE', 'I', 0.1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUDROCORTISONE 21-ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7203, 5642, 'NAPHAZOLINE NITRATE', 'I', 0.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: NAPHAZOLINE NITRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (258, 8954, 'HOMATROPINE HYDROBROMIDE', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: HOMATROPINE HYDROBROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (257, 8954, 'HOMATROPINE HYDROBROMIDE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: HOMATROPINE HYDROBROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19401, 9622, 'CARBACHOL', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: CARBACHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3906, 9622, 'CARBACHOL', 'I', 0.01, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBACHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (575, 9622, 'CARBACHOL', 'I', 1.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBACHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (255, 9622, 'CARBACHOL', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: CARBACHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17400, 9622, 'CARBACHOL', 'I', 0.25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CARBACHOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12549, 7948, 'ETHOPROPAZINE (ETHOPROPAZINE HYDROCHLORIDE)', 'I', 50, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: ETHOPROPAZINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8595, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8596, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5846, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5847, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6733, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6734, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6735, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6737, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 60, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6122, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11597, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7123, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6539, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6540, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6903, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6182, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MORPHINE HYDROCHLORIDE TIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6183, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: MORPHINE HYDROCHLORIDE TRIHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6171, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6736, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3752, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4297, 9913, 'MORPHINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MORPHINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37239, 1313, 'PERMETHRIN', 'I', 5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PERMETHRIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8964, 1313, 'PERMETHRIN', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: PERMETHRIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50657, 1313, 'PERMETHRIN', 'I', 5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50804, 1313, 'PERMETHRIN', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84909, 1313, 'PERMETHRIN', 'I', 10, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (287, 10302, 'D-PENICILLAMINE', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: D-             PENICILLAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8170, 10146, 'HALOPERIDOL', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: HALOPERIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8171, 10146, 'HALOPERIDOL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: HALOPERIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8172, 10146, 'HALOPERIDOL', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: HALOPERIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8477, 10146, 'HALOPERIDOL', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: HALOPERIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7128, 10146, 'HALOPERIDOL', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: HALOPERIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7129, 10146, 'HALOPERIDOL', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: HALOPERIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7130, 10146, 'HALOPERIDOL', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: HALOPERIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7131, 10146, 'HALOPERIDOL', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: HALOPERIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5859, 10146, 'HALOPERIDOL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: HALOPERIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3918, 10146, 'HALOPERIDOL', 'I', 0.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: HALOPERIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3919, 10146, 'HALOPERIDOL', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: HALOPERIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16901, 10146, 'HALOPERIDOL (HALOPERIDOL DECANOATE)', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HALOPERIDOL ((AS DECANOATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16902, 10146, 'HALOPERIDOL (HALOPERIDOL DECANOATE)', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HALOPERIDOL ((AS DECANOATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8558, 10146, 'HALOPERIDOL', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HALOPERIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5197, 10146, 'HALOPERIDOL', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HALOPERIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49965, 10146, 'HALOPERIDOL (HALOPERIDOL DECANOATE)', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49967, 10146, 'HALOPERIDOL (HALOPERIDOL DECANOATE)', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63111, 10146, 'HALOPERIDOL (HALOPERIDOL DECANOATE)', 'I', 50, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63112, 10146, 'HALOPERIDOL (HALOPERIDOL DECANOATE)', 'I', 100, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66072, 10146, 'HALOPERIDOL (HALOPERIDOL DECANOATE)', 'I', 50, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66074, 10146, 'HALOPERIDOL (HALOPERIDOL DECANOATE)', 'I', 100, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44807, 7566, 'PREDNISONE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PREDNISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17756, 7566, 'PREDNISONE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: PREDNISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14281, 7566, 'PREDNISONE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: PREDNISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6402, 7566, 'PREDNISONE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PREDNISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5826, 7566, 'PREDNISONE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: PREDNISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4732, 7566, 'PREDNISONE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PREDNISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4736, 7566, 'PREDNISONE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: PREDNISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1286, 7566, 'PREDNISONE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: PREDNISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3076, 7566, 'PREDNISONE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: PREDNISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (733, 7566, 'PREDNISONE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PREDNISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (507, 7566, 'PREDNISONE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PREDNISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (236, 7566, 'PREDNISONE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: PREDNISONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66101, 7566, 'PREDNISONE', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63884, 5080, 'ANETHOLE TRITHIONE', 'I', 25.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15176, 2097, 'PINAVERIUM BROMIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: PINAVERIUM BROMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49943, 2097, 'PINAVERIUM BROMIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18988, 7624, 'METHYLPREDNISOLONE ACETATE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METHYLPREDNISOLONE-21-ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16275, 7624, 'METHYLPREDNISOLONE ACETATE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METHYLPREDNISOLONE-21-ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16276, 7624, 'METHYLPREDNISOLONE ACETATE', 'I', 80, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METHYLPREDNISOLONE-21-ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13821, 7624, 'METHYLPREDNISOLONE ACETATE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METHYLPREDNISOLONE ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10781, 7624, 'METHYLPREDNISOLONE ACETATE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METHYLPREDNISOLONE-21-ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4716, 7624, 'METHYLPREDNISOLONE ACETATE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METHYLPREDNISOLONE-21-ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1394, 7624, 'METHYLPREDNISOLONE ACETATE', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METHYLPREDNISOLONE-21-ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2543, 7624, 'METHYLPREDNISOLONE ACETATE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METHYLPREDNISOLONE-21-ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1134, 7624, 'METHYLPREDNISOLONE ACETATE', 'I', 40, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: METHYLPREDNISOLONE-21-ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1619, 7624, 'METHYLPREDNISOLONE ACETATE', 'I', 40, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: METHYLPREDNISOLONE-21-ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1527, 7624, 'METHYLPREDNISOLONE ACETATE', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: METHYLPREDNISOLONE-21-ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (789, 7624, 'METHYLPREDNISOLONE ACETATE', 'I', 80, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: METHYLPREDNISOLONE-21-ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69444, 7624, 'METHYLPREDNISOLONE ACETATE', 'I', 40, 'MG', '', '', 'N', 'ML', 'SINGLE USE VIAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69454, 7624, 'METHYLPREDNISOLONE ACETATE', 'I', 80, 'MG', '', '', 'N', 'ML', 'MULTIDOSE VIAL WITH PRESERVATIVE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69455, 7624, 'METHYLPREDNISOLONE ACETATE', 'I', 40, 'MG', '', '', 'N', 'ML', 'SINGLE USE VIAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69456, 7624, 'METHYLPREDNISOLONE ACETATE', 'I', 80, 'MG', '', '', 'N', 'ML', 'MULTIDOSE VIAL WITH PRESERVATIVE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47126, 1338, 'ACETYL-L-TYROSINE', 'I', 115, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: N-ACETYL-L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18701, 1338, 'ACETYL-L-TYROSINE', 'I', 115, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: N-ACETYL-L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18700, 1338, 'ACETYL-L-TYROSINE', 'I', 94, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: N-ACETYL-L-TYROSINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1251, 6103, 'PARAFORMALDEHYDE', 'I', 2.2, 'G', '', '100', 'N', 'G', 'Historic Freeform Text: PARAFORMALDEHYDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18800, 1997, 'FLUPENTIXOL DECANOATE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FLUPENTHIXOL DECANOATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18737, 1997, 'FLUPENTIXOL DECANOATE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FLUPENTHIXOL DECANOATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81742, 1997, 'FLUPENTIXOL DECANOATE', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2189, 7425, 'ESTRADIOL CYPIONATE', 'I', 4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ESTRADIOL-17-B-CYPIONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78467, 7425, 'ESTRADIOL CYPIONATE', 'I', 1.0, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11221, 2434, 'MEBENDAZOLE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: MEBENDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4743, 2434, 'MEBENDAZOLE', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: MEBENDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12328, 2434, 'MEBENDAZOLE', 'I', 200, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: MEBENDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67886, 2434, 'MEBENDAZOLE', 'I', 100, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11224, 7486, 'TESTOSTERONE ENANTHATE', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TESTOSTERONE ENANTHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11012, 7486, 'TESTOSTERONE ENANTHATE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TESTOSTERONE ENANTHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1275, 7486, 'TESTOSTERONE ENANTHATE', 'I', 200, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TESTOSTERONE ENANTHATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14688, 9963, 'AMINOPHYLLINE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMINOPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13453, 9963, 'AMINOPHYLLINE', 'I', 1, 'G', '', '15', 'N', 'ML', 'Historic Freeform Text: AMINOPHYLLIN ((ANHYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13454, 9963, 'AMINOPHYLLINE', 'I', 1, 'G', '', '15', 'N', 'ML', 'Historic Freeform Text: AMINOPHYLLIN ((ANYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (28683, 9963, 'AMINOPHYLLINE', 'I', 66.67, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: AMINOPHYLLIN ((ANYDROUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5704, 9963, 'AMINOPHYLLINE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: AMINOPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5705, 9963, 'AMINOPHYLLINE', 'I', 25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: AMINOPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4226, 9963, 'AMINOPHYLLINE', 'I', 25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: AMINOPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4227, 9963, 'AMINOPHYLLINE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: AMINOPHYLLINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (29542, 1896, 'LABETALOL HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: LABETALOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (29543, 1896, 'LABETALOL HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: LABETALOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67456, 1896, 'LABETALOL HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: LABETALOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67457, 1896, 'LABETALOL HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: LABETALOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51066, 1896, 'LABETALOL HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (39484, 8917, 'EPINEPHRINE RACEMIC', 'I', 22.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE RACEMIC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85000, 8565, 'TOBRAMYCIN', 'I', 28, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11068, 8565, 'TOBRAMYCIN', 'I', 0.3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TOBRAMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10971, 8565, 'TOBRAMYCIN', 'I', 0.3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TOBRAMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65418, 8565, 'TOBRAMYCIN', 'I', 0.3, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69799, 8565, 'TOBRAMYCIN', 'I', 0.3, '%', '', '', 'N', '', 'W/V');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5402, 8565, 'TOBRAMYCIN (TOBRAMYCIN SULFATE)', 'I', 1.2, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77066, 8565, 'TOBRAMYCIN (TOBRAMYCIN SULFATE)', 'I', 1.2, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4571, 8565, 'TOBRAMYCIN', 'I', 0.3, '%', '', '', 'N', '%', 'Historic Freeform Text: TOBRAMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49816, 8565, 'TOBRAMYCIN (TOBRAMYCIN SULFATE)', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50749, 2098, 'CEFACLOR', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49817, 8565, 'TOBRAMYCIN (TOBRAMYCIN SULFATE)', 'I', 40, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63055, 8565, 'TOBRAMYCIN', 'I', 3, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63101, 8565, 'TOBRAMYCIN (TOBRAMYCIN SULFATE)', 'I', 300, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64815, 8565, 'TOBRAMYCIN (TOBRAMYCIN SULFATE)', 'I', 10, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64816, 8565, 'TOBRAMYCIN (TOBRAMYCIN SULFATE)', 'I', 40, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5707, 8565, 'TOBRAMYCIN', 'I', 3, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: TOBRAMYCIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10225, 1897, 'AMITRAZ', 'I', 19.9, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43349, 1890, 'BUSPIRONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUSPIRONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19799, 1890, 'BUSPIRONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUSPIRONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20011, 1890, 'BUSPIRONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: BUSPIRONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52040, 1890, 'BUSPIRONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50219, 1890, 'BUSPIRONE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50220, 1890, 'BUSPIRONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50822, 1890, 'BUSPIRONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50317, 1890, 'BUSPIRONE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50318, 1890, 'BUSPIRONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65827, 1890, 'BUSPIRONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74832, 1890, 'BUSPIRONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15902, 1898, 'AURANOFIN', 'I', 3, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AURANOFIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11743, 1925, 'TRIMEBUTINE MALEATE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIMEBUTINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69763, 1925, 'TRIMEBUTINE MALEATE', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TRIMEBUTINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69764, 1925, 'TRIMEBUTINE MALEATE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIMEBUTINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13314, 6161, 'HYDROCODONE BITARTRATE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIHYDROCODEINONE BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16635, 6161, 'HYDROCODONE BITARTRATE', 'I', 5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIHYDROCODEINONE BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16640, 6161, 'HYDROCODONE BITARTRATE', 'I', 1.7, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIHYDROCODEINONE BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13315, 6161, 'HYDROCODONE BITARTRATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIHYDROCODEINONE BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5475, 6161, 'HYDROCODONE BITARTRATE', 'I', 0.33, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIHYDROCODEINONE BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7082, 6161, 'HYDROCODONE BITARTRATE', 'I', 5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIHYDROCODEINONE BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4124, 6161, 'HYDROCODONE BITARTRATE', 'I', 2.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DIHYDROCODEINONE BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4615, 6161, 'HYDROCODONE BITARTRATE', 'I', 0.33, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIHYDROCODEINONE BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50030, 6161, 'HYDROCODONE BITARTRATE', 'I', 0.33, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIHYDROCODEINONE BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68035, 6161, 'HYDROCODONE BITARTRATE', 'I', 1.8, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80973, 6161, 'HYDROCODONE BITARTRATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DIHYDROCODEINONE BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43484, 11085, 'DOBUTAMINE (DOBUTAMINE HYDROCHLORIDE)', 'I', 12.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DOBUTAMINE ((AS DOBUTAMINE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43041, 11085, 'DOBUTAMINE (DOBUTAMINE HYDROCHLORIDE)', 'I', 12.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DOBUTAMINE ((AS DOBUTAMINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47337, 11085, 'DOBUTAMINE (DOBUTAMINE HYDROCHLORIDE)', 'I', 12.5, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65680, 11085, 'DOBUTAMINE (DOBUTAMINE HYDROCHLORIDE)', 'I', 12.5, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43485, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LOPERAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43486, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOPERAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43419, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LOPERAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35201, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOPERAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20012, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOPERAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18071, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOPERAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (47464, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49614, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60618, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'FORM = CHEWABLE TABLET.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61436, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61604, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63011, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69200, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOPERAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74169, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LOPERAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74281, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOPERAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73379, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOPERAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78349, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: LOPERAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42934, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LOPERAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19218, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LOPERAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14567, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 0.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LOPERAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77716, 2251, 'LOPERAMIDE HYDROCHLORIDE', 'I', 2, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81886, 20014, 'GADOFOSVESET TRISODIUM', 'I', 244, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64641, 20380, 'VARICELLA-ZOSTER VIRUS VACCINE LIVE ATTENUATED (OKA/MERCK STRAIN)', 'I', 2000, 'UNIT', '', '0.5', 'N', 'ML', '2000 PFU/VIAL/KIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70216, 20380, 'VARICELLA-ZOSTER VIRUS VACCINE LIVE ATTENUATED (OKA/MERCK STRAIN)', 'I', 1350, 'UNIT', '', '0.5', 'N', 'ML', 'PFU=PLAQUE FORMING UNITS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78322, 20380, 'VARICELLA-ZOSTER VIRUS VACCINE LIVE ATTENUATED (OKA/MERCK STRAIN)', 'I', 1995.2623, 'UNIT', '', '0.5', 'N', 'ML', 'VARICELLA VIRUS VACCINE LIVE ATTENUATED OKA         STRAIN >= 10 TO THE POWER OF 3.3 CCID SUBSCRIPT ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80146, 20380, 'VARICELLA-ZOSTER VIRUS VACCINE LIVE ATTENUATED (OKA/MERCK STRAIN)', 'I', 19400, 'PFU', '', '0.65', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17004, 20237, 'CHLORPROMAZINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CHLORPROMAZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8488, 20237, 'CHLORPROMAZINE HYDROCHLORIDE', 'I', 27.9, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CHLORPROMAZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8524, 20239, 'CLENBUTEROL HYDROCHLORIDE', 'I', 0.025, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CLENBUTEROL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5921, 20239, 'CLENBUTEROL HYDROCHLORIDE', 'I', 0.03, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CLENBUTEROL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (25828, 20241, 'COCAINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: COCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18334, 20241, 'COCAINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: COCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13391, 20241, 'COCAINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: COCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12625, 20241, 'COCAINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: COCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4388, 20246, 'PHENAZOPYRIDINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PHENAZOPYRIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4260, 20246, 'PHENAZOPYRIDINE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PHENAZOPYRIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3329, 20246, 'PHENAZOPYRIDINE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: PHENAZOPYRIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1695, 20246, 'PHENAZOPYRIDINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: PHENAZOPYRIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (937, 20254, 'DIPHENOXYLATE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPHENOXYLATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5590, 20256, 'DODICIN HYDROCHLORIDE', 'I', 10, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DODICIN HCL 2010.08.10. ACTIVE INGREDIENT NAME CHANGED FROM DODICIN HYDROCHL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5132, 20256, 'DODICIN HYDROCHLORIDE', 'I', 3.5, '%', '', '', 'N', '', 'Historic Freeform Text: DODICIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2405, 20256, 'DODICIN HYDROCHLORIDE', 'I', 3, '%', '', '', 'N', '', 'Historic Freeform Text: DODICIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9525, 8921, 'EPINEPHRINE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9528, 8921, 'EPINEPHRINE HYDROCHLORIDE', 'I', 0.01, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: EPINEPHRINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78641, 20259, 'EPIRUBICIN HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'VIAL', 'EACH VIAL OF LYOPHILIZED POWDER ACTUALLY CONTAINS EPIRUBICIN HYDROCHLORIDE 50.3MG, HOWEVER, FIRST PA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18504, 20259, 'EPIRUBICIN HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: EPIRUBICIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75043, 20259, 'EPIRUBICIN HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79761, 20259, 'EPIRUBICIN HYDROCHLORIDE', 'I', 2.0, 'MG', '', '', 'N', 'ML', 'EACH VIAL OF LYOPHILIZED POWDER ACTUALLY CONTAINS EPIRUBICIN HYDROCHLORIDE 50.3MG, HOWEVER, FIRST PA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78921, 20259, 'EPIRUBICIN HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80958, 20259, 'EPIRUBICIN HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42910, 20260, 'ESMOLOL HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ESMOLOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79483, 20260, 'ESMOLOL HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', '250ML (10MG/ML) PREMIXED BAG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1471, 20261, 'ETHAMBUTOL HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHAMBUTOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1472, 20261, 'ETHAMBUTOL HYDROCHLORIDE', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHAMBUTOL HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12572, 20269, 'FLUPHENAZINE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUPHENAZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12573, 20269, 'FLUPHENAZINE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUPHENAZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12574, 20269, 'FLUPHENAZINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUPHENAZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2858, 20269, 'FLUPHENAZINE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUPHENAZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2859, 20269, 'FLUPHENAZINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUPHENAZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2860, 20269, 'FLUPHENAZINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUPHENAZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2861, 20269, 'FLUPHENAZINE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUPHENAZINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43838, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROMORPHONE HCL Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35655, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35658, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 8, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20171, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 12, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROMORPHONE HCL Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20172, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 24, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROMORPHONE HCL Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18556, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 3, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROMORPHONE HCL Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18558, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 6, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROMORPHONE HCL Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13113, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 3, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11869, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 3, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11428, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11425, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11413, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11363, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9509, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 8, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5940, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 4, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5939, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6889, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67480, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 18, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROMORPHONE HCL QTY UNIT: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69806, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69807, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69808, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 8, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73474, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73475, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82286, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82287, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 8, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82288, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 16, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82289, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 32, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84452, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 4.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84453, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 9.0, 'MG', '', '', 'N', '', 'Historic Freeform Text: HYDROMORPHONE HCL Qty Unit: SRC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16679, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17822, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17823, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18323, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18324, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18325, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18315, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11870, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10173, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5936, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5937, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68787, 20280, 'HYDROMORPHONE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: HYDROMORPHONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13591, 11177, 'LODOXAMIDE (LODOXAMIDE TROMETHAMINE)', 'I', 0.1, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: LODOXAMIDE TROMETHAMINE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42872, 2098, 'CEFACLOR', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEFACLOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42873, 2098, 'CEFACLOR', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: CEFACLOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3728, 2098, 'CEFACLOR', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3729, 2098, 'CEFACLOR', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48998, 2098, 'CEFACLOR', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48999, 2098, 'CEFACLOR', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50748, 2098, 'CEFACLOR', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (51070, 2098, 'CEFACLOR', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61083, 2098, 'CEFACLOR', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61084, 2098, 'CEFACLOR', 'I', 500, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42874, 2098, 'CEFACLOR', 'I', 25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CEFACLOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42875, 2098, 'CEFACLOR', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CEFACLOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42876, 2098, 'CEFACLOR', 'I', 75, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: CEFACLOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10545, 2098, 'CEFACLOR', 'I', 375, 'MG', '', '5', 'N', 'ML', 'CEFACLOR 386.3 MG/5 ML (EQUIVALENT TO)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3730, 2098, 'CEFACLOR', 'I', 125, 'MG', '', '5', 'Y', 'ML', 'EQUIVALENT TO 128.8 MG/5 ML CEFACLOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3731, 2098, 'CEFACLOR', 'I', 250, 'MG', '', '5', 'Y', 'ML', 'EQUIVALENT TO 257.7 MG/5ML OF CEFACLOR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60834, 2098, 'CEFACLOR', 'I', 125, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60835, 2098, 'CEFACLOR', 'I', 250, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60836, 2098, 'CEFACLOR', 'I', 375, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18060, 3776, 'METOCLOPRAMIDE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOCLOPRAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18061, 3776, 'METOCLOPRAMIDE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOCLOPRAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10495, 3776, 'METOCLOPRAMIDE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOCLOPRAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10496, 3776, 'METOCLOPRAMIDE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: METOCLOPRAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49332, 3776, 'METOCLOPRAMIDE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49335, 3776, 'METOCLOPRAMIDE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42950, 3776, 'METOCLOPRAMIDE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: METOCLOPRAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19409, 3776, 'METOCLOPRAMIDE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METOCLOPRAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49340, 3776, 'METOCLOPRAMIDE HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67481, 3776, 'METOCLOPRAMIDE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: METOCLOPRAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37370, 10091, 'FUROSEMIDE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37375, 10091, 'FUROSEMIDE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37369, 10091, 'FUROSEMIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19189, 10091, 'FUROSEMIDE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9240, 10091, 'FUROSEMIDE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6827, 10091, 'FUROSEMIDE', 'I', 80, 'MG', '', '', 'N', '', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3809, 10091, 'FUROSEMIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2472, 10091, 'FUROSEMIDE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2447, 10091, 'FUROSEMIDE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2333, 10091, 'FUROSEMIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2851, 10091, 'FUROSEMIDE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2798, 10091, 'FUROSEMIDE', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62684, 10091, 'FUROSEMIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62685, 10091, 'FUROSEMIDE', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71616, 10091, 'FUROSEMIDE', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71617, 10091, 'FUROSEMIDE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71743, 10091, 'FUROSEMIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71744, 10091, 'FUROSEMIDE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72451, 10091, 'FUROSEMIDE', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72452, 10091, 'FUROSEMIDE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83669, 10091, 'FUROSEMIDE', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83670, 10091, 'FUROSEMIDE', 'I', 40, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83671, 10091, 'FUROSEMIDE', 'I', 80, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37372, 10091, 'FUROSEMIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12218, 10091, 'FUROSEMIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6884, 10091, 'FUROSEMIDE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4431, 10091, 'FUROSEMIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4910, 10091, 'FUROSEMIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: FUROSEMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68956, 10091, 'FUROSEMIDE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84533, 10091, 'FUROSEMIDE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84539, 10091, 'FUROSEMIDE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43365, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUOXETINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43366, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUOXETINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79246, 20195, 'ETRAVIRINE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20259, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: FLUOXETINE ((AS FLUOXETINE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20260, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: FLUOXETINE ((AS FLUOXETINE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19961, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUOXETINE ((AS FLUOXETINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19962, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUOXETINE ((AS FLUOXETINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19916, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19895, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUOXETINE ((AS FLUOXETINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19064, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19071, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUOXETINE ((AS FLUOXETINE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19073, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUOXETINE ((AS FLUOXETINE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19074, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13723, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', 'Historic Freeform Text: FLUOXETINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9703, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: FLUOXETINE HCL ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61172, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61173, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63304, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63305, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65801, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: FLUOXETINE ((AS FLUOXETINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65802, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: FLUOXETINE ((AS FLUOXETINE HCL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65856, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65857, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65003, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65006, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67397, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUOXETINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67398, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUOXETINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77154, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77155, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79361, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 8, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79362, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 16, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79363, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 32, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79364, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 64, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79103, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79104, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80053, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', 'Historic Freeform Text: FLUOXETINE ((AS FLUOXETINE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80054, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', '', 'Historic Freeform Text: FLUOXETINE ((AS FLUOXETINE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78795, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', '', 'Historic Freeform Text: FLUOXETINE ((AS FLUOXETINE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78796, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: FLUOXETINE ((AS FLUOXETINE HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82954, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82955, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43418, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: FLUOXETINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44218, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: FLUOXETINE ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50635, 11130, 'FLUOXETINE (FLUOXETINE HYDROCHLORIDE)', 'I', 20, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8199, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 75, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9417, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9418, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9346, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5717, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5726, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5727, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3141, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3413, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 75, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1929, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1878, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1263, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1264, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1265, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2426, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2427, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1690, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2213, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2214, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2215, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71408, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71409, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71411, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71545, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71546, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71547, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72460, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72461, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72462, 10187, 'AMITRIPTYLINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: AMITRIPTYLINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13030, 1263, 'ALBENDAZOLE', 'I', 113.6, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ALBENDAZOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43086, 11118, 'CEFUROXIME (CEFUROXIME AXETIL)', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CEFUROXIME ((AS CEFUROXIME AXETIL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43087, 11118, 'CEFUROXIME (CEFUROXIME AXETIL)', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CEFUROXIME ((AS CEFUROXIME AXETIL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66439, 11118, 'CEFUROXIME (CEFUROXIME AXETIL)', 'I', 250, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66440, 11118, 'CEFUROXIME (CEFUROXIME AXETIL)', 'I', 500, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68362, 11118, 'CEFUROXIME (CEFUROXIME AXETIL)', 'I', 250, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68363, 11118, 'CEFUROXIME (CEFUROXIME AXETIL)', 'I', 500, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79704, 11118, 'CEFUROXIME (CEFUROXIME AXETIL)', 'I', 500, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65299, 11118, 'CEFUROXIME (CEFUROXIME SODIUM)', 'I', 1.5, 'G', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65300, 11118, 'CEFUROXIME (CEFUROXIME SODIUM)', 'I', 7.5, 'G', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65298, 11118, 'CEFUROXIME (CEFUROXIME SODIUM)', 'I', 750, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43089, 11118, 'CEFUROXIME (CEFUROXIME AXETIL)', 'I', 125, 'MG', '', '5', 'Y', 'ML', 'Historic Freeform Text: CEFUROXIME ((AS CEFUROXIME AXETIL))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2148, 6896, 'GUAIACOL CARBONATE', 'I', 600, 'MG', '', '', 'N', '', 'Historic Freeform Text: GUAIACOL CARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2149, 6896, 'GUAIACOL CARBONATE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: GUAIACOL CARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2150, 6896, 'GUAIACOL CARBONATE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: GUAIACOL CARBONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66191, 12002, 'VALRUBICIN', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77957, 20128, 'MICAFUNGIN SODIUM', 'I', 50, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79665, 20128, 'MICAFUNGIN SODIUM', 'I', 100, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50121, 11378, 'EPOPROSTENOL (EPOPROSTENOL SODIUM)', 'I', 0.5, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50122, 11378, 'EPOPROSTENOL (EPOPROSTENOL SODIUM)', 'I', 1.5, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19312, 7579, 'FLUOCINONIDE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUOCINONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19317, 7579, 'FLUOCINONIDE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUOCINONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20008, 7579, 'FLUOCINONIDE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUOCINONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19203, 7579, 'FLUOCINONIDE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: FLUOCINONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9276, 7579, 'FLUOCINONIDE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: FLUOCINONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5439, 7579, 'FLUOCINONIDE', 'I', 0.05, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLUOCINOLONE ACETONIDE-21 ACETATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60294, 7579, 'FLUOCINONIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60295, 7579, 'FLUOCINONIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11682, 7579, 'FLUOCINONIDE', 'I', 0.05, '%', '', '', 'N', 'W/W', 'Historic Freeform Text: FLUOCINONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63806, 7579, 'FLUOCINONIDE', 'I', 0.5, 'MG', '', '', 'N', 'G', '0.05% W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49287, 11320, 'CARBOPROST (CARBOPROST TROMETHAMINE)', 'I', 250, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10898, 8035, 'ACEPROMAZINE MALEATE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACEPROMAZINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11890, 8035, 'ACEPROMAZINE MALEATE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACEPROMAZINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (86, 8035, 'ACEPROMAZINE MALEATE', 'I', 0.56, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14402, 8035, 'ACEPROMAZINE MALEATE', 'I', 25, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ACEPROMAZINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5878, 8035, 'ACEPROMAZINE MALEATE', 'I', 25, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ACEPROMAZINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4738, 8035, 'ACEPROMAZINE MALEATE', 'I', 25, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ACEPROMAZINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85, 8035, 'ACEPROMAZINE MALEATE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ACEPROMAZINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11900, 8035, 'ACEPROMAZINE MALEATE', 'I', 1.25, 'G', '', '227', 'N', 'G', 'Historic Freeform Text: ACEPROMAZINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20205, 1996, 'PIROXICAM', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: PIROXICAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20206, 1996, 'PIROXICAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PIROXICAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19269, 1996, 'PIROXICAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PIROXICAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19270, 1996, 'PIROXICAM', 'I', 20, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PIROXICAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18333, 1996, 'PIROXICAM', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: PIROXICAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18335, 1996, 'PIROXICAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PIROXICAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11178, 1996, 'PIROXICAM', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: PIROXICAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11179, 1996, 'PIROXICAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PIROXICAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6812, 1996, 'PIROXICAM', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: PIROXICAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6813, 1996, 'PIROXICAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PIROXICAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6714, 1996, 'PIROXICAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PIROXICAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6715, 1996, 'PIROXICAM', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: PIROXICAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63012, 1996, 'PIROXICAM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2684, 2161, 'DINOPROSTONE', 'I', 0.5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DINOPROSTONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50327, 2161, 'DINOPROSTONE', 'I', 10, 'MG', '', '', 'N', 'INSERT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10492, 2161, 'DINOPROSTONE', 'I', 0.5, 'MG', '', '2.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11830, 2161, 'DINOPROSTONE', 'I', 1, 'MG', '', '3', 'N', 'G', 'HISTORIC FREEFORM TEXT: DINOPROSTONE 1MG PER 3GM SYRINGE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11831, 2161, 'DINOPROSTONE', 'I', 2, 'MG', '', '3', 'N', 'G', 'HISTORIC FREEFORM TEXT: DINOPROSTONE 2MG PER 3GM SYRINGE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6269, 9557, 'DIAZOXIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIAZOXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7520, 9419, 'FLAVOXATE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLAVOXATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60251, 9419, 'FLAVOXATE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68832, 9419, 'FLAVOXATE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69540, 9419, 'FLAVOXATE HYDROCHLORIDE', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FLAVOXATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10552, 11216, 'APRAMYCIN (APRAMYCIN SULFATE)', 'I', 100, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: APRAMYCIN SULFATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37379, 2191, 'DISOPYRAMIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DISOPYRAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37380, 2191, 'DISOPYRAMIDE', 'I', 150, 'MG', '', '', 'N', '', 'Historic Freeform Text: DISOPYRAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13164, 7968, 'PIPOTIAZINE PALMITATE', 'I', 25, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PIPOTIAZINE PALMITATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12223, 7968, 'PIPOTIAZINE PALMITATE', 'I', 50, 'MG', '', '', 'N', 'ML', 'PRODUCT HAS 2 PACKAGE SIZES - 50MG/ML - 5AMPOULES OF 1 ML, 100MG/2ML - 5 AMPOULES OF 2 ML. PRODUCT N');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13831, 20299, 'METOMIDATE HYDROCHLORIDE', 'I', 1000, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: METOMIDATE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43143, 20300, 'NALTREXONE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: NALTREXONE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79795, 20301, 'DABIGATRAN ETEXILATE (DABIGATRAN ETEXILATE MESILATE)', 'I', 110, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79794, 20301, 'DABIGATRAN ETEXILATE (DABIGATRAN ETEXILATE MESILATE)', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84384, 20301, 'DABIGATRAN ETEXILATE (DABIGATRAN ETEXILATE MESILATE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79806, 20305, 'PERTUSSIS TOXOID ADSORBED', 'I', 8, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79806, 20306, 'FILAMENTOUS HAEMAGGLUTININ ADSORBED', 'I', 8, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79806, 20307, 'PERTACTIN ADSORBED', 'I', 2.5, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4266, 8280, 'PHENOBARBITAL SODIUM', 'I', 120, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PHENOBARBITAL SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4515, 8280, 'PHENOBARBITAL SODIUM', 'I', 30, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: PHENOBARBITAL SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78939, 8280, 'PHENOBARBITAL SODIUM', 'I', 30, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78940, 8280, 'PHENOBARBITAL SODIUM', 'I', 120, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43160, 7426, 'ETHINYL ESTRADIOL', 'I', 30, 'µG', '', '', 'N', '', 'Historic Freeform Text: ETHINYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18754, 7426, 'ETHINYL ESTRADIOL', 'I', 30, 'µG', '', '', 'N', '', 'Historic Freeform Text: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18755, 7426, 'ETHINYL ESTRADIOL', 'I', 30, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHYNYL ESTRADIOL WHITE TABS.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8123, 7426, 'ETHINYL ESTRADIOL', 'I', 30, 'µG', '', '', 'N', '', 'Historic Freeform Text: ETHINYL ESTRADIOL ((OCHREOUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8124, 7426, 'ETHINYL ESTRADIOL', 'I', 30, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHINYL ESTRADIOL ((LIGHT BRN))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8124, 7426, 'ETHINYL ESTRADIOL', 'I', 40, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHINYL ESTRADIOL ((WHITE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8124, 7426, 'ETHINYL ESTRADIOL', 'I', 30, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHINYL ESTRADIOL ((OCHREOUS))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8123, 7426, 'ETHINYL ESTRADIOL', 'I', 40, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHINYL ESTRADIOL ((WHITE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8123, 7426, 'ETHINYL ESTRADIOL', 'I', 30, 'µG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHINYL ESTRADIOL ((LIGHT BRN))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3633, 7426, 'ETHINYL ESTRADIOL', 'I', 30, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3374, 7426, 'ETHINYL ESTRADIOL', 'I', 30, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1922, 7426, 'ETHINYL ESTRADIOL', 'I', 30, 'µG', '', '', 'N', '', 'Historic Freeform Text: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2386, 7426, 'ETHINYL ESTRADIOL', 'I', 30, 'µG', '', '', 'N', '', 'Historic Freeform Text: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2254, 7426, 'ETHINYL ESTRADIOL', 'I', 20, 'µG', '', '', 'N', '', 'Historic Freeform Text: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2255, 7426, 'ETHINYL ESTRADIOL', 'I', 20, 'µG', '', '', 'N', '', 'Historic Freeform Text: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53444, 7426, 'ETHINYL ESTRADIOL', 'I', 35, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60269, 7426, 'ETHINYL ESTRADIOL', 'I', 20, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60270, 7426, 'ETHINYL ESTRADIOL', 'I', 20, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66279, 7426, 'ETHINYL ESTRADIOL', 'I', 5, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78383, 7426, 'ETHINYL ESTRADIOL', 'I', 20, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78384, 7426, 'ETHINYL ESTRADIOL', 'I', 20, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42921, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42922, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42890, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'HISTORICAL FREEFORM TEXT: ETHINYL ESTRADIOL (WHITE TABLET).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42960, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHINYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42952, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42888, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42889, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHINYL ESTRADIOL (BLUE TABLET)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42889, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHINYL ESTRADIOL (WHITE TABLET)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42890, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'HISTORICAL FREEFORM TEXT: ETHINYL ESTRADIOL (BLUE TABLET).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20162, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14191, 7426, 'ETHINYL ESTRADIOL', 'I', 0.03, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12988, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12998, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14355, 7426, 'ETHINYL ESTRADIOL', 'I', 0.03, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14354, 7426, 'ETHINYL ESTRADIOL', 'I', 0.03, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14199, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHINYL ESTRADIOL ((LIGHT BLUE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14199, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHINYL ESTRADIOL ((BLUE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14199, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHINYL ESTRADIOL ((WHITE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14197, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHINYL ESTRADIOL ((WHITE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14197, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHINYL ESTRADIOL ((LIGHT BLUE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14197, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHINYL ESTRADIOL ((BLUE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5482, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHINYL ESTRADIOL ((AS WHITE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5482, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHINYL ESTRADIOL ((AS LT PEACH TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5482, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHINYL ESTRADIOL ((AS DK PEACH TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5483, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHINYL ESTRADIOL ((AS WHITE TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5483, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHINYL ESTRADIOL ((AS LT PEACH TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5483, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHINYL ESTRADIOL ((AS DK PEACH TAB))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5103, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5104, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5105, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5106, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74243, 7426, 'ETHINYL ESTRADIOL', 'I', 0.025, 'MG', '', '', 'N', '', 'YELLOW TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74243, 7426, 'ETHINYL ESTRADIOL', 'I', 0.025, 'MG', '', '', 'N', '', 'ORANGE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74243, 7426, 'ETHINYL ESTRADIOL', 'I', 0.025, 'MG', '', '', 'N', '', 'RED TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74376, 7426, 'ETHINYL ESTRADIOL', 'I', 0.025, 'MG', '', '', 'N', '', 'ETHINYL ESTRADIOL (WHITE TAB)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74376, 7426, 'ETHINYL ESTRADIOL', 'I', 0.025, 'MG', '', '', 'N', '', 'ETHINYL ESTRADIOL (LIGHT BLUE TAB)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74376, 7426, 'ETHINYL ESTRADIOL', 'I', 0.025, 'MG', '', '', 'N', '', 'ETHINYL ESTRADIOL (DARK BLUE TAB)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74378, 7426, 'ETHINYL ESTRADIOL', 'I', 0.025, 'MG', '', '', 'N', '', 'ETHINYL ESTRADIOL (WHITE TAB)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74378, 7426, 'ETHINYL ESTRADIOL', 'I', 0.025, 'MG', '', '', 'N', '', 'ETHINYL ESTRADIOL (LIGHT BLUE TAB)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74378, 7426, 'ETHINYL ESTRADIOL', 'I', 0.025, 'MG', '', '', 'N', '', 'ETHINYL ESTRADIOL (DARK BLUE TAB)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75841, 7426, 'ETHINYL ESTRADIOL', 'I', 0.025, 'MG', '', '', 'N', '', 'YELLOW TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75841, 7426, 'ETHINYL ESTRADIOL', 'I', 0.025, 'MG', '', '', 'N', '', 'ORANGE TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75841, 7426, 'ETHINYL ESTRADIOL', 'I', 0.025, 'MG', '', '', 'N', '', 'RED TAB');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74710, 7426, 'ETHINYL ESTRADIOL', 'I', 0.030, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74711, 7426, 'ETHINYL ESTRADIOL', 'I', 0.030, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72637, 7426, 'ETHINYL ESTRADIOL', 'I', 0.60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73815, 7426, 'ETHINYL ESTRADIOL', 'I', 2.6, 'MG', '', '', 'N', '', 'DELIVERS 15 MICROGRAM ETHINYL ESTRADIOL PER DAY.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78129, 7426, 'ETHINYL ESTRADIOL', 'I', 0.03, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78130, 7426, 'ETHINYL ESTRADIOL', 'I', 0.03, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77558, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78201, 7426, 'ETHINYL ESTRADIOL', 'I', 0.03, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80270, 7426, 'ETHINYL ESTRADIOL', 'I', 0.03, 'MG', '', '', 'N', '', 'Historic Freeform Text: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79517, 7426, 'ETHINYL ESTRADIOL', 'I', 0.035, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80656, 7426, 'ETHINYL ESTRADIOL', 'I', 0.02, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80272, 7426, 'ETHINYL ESTRADIOL', 'I', 0.03, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ETHYNYL ESTRADIOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83160, 7426, 'ETHINYL ESTRADIOL', 'I', 0.01, 'MG', '', '', 'N', '', 'YELLOW TABLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83160, 7426, 'ETHINYL ESTRADIOL', 'I', 0.03, 'MG', '', '', 'N', '', 'LIGHT BLUE TABLET');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1883, 9108, 'PROBENECID', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROBENECID');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19258, 1745, 'IDARUBICIN HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: IDARUBICIN HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19259, 1745, 'IDARUBICIN HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: IDARUBICIN HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76813, 1745, 'IDARUBICIN HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82316, 1745, 'IDARUBICIN HYDROCHLORIDE', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14931, 8151, 'SULFINPYRAZONE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFINPYRAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3425, 8151, 'SULFINPYRAZONE', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: SULFINPYRAZONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1116, 5918, 'PYRIMETHAMINE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PYRIMETHAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19091, 5918, 'PYRIMETHAMINE', 'I', 9.8, 'G', '', '', 'N', 'L', 'HISTORIC FREEFORM TEXT: PYRIMETHAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5892, 5918, 'PYRIMETHAMINE', 'I', 9.8, 'G', '', '', 'N', 'L', 'Historic Freeform Text: PYRIMETHAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63125, 7485, 'TESTOSTERONE', 'I', 12.2, 'MG', '', '', 'N', '', 'DERMAL PATCH: DELIVERS 2.5MG / 24 HOURS / PATCH (37 SQUARE CM).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70098, 7485, 'TESTOSTERONE', 'I', 24.3, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69384, 7485, 'TESTOSTERONE', 'I', 1, '%', '', '', 'N', '', 'DERMAL PATCH: DELIVERS 2.5MG / 24 HOURS / PATCH (37 SQUARE CM).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69385, 7485, 'TESTOSTERONE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76591, 7485, 'TESTOSTERONE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73432, 7485, 'TESTOSTERONE', 'I', 1, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5745, 7485, 'TESTOSTERONE', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: TESTOSTERONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12922, 4913, 'MENADIONE', 'I', 4.52, 'G', '', '400', 'N', 'G', 'Historic Freeform Text: MENADIONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36843, 4913, 'MENADIONE (MENADIONE SODIUM BISULFITE)', 'I', 500, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: MENADIONE ((AS MENADIONE SODIUM BISULFITE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24400, 4913, 'MENADIONE', 'I', 545, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: MENADIONE SODIUM BISULFITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17818, 4913, 'MENADIONE (MENADIONE SODIUM BISULFITE)', 'I', 500, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: MENADIONE ((AS MENADIONE SODIUM BISULFITE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17121, 4913, 'MENADIONE (MENADIONE SODIUM BISULFITE)', 'I', 500, 'MG', '', '400', 'Y', 'G', 'HISTORIC FREEFORM TEXT: MENADIONE ((AS MENADIONE SODIUM BISULFITE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14119, 4913, 'MENADIONE', 'I', 500, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: MENADIONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14115, 4913, 'MENADIONE', 'I', 333, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: MENADIONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10527, 4913, 'MENADIONE (MENADIONE SODIUM BISULFITE)', 'I', 12.5, 'MG', '', '75', 'N', 'G', 'Historic Freeform Text: VIT K ((MENADIONE SODIUM BISULFITE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5125, 4913, 'MENADIONE', 'I', 333, 'MG', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: MENADIONE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1617, 4913, 'MENADIONE', 'I', 1125, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: MENADIONE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5144, 4913, 'MENADIONE', 'I', 333, 'MG', '', '100', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43354, 10024, 'DESIPRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43355, 10024, 'DESIPRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43356, 10024, 'DESIPRAMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43357, 10024, 'DESIPRAMINE HYDROCHLORIDE', 'I', 75, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43060, 10024, 'DESIPRAMINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20084, 10024, 'DESIPRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESIPRAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20085, 10024, 'DESIPRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESIPRAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20031, 10024, 'DESIPRAMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20032, 10024, 'DESIPRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20033, 10024, 'DESIPRAMINE HYDROCHLORIDE', 'I', 75, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20000, 10024, 'DESIPRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESIPRAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19220, 10024, 'DESIPRAMINE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESIPRAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14116, 10024, 'DESIPRAMINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESIPRAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14117, 10024, 'DESIPRAMINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESIPRAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14118, 10024, 'DESIPRAMINE HYDROCHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESIPRAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14288, 10024, 'DESIPRAMINE HYDROCHLORIDE', 'I', 75, 'MG', '', '', 'N', '', 'Historic Freeform Text: DESIPRAMINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44136, 2091, 'FEBANTEL', 'I', 113.4, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FEBANTEL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44137, 2091, 'FEBANTEL', 'I', 340.2, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FEBANTEL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11034, 7219, 'DIPYRIDAMOLE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPYRIDAMOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11035, 7219, 'DIPYRIDAMOLE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPYRIDAMOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11036, 7219, 'DIPYRIDAMOLE', 'I', 75, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPYRIDAMOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5893, 7219, 'DIPYRIDAMOLE', 'I', 75, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPYRIDAMOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4915, 7219, 'DIPYRIDAMOLE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPYRIDAMOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4916, 7219, 'DIPYRIDAMOLE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: DIPYRIDAMOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65795, 7219, 'DIPYRIDAMOLE', 'I', 200, 'MG', '', '', 'Y', '', 'CAPSULE, EXTENDED RELEASE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6720, 7219, 'DIPYRIDAMOLE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIPYRIDAMOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68907, 7219, 'DIPYRIDAMOLE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIPYRIDAMOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68448, 7219, 'DIPYRIDAMOLE', 'I', 5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DIPYRIDAMOLE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (45324, 7991, 'PROCHLORPERAZINE (PROCHLORPERAZINE MALEATE)', 'I', 10, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PROCHLORPERAZINE MALEATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (45325, 7991, 'PROCHLORPERAZINE (PROCHLORPERAZINE MALEATE)', 'I', 5, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: PROCHLORPERAZINE MALEATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13641, 7991, 'PROCHLORPERAZINE (PROCHLORPERAZINE MALEATE)', 'I', 5, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: PROCHLORPERAZINE BIMALEATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13642, 7991, 'PROCHLORPERAZINE (PROCHLORPERAZINE MALEATE)', 'I', 10, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: PROCHLORPERAZINE BIMALEATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9564, 7991, 'PROCHLORPERAZINE (PROCHLORPERAZINE MALEATE)', 'I', 10, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PROCHLORPERAZINE MALEATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9565, 7991, 'PROCHLORPERAZINE (PROCHLORPERAZINE MALEATE)', 'I', 5, 'MG', '', '', 'Y', '', 'Historic Freeform Text: PROCHLORPERAZINE MALEATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9919, 7991, 'PROCHLORPERAZINE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROCHLORPERAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9629, 7991, 'PROCHLORPERAZINE', 'I', 10, 'MG', '', '', 'N', 'SUP', 'Historic Freeform Text: PROCHLORPERAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9972, 7991, 'PROCHLORPERAZINE (PROCHLORPERAZINE MESYLATE)', 'I', 5, 'MG', '', '', 'Y', 'ML', 'HISTORIC FREEFORM TEXT: PROCHLORPERAZINE MESYLATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9920, 7991, 'PROCHLORPERAZINE (PROCHLORPERAZINE MESYLATE)', 'I', 5, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: PROCHLORPERAZINE MESYLATE ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42959, 109, 'TETRABENAZINE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: TETRABENAZINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60071, 9867, 'ORCIPRENALINE SULFATE', 'I', 2, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62807, 20364, 'TRIPELENNAMINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16629, 20365, 'PROXYMETACAINE HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: PROXYMETACAIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6721, 20365, 'PROXYMETACAINE HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', '', 'Historic Freeform Text: PROXYMETACAIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6105, 20365, 'PROXYMETACAINE HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PROXYMETACAIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1172, 20365, 'PROXYMETACAINE HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PROXYMETACAIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79969, 20374, 'IDEBENONE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80138, 20378, 'NILOTINIB (NILOTINIB HYDROCHLORIDE MONOHYDRATE)', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85322, 20378, 'NILOTINIB (NILOTINIB HYDROCHLORIDE MONOHYDRATE)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80166, 20383, 'EMODEPSIDE', 'I', 7.5, 'MG', '', '0.35', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80167, 20383, 'EMODEPSIDE', 'I', 15.0, 'MG', '', '0.70', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80168, 20383, 'EMODEPSIDE', 'I', 24.0, 'MG', '', '1.12', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3139, 713, 'LANOLIN - ANHYDROUS', 'I', 7.19, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12217, 20386, 'HYDROCODONE', 'I', 5, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DIHYDROCODEINONE BITARTRATE  HYDROCODONE RESIN COMPLEX EQUVALENT TO 5 MG HYD');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12216, 20386, 'HYDROCODONE', 'I', 5, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DIHYDROCODEINONE BITARTRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80247, 20387, 'RIVAROXABAN', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9362, 8093, 'IOXAGLATE MEGLUMINE', 'I', 246, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: IOXAGLATE MEGLUMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5554, 8093, 'IOXAGLATE MEGLUMINE', 'I', 393, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: IOXAGLATE MEGLUMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12887, 5440, 'BETHANECHOL CHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: BETHANECHOL CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12745, 5440, 'BETHANECHOL CHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: BETHANECHOL CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12746, 5440, 'BETHANECHOL CHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: BETHANECHOL CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10708, 5440, 'BETHANECHOL CHLORIDE', 'I', 25, 'MG', '', '', 'N', '', 'Historic Freeform Text: BETHANECHOL CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10709, 5440, 'BETHANECHOL CHLORIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: BETHANECHOL CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10710, 5440, 'BETHANECHOL CHLORIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: BETHANECHOL CHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60352, 5440, 'BETHANECHOL CHLORIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60350, 5440, 'BETHANECHOL CHLORIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60351, 5440, 'BETHANECHOL CHLORIDE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4989, 8970, 'ATROPINE SULFATE', 'I', 7.5, 'µG', '', '', 'N', '', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1612, 8970, 'ATROPINE SULFATE', 'I', 0.1, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (937, 8970, 'ATROPINE SULFATE', 'I', 0.025, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2005, 8970, 'ATROPINE SULFATE', 'I', 0.1, 'MG', '', '', 'N', '', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16476, 8970, 'ATROPINE SULFATE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12215, 8970, 'ATROPINE SULFATE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (254, 8970, 'ATROPINE SULFATE', 'I', 1, '%', '', '', 'N', '', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18862, 8970, 'ATROPINE SULFATE', 'I', 1, '%', '', '', 'N', 'W/V', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1993, 8970, 'ATROPINE SULFATE', 'I', 2.5, 'µG', '', '', 'N', 'ML', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17184, 8970, 'ATROPINE SULFATE', 'I', 0.4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17186, 8970, 'ATROPINE SULFATE', 'I', 0.6, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9020, 8970, 'ATROPINE SULFATE', 'I', 0.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9569, 8970, 'ATROPINE SULFATE', 'I', 0.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4291, 8970, 'ATROPINE SULFATE', 'I', 0.3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4228, 8970, 'ATROPINE SULFATE', 'I', 0.4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4229, 8970, 'ATROPINE SULFATE', 'I', 0.6, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3553, 8970, 'ATROPINE SULFATE', 'I', 0.6, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3554, 8970, 'ATROPINE SULFATE', 'I', 0.4, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4440, 8970, 'ATROPINE SULFATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1766, 8970, 'ATROPINE SULFATE', 'I', 2.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2390, 8970, 'ATROPINE SULFATE', 'I', 0.1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2785, 8970, 'ATROPINE SULFATE', 'I', 0.5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2786, 8970, 'ATROPINE SULFATE', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ATROPINE SULFATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43018, 1950, 'ACYCLOVIR', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ACYCLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43019, 1950, 'ACYCLOVIR', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACYCLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43020, 1950, 'ACYCLOVIR', 'I', 800, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACYCLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19814, 1950, 'ACYCLOVIR', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACYCLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19815, 1950, 'ACYCLOVIR', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACYCLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19816, 1950, 'ACYCLOVIR', 'I', 800, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACYCLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15894, 1950, 'ACYCLOVIR', 'I', 800, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACYCLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15895, 1950, 'ACYCLOVIR', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACYCLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15896, 1950, 'ACYCLOVIR', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACYCLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11420, 1950, 'ACYCLOVIR', 'I', 400, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACYCLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7063, 1950, 'ACYCLOVIR', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: ACYCLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66607, 1950, 'ACYCLOVIR', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66188, 1950, 'ACYCLOVIR', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66189, 1950, 'ACYCLOVIR', 'I', 800, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77144, 1950, 'ACYCLOVIR', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77145, 1950, 'ACYCLOVIR', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77146, 1950, 'ACYCLOVIR', 'I', 800, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77200, 1950, 'ACYCLOVIR', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77201, 1950, 'ACYCLOVIR', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77202, 1950, 'ACYCLOVIR', 'I', 800, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15525, 1950, 'ACYCLOVIR', 'I', 5, '%', '', '', 'N', 'W/W', 'Historic Freeform Text: ACYCLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4959, 1950, 'ACYCLOVIR', 'I', 5, '%', '', '', 'N', 'W/W', 'HISTORIC FREEFORM TEXT: ACYCLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50497, 1950, 'ACYCLOVIR (ACYCLOVIR SODIUM)', 'I', 500, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11416, 1950, 'ACYCLOVIR', 'I', 200, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: ACYCLOVIR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60218, 1950, 'ACYCLOVIR (ACYCLOVIR SODIUM)', 'I', 50, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60208, 1950, 'ACYCLOVIR (ACYCLOVIR SODIUM)', 'I', 25, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12889, 6500, 'PHENYLEPHRINE (PHENYLEPHRINE HYDROCHLORIDE)', 'I', 10, 'MG', '', '', 'Y', 'ML', 'Historic Freeform Text: PHENYLEPHRINE HCL ((PHENYLEPHRINE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79616, 932, 'RAMIPRIL', 'I', 10.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13411, 7469, 'TESTOSTERONE UNDECANOATE', 'I', 40, 'MG', '', '', 'N', '', 'Historic Freeform Text: TESTOSTERONE UNDECANOATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80793, 7469, 'TESTOSTERONE UNDECANOATE', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18814, 5643, 'DIMERCAPROL', 'I', 100, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DIMERCAPROL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20239, 4068, 'LEVODOPA', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20189, 4068, 'LEVODOPA', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20190, 4068, 'LEVODOPA', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19767, 4068, 'LEVODOPA', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19758, 4068, 'LEVODOPA', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19766, 4068, 'LEVODOPA', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14082, 4068, 'LEVODOPA', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: LEVODOPA Qty Unit: SRT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11481, 4068, 'LEVODOPA', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4008, 4068, 'LEVODOPA', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3331, 4068, 'LEVODOPA', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4459, 4068, 'LEVODOPA', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2723, 4068, 'LEVODOPA', 'I', 100, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2724, 4068, 'LEVODOPA', 'I', 200, 'MG', '', '', 'N', '', 'Historic Freeform Text: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2142, 4068, 'LEVODOPA', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68470, 4068, 'LEVODOPA', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68471, 4068, 'LEVODOPA', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68472, 4068, 'LEVODOPA', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69226, 4068, 'LEVODOPA', 'I', 200, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71866, 4068, 'LEVODOPA', 'I', 100, 'MG', '', '', 'N', '', 'Historic Freeform Text: LEVODOPA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75839, 4068, 'LEVODOPA', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82347, 4068, 'LEVODOPA', 'I', 75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82348, 4068, 'LEVODOPA', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79150, 4068, 'LEVODOPA', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79151, 4068, 'LEVODOPA', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79152, 4068, 'LEVODOPA', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79676, 4068, 'LEVODOPA', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77753, 4068, 'LEVODOPA', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73177, 8309, 'AMPHETAMINE SULFATE', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73178, 8309, 'AMPHETAMINE SULFATE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73179, 8309, 'AMPHETAMINE SULFATE', 'I', 3.75, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73180, 8309, 'AMPHETAMINE SULFATE', 'I', 5.00, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73181, 8309, 'AMPHETAMINE SULFATE', 'I', 6.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73182, 8309, 'AMPHETAMINE SULFATE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43505, 8042, 'IOPAMIDOL', 'I', 61, '%', '', '', 'N', '', 'Historic Freeform Text: IOPAMIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43506, 8042, 'IOPAMIDOL', 'I', 76, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IOPAMIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65799, 8042, 'IOPAMIDOL', 'I', 76, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IOPAMIDOL 755MG/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65800, 8042, 'IOPAMIDOL', 'I', 61, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IOPAMIDOL 612MG/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43504, 8042, 'IOPAMIDOL', 'I', 41, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: IOPAMIDOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9562, 9956, 'OXAZEPAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9563, 9956, 'OXAZEPAM', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9353, 9956, 'OXAZEPAM', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5563, 9956, 'OXAZEPAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3807, 9956, 'OXAZEPAM', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3808, 9956, 'OXAZEPAM', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3806, 9956, 'OXAZEPAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4794, 9956, 'OXAZEPAM', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4795, 9956, 'OXAZEPAM', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4796, 9956, 'OXAZEPAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3656, 9956, 'OXAZEPAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3657, 9956, 'OXAZEPAM', 'I', 15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3658, 9956, 'OXAZEPAM', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5213, 9956, 'OXAZEPAM', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5214, 9956, 'OXAZEPAM', 'I', 30, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3463, 9956, 'OXAZEPAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3464, 9956, 'OXAZEPAM', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3465, 9956, 'OXAZEPAM', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71419, 9956, 'OXAZEPAM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71420, 9956, 'OXAZEPAM', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71421, 9956, 'OXAZEPAM', 'I', 30, 'MG', '', '', 'N', '', 'Historic Freeform Text: OXAZEPAM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17893, 1226, 'OLSALAZINE SODIUM', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: OLSALAZINE SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65460, 5927, 'CYCLOPHOSPHAMIDE', 'I', 25, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CYCLOPHOSPHAMIDE -PROVIDED AS ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65461, 5927, 'CYCLOPHOSPHAMIDE', 'I', 50, 'MG', '', '', 'Y', '', '-PROVIDED AS THE ANHYDROUS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65462, 5927, 'CYCLOPHOSPHAMIDE', 'I', 200, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65463, 5927, 'CYCLOPHOSPHAMIDE', 'I', 500, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65464, 5927, 'CYCLOPHOSPHAMIDE', 'I', 1000, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65465, 5927, 'CYCLOPHOSPHAMIDE', 'I', 2000, 'MG', '', '', 'Y', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3546, 8859, 'ANTIPYRINE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ANTIPYRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81814, 8859, 'ANTIPYRINE', 'I', 54, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ANTIPYRINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82510, 8036, 'ACEPROMAZINE (ACEPROMAZINE MALEATE)', 'I', 5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ACEPROMAZINE MALEATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (34463, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31582, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19488, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 2.5, '%', '', '', 'N', '', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18014, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17002, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16823, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10977, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48182, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64645, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 2.25, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65636, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 0.70, '%', '', '', 'N', '', 'EQUIV. TO 0.745% OF LIDOCAINE HYDROCHLORIDE MONOHYDRATE.CHANGED WAS MADE ON STRENGHT PER COMPANY REQ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65637, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 0.70, '%', '', '', 'N', '', 'EQUIV. TO  0.745% OF LIDOCAINE HYDROCHLORIDE MONOHYDRATE. CHANGED ON STRENGHT WAS MADE PER COMPANY''S');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68438, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68947, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68948, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68949, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75376, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 0.5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74327, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74760, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 0.72, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73395, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78152, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 2, '%', '', '', 'N', '', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77330, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 1.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79467, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 5, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69189, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 0.50, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78032, 10225, 'LIDOCAINE HYDROCHLORIDE (LIDOCAINE HYDROCHLORIDE MONOHYDRATE)', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82759, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 1, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 2.0, '%', '', '', 'N', 'W/V', 'LIDOCAINE HCL ADDED AS PER BOTH ORIGINAL (SCANNED) AND CURRENT LABEL, AND ALSO ORIGINAL 3011 FORM FR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42940, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 1.5, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31563, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18012, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LIDOCAINE HCL, MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17964, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17901, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10518, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10519, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10520, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 8, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10912, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12645, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12648, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12649, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9802, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8351, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LIDOCAINE HCL, MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9528, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7403, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7404, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5536, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3155, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5339, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5340, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 2, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4478, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 100, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (635, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (636, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2541, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 36, 'MG', '', '1.8', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2506, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 36, 'MG', '', '1.8', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1830, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (584, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 5, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78083, 932, 'RAMIPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (585, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (587, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (589, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (590, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (591, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 15, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (592, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (593, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1619, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2935, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2881, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (781, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20.4, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (209, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (210, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (212, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62611, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68622, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75645, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75640, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78153, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78332, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81732, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20.00, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78773, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78774, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: LIDOCAINE HYDROCHLORIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83052, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 20, 'MG', '', '', 'N', 'ML', 'STRENGTH EXPRESSED IN A DIFFERENT WAY FROM THE ORIGINAL DIN (20 MG/ML LIDOCAINE HCL INSTEAD OF 36 MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83355, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62658, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60209, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 40, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72525, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80057, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78974, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80335, 10225, 'LIDOCAINE HYDROCHLORIDE', 'I', 50, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82934, 932, 'RAMIPRIL', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6366, 11968, 'SODIUM ACETATE TRIHYDRATE', 'I', 0.39, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: SODIUM ACETATE  2008.11.28. TRIHYDRATE ADDED TO A. I. SODIUM ACETATE AS REQU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83774, 11968, 'SODIUM ACETATE TRIHYDRATE', 'I', 1.16, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83777, 11968, 'SODIUM ACETATE TRIHYDRATE', 'I', 1.50, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83779, 11968, 'SODIUM ACETATE TRIHYDRATE', 'I', 1.50, 'G', '', '', 'N', 'L', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (955, 6494, 'TRIPROLIDINE HYDROCHLORIDE', 'I', 4, 'MG', '', '', 'N', '', 'Historic Freeform Text: TRIPROLIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62610, 6494, 'TRIPROLIDINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61704, 6494, 'TRIPROLIDINE HYDROCHLORIDE', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20329, 6494, 'TRIPROLIDINE HYDROCHLORIDE', 'I', 2, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: TRIPROLIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15618, 6494, 'TRIPROLIDINE HYDROCHLORIDE', 'I', 2, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: TRIPROLIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (956, 6494, 'TRIPROLIDINE HYDROCHLORIDE', 'I', 2, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: TRIPROLIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (957, 6494, 'TRIPROLIDINE HYDROCHLORIDE', 'I', 2, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: TRIPROLIDINE HCL.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66929, 6494, 'TRIPROLIDINE HYDROCHLORIDE', 'I', 2, 'MG', '', '5', 'N', 'ML', 'AS MONOHYDRATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7150, 9702, 'PROCAINAMIDE HYDROCHLORIDE', 'I', 375, 'G', '', '', 'N', '', 'Historic Freeform Text: PROCAINAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7149, 9702, 'PROCAINAMIDE HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROCAINAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7151, 9702, 'PROCAINAMIDE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', '', 'Historic Freeform Text: PROCAINAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6086, 9702, 'PROCAINAMIDE HYDROCHLORIDE', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PROCAINAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6087, 9702, 'PROCAINAMIDE HYDROCHLORIDE', 'I', 750, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PROCAINAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6088, 9702, 'PROCAINAMIDE HYDROCHLORIDE', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: PROCAINAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19357, 9702, 'PROCAINAMIDE HYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PROCAINAMIDE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5698, 4904, 'MENADIONE SODIUM BISULFITE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: MENADIONE SODIUM BISULFITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2824, 4904, 'MENADIONE SODIUM BISULFITE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MENADIONE SODIUM BISULFITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2817, 4904, 'MENADIONE SODIUM BISULFITE', 'I', 50, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: MENADIONE SODIUM BISULFITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8371, 4904, 'MENADIONE SODIUM BISULFITE', 'I', 335, 'MG', '', '', 'N', 'KG', 'Historic Freeform Text: MENADIONE SODIUM BISULFITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26583, 4904, 'MENADIONE SODIUM BISULFITE', 'I', 2.5, 'G', '', '100', 'N', 'G', 'HISTORIC FREEFORM TEXT: MENADIONE NA BISULFATE ((VIT. K3 EQ.)) (BASE OF VITAMIN K ACTIVITY).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33790, 4904, 'MENADIONE SODIUM BISULFITE', 'I', 3, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: MENADIONE SODIUM BISULFITE ((S.OF VIT.K3))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (24471, 4904, 'MENADIONE SODIUM BISULFITE', 'I', 748, 'MG', '', '170', 'N', 'G', 'Historic Freeform Text: MENADIONE SODIUM BISULFITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16510, 4904, 'MENADIONE SODIUM BISULFITE', 'I', 748, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: MENADIONE SODIUM BISULFITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14113, 4904, 'MENADIONE SODIUM BISULFITE', 'I', 748, 'MG', '', '100', 'N', 'G', 'Historic Freeform Text: MENADIONE SODIUM BISULFITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12923, 4904, 'MENADIONE SODIUM BISULFITE', 'I', 2.43, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: MENADIONE SODIUM BISULFITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15001, 4904, 'MENADIONE SODIUM BISULFITE', 'I', 3, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: MENADIONE NA BISULF. ((SOURCE OF VIT.K3))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8101, 4904, 'MENADIONE SODIUM BISULFITE', 'I', 35, 'MG', '', '400', 'N', 'G', 'Historic Freeform Text: MENADIONE SODIUM BISULFITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5510, 4904, 'MENADIONE SODIUM BISULFITE', 'I', 25, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: MENADIONE SODIUM BISULFITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5322, 4904, 'MENADIONE SODIUM BISULFITE', 'I', 3.3, 'MG', '', '', 'N', 'G', 'Historic Freeform Text: MENADIONE SODIUM BISULFITE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17116, 8375, 'CLOXACILLIN (CLOXACILLIN SODIUM)', 'I', 500, 'MG', '', '', 'N', '', 'Historic Freeform Text: CLOXACILLIN ((AS CLOXACILLIN SOD.MONOHYD.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11164, 8375, 'CLOXACILLIN (CLOXACILLIN SODIUM)', 'I', 500, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: CLOXACILLIN SOD. ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11165, 8375, 'CLOXACILLIN (CLOXACILLIN SODIUM)', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLOXACILLIN SOD. ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2233, 8375, 'CLOXACILLIN (CLOXACILLIN SODIUM)', 'I', 250, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLOXACILLIN SODIUM ((EQ 250MG BASE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2234, 8375, 'CLOXACILLIN (CLOXACILLIN SODIUM)', 'I', 500, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CLOXACILLIN SODIUM ((EQ TO 500MG BASE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44190, 8375, 'CLOXACILLIN (CLOXACILLIN BENZATHINE)', 'I', 500, 'MG', '', '10', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CLOXACILLIN ((AS CLOXACILLIN BENZATHINE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11163, 8375, 'CLOXACILLIN (CLOXACILLIN SODIUM)', 'I', 125, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: CLOXACILLIN SOD. ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43498, 3359, 'DIHYDROERGOTAMINE MESYLATE', 'I', 4, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (415, 3359, 'DIHYDROERGOTAMINE MESYLATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DIHYDROERGOTAMINE METHANESULFONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (64769, 3359, 'DIHYDROERGOTAMINE MESYLATE', 'I', 1, 'MG', '', '', 'N', 'ML', 'FISH SOURCE IS DERIVED FROM FISH TRIMMING AND WHOLE FISH.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76647, 19249, 'SUNITINIB (SUNITINIB MALATE)', 'I', 12.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76648, 19249, 'SUNITINIB (SUNITINIB MALATE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76649, 19249, 'SUNITINIB (SUNITINIB MALATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77111, 19961, 'CICLESONIDE', 'I', 100, 'µG', '', '', 'N', 'ACT', 'PER DOSAGE UNIT CHANGED FROM DOSE TO ACTUATION AS PER SHARON DUNN E-MAIL DATED 2006.09.08./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77112, 19961, 'CICLESONIDE', 'I', 200, 'µG', '', '', 'N', 'ACT', 'PER DOSAGE UNIT CHANGED FROM DOSE TO ACTUATION AS PER SHARON DUNN E-MAIL DATED 2006.09.08./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78899, 19961, 'CICLESONIDE', 'I', 50, 'µG', '', '', 'N', 'ACT', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78104, 20137, 'NALOXONE (NALOXONE HYDROCHLORIDE DIHYDRATE)', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78105, 20137, 'NALOXONE (NALOXONE HYDROCHLORIDE DIHYDRATE)', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44197, 11178, 'AMIKACIN (AMIKACIN SULFATE)', 'I', 250, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: AMIKACIN ((AS AMIKACIN SULFATE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66810, 11178, 'AMIKACIN (AMIKACIN SULFATE)', 'I', 250, 'MG', '', '', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (696, 9252, 'ERGOTAMINE TARTRATE', 'I', 1, 'MG', '', '', 'N', '', 'Historic Freeform Text: ERGOTAMINE TARTARATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (413, 9252, 'ERGOTAMINE TARTRATE', 'I', 1, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: ERGOTAMINE TARTARATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (48361, 9252, 'ERGOTAMINE TARTRATE', 'I', 0.6, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (129, 6767, 'POTASSIUM CHLORATE', 'I', 908, 'G', '', '81.6', 'N', 'L', 'Historic Freeform Text: POTASSIUM CHLORATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36788, 6854, 'HAMAMELIS VIRGINIANA', 'I', 50, '%', '', '', 'N', '', 'Historic Freeform Text: HAMAMELIS VIRGINIANA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80415, 20396, 'OLMESARTAN  MEDOXOMIL', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80414, 20396, 'OLMESARTAN  MEDOXOMIL', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80508, 20396, 'OLMESARTAN  MEDOXOMIL', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80509, 20396, 'OLMESARTAN  MEDOXOMIL', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80510, 20396, 'OLMESARTAN  MEDOXOMIL', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17818, 20409, 'MAGNESIUM CHLORIDE ANHYDROUS', 'I', 7.14, 'G', '', '400', 'N', 'G', 'HISTORIC FREEFORM TEXT: MG ((AS CHLORIDE 7.14GM)). 2009.04.02. MAGNESIUM CHLORIDE HEXAHYDRATE CORREC');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80596, 20412, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 1 CONJUGATED TO PROTEIN D CARRIER PROTEIN', 'I', 1, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80596, 20413, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 4 CONJUGATED TO PROTEIN D CARRIER PROTEIN', 'I', 3, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81683, 932, 'RAMIPRIL', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80596, 20414, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 5 CONJUGATED TO PROTEIN D CARRIER PROTEIN', 'I', 1, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80596, 20415, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 6B CONJUGATED TO PROTEIN D CARRIER PROTEIN', 'I', 1, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80596, 20416, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 7F CONJUGATED TO PROTEIN D CARRIER PROTEIN', 'I', 1, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80596, 20417, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 9V CONJUGATED TO PROTEIN D CARRIER PROTEIN', 'I', 1, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80596, 20418, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 14 CONJUGATED TO PROTEIN D CARRIER PROTEIN', 'I', 1, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80596, 20419, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 23F CONJUGATED TO PROTEIN D CARRIER PROTEIN', 'I', 1, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80608, 20422, 'USTEKINUMAB', 'I', 45, 'MG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80652, 20429, 'LOTEPREDNOL ETABONATE', 'I', 0.5, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80634, 20429, 'LOTEPREDNOL ETABONATE', 'I', 0.2, '%', '', '', 'N', 'W/V', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80650, 20430, 'DESVENLAFAXINE (DESVENLAFAXINE SUCCINATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80651, 20430, 'DESVENLAFAXINE (DESVENLAFAXINE SUCCINATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76398, 18561, 'HISTRELIN ACETATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76900, 19728, 'LANREOTIDE (LANREOTIDE ACETATE)', 'I', 60, 'MG', '', '0.3', 'N', 'ML', 'PRE-FILLED SYRINGE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76901, 19728, 'LANREOTIDE (LANREOTIDE ACETATE)', 'I', 90, 'MG', '', '0.3', 'N', 'ML', 'PRE-FILLED SYRINGE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76902, 19728, 'LANREOTIDE (LANREOTIDE ACETATE)', 'I', 120, 'MG', '', '0.5', 'N', 'ML', 'PRE-FILLED SYRINGE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78588, 20167, 'ROTAVIRUS VACCINE (RIX4414 STRAIN), LIVE, ORAL, ATTENUATED (HUMAN)', 'I', 1000000, 'CCID50', '', '', 'N', 'ML', 'NON LESS THAN 1000000 CCID50 PER 1.5 ML. ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11624, 2322, 'DOPAMINE HYDROCHLORIDE', 'I', 3.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DOPAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11625, 2322, 'DOPAMINE HYDROCHLORIDE', 'I', 1.6, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DOPAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12256, 2322, 'DOPAMINE HYDROCHLORIDE', 'I', 0.8, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DOPAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12681, 2322, 'DOPAMINE HYDROCHLORIDE', 'I', 3.2, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DOPAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6768, 2322, 'DOPAMINE HYDROCHLORIDE', 'I', 1.6, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DOPAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6769, 2322, 'DOPAMINE HYDROCHLORIDE', 'I', 0.8, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DOPAMINE HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19100, 1938, 'CARBON MONOXIDE', 'I', 0.3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBON MONOXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19101, 1938, 'CARBON MONOXIDE', 'I', 0.3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBON MONOXIDE ((0.1% TO 0.3%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13920, 1938, 'CARBON MONOXIDE', 'I', 0.3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBON MONOXIDE ((.2-.3%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13895, 1938, 'CARBON MONOXIDE', 'I', 0.3, '%', '', '', 'N', '', 'Historic Freeform Text: CARBON MONOXIDE ((.005-.3%))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8185, 1938, 'CARBON MONOXIDE', 'I', 0.3, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: CARBON MONOXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (44612, 1938, 'CARBON MONOXIDE', 'I', 0.1, '%', '', '', 'N', '%', 'Historic Freeform Text: CARBON MONOXIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (127, 6325, 'CARBARYL', 'I', 5, '%', '', '', 'N', '', 'Historic Freeform Text: CARBARYL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74689, 11268, 'CEFOTAXIME (CEFOTAXIME SODIUM)', 'I', 1.0, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74690, 11268, 'CEFOTAXIME (CEFOTAXIME SODIUM)', 'I', 2.0, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74688, 11268, 'CEFOTAXIME (CEFOTAXIME SODIUM)', 'I', 500, 'MG', '', '', 'Y', 'VIAL', 'HISTORIC FREEFORM TEXT: CEFOTAXIME SODIUM ((CEFOTAXIME EQ.))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43312, 1243, 'NILUTAMIDE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: NILUTAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77863, 20124, 'ACAMPROSATE CALCIUM', 'I', 333, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9518, 10155, 'SCARLET RED', 'I', 0.19, '%', '', '', 'N', '', 'SCARLET RED 0.16% CHG TO 0.19% AS PER VDD 2006.04.05');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (621, 10155, 'SCARLET RED', 'I', 0.02, '%', '', '', 'N', '', 'Historic Freeform Text: SCARLET RED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80774, 20432, 'ECULIZUMAB', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80782, 20435, 'ARIPIPRAZOLE', 'I', 2.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80783, 20435, 'ARIPIPRAZOLE', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80784, 20435, 'ARIPIPRAZOLE', 'I', 10.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80785, 20435, 'ARIPIPRAZOLE', 'I', 15.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80786, 20435, 'ARIPIPRAZOLE', 'I', 20.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80790, 20435, 'ARIPIPRAZOLE', 'I', 30.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80832, 20436, 'ROMIPLOSTIM', 'I', 250, 'µG', '', '0.5', 'N', 'ML', 'EACH 250 MICROGRAM VIAL CONTAINS 375 MICROGRAMS ROMIPLOSTIM TO BE RECONSTITUTED WITH 0.72ML DILUENT ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80833, 20436, 'ROMIPLOSTIM', 'I', 500, 'µG', '', '', 'N', 'ML', 'EACH 250 MICROGRAM VIAL CONTAINS 625 MICROGRAMS ROMIPLOSTIM, TO BE RECONSTITUTED WITH 1.2ML DILUENT ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80844, 20437, 'LISDEXAMFETAMINE DIMESYLATE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80843, 20437, 'LISDEXAMFETAMINE DIMESYLATE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83254, 20437, 'LISDEXAMFETAMINE DIMESYLATE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83255, 20437, 'LISDEXAMFETAMINE DIMESYLATE', 'I', 40, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83256, 20437, 'LISDEXAMFETAMINE DIMESYLATE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80855, 20438, 'EPLERENONE', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80856, 20438, 'EPLERENONE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80876, 20439, 'METHYL AMINOLEVULINATE (METHYL AMINOLEVULINATE HYDROCHLORIDE)', 'I', 168, 'MG', '', '', 'N', 'G', '16.8%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80952, 20442, 'CLOSTRIDIUM BOTULINUM NEUROTOXIN TYPE A (150KD), FREE FROM COMPLEXING PROTEINS', 'I', 100, 'UNIT', '', '', 'N', 'VIAL', '100 LD SUBSCRIPT 50 UNITS PER VIAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80961, 20444, 'ZILPATEROL HYDROCHLORIDE', 'I', 48, 'G', '', '', 'N', 'KG', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77394, 20446, 'BISOCTRIZOLE', 'I', 3, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77395, 20446, 'BISOCTRIZOLE', 'I', 2.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77396, 20446, 'BISOCTRIZOLE', 'I', 1.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83705, 20446, 'BISOCTRIZOLE', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83706, 20446, 'BISOCTRIZOLE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83710, 20446, 'BISOCTRIZOLE', 'I', 6.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77394, 20447, 'BEMOTRIZINOL', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77395, 20447, 'BEMOTRIZINOL', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77396, 20447, 'BEMOTRIZINOL', 'I', 2, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82930, 20447, 'BEMOTRIZINOL', 'I', 0.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82931, 20447, 'BEMOTRIZINOL', 'I', 3.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83705, 20447, 'BEMOTRIZINOL', 'I', 2.0, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83706, 20447, 'BEMOTRIZINOL', 'I', 4.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83710, 20447, 'BEMOTRIZINOL', 'I', 3.5, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84835, 20449, 'FOSAPREPITANT (FOSAPREPITANT DIMEGLUMINE)', 'I', 150, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81020, 20450, 'GOLIMUMAB', 'I', 50, 'MG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81021, 20450, 'GOLIMUMAB', 'I', 50, 'MG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81089, 20460, 'STANDARDIZED SWEET VERNAL GRASS POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '100000 BAU/ML (BAU STANDS FOR BIOEQUIVALENT ALLERGY UNIT)./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81092, 20460, 'STANDARDIZED SWEET VERNAL GRASS POLLEN', 'I', 20000, 'UNIT', '', '', 'N', 'ML', '20000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61909, 5789, 'STANDARDIZED REDTOP GRASS POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '100,000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61910, 5789, 'STANDARDIZED REDTOP GRASS POLLEN', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '10,000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66459, 5789, 'STANDARDIZED REDTOP GRASS POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '(AGROSTIS ALBA). 100000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81087, 5789, 'STANDARDIZED REDTOP GRASS POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '100000 BAU/ML (BAU STANDS FOR BIO-EQUIVALENT ALLERGY UNIT)./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81091, 5789, 'STANDARDIZED REDTOP GRASS POLLEN', 'I', 25000, 'UNIT', '', '', 'N', 'ML', '25000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81092, 5789, 'STANDARDIZED REDTOP GRASS POLLEN', 'I', 20000, 'UNIT', '', '', 'N', 'ML', '20000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81684, 932, 'RAMIPRIL', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61892, 4486, 'STANDARDIZED MEADOW FESCUE GRASS POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '100,000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61893, 4486, 'STANDARDIZED MEADOW FESCUE GRASS POLLEN', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '10,000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66461, 4486, 'STANDARDIZED MEADOW FESCUE GRASS POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '(FESTUCA ELATIOR). 100000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81090, 4486, 'STANDARDIZED MEADOW FESCUE GRASS POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '100000 BAU/ML (BAU STANDS FOR BIOEQUIVALENT ALLERGY UNIT)./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61922, 5158, 'STANDARDIZED PERENNIAL RYE GRASS POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '100,000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61923, 5158, 'STANDARDIZED PERENNIAL RYE GRASS POLLEN', 'I', 10000, 'UNIT', '', '', 'N', 'ML', '10,000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66465, 5158, 'STANDARDIZED PERENNIAL RYE GRASS POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '(LOLIUM PERENNE). 100000 BAU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81088, 5158, 'STANDARDIZED PERENNIAL RYE GRASS POLLEN', 'I', 100000, 'UNIT', '', '', 'N', 'ML', '100000 BAU/ML (BAU STANDS FOR BIOEQUIVALENT ALLERGY UNIT)./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81151, 20461, 'APROTININ (SYNTHETIC)', 'I', 3000, 'KIU', '', '', 'N', 'ML', 'APROTININ SOLUTION.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81151, 20462, 'SEALER PROTEIN (HUMAN)', 'I', 125, 'MG', '', '', 'N', 'ML', 'SEALER PROTEIN CONCENTRATE 1ML.  TOTAL PROTEIN 96-125MG/ML, OF WHICH 72-110MG/ML IS FIBRINOGEN(HUMAN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81179, 20463, 'LAPATINIB (LAPATINIB DITOSYLATE MONOHYDRATE)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81300, 20475, 'VORINOSTAT', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76999, 19827, 'HUMAN-BOVINE ROTAVIRUS REASSORTANT TYPE G1', 'I', 2210000, 'UNIT', '', '', 'N', 'DOSE', 'INFECTIOUS UNITS/DOSE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76999, 19828, 'HUMAN-BOVINE ROTAVIRUS REASSORTANT TYPE G2', 'I', 2840000, 'UNIT', '', '', 'N', 'DOSE', 'INFECTIOUS UNITS/DOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76999, 19829, 'HUMAN-BOVINE ROTAVIRUS REASSORTANT TYPE G3', 'I', 2220000, 'UNIT', '', '', 'N', 'DOSE', 'INFECTIOUS UNITS/DOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76999, 19830, 'HUMAN-BOVINE ROTAVIRUS REASSORTANT TYPE G4', 'I', 2040000, 'UNIT', '', '', 'N', 'DOSE', 'INFECTIOUS UNITS/DOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76999, 19831, 'HUMAN-BOVINE ROTAVIRUS REASSORTANT TYPE P1(8)', 'I', 2290000, 'UNIT', '', '', 'N', 'DOSE', 'INFECTIOUS UNITS/DOSE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77019, 19840, 'RASAGILINE (RASAGILINE MESYLATE)', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77020, 19840, 'RASAGILINE (RASAGILINE MESYLATE)', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43536, 7512, 'DESONIDE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: DESONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43537, 7512, 'DESONIDE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: DESONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33930, 7512, 'DESONIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (33931, 7512, 'DESONIDE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: DESONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17138, 7512, 'DESONIDE', 'I', 0.05, '%', '', '', 'N', '', 'Historic Freeform Text: DESONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83384, 7512, 'DESONIDE', 'I', 0.05, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17137, 7512, 'DESONIDE', 'I', 0.05, '%', '', '', 'N', '%', 'Historic Freeform Text: DESONIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43034, 1239, 'DIPIVEFRIN HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '', 'Historic Freeform Text: DIPIVEFRIN HCL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (61228, 1239, 'DIPIVEFRIN HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65914, 1239, 'DIPIVEFRIN HYDROCHLORIDE', 'I', 0.1, '%', '', '', 'N', '%', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77090, 19932, 'TIGECYCLINE', 'I', 50, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77850, 20122, 'DASATINIB (DASATINIB MONOHYDRATE)', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77851, 20122, 'DASATINIB (DASATINIB MONOHYDRATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77852, 20122, 'DASATINIB (DASATINIB MONOHYDRATE)', 'I', 70, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80564, 20122, 'DASATINIB (DASATINIB MONOHYDRATE)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78217, 20146, 'RANIBIZUMAB', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13384, 885, 'GADOPENTETATE DIMEGLUMINE', 'I', 469, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: GADOPENTETATE DIMEGLUMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (42964, 8327, 'CIPROFLOXACIN HYDROCHLORIDE', 'I', 0.3, '%', '', '', 'N', '%', 'HISTORIC FREEFORM TEXT: CIPROFLOXACIN ((AS HYDROCHLORIDE))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11957, 8428, 'PENICILLIN V (PENICILLIN V POTASSIUM)', 'I', 300, 'MG', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: PENICILLIN V POTASSIUM ((BASE EQ))');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43308, 932, 'RAMIPRIL', 'I', 1.25, 'MG', '', '', 'N', '', 'Historic Freeform Text: RAMIPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43309, 932, 'RAMIPRIL', 'I', 2.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: RAMIPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43310, 932, 'RAMIPRIL', 'I', 5, 'MG', '', '', 'N', '', 'Historic Freeform Text: RAMIPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43311, 932, 'RAMIPRIL', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: RAMIPRIL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81078, 932, 'RAMIPRIL', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63844, 932, 'RAMIPRIL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63845, 932, 'RAMIPRIL', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72226, 932, 'RAMIPRIL', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72227, 932, 'RAMIPRIL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72228, 932, 'RAMIPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72255, 932, 'RAMIPRIL', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72256, 932, 'RAMIPRIL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72257, 932, 'RAMIPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74047, 932, 'RAMIPRIL', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74048, 932, 'RAMIPRIL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74051, 932, 'RAMIPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76678, 932, 'RAMIPRIL', 'I', 15.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73644, 932, 'RAMIPRIL', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73646, 932, 'RAMIPRIL', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73648, 932, 'RAMIPRIL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73650, 932, 'RAMIPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78066, 932, 'RAMIPRIL', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78079, 932, 'RAMIPRIL', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78081, 932, 'RAMIPRIL', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78082, 932, 'RAMIPRIL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76878, 932, 'RAMIPRIL', 'I', 10.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76876, 932, 'RAMIPRIL', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76877, 932, 'RAMIPRIL', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76879, 932, 'RAMIPRIL', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76880, 932, 'RAMIPRIL', 'I', 10.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78477, 932, 'RAMIPRIL', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77332, 932, 'RAMIPRIL', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77334, 932, 'RAMIPRIL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77335, 932, 'RAMIPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77336, 932, 'RAMIPRIL', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77337, 932, 'RAMIPRIL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77338, 932, 'RAMIPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77676, 932, 'RAMIPRIL', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77677, 932, 'RAMIPRIL', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77678, 932, 'RAMIPRIL', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77679, 932, 'RAMIPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77309, 932, 'RAMIPRIL', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77310, 932, 'RAMIPRIL', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77311, 932, 'RAMIPRIL', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77312, 932, 'RAMIPRIL', 'I', 10.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79678, 932, 'RAMIPRIL', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82763, 932, 'RAMIPRIL', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82764, 932, 'RAMIPRIL', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82765, 932, 'RAMIPRIL', 'I', 10.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82766, 932, 'RAMIPRIL', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82767, 932, 'RAMIPRIL', 'I', 10.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78648, 932, 'RAMIPRIL', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78649, 932, 'RAMIPRIL', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78650, 932, 'RAMIPRIL', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78651, 932, 'RAMIPRIL', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79402, 932, 'RAMIPRIL', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79403, 932, 'RAMIPRIL', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79613, 932, 'RAMIPRIL', 'I', 1.25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79614, 932, 'RAMIPRIL', 'I', 2.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79615, 932, 'RAMIPRIL', 'I', 5.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43427, 1187, 'IOVERSOL', 'I', 51, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT:  IOVERSOL 51% PROVIDES 509MG OF IOVERSOL. OPTIRAY 160 PROVIDES 16% (160MG/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43599, 1187, 'IOVERSOL', 'I', 64, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IOVERSOL IOVERSOL 64% PROVIDES 636MG OF IOVERSOL. OPTIRAY 300MG PROVIDES 30%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (43604, 1187, 'IOVERSOL', 'I', 68, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IOVERSOL IOVERSOL INJ 68% PROVIDES 678 MG OF IOVERSOL. OPTIRAY 320 PROVIDES ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19898, 1187, 'IOVERSOL', 'I', 51, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IOVERSOL IOVERSOL 51% PROVIDES 509 OF IOVERSOL. OPTIRAY 240 PROVIDES 24% (24');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19899, 1187, 'IOVERSOL', 'I', 74, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IOVERSOL IOVERSOL INJ 74% PROVIDES 741MG OF IOVERSOL. OPTIRAY 350 PROVIDES 3');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14389, 1187, 'IOVERSOL', 'I', 74, '%', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: IOVERSOL IOVERSOL 74% PROVIDES 741MG OF IOVERSOL. OPTIRAY 350MG PROVIDES 35%');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11328, 1187, 'IOVERSOL', 'I', 68, '%', '', '', 'Y', '', 'HISTORIC FREEFORM TEXT: IOVERSOL ((IODINE EQ)) IOVERSOL 68% PROVIDES 678MG OF IOVERSOL. OPTIRAY 320 ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12759, 1744, 'FOSINOPRIL SODIUM', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: FOSINOPRIL SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12760, 1744, 'FOSINOPRIL SODIUM', 'I', 20, 'MG', '', '', 'N', '', 'Historic Freeform Text: FOSINOPRIL SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72096, 1744, 'FOSINOPRIL SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72097, 1744, 'FOSINOPRIL SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75137, 1744, 'FOSINOPRIL SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75138, 1744, 'FOSINOPRIL SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75144, 1744, 'FOSINOPRIL SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75145, 1744, 'FOSINOPRIL SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74117, 1744, 'FOSINOPRIL SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74116, 1744, 'FOSINOPRIL SODIUM', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: FOSINOPRIL SODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74778, 1744, 'FOSINOPRIL SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74779, 1744, 'FOSINOPRIL SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77986, 1744, 'FOSINOPRIL SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77987, 1744, 'FOSINOPRIL SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78832, 1744, 'FOSINOPRIL SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78833, 1744, 'FOSINOPRIL SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81674, 1744, 'FOSINOPRIL SODIUM', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81675, 1744, 'FOSINOPRIL SODIUM', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81374, 20481, 'EMAMECTIN BENZOATE', 'I', 2, 'G', '', '', 'N', 'KG', '0.2%W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81614, 20504, 'CLOFARABINE', 'I', 1, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81737, 20513, 'CERTOLIZUMAB PEGOL', 'I', 200, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81817, 20518, 'SPINOSAD', 'I', 140, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81818, 20518, 'SPINOSAD', 'I', 270, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81819, 20518, 'SPINOSAD', 'I', 560, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81820, 20518, 'SPINOSAD', 'I', 810, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81821, 20518, 'SPINOSAD', 'I', 1620, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81855, 20519, 'DORIPENEM (DORIPENEM MONOHYDRATE)', 'I', 500, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70916, 20521, 'DEXTROSE ANHYDROUS', 'I', 500, 'G', '', '1000', 'N', 'ML', 'GLUCOSE ANHYDROUS - COMPARTMENT A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70916, 20521, 'DEXTROSE ANHYDROUS', 'I', 500, 'G', '', '1000', 'N', 'ML', 'GLUCOSE ANHYDROUS - COMPARTMENT B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70917, 20521, 'DEXTROSE ANHYDROUS', 'I', 500, 'G', '', '1000', 'N', 'ML', 'GLUCOSE ANHYDROUS -  COMPARTMENT A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70917, 20521, 'DEXTROSE ANHYDROUS', 'I', 500, 'G', '', '1000', 'N', 'ML', 'GLUCOSE ANHYDROUS - COMPARTMENT B');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76308, 20521, 'DEXTROSE ANHYDROUS', 'I', 22.00, 'G', '', '1000', 'N', 'ML', 'ANHYDROUS. SOLUTION A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76310, 20521, 'DEXTROSE ANHYDROUS', 'I', 22.00, 'G', '', '1000', 'N', 'ML', 'ANHYDROUS. SOLUTION A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49560, 20521, 'DEXTROSE ANHYDROUS (DEXTROSE MONOHYDRATE)', 'I', 1.1, 'G', '', '', 'N', 'L', 'ANHYDROUS.  AS DEXTROSE MONOHYDRATE 1.1G. 2010.01.22.DEXTROSE ANHYDROUS GLUCOSE ANHYDROUS) AS PER AP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (49559, 20521, 'DEXTROSE ANHYDROUS (DEXTROSE MONOHYDRATE)', 'I', 1.1, 'G', '', '', 'N', 'L', 'ANHYDROUS.  AS DEXTROSE MONOHYDRATE 1.1G. 2010.01.22.DEXTROSE ANHYDROUS GLUCOSE ANHYDROUS) AS PER AP');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78012, 20521, 'DEXTROSE ANHYDROUS', 'I', 1.33, 'G', '', '', 'N', 'L', 'GLUCOSE ANHYDROUS    LARGE COMPARTMENT  2010.01.22. DEXTROSE REVISED TO DEXTROSE ANHYDROUS  AS REQUE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81890, 20523, 'INACT.JAPANESE ENCEPHAL VIRUS(ATTENUAT. STRAIN SA14-14-2 PRODUCED IN VERO CELLS)', 'I', 6, 'µG', '', '0.5', 'N', 'ML', 'ACTIVE INGREDIENT NAME PROVIDED BY BGTD. THIS IS FROM THE WHO GUIDELINES FOR DIFFERENT CLASSES OF VA');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81917, 20524, 'SAXAGLIPTIN (SAXAGLIPTIN HYDROCHLORIDE)', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81963, 20527, 'DEXMEDETOMIDINE HYDROCHLORIDE', 'I', 0.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68040, 20528, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 14', 'I', 2, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82074, 20528, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 14', 'I', 2.2, 'µG', '', '0.5', 'N', 'ML', 'CONJUGATED TO DIPHTHERIA CRM 197 PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20528, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 14', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68040, 20530, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 18C', 'I', 2, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82074, 20530, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 18C', 'I', 2.2, 'µG', '', '0.5', 'N', 'ML', 'CONJUGATED TO DIPHTHERIA CRM 197 PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20530, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 18C', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68040, 20531, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 19F', 'I', 2, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82074, 20531, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 19F', 'I', 2.2, 'µG', '', '0.5', 'N', 'ML', 'CONJUGATED TO DIPHTHERIA CRM 197 PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20531, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 19F', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68040, 20532, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 23F', 'I', 2, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82074, 20532, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 23F', 'I', 2.2, 'µG', '', '0.5', 'N', 'ML', 'CONJUGATED TO DIPHTHERIA CRM 197 PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20532, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 23F', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68040, 20533, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 4', 'I', 2, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82074, 20533, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 4', 'I', 2.2, 'µG', '', '0.5', 'N', 'ML', 'CONJUGATED TO DIPHTHERIA CRM 197 PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20533, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 4', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68040, 20534, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 6B', 'I', 4, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82074, 20534, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 6B', 'I', 4.4, 'µG', '', '0.5', 'N', 'ML', 'CONJUGATED TO DIPHTHERIA CRM 197 PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20534, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 6B', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68040, 20536, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 9V', 'I', 2, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82074, 20536, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 9V', 'I', 2.2, 'µG', '', '0.5', 'N', 'ML', 'CONJUGATED TO DIPHTHERIA CRM 197 PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20536, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 9V', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82074, 20539, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 3', 'I', 2.2, 'µG', '', '0.5', 'N', 'ML', 'CONJUGATED TO DIPHTHERIA CRM 197 PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20539, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 3', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82074, 20541, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 5', 'I', 2.2, 'µG', '', '0.5', 'N', 'ML', 'CONJUGATED TO DIPHTHERIA CRM 197 PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20541, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 5', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82074, 20542, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 6A', 'I', 2.2, 'µG', '', '0.5', 'N', 'ML', 'CONJUGATED TO DIPHTHERIA CRM 197 PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82074, 20544, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 7F', 'I', 2.2, 'µG', '', '0.5', 'N', 'ML', 'CONJUGATED TO DIPHTHERIA CRM 197 PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20544, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 7F', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82225, 20553, 'HAEMAGGLUTININ FROM A/CALIFORNIA/7/2009 (H1N1)V-LIKE STRAIN (X-179A)', 'I', 3.75, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82233, 20554, 'AZACITIDINE', 'I', 100, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77041, 19883, 'ALGLUCOSIDASE ALFA', 'I', 50, 'MG', '', '', 'N', 'VIAL', '50MG VIAL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77052, 19910, 'DESMOPRESSIN (DESMOPRESSIN ACETATE)', 'I', 60, 'µG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77053, 19910, 'DESMOPRESSIN (DESMOPRESSIN ACETATE)', 'I', 120, 'µG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77054, 19910, 'DESMOPRESSIN (DESMOPRESSIN ACETATE)', 'I', 240, 'µG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77094, 19933, 'TULATHROMYCIN', 'I', 100, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77381, 20037, 'TELBIVUDINE', 'I', 600, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (59791, 1844, 'ATRACURIUM BESYLATE', 'I', 10, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60046, 1844, 'ATRACURIUM BESYLATE', 'I', 10, 'MG', '', '', 'N', 'ML', '10 MG/ML ATRACURIUM BESYLATE IN WATER FOR INJECTION WITH 0.9% BENZYL ALCOHOL AS PRESERVATIVE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18669, 1757, 'ALTRETAMINE', 'I', 50, 'MG', '', '', 'N', '', 'Historic Freeform Text: ALTRETAMINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (6073, 3330, 'CASEIN HYDROLYSATE', 'I', 71.3, 'MG', '', '100', 'N', 'ML', 'Historic Freeform Text: ENZYMATIC CASEIN HYDROLYSATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53282, 6603, 'PLASMINOGEN', 'I', 120, 'µG', '', '1', 'N', 'ML', 'PLASMINOGEN 40 - 120 MCG PER KIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (53284, 6603, 'PLASMINOGEN', 'I', 600, 'µG', '', '5', 'N', 'ML', 'PLASMINOGEN 200 - 600 MCG PER KIT');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10958, 7527, 'ACTH', 'I', 40, 'UNIT', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: ACTH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8168, 7527, 'ACTH', 'I', 40, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: ACTH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5163, 7527, 'ACTH', 'I', 40, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: ACTH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5162, 7527, 'ACTH', 'I', 80, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: ACTH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2757, 7527, 'ACTH', 'I', 40, 'UNIT', '', '', 'N', 'ML', 'Historic Freeform Text: ACTH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11439, 7649, 'FOLLICLE STIMULATING HORMONE (FSH)', 'I', 400, 'MG', '', '', 'N', 'VIAL', 'FSH 20MG/ML WHEN RECONSTITUTED');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83526, 7649, 'FOLLICLE STIMULATING HORMONE (FSH)', 'I', 400, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72083, 7369, 'MENOTROPINS', 'I', 75, 'UNIT', '', '', 'N', 'VIAL', '75IU FSH AND 75 IU LH ACTIVITY');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76872, 7369, 'MENOTROPINS', 'I', 75, 'UNIT', '', '', 'N', 'VIAL', '75IU FSH AND 75IU LH ACTIVITY');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19706, 7354, 'GONADOTROPHIN SERUM (PMSG)', 'I', 400, 'UNIT', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: GONADOTROPHIN SERUM (PMSG)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65082, 7354, 'GONADOTROPHIN SERUM (PMSG)', 'I', 5000, 'UNIT', '', '', 'N', 'VIAL', 'IU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75293, 7354, 'GONADOTROPHIN SERUM (PMSG)', 'I', 6000, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82490, 7354, 'GONADOTROPHIN SERUM (PMSG)', 'I', 6000, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10688, 7354, 'GONADOTROPHIN SERUM (PMSG)', 'I', 5000, 'UNIT', '', '25', 'N', 'ML', 'Historic Freeform Text: GONADOTROPHIN SERUM (PMSG)');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10065, 17827, 'PARACHLOROPHENOL', 'I', 35, '%', '', '', 'N', '', 'Historic Freeform Text: P-CHLOROPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2977, 17827, 'PARACHLOROPHENOL', 'I', 300, 'MG', '', '1', 'N', 'G', 'Historic Freeform Text: P-CHLOROPHENOL');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82074, 20548, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYP 19A', 'I', 2.2, 'µG', '', '0.5', 'N', 'ML', 'CONJUGATED TO DIPHTHERIA CRM 197 PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82082, 20551, 'SILVER DIHYDROGEN CITRATE', 'I', 0.003, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20552, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 1', 'I', 25, 'µG', '', '0.5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: PNEUMONIAE VACCINE ((VARIOUS TYPES))  2010.12.21. ACTIVE INGREDIENT AND STRE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82074, 20552, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 1', 'I', 2.2, 'µG', '', '0.5', 'N', 'ML', 'CONJUGATED TO DIPHTHERIA CRM 197 PROTEIN');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82246, 20556, 'BESIFLOXACIN', 'I', 0.6, '%', '', '', 'N', 'W/V', 'EACH ML OF BESIVANCE CONTAINS 6MG BESIFLOXACIN BASE DERIVED FROM 6.63 MG BESIFLOXACIN HYDROCHLORIDE.');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82263, 20557, 'DEGARELIX (DEGARELIX ACETATE)', 'I', 80, 'MG', '', '', 'N', 'VIAL', 'DEGARELIX AS DEGARELIX ACETATE HYDRATED CONFIRMED WITH BPS/MOIZ CHHIL. EW');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82264, 20557, 'DEGARELIX (DEGARELIX ACETATE)', 'I', 120, 'MG', '', '', 'N', 'VIAL', 'DEGARELIX AS DEGARELIX ACETATE HYDRATED CONFIRMED WITH BPS. EW');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82419, 20560, 'TOCERANIB (TOCERANIB PHOSPHATE)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82420, 20560, 'TOCERANIB (TOCERANIB PHOSPHATE)', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82421, 20560, 'TOCERANIB (TOCERANIB PHOSPHATE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82488, 20562, 'THROMBIN ALFA', 'I', 6000, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82498, 20565, 'DEXMEDETOMIDINE (DEXMEDETOMIDINE HYDROCHLORIDE)', 'I', 100, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82625, 20566, 'GADOXETATE DISODIUM', 'I', 181.43, 'MG', '', '', 'N', 'ML', 'EQUIVALENT TO GADOXETATE DISODIUM 0.25 MMOL/ML./KK');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83017, 20572, 'MOMETASONE (MOMETASONE FUROATE MONOHYDRATE)', 'I', 1, 'MG', '', '', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83040, 20575, 'CANAKINUMAB', 'I', 150, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76507, 18938, 'INSULIN GLULISINE (RECOMBINANT DNA ORIGIN)', 'I', 100, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76506, 18938, 'INSULIN GLULISINE (RECOMBINANT DNA ORIGIN)', 'I', 100, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77968, 18938, 'INSULIN GLULISINE (RECOMBINANT DNA ORIGIN)', 'I', 100, 'UNIT', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77569, 20061, 'DICLOFENAC DIETHYLAMINE', 'I', 1.16, '%', '', '', 'N', '', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82423, 20061, 'DICLOFENAC DIETHYLAMINE', 'I', 1.16, '%', '', '', 'N', 'W/W', 'W/W');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77877, 20127, 'POSACONAZOLE', 'I', 40, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84428, 20131, 'PROTEIN C', 'I', 820, 'UNIT', '', '', 'N', '', '420-820IU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78001, 20131, 'PROTEIN C', 'I', 620, 'UNIT', '', '', 'N', 'VIAL', '140-620 INTERN. UNIT; AFTER RECONSTITUTION: 7-31 IU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84428, 20132, 'PROTEIN S', 'I', 680, 'UNIT', '', '', 'N', '', '240-680IU');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78001, 20132, 'PROTEIN S', 'I', 640, 'UNIT', '', '', 'N', 'VIAL', '140-640 INTERN. UNIT; AFTER RECONSTITUTION: 7-32 IU/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78410, 20156, 'APREPITANT', 'I', 80, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78411, 20156, 'APREPITANT', 'I', 125, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78412, 20156, 'APREPITANT', 'I', 125, 'MG', '', '', 'N', '', 'THE TRI-PACK HAS 2 CAPSULES OF 80MG AND 1 CAPSULE OF 125MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78412, 20156, 'APREPITANT', 'I', 80, 'MG', '', '', 'N', '', 'THE TRI-PACK HAS 2 CAPSULES OF 80MG AND 1 CAPSULE OF 125MG');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78525, 20161, 'DAPTOMYCIN', 'I', 500, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78722, 20173, 'RALTEGRAVIR (RALTEGRAVIR POTASSIUM)', 'I', 400, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17205, 2089, 'CALCIUM POLYSTYRENE SULFONATE', 'I', 999, 'MG', '', '', 'N', 'G', 'HISTORIC FREEFORM TEXT: CALCIUM POLYSTYRENE SULPHONATE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77065, 2107, 'BENZOPHENONE', 'I', 3.0, '%', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37150, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22846, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (22847, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (20261, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17887, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (17880, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19103, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16437, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11646, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11041, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 3.75, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8249, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8250, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8251, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8252, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62614, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63999, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65178, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65249, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65250, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67104, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68103, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72216, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70285, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'Y', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70286, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69737, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69738, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (70399, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71091, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76429, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76431, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73931, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73934, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72935, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74005, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74007, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76681, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74414, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74415, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75728, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75767, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74549, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74550, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75821, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75828, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75829, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76130, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76138, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76167, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76171, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76178, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76185, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76190, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76189, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76192, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73702, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73703, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73742, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78062, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77849, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77891, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77892, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77847, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77185, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81657, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82152, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79088, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79269, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79278, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79504, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80829, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79146, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79071, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (82084, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83056, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83258, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '', 'N', '', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83303, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83304, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '', 'N', '', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83878, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (35886, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20, 'MG', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37105, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (21167, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '', 'N', 'PCK', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11901, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '', 'N', 'PCK', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65873, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65633, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75146, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77936, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83004, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20, 'MG', '', '', 'N', 'PCK', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37038, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36293, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (36232, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (37183, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (31502, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30945, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (30826, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27462, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (27463, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26149, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (26864, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19772, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19060, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19129, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19026, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (18910, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20, 'MG', '', '15', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16698, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16177, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 12.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (16662, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12950, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13565, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13517, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15140, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14551, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13479, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 28.5, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13440, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (14485, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13960, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13361, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (13296, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11847, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11848, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11229, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12449, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12410, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12411, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11649, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (11027, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12719, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12720, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12722, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '20', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12723, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '15', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12717, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12718, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12192, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12788, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 3, 'MG', '', '', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12621, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (12504, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (8324, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (9543, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (10054, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (5431, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (7354, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 12.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4252, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (4590, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (3422, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 3, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (1498, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50620, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE (DEXTROMETHORPHAN POLISTIREX)', 'I', 30, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (50719, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE (DEXTROMETHORPHAN POLISTIREX)', 'I', 30, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52513, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (52514, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60760, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE (DEXTROMETHORPHAN POLISTIREX)', 'I', 15, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60140, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (60207, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63140, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66361, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66839, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66840, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66851, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66928, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66947, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (66983, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65129, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65130, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65131, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65132, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65133, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65134, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65135, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'Y', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67912, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68650, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69080, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (67672, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72095, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (69814, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '15', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76432, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76469, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75087, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75088, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75189, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75190, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72923, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75285, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10.0, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75286, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20.0, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76233, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75515, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75516, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75558, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 2.5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75559, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 5, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74432, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75827, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20.0, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75858, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75882, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74668, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74683, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74797, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74799, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76166, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74852, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (74853, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76254, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (73724, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76356, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76366, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77475, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77628, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77585, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '30', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77674, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77675, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77749, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (76949, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81390, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80637, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81394, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80467, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '5', 'N', 'ML', 'HISTORIC FREEFORM TEXT: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79105, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 7.5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78620, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79122, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 5, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (81416, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 5.0, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78973, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '30', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (79763, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80102, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80103, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20, 'MG', '', '5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80682, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 15, 'MG', '', '15', 'N', 'ML', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (80938, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 10, 'MG', '', '15', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (19088, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '23', 'N', 'G', 'Historic Freeform Text: DEXTROMETHORPHAN HBR');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (65060, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 30, 'MG', '', '22', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (71050, 10247, 'DEXTROMETHORPHAN HYDROBROMIDE', 'I', 20, 'MG', '', '24', 'N', 'G', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16462, 'AMYL CINNAMAL', 'I', 0.015, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS FRAGRANCE MIX 0.35MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16466, 'ISOEUGENOL', 'I', 0.015, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS FRAGRANCE MIX 0.35MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16467, 'CINNAMYL ALCOHOL', 'I', 0.054, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS FRAGRANCE MIX 0.35MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16468, 'HYDROXYCITRONELLAL', 'I', 0.054, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS FRAGRANCE MIX 0.35MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16469, 'OAK MOSS', 'I', 0.07, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS FRAGRANCE MIX 0.35MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16470, 'DIPHENYLGUANIDINE', 'I', 0.068, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS CARBA MIX 0.20 MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16471, 'ZINC DIETHYLDITHIOCARBAMATE', 'I', 0.068, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS CARBA MIX 0.20 MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (75739, 16472, 'ZINC DIBUTYLDITHIOCARBAMATE', 'I', 0.068, 'MG', '', '', 'N', 'PATCH', 'LABEL HAS CARBA MIX 0.20 MG/PATCH');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15224, 19818, 'TICARCILLIN (TICARCILLIN DISODIUM)', 'I', 3, 'G', '', '', 'N', 'VIAL', 'HISTORIC FREEFORM TEXT: TICARCILLIN DISODIUM');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (72188, 19818, 'TICARCILLIN (TICARCILLIN DISODIUM)', 'I', 30, 'G', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77655, 20097, 'VARENICLINE (VARENICLINE TARTRATE)', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (77656, 20097, 'VARENICLINE (VARENICLINE TARTRATE)', 'I', 1.0, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78360, 20097, 'VARENICLINE (VARENICLINE TARTRATE)', 'I', 0.5, 'MG', '', '', 'N', '', 'THIS STARTER PACK HAS 11 OF THE 0.5MG TABLETS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (78360, 20097, 'VARENICLINE (VARENICLINE TARTRATE)', 'I', 1.0, 'MG', '', '', 'N', '', 'THIS STARTER PACK HAS 14 OF THE 1.0 MG TABLETS');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (457, 9537, 'SALICYLAMIDE', 'I', 325, 'MG', '', '', 'N', '', 'Historic Freeform Text: SALICYLAMIDE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (15870, 898, 'ROMIFIDINE', 'I', 10, 'MG', '', '', 'N', 'ML', 'Historic Freeform Text: ROMIFIDINE');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83276, 20580, 'MENINGOCOCCAL GROUP A OLIGOSACCHARIDE', 'I', 10, 'µG', '', '0.5', 'N', 'ML', 'CONJUGATED TO CORYNEBACTERIUM DIPHTHERIAE CRM 197 PROTEIN 16.7 TO 33.3 MCG (AS PER PM).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83276, 20581, 'MENINGOCOCCAL GROUP Y OLIGOSACCHARIDE', 'I', 5, 'µG', '', '0.5', 'N', 'ML', 'CONJUGATED TO CORYNEBACTERIUM DIPHTHERIAE CRM 197 PROTEIN 5.6 TO 10 MCG (AS PER PM).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83276, 20582, 'MENINGOCOCCAL GROUP W-135 OLIGOSACCHARIDE', 'I', 5, 'µG', '', '0.5', 'N', 'ML', 'CONJUGATED TO CORYNEBACTERIUM DIPHTHERIAE CRM 197 PROTEIN 3.3 TO 8.3 MCG (AS PER PM).');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83279, 20583, 'GAMITHROMYCIN', 'I', 150, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83444, 20588, 'Prasugrel (Prasugrel Hydrochloride)', 'I', 10, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83533, 20590, 'TOCILIZUMAB', 'I', 80, 'MG', '', '4', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83534, 20590, 'TOCILIZUMAB', 'I', 200, 'MG', '', '10', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83535, 20590, 'TOCILIZUMAB', 'I', 400, 'MG', '', '20', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83577, 20591, 'SAPROPTERIN DIHYDROCHLORIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83627, 20592, 'LIRAGLUTIDE', 'I', 6, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83679, 20593, 'TRABECTEDIN', 'I', 1, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (63789, 20594, 'FIMBRIAE TYPES 2 AND 3 (FIM)', 'I', 5, 'µG', '', '0.5', 'N', 'ML', 'ACTIVE CHANGED FROM FIMBRIAE TO FIMBRIAE TYPES 2 AND 3 (FIM) AS PER E-MAIL FROM BGTD. 2010.05.20 EW ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83726, 20594, 'FIMBRIAE TYPES 2 AND 3 (FIM)', 'I', 5, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83758, 20595, 'Pazopanib (Pazopanib Hydrochloride)', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83783, 20597, 'Human C1 Esterase Inhibitor', 'I', 500, 'UNIT', '', '', 'N', 'VIAL', '400-625U IU IS EQUIVALENT TO THE C1-INH ACTIVITY IN 1ML OF FRESH CITRATED PLASMA OF HELATHY DONORS. ');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83789, 20598, 'Influenza Virus Type A (H1N1)', 'I', 7, 'UNIT', '', '0.2', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83789, 20599, 'Influenza Virus Type A (H3N2)', 'I', 7, 'UNIT', '', '0.2', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83789, 20600, 'Influenza Virus Type B', 'I', 7, 'UNIT', '', '0.2', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83974, 20603, 'Sevelamer Carbonate', 'I', 800, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (83993, 20612, 'ZUCAPSAICIN', 'I', 0.075, '%', '', '', 'N', 'W/W', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84014, 20625, 'DEXLANSOPRAZOLE', 'I', 30, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84015, 20625, 'DEXLANSOPRAZOLE', 'I', 60, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84060, 20634, 'TOLTRAZURIL', 'I', 50, 'MG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84221, 20635, 'VELAGLUCERASE ALFA', 'I', 400, 'UNIT', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84272, 20636, 'LACOSAMIDE', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84273, 20636, 'LACOSAMIDE', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84274, 20636, 'LACOSAMIDE', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84275, 20636, 'LACOSAMIDE', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84447, 20639, 'Roflumilast', 'I', 500, 'µG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84451, 20641, 'Sodium Sulfate Anhydrous', 'I', 7.500, 'G', '', '', 'N', 'PCK', 'SACHET A');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84534, 20642, 'Tapentadol (Tapentadol Hydrochloride)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84535, 20642, 'Tapentadol (Tapentadol Hydrochloride)', 'I', 100, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84536, 20642, 'Tapentadol (Tapentadol Hydrochloride)', 'I', 150, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84537, 20642, 'Tapentadol (Tapentadol Hydrochloride)', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84538, 20642, 'Tapentadol (Tapentadol Hydrochloride)', 'I', 250, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20646, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 2', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20647, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYP 8', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20648, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 9N', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20649, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 10A', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20650, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 11A', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20651, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 12F', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20652, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 15B', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20653, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 17F', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20654, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 19A', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20655, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 20', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20656, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 22F', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (2969, 20657, 'PNEUMOCOCCAL POLYSACCHARIDE SEROTYPE 33F', 'I', 25, 'µG', '', '0.5', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84685, 20660, 'EXENATIDE', 'I', 250, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84686, 20660, 'EXENATIDE', 'I', 250, 'µG', '', '', 'N', 'ML', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84687, 20661, 'ELTROMBOPAG (ELTROMBOPAG OLAMINE)', 'I', 25, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (84688, 20661, 'ELTROMBOPAG (ELTROMBOPAG OLAMINE)', 'I', 50, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85038, 20671, 'Fingolimod (Fingolimod Hydrochloride)', 'I', 0.5, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85352, 20742, 'Ticagrelor', 'I', 90, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85445, 20792, 'CABAZITAXEL', 'I', 40, 'MG', '', '', 'N', 'ML', 'ANHYDROUS. 40MG/ML');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62518, 20821, 'TOLTERODINE TARTRATE', 'I', 1, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (62519, 20821, 'TOLTERODINE TARTRATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68599, 20821, 'TOLTERODINE TARTRATE', 'I', 2, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (68600, 20821, 'TOLTERODINE TARTRATE', 'I', 4, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85508, 20836, 'BELIMUMAB', 'I', 120, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85509, 20836, 'BELIMUMAB', 'I', 400, 'MG', '', '', 'N', 'VIAL', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85593, 20878, 'BOCEPREVIR', 'I', 200, 'MG', '', '', 'N', '', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85660, 20878, 'BOCEPREVIR', 'I', 200, 'MG', '', '', 'N', 'CAP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85661, 20878, 'BOCEPREVIR', 'I', 200, 'MG', '', '', 'N', 'CAP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85662, 20878, 'BOCEPREVIR', 'I', 200, 'MG', '', '', 'N', 'CAP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85663, 20878, 'BOCEPREVIR', 'I', 200, 'MG', '', '', 'N', 'CAP', '');
INSERT INTO staging.ingred (drug_code, ingred_code, description, supplied, strength, strength_unit, strength_type, dosage_value, base, dosage_unit, notes) VALUES (85626, 20883, 'Abiraterone acetate', 'I', 250, 'MG', '', '', 'N', '', '');


--
-- PostgreSQL database dump complete
--

--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = staging, pg_catalog;

--
-- Data for Name: consumable_substance; Type: TABLE DATA; Schema: staging; Owner: gm-dbo
--

INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aldioxa', NULL, 0.2, '%', 1338);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meglumine iodipamide', NULL, 26.9, '%', 37573);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eugenol', NULL, 13.7, 'g / 100 g', 4875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenylpyraline hydrochloride', NULL, 1.5, 'mg', 2148);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenylpyraline hydrochloride', NULL, 0.25, 'mg', 2149);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenylpyraline hydrochloride', NULL, 0.5, 'mg', 2150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg', 37150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg', 19103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 250, 'mg', 4468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg', 65822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg', 70399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg', 71091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 600, 'mg', 71201);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg', 76681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg', 76178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg', 76236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg', 78062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg', 77185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg', 81657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg', 82152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg', 79088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg', 83056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg', 83303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg', 83304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 400, 'mg', 83878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 400, 'mg / pck', 65633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 50, 'mg / 5 ml', 41646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 36293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 5 ml', 36232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 34650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 30826);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 27463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 19772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 19690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 19625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 5 ml', 19060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 5 ml', 19026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 15 ml', 18910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 16698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 5 ml', 16662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 15618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 13565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 13494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 221, 'mg / 30 ml', 13479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 5 ml', 13440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 14485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 13296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 12449);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 15 ml', 12717);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 12192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 50, 'mg / 5 ml', 4252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 50, 'mg / 5 ml', 4258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 10, 'mg / ml', 1980);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 1498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 5 ml', 52513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 5 ml', 52514);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 60207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 15 ml', 66840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 5 ml', 66851);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 66947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 30 ml', 66983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 5 ml', 65129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 65130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 65131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 67954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 68034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 68035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 69813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 15 ml', 69814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 50, 'mg / 5 ml', 76388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 5 ml', 75087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 5 ml', 75088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 72923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 75515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 5 ml', 75516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 74333);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 74432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 30 ml', 74797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 5 ml', 74852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 5 ml', 74853);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 15 ml', 73724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 30 ml', 77475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 5 ml', 80637);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 400, 'mg / 30 ml', 79002);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 100, 'mg / 15 ml', 80682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', NULL, 200, 'mg / 15 ml', 80938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline hydrochloride', NULL, 0.025, '%', 16653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline hydrochloride', NULL, 0.02675, '%', 8155);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline hydrochloride', NULL, 0.025, '%', 3743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline hydrochloride', NULL, 0.05, '%', 3028);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline hydrochloride', NULL, 0.025, '%', 66582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline hydrochloride', NULL, 0.012, '%', 72379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline hydrochloride', NULL, 0.012, '%', 78028);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline hydrochloride', NULL, 0.051, '%', 80140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline hydrochloride', NULL, 0.03, '% / w/w', 84583);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline hydrochloride', NULL, 0.5, 'mg / ml', 33329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mannitol', NULL, 500, 'mg / 100 ml', 9829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mannitol', NULL, 5.4, 'mg / ml', 3823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetanus protein', NULL, 20, 'µg / 0.5 ml', 13140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetanus protein', NULL, 20, 'µg / 0.5 ml', 50651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetanus protein', NULL, 20, 'µg / 0.5 ml', 67042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (v.c.o.) type 2 mef1', NULL, 8, 'unit / 0.5 ml', 44019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dermatophagoides farinae', NULL, 5000, 'unit / ml', 50632);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone acetate', NULL, 3, 'mg / ml', 354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone acetate', NULL, 3, 'mg / ml', 61194);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', NULL, 0.05, '%', 10748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', NULL, 0.05, '%', 3718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', NULL, 0.05, '%', 3719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone valerate)', NULL, 0.1, '%', 816);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone sodium phosphate)', NULL, 1, 'mg / ml', 7418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone sodium phosphate)', NULL, 3, 'mg / ml', 354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone 21-disodium phosphate)', NULL, 3, 'mg / ml', 61194);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone sodium phosphate)', NULL, 1, 'mg / ml', 68998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', NULL, 0.5, 'mg / g', 5561);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone sodium phosphate)', NULL, 1, 'mg / g', 5315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', NULL, 0.5, 'mg / g', 5287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone valerate)', NULL, 1, 'mg / g', 1285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', NULL, 0.5, 'mg / g', 68084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', NULL, 0.5, 'mg / g', 69789);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', NULL, 0.5, 'mg / g', 80450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisolone acetate', NULL, 0.5, '%', 16625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisolone acetate', NULL, 0.2, '%', 10169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisolone acetate', NULL, 0.2, '%', 1971);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mannitol', 'B05CX04', 5, '%', 15491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisolone acetate', NULL, 5, 'mg / ml', 6365);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisolone acetate', NULL, 5, 'mg / g', 16649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('budesonide', NULL, 100, 'µg / dose', 69428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('budesonide', NULL, 200, 'µg / dose', 69429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', NULL, 1, 'mg / g', 15598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', NULL, 1, 'mg / g', 12862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', NULL, 1, 'mg / g', 9448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', NULL, 1, 'mg / g', 9449);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', NULL, 0.7, 'mg', 84844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', NULL, 0.1, '%', 11068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', NULL, 0.1, '%', 10971);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', NULL, 0.1, '%', 73758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone (dexamethasone sodium metasulphobenzoate)', NULL, 0.5, 'mg / ml', 37363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', NULL, 1, 'mg / ml', 16624);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', NULL, 1, 'mg / ml', 13146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', NULL, 1, 'mg / ml', 259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone (dexamethasone sodium metasulphobenzoate)', NULL, 0.5, 'mg / ml', 72229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamabrom', NULL, 25, 'mg', 63299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', NULL, 1, 'mg / g', 16648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', NULL, 10, 'mg / 100 g', 1251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', NULL, 1, 'mg / g', 2423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', NULL, 1, 'mg / 1 g', 2977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', NULL, 2.5, 'mg', 66710);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', NULL, 5.0, 'mg', 66711);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-cysteine (l-cysteine hydrochloride)', NULL, 13.9, 'mg / 100 ml', 44068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-cysteine (l-cysteine hydrochloride)', NULL, 13, 'mg / 100 ml', 15493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-cysteine', NULL, 189, 'mg / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lauryl sulfoacetate', NULL, 9, 'mg / ml', 18290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.04, 'g / 100 ml', 20278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.49, 'g / 100 ml', 19306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.04, 'g / 100 ml', 19610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.04, 'g / 100 ml', 20302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.04, 'g / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.04, 'g / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.04, 'g / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.04, 'g / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.04, 'g / 100 ml', 20279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.04, 'g / 100 ml', 18550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.04, 'g / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.04, 'g / 100 ml', 14077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.04, 'g / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.04, 'g / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.04, 'g / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.04, 'g / 100 ml', 14067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 2.07, 'g / 100 ml', 11329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.1, 'g / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.1, 'g / 100 ml', 5890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 2.08, 'g / 100 ml', 4661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1.28, 'g / 100 ml', 3468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 422, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 880, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 880, 'mg / 100 ml', 20303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 880, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 880, 'mg / 100 ml', 20289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 520, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 422, 'mg / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 422, 'mg / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 348, 'mg / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 422, 'mg / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 1040, 'mg / 100 ml', 19143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 422, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 348, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 496, 'mg / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 348, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 422, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 490, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 993, 'mg / 100 ml', 18644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 348, 'mg / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 993, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 695, 'mg / 100 ml', 18608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 698, 'mg / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 844, 'mg / 100 ml', 18607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 880, 'mg / 100 ml', 14073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 880, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 880, 'mg / 100 ml', 14071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 520, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 880, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 900, 'mg / 100 ml', 4560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 640, 'mg / 100 ml', 2776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-alanine', NULL, 800, 'mg / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alanine', NULL, 2.76, 'g / 100 ml', 43947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alanine', NULL, 2.08, 'g / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alanine', NULL, 600, 'mg / 100 ml', 44068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alanine', NULL, 3.66, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alanine', NULL, 6.41, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alanine', NULL, 8.24, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alanine', NULL, 8.24, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coagulation factor ii (human)', NULL, 800, 'unit', 84428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coagulation factor ii (human)', NULL, 760, 'unit / vial', 78001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prilocaine hydrochloride', NULL, 40, 'mg / ml', 4202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prilocaine hydrochloride', NULL, 40, 'mg / ml', 2828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prilocaine hydrochloride', NULL, 40, 'mg / ml', 83307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (lysine acetate)', NULL, 1.35, 'g / 100 ml', 43947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (lysine acetate)', NULL, 446, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (lysine acetate)', NULL, 620, 'mg / 100 ml', 44068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (l-lysine hydrochloride)', NULL, 290, 'mg / 100 ml', 20279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (l-lysine hydrochloride)', NULL, 290, 'mg / 100 ml', 20278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (l-lysine hydrochloride)', NULL, 246.5, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (l-lysine hydrochloride)', NULL, 246.5, 'mg / 100 ml', 20303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (l-lysine hydrochloride)', NULL, 290, 'mg / 100 ml', 20302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (l-lysine hydrochloride)', NULL, 246.5, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (l-lysine hydrochloride)', NULL, 290, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (l-lysine hydrochloride)', NULL, 246.5, 'mg / 100 ml', 20289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (l-lysine hydrochloride)', NULL, 290, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (l-lysine hydrochloride)', NULL, 290, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (l-lysine hydrochloride)', NULL, 290, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (lysine acetate)', NULL, 640, 'mg / 100 ml', 15493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (lysine acetate)', NULL, 535, 'mg / 100 ml', 7163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (lysine acetate)', NULL, 624, 'mg / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (l-lysine acetate)', NULL, 1.99, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (l-lysine acetate)', NULL, 3.48, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (l-lysine acetate)', NULL, 4.48, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (l-lysine acetate)', NULL, 4.48, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', NULL, 2, '%', 10673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', NULL, 30, '%', 9361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', NULL, 2, '%', 5634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', NULL, 2, '%', 5635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', NULL, 30, '%', 5314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', NULL, 2, '%', 2072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', NULL, 3.0, '% / w/w', 18807);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', NULL, 2, '%', 8599);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', NULL, 20, 'mg / g', 5561);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', NULL, 30, 'mg / g', 5287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', NULL, 20, 'mg / g', 69789);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium salicylate', NULL, 56, 'mg / ml', 3546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexbrompheniramine maleate', NULL, 2, 'mg', 33922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexbrompheniramine maleate', NULL, 2, 'mg', 3717);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexbrompheniramine maleate', NULL, 6, 'mg', 2048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexbrompheniramine maleate', NULL, 1.5, 'mg / 5 ml', 20066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium acetate', NULL, 860, 'mg / 25 ml', 23184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyproterone acetate', NULL, 2, 'mg', 53444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyproterone acetate', NULL, 2.0, 'mg', 77558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyproterone acetate', NULL, 2, 'mg', 79517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diflucortolone valerate', NULL, 0.1, '% / w/w', 18807);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 10, 'mg', 36799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 10, 'mg', 6418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 10, 'mg', 4629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 10, 'mg', 4630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 10, 'mg', 59873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 10, 'mg', 64442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 10, 'mg', 66620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 10, 'mg', 66621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 0.5, '%', 18240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 1, '%', 8338);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 0.5, '%', 6417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 0.5, '%', 4390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 0.5, '%', 4389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 1, '%', 5280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 1, '%', 3492);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 1, '%', 4583);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 1, '%', 49970);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 0.5, '%', 55837);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 1, '%', 62005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 1.0, '%', 61410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 10, 'mg / sup', 63617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 0.5, '%', 34945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 10, 'mg / ml', 13383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 1, 'g / 100 g', 1251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 10, 'mg / g', 13682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 5, 'mg / g', 71955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', NULL, 5, 'mg / g', 71956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norgestimate', NULL, 0.25, 'mg', 12988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norgestimate', NULL, 0.25, 'mg', 12998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norgestimate', NULL, 0.215, 'mg', 14199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norgestimate', NULL, 0.25, 'mg', 14199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norgestimate', NULL, 0.18, 'mg', 14197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norgestimate', NULL, 0.215, 'mg', 14197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norgestimate', NULL, 0.25, 'mg', 14197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norgestimate', NULL, 0.18, 'mg', 14199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norgestimate', NULL, 0.180, 'mg', 74376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norgestimate', NULL, 0.215, 'mg', 74376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norgestimate', NULL, 0.250, 'mg', 74376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norgestimate', NULL, 0.180, 'mg', 74378);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norgestimate', NULL, 0.215, 'mg', 74378);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norgestimate', NULL, 0.250, 'mg', 74378);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norgestrel', NULL, 300, 'µg', 43160);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone acetate', NULL, 1.5, 'mg', 1922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone acetate', NULL, 1.5, 'mg', 2386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone acetate', NULL, 1, 'mg', 2254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone acetate', NULL, 1, 'mg', 2255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone acetate', NULL, 2.7, 'mg', 65502);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone acetate', NULL, 4.8, 'mg', 65503);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone acetate', NULL, 1, 'mg', 66279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone acetate', NULL, 0.5, 'mg', 73420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone acetate', NULL, 0.1, 'mg', 79461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 1, 'mg', 42921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 1, 'mg', 42922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 1.0, 'mg', 42952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 1.0, 'mg', 42960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 0.5, 'mg', 42888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 0.5, 'mg', 42889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamabrom', NULL, 25, 'mg', 63901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 1.0, 'mg', 42889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 0.5, 'mg', 42890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 1.0, 'mg', 42890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 0.5, 'mg', 20162);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 0.75, 'mg', 5482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 1, 'mg', 5482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 0.5, 'mg', 5483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 0.75, 'mg', 5483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 1, 'mg', 5483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 0.5, 'mg', 5482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 1, 'mg', 5103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 0.5, 'mg', 5104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 1, 'mg', 5105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', NULL, 0.5, 'mg', 5106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium acetate', NULL, 32, 'mg / 100 ml', 11038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium acetate', NULL, 0.21, 'mg / ml', 1739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine acetate', NULL, 0.5, '%', 13349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth camphocarbonate', NULL, 150, 'mg', 4468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', NULL, 0.02, '%', 41931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', NULL, 0.15, '%', 18442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', NULL, 0.15, '%', 13617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', NULL, 0.3, '%', 14444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', NULL, 0.15, '%', 12792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', NULL, 0.6, '%', 5480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', NULL, 0.15, '%', 7121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', NULL, 0.5, '%', 2072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', NULL, 0.1, '%', 50083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', NULL, 0.3, '%', 77106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', NULL, 0.3, '% / w/w', 81365);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', NULL, 0.300, '% / w/w', 84966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', NULL, 0.5, '%', 8599);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', NULL, 2.5, '%', 16733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', NULL, 2.5, '%', 81134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', NULL, 15, 'g / 100 g', 37164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', NULL, 5, 'g / 100 g', 4410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', NULL, 25, 'mg / g', 11440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', NULL, 50, 'mg / g', 64139);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', NULL, 50, 'mg / g', 78975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamabrom', NULL, 25, 'mg', 7288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamabrom', NULL, 25, 'mg', 50547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamabrom', NULL, 25, 'mg', 62514);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamabrom', NULL, 25, 'mg', 70470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamabrom', NULL, 25, 'mg', 76087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamabrom', NULL, 25, 'mg', 73655);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamabrom', NULL, 25, 'mg', 77787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('proline', NULL, 1.34, 'g / 100 ml', 43947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('proline', NULL, 950, 'mg / 100 ml', 44068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('proline', NULL, 680, 'mg / 100 ml', 11329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('proline', NULL, 750, 'mg / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('proline', NULL, 420, 'mg / 100 ml', 4661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('proline', NULL, 420, 'mg / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('spironolactone', NULL, 25, 'mg', 5858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('spironolactone', NULL, 50, 'mg', 6892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 5.0, '% / w/w', 84425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('spironolactone', NULL, 50, 'mg', 5316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('spironolactone', NULL, 25, 'mg', 1404);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethynodiol diacetate', NULL, 2, 'mg', 3633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethynodiol diacetate', NULL, 2, 'mg', 3374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', NULL, 0.62, 'mg', 65502);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', NULL, 0.51, 'mg', 65503);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', NULL, 1.0, 'mg', 75422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', NULL, 1.0, 'mg', 73420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', NULL, 4.40, 'mg', 73542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', NULL, 0.5, 'mg', 79461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin isophane (nph)', NULL, 70, 'unit / ml', 9788);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin', NULL, 30, 'unit / ml', 9788);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dehydrocholic acid', NULL, 30, 'mg', 5276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dehydrocholic acid', NULL, 50, 'mg', 2981);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 7, '%', 13247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 4.0, '%', 68594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 9.0, '%', 72102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 2.85, '%', 72290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 3.0, '%', 70373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 2, '%', 71277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 2.85, '%', 75151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 4.88, '%', 75235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 8.0, '%', 76600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 6.0, '%', 74039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 6.7, '%', 76743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 8.8, '%', 75513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 3.88, '%', 75531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 4, '%', 72406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 6.8, '%', 74363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 6.65, '%', 75641);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 5, '%', 73157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 5, '%', 73158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 5, '%', 73159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 5, '%', 73161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 2.9, '%', 74455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 6.79, '%', 74458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 3, '%', 75752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 3, '%', 75755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 3, '%', 75756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 2.0, '%', 75920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 6.7, '%', 73304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 16.1, '%', 76132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 7.0, '%', 74880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 1.7, '%', 73606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 3.5, '%', 73607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 8.3, '%', 73654);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 6.7, '%', 73674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 1.5, '%', 74955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 13.9, '%', 72724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 13.9, '%', 72726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 9.3, '%', 72727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 2.4, '%', 76349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 1.75, '%', 76379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 4.8, '%', 78091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 6.0, '%', 77512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 3.0, '%', 77223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 9.3, '%', 77186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 2.0, '%', 77375);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 3.4, '%', 77083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 9.0, '%', 77632);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 13.4, '%', 78240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 5.0, '%', 77076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 0.45, '%', 76910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 1.5, '%', 77411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 5.50, '%', 78047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 2.1, '%', 79021);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 7.6, '%', 79533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 19.0, '%', 79240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 2.9, '%', 79276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 5, '%', 82792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 9.0, '%', 80045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 1.0, '%', 78901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 2.2, '%', 79090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 5.0, '%', 80673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 5.00, '%', 81642);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 5.00, '%', 81643);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 4.8, '%', 80281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 10, '%', 80457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 8.1, '%', 82313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 15, '%', 82530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 40, '%', 83796);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 6, '%', 84130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 4.0, '%', 84246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 3, '% / w/w', 71503);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 40, '% / w/w', 72398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 6.0, '% / w/w', 72764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 3.43, '% / w/w', 78398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 3.92, '% / w/w', 78399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 2.3, '% / w/w', 77463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 10, '% / w/w', 81251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 6.3, '% / w/w', 79770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 3.8, '% / w/w', 79458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 1.9, '% / w/w', 79773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 7.0, '% / w/w', 80773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 2.0, '% / w/w', 81714);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 2.0, '% / w/w', 81715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 8.0, '% / w/w', 80631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 2.7, '% / w/w', 80226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 15, '% / w/w', 82304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 10.5, '% / w/w', 82315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 9.0, '% / w/w', 80775);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 9.0, '% / w/w', 80776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 7.35, '% / w/w', 81293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 3.0, '% / w/w', 82283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 12, '% / w/w', 80131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 3.0, '% / w/w', 79540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 2.45, '% / w/w', 82525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 7.35, '% / w/w', 83168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 10.0, '% / w/w', 83278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 6.00, '% / w/w', 84853);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 6.00, '% / w/w', 84858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 1.96, '% / w/v', 85515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 3, '%', 62743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 20, 'mg / ml', 63661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 30, 'mg / ml', 63662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 5.04, 'g / 100 g', 66124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', NULL, 5, 'g / 100 g', 72236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sennosides', NULL, 8.6, 'mg', 71374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sennosides', NULL, 8.6, 'mg', 71635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sennosides', NULL, 8.6, 'mg', 71178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sennosides', NULL, 8.6, 'mg', 77658);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxetacaine', NULL, 10, 'mg / 5 ml', 18186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cupric chloride', NULL, 0.42, 'mg / ml', 5708);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', NULL, 0.05, '%', 13524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', NULL, 0.01, '%', 13954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', NULL, 0.05, '%', 13958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', NULL, 0.1, '%', 13929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', NULL, 0.025, '%', 13930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', NULL, 0.01, '%', 14397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', NULL, 0.025, '%', 11432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', NULL, 0.025, '% / w/w', 84468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', NULL, 0.01, '% / w/v', 67151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'L01XX14', 10, 'mg', 18080);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 200, 'mg', 65897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penghawar', NULL, 3.5, 'g / 100 g', 4875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('normethadone hydrochloride', NULL, 10, 'mg / ml', 37358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine citrate', NULL, 30, 'mg', 13312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine citrate', NULL, 30, 'mg', 13765);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine citrate', NULL, 30, 'mg', 13761);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine citrate', NULL, 30, 'mg', 11753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine citrate', NULL, 100, 'mg', 696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine citrate', NULL, 30, 'mg', 2178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine citrate', NULL, 30, 'mg', 2179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine citrate', NULL, 30, 'mg', 2180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine citrate', NULL, 30, 'mg', 876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine citrate', NULL, 30, 'mg', 51867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine citrate', NULL, 30, 'mg', 51868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine citrate', NULL, 30, 'mg', 51869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine citrate', NULL, 30, 'mg', 55849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine citrate', NULL, 30, 'mg', 62074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkylc9-c15 tolyl methyl trimethyl ammonium chlori', NULL, 4, '%', 19111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dibucaine', NULL, 0.5, '%', 7153);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium sulfate', NULL, 5.68, 'g / pck', 33649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium sulfate', NULL, 22.96, 'g / pck', 9351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium sulfate', NULL, 5.74, 'g / pck', 81164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium sulfate', NULL, 5.74, 'g / l', 9631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium sulfate', NULL, 22.74, 'g / 4 l', 6370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium sulfate', NULL, 81.2, 'mg / g', 6616);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dl-methionine', NULL, 25, 'mg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dl-methionine', NULL, 450, 'mg / 100 ml', 44068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dl-methionine', NULL, 760, 'mg / 100 ml', 43947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dl-methionine', NULL, 880, 'mg / 100 ml', 15493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodine (potassium iodide)', NULL, 0.025, 'mg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodine (potassium iodide)', NULL, 0.15, 'mg', 70202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodine (potassium iodide)', NULL, 0.15, 'mg', 76186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodine (sodium iodide)', NULL, 25, 'µg / ml', 20314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodine (sodium iodide)', NULL, 60, 'µg / ml', 16226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodine (sodium iodide)', NULL, 75, 'µg / ml', 16227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrilamine maleate', NULL, 15, 'mg', 7288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrilamine maleate', NULL, 15, 'mg', 50547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrilamine maleate', NULL, 15, 'mg', 62514);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrilamine maleate', NULL, 15, 'mg', 63299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrilamine maleate', NULL, 15, 'mg', 63901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrilamine maleate', NULL, 15, 'mg', 75894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrilamine maleate', NULL, 15, 'mg', 76086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrilamine maleate', NULL, 15, 'mg', 76087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrilamine maleate', NULL, 15, 'mg', 73655);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrilamine maleate', NULL, 15, 'mg', 77787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrilamine maleate', NULL, 0.1, '%', 2963);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrilamine maleate', NULL, 10, 'mg / 5 ml', 41646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrilamine maleate', NULL, 1.2, 'mg / ml', 1980);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylene blue', NULL, 0.2, 'mg / ml', 33329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('senega', NULL, 0.566, 'mg / 1 ml', 5504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinamide', NULL, 5, 'mg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinamide', NULL, 20, 'mg', 70202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinamide', NULL, 20, 'mg', 76186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinamide', NULL, 17, 'mg / vial', 66277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinamide', NULL, 1.111, 'mg / ml', 18602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinamide', NULL, 8, 'mg / ml', 16462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinamide', NULL, 10, 'mg / ml', 5613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinamide', NULL, 100, 'mg / ml', 3497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinamide', NULL, 75, 'mg / ml', 31);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinamide', NULL, 8, 'mg / ml', 68684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiamine hydrochloride', NULL, 0.222, 'mg / ml', 18602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiamine hydrochloride', NULL, 100, 'mg / ml', 3497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('d-pantothenic acid (calcium d-pantothenate)', NULL, 50, 'mg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('d-pantothenic acid (calcium d-pantothenate)', NULL, 5, 'mg', 70202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('d-pantothenic acid (calcium d-pantothenate)', NULL, 5, 'mg', 76186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('d-pantothenic acid (calcium d-pantothenate, riboflavin-5-phosphate)', NULL, 2.6, 'mg / ml', 5613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyridoxine hydrochloride', NULL, 10, 'mg', 5509);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyridoxine hydrochloride', NULL, 15, 'mg', 2396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyridoxine hydrochloride', NULL, 1, 'mg / vial', 66277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyridoxine hydrochloride', NULL, 0.042, 'mg / ml', 18602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyridoxine hydrochloride', NULL, 0.8, 'mg / ml', 16462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyridoxine hydrochloride', NULL, 10, 'mg / ml', 3497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyridoxine hydrochloride', NULL, 2, 'mg / ml', 31);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyridoxine hydrochloride', NULL, 0.8, 'mg / ml', 68684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('choline', NULL, 2.222, 'mg / ml', 18602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('choline bitartrate', NULL, 70, 'mg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inositol', NULL, 5, 'mg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inositol', NULL, 2.222, 'mg / ml', 18602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('biotin', NULL, 10, 'µg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('biotin', NULL, 20, 'µg / vial', 66277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('biotin', NULL, 12, 'µg / ml', 16462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('biotin', NULL, 12, 'µg / ml', 68684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin k1', NULL, 0.2, 'mg / vial', 66277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 200, 'mg', 18539);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 200, 'mg', 14492);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 200, 'mg', 71388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 200, 'mg', 75302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 200, 'mg', 75304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 200, 'mg', 75315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 200, 'mg', 76544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 200, 'mg', 73002);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 200, 'mg', 73565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 200, 'mg', 80988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 200, 'mg', 82770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 200, 'mg', 82772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 200, 'mg', 82306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 200, 'mg', 83757);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 200, 'mg', 84104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 200.0, 'mg', 84427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 100, 'mg / 5 ml', 72786);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', NULL, 100, 'mg / 5 ml', 75412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', NULL, 1.0, 'mg / ml', 51050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', NULL, 2.5, 'mg / 2.5 ml', 67727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', NULL, 2.5, 'mg / 2.5 ml', 75181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', NULL, 2.5, 'mg / 2.5 ml', 75820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 46758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupivacaine hydrochloride', NULL, 5, 'mg / ml', 16163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupivacaine hydrochloride', NULL, 2.5, 'mg / ml', 16162);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupivacaine hydrochloride', NULL, 2.5, 'mg / ml', 65585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupivacaine hydrochloride', NULL, 5.0, 'mg / ml', 65586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupivacaine hydrochloride', NULL, 5, 'mg / ml', 79742);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupivacaine hydrochloride', NULL, 5, 'mg / ml', 79063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('manganese chloride', NULL, 0.37, 'mg / ml', 5708);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sorbitol', NULL, 2.5, 'g / 100 ml', 9829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sorbitol', NULL, 625, 'mg / ml', 18290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sorbitol', NULL, 27, 'mg / ml', 3823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', NULL, 1700, 'mg', 69406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', NULL, 1.916, 'g / evt', 42652);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', NULL, 1.68, 'g / pck', 33649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', NULL, 6.76, 'g / pck', 9351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', NULL, 1.69, 'g / pck', 81164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', NULL, 1.69, 'g / l', 9631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', NULL, 6.74, 'g / 4 l', 6370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', NULL, 24.02, 'mg / g', 6616);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('camphor', NULL, 5, 'mg', 2148);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('camphor', NULL, 1, 'mg', 2149);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('camphor', NULL, 2, 'mg', 2150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('camphor', NULL, 0.38, '%', 42607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('camphor', NULL, 65, '%', 10065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('camphor', NULL, 0.38, '%', 42334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('camphor', NULL, 649, 'mg / 1 g', 2977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 35047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 31568);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 33917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 30, 'mg', 23669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 16.2, 'mg', 23354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 32.4, 'mg', 23355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 22274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 19935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 15, 'mg', 19248);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 30, 'mg', 19249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 60, 'mg', 19250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 15805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 30, 'mg', 15579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 30, 'mg', 15580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 60, 'mg', 15581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 15, 'mg', 15578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 13699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 16.2, 'mg', 12944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 32.4, 'mg', 12946);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 12942);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 12943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 14596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 14595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 13312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 13259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 13765);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 13761);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 11753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 11741);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 11065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 11921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 11339);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 30, 'mg', 9626);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 5371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 5372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 6516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 15, 'mg', 6479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 5876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 30, 'mg', 6419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 30, 'mg', 5780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 15, 'mg', 6893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 30, 'mg', 6894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 30, 'mg', 6346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 7434);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 60, 'mg', 6824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 6763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 15, 'mg', 6764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 2918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 1025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 20, 'mg', 955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 2178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 15, 'mg', 2179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 30, 'mg', 2180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 30, 'mg', 873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 15, 'mg', 872);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 30, 'mg', 47954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 15, 'mg', 47955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 30, 'mg', 52221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 51867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 15, 'mg', 51868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 30, 'mg', 51869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 15, 'mg', 55849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 30, 'mg', 62074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 15, 'mg', 62075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 62101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 60750);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 60162);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 60917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 60919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 65859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 15, 'mg', 66118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 66910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 70220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 70240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 60, 'mg', 73918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 30, 'mg', 73920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 73187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 73359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 73537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 73681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg', 78862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 3.3, 'mg / 5 ml', 34650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 10, 'mg / 5 ml', 19690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 3.3, 'mg / 5 ml', 19625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 10, 'mg / 5 ml', 20329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg / 5 ml', 19244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 10, 'mg / 5 ml', 15618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 10, 'mg / 5 ml', 13494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 8, 'mg / 5 ml', 11384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 0.667, 'mg / 1 ml', 5504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 3.33, 'mg / 5 ml', 6844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 3.33, 'mg / 5 ml', 4469);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 10, 'mg / 5 ml', 956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 10, 'mg / 5 ml', 957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 10, 'mg / 5 ml', 66929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 3.33, 'mg / 5 ml', 67953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 3.3, 'mg / 5 ml', 67954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 10, 'mg / 5 ml', 68031);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 10, 'mg / 5 ml', 68034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 3.3, 'mg / 5 ml', 69689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 3.3, 'mg / 5 ml', 69813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', NULL, 3.3, 'mg / 5 ml', 74333);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clioquinol', NULL, 3, '%', 631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clioquinol', NULL, 1, '%', 868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clioquinol', NULL, 3, '% / w/w', 810);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetrimonium bromide', NULL, 0.5, '%', 14568);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetrimonium bromide', NULL, 150, 'mg / 100 g', 4410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetrimonium bromide', NULL, 750, 'mg / 100 g', 1248);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylmetacresol', NULL, 0.6, 'mg', 61969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylmetacresol', NULL, 0.6, 'mg', 59951);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylmetacresol', NULL, 0.6, 'mg', 81250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylmetacresol', NULL, 0.6, 'mg', 80640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycerine', NULL, 0.26, '%', 72379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycerine', NULL, 0.25, '%', 78028);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycerine', NULL, 0.50, '% / w/w', 84583);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycerine', NULL, 1.67, 'g / 100 ml', 43172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycerine', NULL, 2.2, 'g / 100 ml', 18484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycerine', NULL, 2.2, 'g / 100 ml', 18647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycerine', NULL, 800, 'mg / 5 ml', 60965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dibucaine hydrochloride', NULL, 5, 'mg', 37335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dibucaine hydrochloride', NULL, 5, 'mg', 37455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dibucaine hydrochloride', NULL, 5, 'mg', 66276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dibucaine hydrochloride', NULL, 5, 'mg', 72190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dibucaine hydrochloride', NULL, 5, 'mg / g', 37334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dibucaine hydrochloride', NULL, 5, 'mg / g', 37454);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dibucaine hydrochloride', NULL, 5, 'mg / g', 66275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dibucaine hydrochloride', NULL, 5, 'mg / g', 71565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorobutanol', NULL, 38.3, 'g / 100 ml', 1291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorobutanol', NULL, 0.55, 'g / 11 ml', 1103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorobutanol', NULL, 1.41875, 'kg / 576 l', 1958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tannic acid', NULL, 6, '% / w/w', 71907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin d3 (cholecalciferol)', NULL, 250, 'unit', 70202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin d3 (cholecalciferol)', NULL, 250, 'unit', 76186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin d3 (cholecalciferol)', NULL, 2800, 'unit', 76210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin d3 (cholecalciferol)', NULL, 5600, 'unit', 80047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium gluconate', NULL, 94, 'mg / ml', 18936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium levulinate', NULL, 15, 'mg / ml', 4761);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium acetate', NULL, 440, 'mg / 25 ml', 23184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('telmisartan', NULL, 80, 'mg', 68312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('telmisartan', NULL, 80, 'mg', 80418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('telmisartan', NULL, 40, 'mg', 85622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('telmisartan', NULL, 40, 'mg', 85623);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('telmisartan', NULL, 80, 'mg', 85624);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('telmisartan', NULL, 80, 'mg', 85625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('icodextrin', NULL, 75, 'g / l', 64397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ancestim', NULL, 1875, 'µg / vial', 63758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('abacavir (abacavir sulfate)', NULL, 300, 'mg', 68746);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('abacavir (abacavir sulfate)', NULL, 600, 'mg', 75473);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eprosartan (eprosartan mesylate)', NULL, 600, 'mg', 73859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trastuzumab', NULL, 440, 'mg / vial', 64277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('efavirenz', NULL, 600, 'mg', 78602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium', NULL, 35, 'mg', 76526);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esculin', NULL, 10, 'mg', 37335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esculin', NULL, 10, 'mg', 37455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esculin', NULL, 10, 'mg', 66276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esculin', NULL, 10, 'mg', 72190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esculin', NULL, 10, 'mg / g', 37334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esculin', NULL, 10, 'mg / g', 37454);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esculin', NULL, 10, 'mg / g', 66275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esculin', NULL, 10, 'mg / g', 71565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-ephedrine hydrochloride', NULL, 7.5, 'mg / 30 ml', 13479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 5, 'µg / ml', 16163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 5, 'µg / ml', 16162);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', NULL, 5, 'µg / ml', 16508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', NULL, 10, 'µg / ml', 12648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', NULL, 10, 'µg / ml', 12649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 5, 'µg / ml', 9802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 5, 'µg / ml', 4202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', NULL, 18, 'µg / 1.8 ml', 2541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 36, 'µg / 1.8 ml', 2506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', NULL, 5, 'µg / ml', 1830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', NULL, 5, 'µg / ml', 590);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', NULL, 5, 'µg / ml', 591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', NULL, 5, 'µg / ml', 2828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', NULL, 5, 'µg / ml', 83307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', NULL, 0.01, 'mg / ml', 17901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', NULL, 0.01, 'mg / ml', 16511);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 0.01, 'mg / ml', 16850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 0.005, 'mg / ml', 16851);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', NULL, 0.01, 'mg / ml', 3805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 0.02, 'mg / ml', 635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 0.01, 'mg / ml', 636);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', NULL, 0.01, 'mg / ml', 589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 0.01, 'mg / ml', 592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 0.02, 'mg / ml', 593);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 0.01, 'mg / ml', 68622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 0.01, 'mg / ml', 72840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 0.005, 'mg / ml', 72841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 0.01, 'mg / ml', 74608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', NULL, 0.01, 'mg / ml', 78332);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', NULL, 0.01, 'mg / ml', 81732);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 0.02, 'mg / ml', 83052);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-hydroxyephedrine hydrochloride', NULL, 20, 'mg / ml', 37358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etafedrin hydrochloride', NULL, 3.33, 'mg / ml', 5475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etafedrin hydrochloride', NULL, 3.33, 'mg / ml', 4615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etafedrin hydrochloride', NULL, 3.33, 'mg / ml', 50030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 7.5, 'mg', 186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 15, 'mg', 78568);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 3, '%', 41931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 14, '%', 26564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 14, '%', 16688);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 20, '%', 15550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 18, '%', 13347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 18, '%', 50238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 10, '%', 61410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 18, '%', 80364);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 10, '% / w/w', 71907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 20, '% / w/w', 73832);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 2, '%', 13349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 23, '%', 1062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 18, '%', 63187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 18, '%', 64576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 14, 'mg / ml', 81814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 180, 'mg / g', 13766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', NULL, 180, 'mg / g', 3276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lanolin', NULL, 9.88, '%', 76990);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenol', NULL, 0.48, '%', 42607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenol', NULL, 0.45, '%', 42334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('euphorbia', NULL, 3.73, 'mg / 1 ml', 5504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 0.5, '%', 17733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 0.3, '%', 16653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 0.5, '%', 6773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 0.3, '%', 3743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 0.315, '%', 8155);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 0.3, '%', 66582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 0.20, '% / w/v', 41952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 20, 'mg / pck', 37051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 20, 'mg / pck', 26396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 20, 'mg / pck', 26397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 20, 'mg / pck', 21167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 20, 'mg / pck', 21168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 20, 'mg / pck', 11901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 20, 'mg / pck', 70790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 20, 'mg / pck', 76387);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 20, 'mg / pck', 76511);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 7.5, 'mg / 5 ml', 19690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 7.5, 'mg / 5 ml', 13494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 5, 'mg / 5 ml', 5431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 7.5, 'mg / 5 ml', 4252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 20, 'mg / 22 mg', 62576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 20, 'mg / 22 g', 31530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 20, 'mg / 23 g', 32780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 20, 'mg / 23 g', 19088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 20, 'mg / 23 g', 62330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 20, 'mg / 22 g', 65060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pheniramine maleate', NULL, 20, 'mg / 22 g', 73067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', NULL, 4, '%', 5634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', NULL, 4, '%', 5635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', NULL, 5, '%', 72824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', NULL, 2.5, '% / w/w', 85075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', NULL, 50, 'mg / g', 43428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', NULL, 50, 'mg / g', 67033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium glycerophosphate', NULL, 1.91, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium glycerophosphate', NULL, 3.67, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium glycerophosphate', NULL, 3.67, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium glycerophosphate', NULL, 10, 'mg / ml', 4761);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brinzolamide', NULL, 1.0, '%', 81730);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('candesartan cilexetil', NULL, 16, 'mg', 67964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('candesartan cilexetil', NULL, 32, 'mg', 81858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('candesartan cilexetil', NULL, 32, 'mg', 81859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 150, 'mg', 65483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 300, 'mg', 65484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 300, 'mg', 76589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 150, 'mg', 81403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 300, 'mg', 81404);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 300, 'mg', 81405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 150, 'mg', 81624);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 300, 'mg', 81625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 300, 'mg', 81626);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 150, 'mg', 82301);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 300, 'mg', 82302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 300, 'mg', 82303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 150, 'mg', 80153);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 300, 'mg', 80154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 300, 'mg', 80155);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 150, 'mg', 84252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 300, 'mg', 84253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 300, 'mg', 84254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 150, 'mg', 84821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 300, 'mg', 84822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 300, 'mg', 84823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 150, 'mg', 85001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 300, 'mg', 85002);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', NULL, 300, 'mg', 85003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('proguanil hydrochloride', NULL, 100, 'mg', 61542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('proguanil hydrochloride', NULL, 25.0, 'mg', 75044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 1.02, 'g / 100 ml', 43947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 1.107, 'g / 100 ml', 19306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 1, 'g / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 314, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 314, 'mg / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 314, 'mg / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 258, 'mg / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 314, 'mg / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 314, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 258, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 369, 'mg / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 258, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 314, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 258, 'mg / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 576, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 738, 'mg / 100 ml', 18644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 738, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 627, 'mg / 100 ml', 18607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 517, 'mg / 100 ml', 18608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 820, 'mg / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 1.26, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 2.21, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 2.84, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutamic acid', NULL, 2.84, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propyl alcohol', NULL, 10.0, '%', 72560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', NULL, 75, '%', 15893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', NULL, 40, '%', 15829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', NULL, 70, '%', 64391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', NULL, 61, '%', 71113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', NULL, 54.1, '%', 72560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', NULL, 70, '% / w/w', 77576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 80, 'mg', 84182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', NULL, 70, '% / v/v', 77225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', NULL, 0.2, 'ml / ml', 12803);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', NULL, 0.05, 'ml / ml', 5475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', NULL, 0.05, 'ml / ml', 50030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gelatin', NULL, 13.3, '%', 42486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('senna', NULL, 187, 'mg', 2133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('squill', NULL, 0.566, 'mg / 1 ml', 5504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium gluconate', NULL, 1.09, 'g / 25 ml', 23184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium gluconate', NULL, 500, 'mg / 100 ml', 21757);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium gluconate', NULL, 500, 'mg / 100 ml', 21998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium gluconate', NULL, 500, 'mg / 100 ml', 12741);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium gluconate', NULL, 5.02, 'mg / ml', 1737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium gluconate', NULL, 5.02, 'mg / ml', 1738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium gluconate', NULL, 502, 'mg / 100 ml', 1623);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium gluconate', NULL, 502, 'mg / 100 ml', 1622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium gluconate', NULL, 502, 'mg / 100 ml', 82495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracaine hydrochloride', NULL, 2, '%', 26564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracaine hydrochloride', NULL, 2, '%', 16688);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracaine hydrochloride', NULL, 2, '%', 13347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracaine hydrochloride', NULL, 2, '%', 50238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracaine hydrochloride', NULL, 2, '%', 80364);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracaine hydrochloride', NULL, 2, '%', 63187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracaine hydrochloride', NULL, 2, '%', 64576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracaine hydrochloride', NULL, 20, 'mg / g', 3276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('podophyllin', NULL, 2, '%', 9361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('podophyllin', NULL, 5, '%', 5314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thrombin (human)', NULL, 4, 'unit / 1 ml', 53282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thrombin (human)', NULL, 500, 'unit / 1 ml', 53282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thrombin (human)', NULL, 20, 'unit / 5 ml', 53284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thrombin (human)', NULL, 2500, 'unit / 5 ml', 53284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thrombin (human)', NULL, 500, 'unit / ml', 81151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thrombin (human)', NULL, 1200, 'unit / ml', 83385);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('total protein', NULL, 130, 'mg / 1 ml', 53282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('total protein', NULL, 650, 'mg / 5 ml', 53284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('plasmafibronectin (cig)', NULL, 9, 'mg / 1 ml', 53282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('plasmafibronectin (cig)', NULL, 45, 'mg / 5 ml', 53284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aprotinin (bovine)', NULL, 3000, 'kiu / 1 ml', 53282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aprotinin (bovine)', NULL, 15000, 'kiu / 5 ml', 53284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('urea', NULL, 5, '%', 5569);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('urea', NULL, 10, '%', 5280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('urea', NULL, 10, '%', 4583);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('urea', NULL, 25.0, '%', 76990);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('urea', NULL, 10, '%', 49970);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('urea', NULL, 10, '%', 8338);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 160, 'mg', 84183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin', NULL, 2, '%', 15893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin', NULL, 4, '%', 13524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin', NULL, 4, '%', 14397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin', NULL, 4, '%', 11432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin (erythromycin ethylsuccinate)', NULL, 200, 'mg / 5 ml', 5294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin', NULL, 30, 'mg / g', 43428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('framycetin sulfate', NULL, 10, 'mg', 37335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('framycetin sulfate', NULL, 10, 'mg', 37455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('framycetin sulfate', NULL, 10, 'mg', 66276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('framycetin sulfate', NULL, 10, 'mg', 72190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('framycetin sulfate', NULL, 12.5, 'mg / ml', 37384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('framycetin sulfate', NULL, 5, 'mg / ml', 37363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('framycetin sulfate', NULL, 5, 'mg / ml', 72229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('framycetin sulfate', NULL, 10, 'mg / g', 37334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('framycetin sulfate', NULL, 10, 'mg / g', 37454);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('framycetin sulfate', NULL, 15, 'mg / g', 37385);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('framycetin sulfate', NULL, 10, 'mg / g', 66275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('framycetin sulfate', NULL, 10, 'mg / g', 71565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', NULL, 0.1, '%', 3718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamycin sulfate)', NULL, 0.1, '%', 3719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', NULL, 0.1, '%', 816);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', NULL, 3, 'mg / ml', 7418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', NULL, 3, 'mg / ml', 68998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', NULL, 3, 'mg / g', 5315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', NULL, 1, 'mg / g', 1285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin sulfate', NULL, 3.5, 'mg / ml', 13146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin sulfate', NULL, 3.5, 'mg / ml', 12843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin sulfate', NULL, 2.5, 'mg / ml', 1394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin sulfate', NULL, 3.5, 'mg / g', 16648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carbonate (anhydrous)', NULL, 4.3, 'mg / ml', 2122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carbonate (anhydrous)', NULL, 2.2, 'mg / ml', 744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('safflower oil', NULL, 10, '%', 8197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('safflower oil', NULL, 5, '%', 8198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('safflower oil', NULL, 5.0, 'g / 100 ml', 47094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antazoline phosphate', NULL, 0.5, '%', 3028);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antazoline phosphate', NULL, 0.51, '%', 80140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoniazid', NULL, 50, 'mg', 19033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoniazid', NULL, 300, 'mg', 2396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olive oil', NULL, 24, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olive oil', NULL, 32, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olive oil', NULL, 32, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olive oil', NULL, 32, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrethrum', NULL, 0.33, '% / w/w', 47572);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cinnamaldehyde', NULL, 5, 'ml / 100 ml', 1291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cantharidin', NULL, 1, '%', 9361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cantharidin', NULL, 1, '%', 5314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thyroid', 'H03AA05', 30, 'mg', 772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-ornithine dihydrochloride', NULL, 318, 'mg / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brimonidine tartrate', NULL, 0.2, '%', 72692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 80, 'mg', 65570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 160, 'mg', 65571);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 160, 'mg', 71182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 320, 'mg', 79451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 320, 'mg', 79452);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 160, 'mg', 84184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 320, 'mg', 84185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 320, 'mg', 84186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 80, 'mg', 84210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 160, 'mg', 84211);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 160, 'mg', 84212);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 320, 'mg', 84213);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 320, 'mg', 84214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 80, 'mg', 85260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 160, 'mg', 85261);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', NULL, 160, 'mg', 85262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin phosphate)', NULL, 1, '%', 72824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin phosphate)', NULL, 10, 'mg / g', 67033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rifampin', NULL, 120, 'mg', 19033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin zinc', NULL, 500, 'unit / g', 20134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin zinc', NULL, 400, 'unit / g', 16650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin zinc', NULL, 500, 'unit / g', 48982);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin zinc', NULL, 500, 'unit / g', 60545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin zinc', NULL, 500, 'unit / g', 60546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin zinc', NULL, 500, 'unit / g', 60248);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin zinc', NULL, 500, 'unit / g', 64139);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin zinc', NULL, 500, 'unit / g', 70888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin zinc', NULL, 500, 'unit / g', 73188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin zinc', NULL, 500, 'unit / g', 76903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin zinc', NULL, 500, 'unit / g', 77712);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin zinc', NULL, 500, 'unit / g', 78327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin zinc', NULL, 500, 'unit / g', 78975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin (bacitracin zinc)', NULL, 500, 'unit / g', 19303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin (bacitracin zinc)', NULL, 400, 'unit / g', 8528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin (bacitracin zinc)', NULL, 400, 'unit / g', 7030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin (bacitracin zinc)', NULL, 500, 'unit / g', 62613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin', NULL, 500, 'unit / g', 60209);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin (bacitracin zinc)', NULL, 400, 'unit / g', 66223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fusidic acid', NULL, 2, '%', 62005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nystatin', NULL, 100000, 'unit', 12654);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nystatin', NULL, 100000, 'unit / g', 15598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nystatin', NULL, 100000, 'unit / 4.5 g', 12996);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nystatin', NULL, 100000, 'unit / g', 12862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nystatin', NULL, 100000, 'unit / g', 9448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nystatin', NULL, 100000, 'unit / g', 9449);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / ml', 16624);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / ml', 13328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / ml', 13146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / ml', 11287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / ml', 12843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / ml', 10912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 6000, 'unit / ml', 259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / ml', 63906);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / g', 20134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / g', 16648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / g', 16650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 6000, 'unit / g', 2423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / g', 48982);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / g', 60248);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / g', 77712);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / g', 78327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / g', 78975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / g', 79738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / g', 80057);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / g', 78974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / g', 80317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b sulfate', NULL, 10000, 'unit / g', 80335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / ml', 13628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / ml', 10062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / ml', 10025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 200000, 'unit / ml', 6727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / ml', 49184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / ml', 62611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / ml', 62612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / g', 19303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 5000, 'unit / g', 8528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 5000, 'unit / g', 7030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / g', 50105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / g', 50407);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / g', 62613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / g', 62658);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / g', 60545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / g', 60546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / g', 60209);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / g', 64139);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / g', 66223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / g', 70888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / g', 73188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / g', 72525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000, 'unit / g', 76903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.05, 'mg / ml', 37384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.05, 'mg / ml', 37363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.025, 'mg / ml', 13328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.025, 'mg / ml', 10062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.025, 'mg / ml', 10025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.025, 'mg / ml', 62612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.05, 'mg / ml', 72229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 50, 'µg / g', 37385);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 15598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 12862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 9448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 9449);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 50105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 50407);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 62658);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 60545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 64139);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 70888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 73188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 72525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 78327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 78975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 79738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 80057);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 78974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 80317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', NULL, 0.25, 'mg / g', 80335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium (magnesium oxide)', NULL, 40, 'mg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium (magnesium hydroxide)', NULL, 56, 'mg', 71557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium (magnesium oxide)', NULL, 50, 'mg', 70202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', NULL, 262, 'mg', 64038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium (magnesium oxide)', NULL, 50, 'mg', 76186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 47167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 41753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 42082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 41830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 41831);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 37037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 37150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 34150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 33120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 27225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 25897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 25898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 22846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 22847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 19429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 17887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 17880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 30 ml', 77674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 19103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 18539);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 17113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 13120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 13607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 14492);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 13804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 12461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg', 11646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 7.5, 'mg', 11041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 11921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 8250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 8251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 8252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 8249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 7.5, 'mg', 8247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 7081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg', 1224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg', 955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg', 62610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg', 62614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg', 62615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 60817);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg', 61704);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg', 63999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg', 64001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 64134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 64135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 120, 'mg', 63341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 65178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 65249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 65250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 65897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 66847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 66950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 65665);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 67104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 69017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 69018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 68103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 68104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg', 72216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg', 72217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 70284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 70285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 70286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 120, 'mg', 70312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 70399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 71047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 120, 'mg', 71201);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 72935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 74005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 74007);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 74016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 74017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 75302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 75304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 75315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 76544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 76681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 73002);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg', 73003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 74181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 75371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 73064);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 74415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 74414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 74549);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 74550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 73565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 73592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 73702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 73703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 73704);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 73705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 78062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 77185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 78348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 81657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 82152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 79084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 79088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 79269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 78913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 80988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 79278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 82084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg / 30 ml', 77675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 83056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg', 83258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 83303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 83304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 83343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 83344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg', 83757);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30.0, 'mg', 84427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg / pck', 35886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg / pck', 37105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg / pck', 65873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg / pck', 65633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg / pck', 75146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg / pck', 83004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 36232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg / 30 ml', 37183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 34650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg / 5 ml', 31502);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg / 5 ml', 30945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 27462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 27463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg / 5 ml', 26863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 19625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 20329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 19129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 19060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 16698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 16177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 15618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg / 5 ml', 14551);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 13440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg / 30 ml', 13960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg / 5 ml', 13361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 12410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 15 ml', 12719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg / 20 ml', 12722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 15 ml', 12718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 12192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg / 5 ml', 12504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 8324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 4124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 1497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 1498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg / 5 ml', 47448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 52513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 60207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg / 5 ml', 63140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg / 5 ml', 66361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 15 ml', 66840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg / 5 ml', 66928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 66929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 66947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg / 30 ml', 66983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 65129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 65130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 65133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg / 5 ml', 65132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 67954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg / 5 ml', 67672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg / 30 ml', 72095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 69813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 15 ml', 69814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 75087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg / 5 ml', 72786);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg / 5 ml', 75412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg / 5 ml', 26864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 74333);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg / 30 ml', 74797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg / 5 ml', 74799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 74852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 5 ml', 74853);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 15 ml', 73724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg / 30 ml', 77475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 15, 'mg / 5 ml', 79105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 30, 'mg / 15 ml', 80682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine hydrochloride', NULL, 60, 'mg / 24 g', 71050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thymol iodide', NULL, 25, 'g / 100 g', 1251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperonyl butoxide', NULL, 3, '%', 18634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperonyl butoxide', NULL, 4, '%', 78333);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperonyl butoxide', NULL, 4, '% / w/w', 47572);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrethrins', NULL, 0.33, '%', 18634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrethrins', NULL, 0.33, '%', 78333);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', NULL, 262, 'mg', 60637);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', NULL, 262, 'mg', 80534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coagulation factor vii (human)', NULL, 500, 'unit', 84428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coagulation factor vii (human)', NULL, 480, 'unit / vial', 78001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coagulation factor x (human)', NULL, 1020, 'unit', 84428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coagulation factor x (human)', NULL, 600, 'unit / vial', 78001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trandolapril', NULL, 4, 'mg', 61488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trandolapril', NULL, 2, 'mg', 64537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fexofenadine hydrochloride', NULL, 60, 'mg', 63341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('latanoprost', NULL, 50, 'µg / ml', 70807);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim', NULL, 80, 'mg', 11857);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim', NULL, 160, 'mg', 11858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim', NULL, 80, 'mg', 11953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim', NULL, 160, 'mg', 11954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim', NULL, 160, 'mg', 6037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim', NULL, 20, 'mg', 3677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim', NULL, 80, 'mg', 3678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim', NULL, 160, 'mg', 3679);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim', NULL, 160, 'mg', 4610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim', NULL, 80, 'mg', 4611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim (trimethoprim sulfate)', NULL, 1, 'mg / ml', 13628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim', NULL, 8, 'mg / ml', 11859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim', NULL, 8, 'mg / ml', 10535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim', NULL, 8, 'mg / ml', 11955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim', NULL, 8, 'mg / ml', 7313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim', NULL, 16, 'mg / ml', 4703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim (trimethoprim sulfate)', NULL, 1, 'mg / ml', 63906);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atovaquone', NULL, 250, 'mg', 61542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atovaquone', NULL, 62.5, 'mg', 75044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', NULL, 500, 'mg / tab', 61948);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 23354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 23355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 22274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 12946);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 12942);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 12943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 12944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 14508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 14509);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 49590);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 50062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 50227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 50484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 62483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 62597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 61372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 61576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 60162);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 60916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 60917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 60918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 60919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 63223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 63224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 65859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 66799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 66818);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 66910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 66913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 66916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 66917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 67870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 500, 'mg', 71388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 73359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 73537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 73656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 73677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 73678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 73680);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 73709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 73710);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 77584);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 77593);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 500, 'mg', 82770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 500, 'mg', 82772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 500, 'mg', 82306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', NULL, 400, 'mg', 84247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', NULL, 20, 'mg', 12763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', NULL, 20, 'mg', 4629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', NULL, 20, 'mg', 64442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', NULL, 20, 'mg', 66620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', NULL, 1, '%', 15948);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', NULL, 1.0, '%', 12764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', NULL, 1, '%', 10052);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', NULL, 1, '%', 4390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', NULL, 1, '%', 3492);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', NULL, 1, '%', 55837);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', NULL, 1, '%', 73264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', NULL, 1, '%', 73689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', NULL, 1.0, '% / w/w', 37185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', NULL, 10, 'mg / g', 71956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', NULL, 10, 'mg / g', 72775);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clidinium bromide', NULL, 2.5, 'mg', 6039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clidinium bromide', NULL, 2.5, 'mg', 6283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clidinium bromide', NULL, 2.5, 'mg', 728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc chloride', NULL, 1.67, 'mg / ml', 5708);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 77048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyl heptyl colamino formylmethyl pyridinium chl', NULL, 0.1, '%', 1062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin (heparin sodium)', NULL, 2, 'unit / ml', 10521);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', NULL, 10, 'mg', 75873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', NULL, 20, 'mg', 75874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', NULL, 40, 'mg', 75875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', NULL, 80, 'mg', 75876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', NULL, 10, 'mg', 75877);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', NULL, 20, 'mg', 75878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', NULL, 40, 'mg', 75879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', NULL, 80, 'mg', 75880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', NULL, 20, 'mg', 84776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', NULL, 10, 'mg', 84775);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', NULL, 40, 'mg', 84777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', NULL, 80, 'mg', 84778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', NULL, 10, 'mg', 84779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', NULL, 20, 'mg', 84780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', NULL, 40, 'mg', 84781);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', NULL, 80, 'mg', 84782);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 77058);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 5, 'mg', 75873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 5, 'mg', 75874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 5, 'mg', 75875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 5, 'mg', 75876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 10, 'mg', 75877);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 10, 'mg', 75878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 10, 'mg', 75879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 10, 'mg', 75880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 5, 'mg', 84775);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 5, 'mg', 84776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 5, 'mg', 84777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 5, 'mg', 84778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 10, 'mg', 84779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 10, 'mg', 84780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 10, 'mg', 84781);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 10, 'mg', 84782);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 5, 'mg', 85622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 10, 'mg', 85623);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 5, 'mg', 85624);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', NULL, 10, 'mg', 85625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mumps virus vaccine live attenuated jeryl lynn strain', NULL, 10000, 'unit / 0.5 ml', 62666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mumps virus vaccine live attenuated jeryl lynn strain', NULL, 5000, 'unit / 0.5 ml', 3569);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mumps virus vaccine live attenuated jeryl lynn strain', NULL, 25118.9, 'unit / 0.5 ml', 78322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salmeterol (salmeterol xinafoate)', NULL, 50, 'µg / dose', 64426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salmeterol (salmeterol xinafoate)', NULL, 50, 'µg / dose', 64427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salmeterol (salmeterol xinafoate)', NULL, 50, 'µg / dose', 64428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salmeterol (salmeterol xinafoate)', NULL, 25, 'µg / dose', 69136);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salmeterol (salmeterol xinafoate)', NULL, 25, 'µg / dose', 69137);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gonadorelin (gonadorelin acetate)', NULL, 100, 'µg / vial', 19030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gonadorelin (gonadorelin acetate)', NULL, 500, 'µg / vial', 16878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 77611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benserazide (benserazide hydrochloride)', NULL, 12.5, 'mg', 4459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benserazide (benserazide hydrochloride)', NULL, 25, 'mg', 2723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benserazide (benserazide hydrochloride)', NULL, 50, 'mg', 2724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilastatin (cilastatin sodium)', NULL, 500, 'mg', 84256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilastatin (cilastatin sodium)', NULL, 250, 'mg / vial', 8348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilastatin (cilastatin sodium)', NULL, 500, 'mg / vial', 8054);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilastatin (cilastatin sodium)', NULL, 250, 'mg / vial', 83695);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilastatin (cilastatin sodium)', NULL, 500, 'mg / vial', 83696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilastatin (cilastatin sodium)', NULL, 250, 'mg / vial', 84339);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilastatin (cilastatin sodium)', NULL, 500, 'mg / vial', 84340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 77533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenobarbital', NULL, 40, 'mg', 48361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextroamphetamine saccharate', NULL, 1.25, 'mg', 73177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextroamphetamine saccharate', NULL, 2.5, 'mg', 73178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextroamphetamine saccharate', NULL, 3.75, 'mg', 73179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextroamphetamine saccharate', NULL, 5.00, 'mg', 73180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextroamphetamine saccharate', NULL, 6.25, 'mg', 73181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextroamphetamine saccharate', NULL, 7.5, 'mg', 73182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextroamphetamine sulfate', NULL, 1.25, 'mg', 73177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextroamphetamine sulfate', NULL, 2.5, 'mg', 73178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextroamphetamine sulfate', NULL, 3.75, 'mg', 73179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextroamphetamine sulfate', NULL, 5.00, 'mg', 73180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextroamphetamine sulfate', NULL, 6.25, 'mg', 73181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextroamphetamine sulfate', NULL, 7.5, 'mg', 73182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amphetamine aspartate monohydrate', NULL, 1.25, 'mg', 73177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amphetamine aspartate monohydrate', NULL, 2.5, 'mg', 73178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amphetamine aspartate monohydrate', NULL, 3.75, 'mg', 73179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amphetamine aspartate monohydrate', NULL, 5.00, 'mg', 73180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amphetamine aspartate monohydrate', NULL, 6.25, 'mg', 73181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amphetamine aspartate monohydrate', NULL, 7.5, 'mg', 73182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butalbital', NULL, 50, 'mg', 23671);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butalbital', NULL, 50, 'mg', 23672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butalbital', NULL, 50, 'mg', 23669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butalbital', NULL, 50, 'mg', 6480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butalbital', NULL, 50, 'mg', 6479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butalbital', NULL, 50, 'mg', 6419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butalbital', NULL, 50, 'mg', 5779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butalbital', NULL, 50, 'mg', 1233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butalbital', NULL, 50, 'mg', 873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butalbital', NULL, 50, 'mg', 872);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butalbital', NULL, 50, 'mg', 47953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butalbital', NULL, 50, 'mg', 47954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butalbital', NULL, 50, 'mg', 47955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butalbital', NULL, 50, 'mg', 47956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butalbital', NULL, 50, 'mg', 66118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfamethoxazole', NULL, 400, 'mg', 11857);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfamethoxazole', NULL, 800, 'mg', 11858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfamethoxazole', NULL, 400, 'mg', 11953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfamethoxazole', NULL, 800, 'mg', 11954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '%', 77540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfamethoxazole', NULL, 800, 'mg', 6037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfamethoxazole', NULL, 100, 'mg', 3677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfamethoxazole', NULL, 400, 'mg', 3678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfamethoxazole', NULL, 800, 'mg', 3679);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfamethoxazole', NULL, 800, 'mg', 4610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfamethoxazole', NULL, 400, 'mg', 4611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfamethoxazole', NULL, 40, 'mg / ml', 11859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfamethoxazole', NULL, 40, 'mg / ml', 10535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfamethoxazole', NULL, 40, 'mg / ml', 11955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfamethoxazole', NULL, 40, 'mg / ml', 7313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfamethoxazole', NULL, 80, 'mg / ml', 4703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfisoxazole (sulfisoxazole acetyl)', NULL, 600, 'mg / 5 ml', 5294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 80510);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benoxinate hydrochloride', NULL, 0.4, '%', 37090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benoxinate hydrochloride', NULL, 0.4, '%', 61132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', NULL, 5, 'mg', 17235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', NULL, 5, 'mg', 15514);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', NULL, 2.5, 'mg', 13316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', NULL, 5, 'mg', 5778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', NULL, 5, 'mg', 5777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', NULL, 5, 'mg', 81249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', NULL, 5, 'mg', 79356);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', NULL, 10, 'mg', 82520);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', NULL, 20, 'mg', 82521);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', NULL, 40, 'mg', 82522);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', NULL, 5, 'mg', 81005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', NULL, 5, 'mg', 84644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone (oxycodone hydrochloride)', NULL, 5, 'mg', 66193);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone (oxycodone hydrochloride)', NULL, 5, 'mg', 69866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethoxy polypropoxy polyethoxy ethanol - iodine complex', NULL, 11.06, '%', 37925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bronopol', NULL, 0.1, '%', 5480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyethylcellulose', NULL, 0.5, '%', 16652);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aluminum hydroxide-magnesium carbonate-co dried gel', NULL, 300, 'mg', 188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aluminum hydroxide-magnesium carbonate-co dried gel', NULL, 400, 'mg / 5 ml', 9572);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dichlorobenzene', NULL, 0.22, 'g / 11 ml', 1103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mepivacaine hydrochloride', NULL, 20, 'mg / ml', 3805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mepivacaine hydrochloride', NULL, 20, 'mg / ml', 2744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mepivacaine hydrochloride', NULL, 20, 'mg / ml', 76704);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mepivacaine hydrochloride', NULL, 20, 'mg / ml', 79940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thymol', NULL, 50, 'mg / 1 g', 2977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meprobamate', NULL, 200, 'mg', 62075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 44252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 17903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 16709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 16636);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 16903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 13431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 50, 'mg', 10494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 11176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 50, 'mg', 12430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 10913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 50, 'mg', 10806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 50, 'mg', 11966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 15, 'mg', 5862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 5858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 15, 'mg', 5820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 5821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 6390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 50, 'mg', 6892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 5672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 6163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 50, 'mg', 5316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 5156);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 50, 'mg', 5157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 4523);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 1404);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 48580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.00, '%', 77614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 60690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 60691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 60692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 64599);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 64437);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 65483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 65484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 65570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 65571);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 68312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 67964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 71182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 76589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 50, 'mg', 74257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 74732);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 74733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 74734);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 73859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 76876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 76877);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 76878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25.0, 'mg', 76879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25.0, 'mg', 76880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 78307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 78308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 78309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 78318);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 77051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 80418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 81403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 81404);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 81405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 78744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 78745);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 78746);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 78710);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 78711);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 78712);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 79451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 79452);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 82763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 82764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 82765);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25.0, 'mg', 82766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25.0, 'mg', 82767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 81625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 81624);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 81626);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 79924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 81838);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 81839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 81840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 81841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 81858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 81859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 78769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 78770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 78771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 80508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 80509);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 82301);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 82302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 82303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 78554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 78555);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 80153);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 80154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 80155);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 83816);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25.0, 'mg', 83817);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 84182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 84183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 84184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 84185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 84186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 84210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 84211);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 84212);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 84213);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 84214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 84252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 84253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 84254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 84793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 84794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 84795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 84821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 84822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 84823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 85001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 85002);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 85003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 85260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 12.5, 'mg', 85261);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', NULL, 25, 'mg', 85262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 85, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 130, 'mg / 100 ml', 44068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 320, 'mg / 100 ml', 43947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 90, 'mg / 100 ml', 20278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 76.5, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 300, 'mg / 100 ml', 19306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 90, 'mg / 100 ml', 19610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 76.5, 'mg / 100 ml', 20303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 90, 'mg / 100 ml', 20302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 76.5, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 90, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 90, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 76.5, 'mg / 100 ml', 20289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 45, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 90, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 90, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 90, 'mg / 100 ml', 20279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 85, 'mg / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 85, 'mg / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 70, 'mg / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 85, 'mg / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 85, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 90, 'mg / 100 ml', 19143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 70, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 100, 'mg / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 70, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 85, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 125, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 200, 'mg / 100 ml', 18644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 70, 'mg / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 200, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 140, 'mg / 100 ml', 18608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 170, 'mg / 100 ml', 18607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 180, 'mg / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 90, 'mg / 100 ml', 18550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 90, 'mg / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 200, 'mg / 100 ml', 15493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 90, 'mg / 100 ml', 14077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 90, 'mg / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 90, 'mg / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 76, 'mg / 100 ml', 14073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 76, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 76, 'mg / 100 ml', 14071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 45, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 90, 'mg / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 90, 'mg / 100 ml', 14067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 76, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 180, 'mg / 100 ml', 11329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 165, 'mg / 100 ml', 7163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 150, 'mg / 100 ml', 5890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 150, 'mg / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 180, 'mg / 100 ml', 4661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 160, 'mg / 100 ml', 3468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 120, 'mg / 100 ml', 4560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 180, 'mg / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 80, 'mg / 100 ml', 2776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 200, 'mg / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 0.42, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 0.74, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 0.95, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', NULL, 0.95, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('arginine', NULL, 1.96, 'g / 100 ml', 43947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('arginine', NULL, 1.15, 'g / 100 ml', 11329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('arginine', NULL, 1.04, 'g / 100 ml', 4661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('arginine', NULL, 1.04, 'g / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('arginine', NULL, 810, 'mg / 100 ml', 44068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('arginine', NULL, 600, 'mg / 100 ml', 7163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('arginine', NULL, 850, 'mg / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('threonine', NULL, 980, 'mg / 100 ml', 43947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('threonine', NULL, 420, 'mg / 100 ml', 11329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('threonine', NULL, 460, 'mg / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('threonine', NULL, 420, 'mg / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 42382);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 16752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 66958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 68230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 1.25, 'mg', 68231);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg', 76427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg', 76429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 75158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 2.5, 'mg', 75728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 75828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 75895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 75896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 75929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 75930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 75939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 76130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 76137);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 76138);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 76167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 76168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 76170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 76171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 76172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 76178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 76185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 76189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 76188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 76190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 76192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 76236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 76238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 2.5, 'mg', 76288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 77849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 77891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 77892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 77847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 79195);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 80829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg', 79146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 0.125, '%', 17733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, '%', 16632);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5.0, '%', 6057);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 0.125, '%', 6773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 0.50, '% / w/v', 41952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 0.12, '%', 16652);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 0.12, '%', 2963);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / pck', 37051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / pck', 26396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / pck', 26397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / pck', 21167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / pck', 21168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / pck', 11901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / pck', 10188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / pck', 70790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / pck', 76387);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / pck', 76511);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / pck', 77936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / pck', 80466);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 2.5, 'mg / ml', 37384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 20, 'mg / 5 ml', 16635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 5 ml', 16640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 2, 'mg / 5 ml', 5431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 20, 'mg / 5 ml', 7082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 3.75, 'mg / 5 ml', 4252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg / 5 ml', 67912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg / 5 ml', 67924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg / 5 ml', 68031);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg / 5 ml', 68034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg / 5 ml', 68035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 5 ml', 69079);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 5 ml', 69080);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 2.5, 'mg / 5 ml', 76388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg / 5 ml', 75162);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 5 ml', 75163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg / 5 ml', 75189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 5 ml', 75190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5.0, 'mg / 5 ml', 75283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5.0, 'mg / 5 ml', 75285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10.0, 'mg / 5 ml', 75286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 2.5, 'mg / 5 ml', 76376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 30 ml', 76233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 1.25, 'mg / ml', 75558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 2.5, 'mg / ml', 75559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10.0, 'mg / 15 ml', 75827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 30 ml', 76164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 30 ml', 76166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 30 ml', 76254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 2.5, 'mg / 5 ml', 76366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 30 ml', 77628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 2.5, 'mg / 5 ml', 81394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 30 ml', 78620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 2.5, 'mg / 5 ml', 81392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 30 ml', 79002);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 2.5, 'mg / 5 ml', 81416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 2.5, 'mg / 5 ml', 80939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg / 5 ml', 80101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 5, 'mg / 5 ml', 80102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 5 ml', 80103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 22 mg', 62576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 22 g', 31530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 23 g', 32780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 23 g', 19088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 23 g', 62330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 22 g', 65060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', NULL, 10, 'mg / 22 g', 73067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 42382);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 41831);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 34150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 25898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 22847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 17887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 16752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 17113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 13804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 1, 'mg', 11646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 0.5, 'mg', 11041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 11921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 8249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 8251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 0.5, 'mg', 8247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 4, 'mg', 1224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 1, 'mg', 63999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 1, 'mg', 64001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 65249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 66958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 68103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 68104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 68230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 0.5, 'mg', 68231);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 70286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 4, 'mg', 69737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 69738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 71094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 75304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 73002);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 75371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 75896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 76138);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 76170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 76171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 76172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 76188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 76190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 76192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 73702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 73704);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 77849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 77892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 79195);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 4, 'mg', 79504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 80829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 79071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 1, 'mg', 83258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg', 83344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2.0, 'mg', 84427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 4, 'mg / pck', 35886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 4, 'mg / pck', 37105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 4, 'mg / pck', 65873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 4, 'mg / pck', 75146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 4, 'mg / pck', 83004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 1, 'mg / 5 ml', 26863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 1, 'mg / 5 ml', 26864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 4, 'mg / 30 ml', 13479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 1, 'mg / 5 ml', 13361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 4, 'mg / 20 ml', 12722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg / 15 ml', 12718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg / 5 ml', 10675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg / 5 ml', 4124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg / 5 ml', 1497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg / 5 ml', 1498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 1, 'mg / 5 ml', 63140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 1, 'mg / 5 ml', 66361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 1, 'mg / 5 ml', 67672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 1, 'mg / 5 ml', 75412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg / 15 ml', 75882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 2, 'mg / 15 ml', 73724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 4, 'mg / 30 ml', 77675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 1, 'mg / 5 ml', 77749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 1, 'mg / 5 ml', 81390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 1, 'mg / 5 ml', 79105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 1, 'mg / 5 ml', 81392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 4, 'mg / 15 ml', 79763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', NULL, 4, 'mg / 24 g', 71050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlordiazepoxide hydrochloride', NULL, 5, 'mg', 6039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlordiazepoxide hydrochloride', NULL, 5, 'mg', 6283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlordiazepoxide hydrochloride', NULL, 5, 'mg', 728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propylene glycol', NULL, 5.9, '%', 72560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylalanine', NULL, 1, 'g / 100 ml', 43947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylalanine', NULL, 480, 'mg / 100 ml', 44068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylalanine', NULL, 880, 'mg / 100 ml', 15493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylalanine', NULL, 560, 'mg / 100 ml', 11329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylalanine', NULL, 726, 'mg / 100 ml', 7163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylalanine', NULL, 380, 'mg / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylalanine', NULL, 620, 'mg / 100 ml', 4661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylalanine', NULL, 620, 'mg / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', NULL, 5, 'mg / tab', 81164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamterene', NULL, 50, 'mg', 11176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamterene', NULL, 50, 'mg', 6390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamterene', NULL, 50, 'mg', 5672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamterene', NULL, 50, 'mg', 4523);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamterene', NULL, 50, 'mg', 64437);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfacetamide sodium', NULL, 10, '%', 37254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfacetamide sodium', NULL, 10, '%', 16625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfacetamide sodium', NULL, 10, '%', 10169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfacetamide sodium', NULL, 10, '%', 1971);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfacetamide sodium', NULL, 100, 'mg / ml', 6365);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfacetamide sodium', NULL, 100, 'mg / g', 16649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ioxaglate sodium', NULL, 123, 'mg / ml', 9362);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ioxaglate sodium', NULL, 196, 'mg / ml', 5554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenyltoloxamine', NULL, 10, 'mg', 12217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenyltoloxamine', NULL, 10, 'mg / 5 ml', 12216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetrahydrozoline hydrochloride', NULL, 0.05, '%', 42685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetrahydrozoline hydrochloride', NULL, 0.05, '%', 73019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetrahydrozoline hydrochloride', NULL, 0.05, '%', 77592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetrahydrozoline hydrochloride', NULL, 0.05, '%', 78699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetrahydrozoline hydrochloride', NULL, 0.05, '% / w/v', 81391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetrahydrozoline hydrochloride', NULL, 0.05, '% / w/v', 82979);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('wild lettuce', NULL, 1.36, 'mg / 1 ml', 5504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ephedrine hydrochloride', NULL, 8, 'mg', 65822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', NULL, 3, 'g / vial', 44168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', NULL, 4, 'g / vial', 44169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', NULL, 2, 'g / vial', 44170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', NULL, 2, 'g / vial', 78500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', NULL, 3, 'g / vial', 78501);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', NULL, 4, 'g / vial', 78502);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', NULL, 2, 'g / vial', 79116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', NULL, 3, 'g / vial', 79117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', NULL, 4, 'g / vial', 79118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', NULL, 12, 'g / vial', 81627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', NULL, 2, 'g / vial', 79408);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', NULL, 3.0, 'g / vial', 79409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', NULL, 4.0, 'g / vial', 79410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tazobactam (tazobactam sodium)', NULL, 0.25, 'g / vial', 78500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tazobactam (tazobactam sodium)', NULL, 0.375, 'g / vial', 78501);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tazobactam (tazobactam sodium)', NULL, 0.5, 'g / vial', 78502);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tazobactam (tazobactam sodium)', NULL, 0.25, 'g / vial', 79116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tazobactam (tazobactam sodium)', NULL, 0.375, 'g / vial', 79117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tazobactam (tazobactam sodium)', NULL, 0.5, 'g / vial', 79118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tazobactam (tazobactam sodium)', NULL, 1.5, 'g / vial', 81627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tazobactam (tazobactam sodium)', NULL, 0.25, 'g / vial', 79408);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tazobactam (tazobactam sodium)', NULL, 0.375, 'g / vial', 79409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tazobactam (tazobactam sodium)', NULL, 0.5, 'g / vial', 79410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tazobactam (tazobactam sodium)', NULL, 375, 'mg / vial', 44168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tazobactam (tazobactam sodium)', NULL, 500, 'mg / vial', 44169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tazobactam (tazobactam sodium)', NULL, 250, 'mg / vial', 44170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (clavulanate potassium)', NULL, 125, 'mg', 15903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (clavulanate potassium)', NULL, 125, 'mg', 62267);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (potassium clavulanate)', NULL, 125, 'mg', 67257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (potassium clavulanate)', NULL, 125, 'mg', 67258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (potassium clavulanate)', NULL, 125, 'mg', 67706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (potassium clavulanate)', NULL, 125, 'mg', 69723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (clavulanate potassium)', NULL, 125, 'mg', 71255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (potassium clavulanate)', NULL, 125, 'mg', 72467);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (potassium clavulanate)', NULL, 125, 'mg', 81188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (potassium clavulanate)', NULL, 125, 'mg', 81189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (potassium clavulanate)', NULL, 1, 'g / vial', 72188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (clavulanate potassium)', NULL, 100, 'mg / vial', 15224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (clavulanate potassium)', NULL, 31.25, 'mg / 5 ml', 15208);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (clavulanate potassium)', NULL, 62.5, 'mg / 5 ml', 15209);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (clavulanate potassium)', NULL, 57, 'mg / 5 ml', 62268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (clavulanate potassium)', NULL, 28.5, 'mg / 5 ml', 62269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (potassium clavulanate)', NULL, 31.25, 'mg / 5 ml', 67930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (potassium clavulanate)', NULL, 62.5, 'mg / 5 ml', 67931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (clavulanate potassium)', NULL, 31.25, 'mg / 5 ml', 68633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (clavulanate potassium)', NULL, 62.5, 'mg / 5 ml', 68634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clavulanic acid (clavulanate potassium)', NULL, 57, 'mg / 5 ml', 77397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinapril (quinapril hydrochloride)', NULL, 10, 'mg', 60690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinapril (quinapril hydrochloride)', NULL, 20, 'mg', 60691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinapril (quinapril hydrochloride)', NULL, 20, 'mg', 60692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', NULL, 0.5, '%', 76384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', NULL, 0.5, '%', 72692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', NULL, 0.5, '%', 81730);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', NULL, 5, 'mg / ml', 63627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', NULL, 5, 'mg / ml', 70807);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', NULL, 5, 'mg / ml', 74388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', NULL, 5, 'mg / ml', 78499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', NULL, 5, 'mg / ml', 82984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b1 (thiamine hydrochloride)', NULL, 20, 'mg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b1 (thiamine mononitrate)', NULL, 3, 'mg', 70202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b1 (thiamine mononitrate)', NULL, 3, 'mg', 76186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b1 (thiamine hydrochloride)', NULL, 1.2, 'mg / vial', 66277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b1 (thiamine hydrochloride)', NULL, 0.6, 'mg / ml', 16462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b1 (thiamine hydrochloride)', NULL, 4.5, 'mg / ml', 5613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b1', NULL, 50, 'mg / ml', 31);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b1 (thiamine hydrochloride)', NULL, 0.6, 'mg / ml', 68684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b2 (riboflavin)', NULL, 5, 'mg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b2 (riboflavin)', NULL, 3.4, 'mg', 70202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b2 (riboflavin)', NULL, 3.4, 'mg', 76186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b2 (riboflavin-5-phosphate)', NULL, 1.4, 'mg / vial', 66277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b2', NULL, 0.111, 'mg / ml', 18602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b2 (riboflavin-5-phosphate)', NULL, 0.72, 'mg / ml', 16462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b2 (riboflavin-5-phosphate)', NULL, 1, 'mg / ml', 5613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b2 (riboflavin 5''-phosphate sodium)', NULL, 10, 'mg / ml', 3497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b2 (riboflavin 5''-phosphate sodium)', NULL, 7.5, 'mg / ml', 31);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b2', NULL, 0.72, 'mg / ml', 68684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('beta-carotene', NULL, 2700, 'unit', 70202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('beta-carotene', NULL, 2700, 'unit', 76186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '% / w/w', 81413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 500, 'mg', 15903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 875, 'mg', 62267);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 250, 'mg', 67257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 500, 'mg', 67258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 500, 'mg', 67706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 875, 'mg', 69723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 875, 'mg', 71255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 875, 'mg', 72467);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '% / w/w', 81415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 500, 'mg', 81188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 875, 'mg', 81189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 125, 'mg / 5 ml', 15208);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 250, 'mg / 5 ml', 15209);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 200, 'mg / 5 ml', 62269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 400, 'mg / 5 ml', 62268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 125, 'mg / 5 ml', 67930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 250, 'mg / 5 ml', 67931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 125, 'mg / 5 ml', 68633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 250, 'mg / 5 ml', 68634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', NULL, 400, 'mg / 5 ml', 77397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin', NULL, 500, 'mg / cap', 61948);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin lispro', NULL, 25, 'unit / ml', 63832);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin lispro', NULL, 50, 'unit / ml', 63835);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perphenazine', NULL, 3, 'mg', 5717);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perphenazine', NULL, 2, 'mg', 5726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perphenazine', NULL, 4, 'mg', 5727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal polysaccharide vaccine grp c', NULL, 10, 'µg / 0.5 ml', 69061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetanus toxoid adsorbed', NULL, 5, 'lf / 0.5 ml', 4109);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetanus toxoid adsorbed', NULL, 5.0, 'lf / 0.5 ml', 79806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetanus toxoid adsorbed', NULL, 40, 'µg / 0.5 ml', 73878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetanus toxoid', NULL, 5, 'lf / 0.5 ml', 43396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetanus toxoid', NULL, 5, 'lf / 0.5 ml', 5907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetanus toxoid', NULL, 5, 'lf / 0.5 ml', 50651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetanus toxoid', NULL, 5, 'lf / 0.5 ml', 50224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetanus toxoid', NULL, 5, 'lf / 0.5 ml', 63789);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetanus toxoid', NULL, 5, 'lf / 0.5 ml', 67042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetanus toxoid', NULL, 10, 'lf / 0.5 ml', 73878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetanus toxoid', NULL, 5, 'lf / 0.5 ml', 83726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetanus toxoid', NULL, 20, 'µg / 0.5 ml', 69061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetanus toxoid', NULL, 20, 'unit / 0.5 ml', 71860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphtheria toxoid adsorbed', NULL, 2, 'lf / 0.5 ml', 4109);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphtheria toxoid adsorbed', NULL, 2.5, 'lf / 0.5 ml', 79806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphtheria toxoid', NULL, 15, 'lf / 0.5 ml', 43396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphtheria toxoid', NULL, 2, 'lf / 0.5 ml', 5907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphtheria toxoid', NULL, 15, 'lf / 0.5 ml', 50651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphtheria toxoid', NULL, 15, 'lf / 0.5 ml', 50224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphtheria toxoid', NULL, 2, 'lf / 0.5 ml', 63789);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphtheria toxoid', NULL, 15, 'lf / 0.5 ml', 67042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphtheria toxoid', NULL, 25, 'lf / 0.5 ml', 73878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphtheria toxoid', NULL, 2, 'lf / 0.5 ml', 83726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphtheria toxoid', NULL, 2, 'unit / 0.5 ml', 71860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrazinamide', NULL, 300, 'mg', 19033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorzoxazone', NULL, 250, 'mg', 19624);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorzoxazone', NULL, 250, 'mg', 11427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorzoxazone', NULL, 250, 'mg', 11339);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pipradrol hydrochloride', NULL, 0.044, 'mg / ml', 18602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('domiphen bromide', NULL, 0.05, '%', 7153);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aluminum chloride', NULL, 25, 'g / 100 ml', 2645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bile salts', NULL, 150, 'mg', 5276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('capsicum oleoresin', NULL, 0.05, '%', 50027);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clove oil', NULL, 63.4, 'ml / 100 ml', 1291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oil of turpentine', NULL, 1.1, 'ml / 11 ml', 1103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 0.15, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diatrizoate meglumine', NULL, 66, '%', 37570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diatrizoate meglumine', NULL, 52.7, '%', 37573);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', NULL, 500, 'mg', 71322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', NULL, 500, 'mg', 71323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', NULL, 500, 'mg', 71324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', NULL, 1000, 'mg', 72791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', NULL, 1000, 'mg', 72792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', NULL, 500, 'mg', 81954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', NULL, 850, 'mg', 81955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', NULL, 1000, 'mg', 81956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 20, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', NULL, 240, 'mg', 61488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', NULL, 240, 'mg', 64537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pectin', NULL, 13.3, '%', 42486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rubella virus vaccine live attenuated wistar ra27/3 strain', NULL, 1000, 'unit / 0.5 ml', 62666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rubella virus vaccine live attenuated wistar ra27/3 strain', NULL, 1000, 'unit / 0.5 ml', 3569);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rubella virus vaccine live attenuated wistar ra27/3 strain', NULL, 1000, 'unit / 0.5 ml', 78322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('measles virus vaccine live attenuated', NULL, 1000, 'unit / 0.5 ml', 62666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('measles virus vaccine live attenuated', NULL, 1000, 'unit / 0.5 ml', 3569);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('measles virus vaccine live attenuated', NULL, 1000, 'unit / 0.5 ml', 78322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemophilus influenzae type b-prp', NULL, 10, 'µg / 0.5 ml', 13140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemophilus influenzae type b-prp', NULL, 10, 'µg / 0.5 ml', 50651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemophilus influenzae type b-prp', NULL, 7.5, 'µg / 0.5 ml', 59709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemophilus influenzae type b-prp', NULL, 10, 'µg / 0.5 ml', 67042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemophilus influenzae type b-prp', NULL, 10, 'µg / 0.5 ml', 73878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 77476);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('corbadrine (corbadrine hydrochloride)', NULL, 50, 'µg / ml', 2744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('corbadrine (corbadrine hydrochloride)', NULL, 50, 'µg / ml', 76704);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('corbadrine (corbadrine hydrochloride)', NULL, 0.05, 'mg / ml', 79940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aluminum acetate', NULL, 0.5, '%', 6696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valine', NULL, 1.44, 'g / 100 ml', 43947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valine', NULL, 560, 'mg / 100 ml', 44068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valine', NULL, 640, 'mg / 100 ml', 15493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valine', NULL, 580, 'mg / 100 ml', 11329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valine', NULL, 528, 'mg / 100 ml', 7163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valine', NULL, 680, 'mg / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valine', NULL, 460, 'mg / 100 ml', 4661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valine', NULL, 460, 'mg / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 0.15, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', NULL, 500, 'mg', 12654);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', NULL, 500, 'mg / 4.5 g', 12996);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolnaftate', NULL, 1, 'g / 100 ml', 42528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetalkonium chloride', NULL, 5, 'mg', 186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (human)', NULL, 300, 'unit / 5 ml', 74661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (human)', NULL, 600, 'unit / 10 ml', 74662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (human)', NULL, 1200, 'unit / 15 ml', 74663);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (human)', NULL, 500, 'unit / 5.0 ml', 77219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (human)', NULL, 1000, 'unit / 10.0 ml', 77222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 81660);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis b surface antigen (recombinant)', NULL, 20, 'µg / 1.0 ml', 49687);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis b surface antigen (recombinant)', NULL, 10, 'µg / 0.5 ml', 60885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis b surface antigen (recombinant)', NULL, 10, 'µg / 0.5 ml', 73878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dermatophagoides pteronyssinus', NULL, 5000, 'unit / ml', 50632);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal polysaccharide antigen group w-135', NULL, 50, 'µg / 0.5 ml', 46485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal polysaccharide antigen group w-135', NULL, 500, 'µg / kit', 9222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal polysaccharide antigen group y', NULL, 50, 'µg / 0.5 ml', 46485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal polysaccharide antigen group y', NULL, 500, 'µg / kit', 9222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal polysaccharide antigen group c', NULL, 50, 'µg / 0.5 ml', 46485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal polysaccharide antigen group c', NULL, 500, 'µg / kit', 9222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal polysaccharide antigen group a', NULL, 50, 'µg / 0.5 ml', 46485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal polysaccharide antigen group a', NULL, 500, 'µg / kit', 9222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin isophane human biosynthetic', NULL, 70, 'unit / ml', 14265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin isophane human biosynthetic', NULL, 70, 'unit / ml', 14269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin isophane human biosynthetic', NULL, 50, 'unit / ml', 14270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin isophane human biosynthetic', NULL, 60, 'unit / ml', 14262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin isophane human biosynthetic', NULL, 70, 'unit / ml', 12568);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin injection human biosynthetic', NULL, 30, 'unit / ml', 14269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin injection human biosynthetic', NULL, 50, 'unit / ml', 14270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin injection human biosynthetic', NULL, 30, 'unit / ml', 14265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin injection human biosynthetic', NULL, 40, 'unit / ml', 14262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin injection human biosynthetic', NULL, 30, 'unit / ml', 12568);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neisseria meningitidis outer membrane protein complex', NULL, 125, 'µg / 0.5 ml', 59709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyl dodecyl benzyl trimethyl ammonium chloride', NULL, 16, '%', 19111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorescein sodium', NULL, 0.25, '%', 37090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorescein sodium', NULL, 0.25, '%', 6721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorescein sodium', NULL, 0.25, '%', 61132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('squalene', NULL, 10.69, 'mg / 0.5 ml', 82225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('copper (cupric oxide)', NULL, 2, 'mg', 70202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('copper (cupric oxide)', NULL, 2, 'mg', 76186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('copper (copper sulfate)', NULL, 0.4, 'mg / ml', 20314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('copper (copper sulfate)', NULL, 0.4, 'mg / ml', 19923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('copper (copper sulfate)', NULL, 0.4, 'mg / ml', 16226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('copper (copper sulfate)', NULL, 1, 'mg / ml', 16227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('copper (copper sulfate)', NULL, 1, 'mg / ml', 16225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 20, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('copper (copper sulfate)', NULL, 1, 'mg / ml', 16224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('copper (copper gluconate)', NULL, 0.45, 'mg / 2 ml', 15975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 170, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 210, 'mg / 100 ml', 20278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 210, 'mg / 100 ml', 20279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 178.5, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 600, 'mg / 100 ml', 19306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 210, 'mg / 100 ml', 19610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 178.5, 'mg / 100 ml', 20303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 210, 'mg / 100 ml', 20302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 178.5, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 210, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 210, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 178.5, 'mg / 100 ml', 20289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 105, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 210, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 210, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 170, 'mg / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 170, 'mg / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 140, 'mg / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 170, 'mg / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 170, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 210, 'mg / 100 ml', 19143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 140, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 200, 'mg / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 140, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 170, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 360, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 400, 'mg / 100 ml', 18644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 140, 'mg / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 400, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 280, 'mg / 100 ml', 18608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 340, 'mg / 100 ml', 18607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 512, 'mg / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 210, 'mg / 100 ml', 18550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 210, 'mg / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 210, 'mg / 100 ml', 14077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 210, 'mg / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 210, 'mg / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 178, 'mg / 100 ml', 14073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 178, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 178, 'mg / 100 ml', 14071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 105, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 210, 'mg / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 210, 'mg / 100 ml', 14067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 178, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 460, 'mg / 100 ml', 5890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 520, 'mg / 100 ml', 3468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 370, 'mg / 100 ml', 4560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 260, 'mg / 100 ml', 2776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 370, 'mg / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 1.26, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 2.21, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 2.84, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-threonine', NULL, 2.84, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 126, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 280, 'mg / 100 ml', 20279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 280, 'mg / 100 ml', 20278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 238, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 447, 'mg / 100 ml', 19306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 238, 'mg / 100 ml', 20303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 280, 'mg / 100 ml', 20302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 238, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 280, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 238, 'mg / 100 ml', 20289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 280, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 140, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 280, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 280, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 126, 'mg / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 126, 'mg / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 104, 'mg / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 126, 'mg / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 77550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 126, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 104, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 149, 'mg / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 104, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 126, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 300, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 104, 'mg / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 298, 'mg / 100 ml', 18644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 298, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 209, 'mg / 100 ml', 18608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 253, 'mg / 100 ml', 18607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 427, 'mg / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 380, 'mg / 100 ml', 5890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 440, 'mg / 100 ml', 3468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 310, 'mg / 100 ml', 4560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 220, 'mg / 100 ml', 2776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 420, 'mg / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 1.76, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 3.07, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 3.95, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine', NULL, 3.95, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 1.5, 'g / 100 ml', 19306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 1, 'g / 100 ml', 18644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 1, 'g / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 1.2, 'g / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 1, 'g / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 425, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 365, 'mg / 100 ml', 20279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 365, 'mg / 100 ml', 20278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 81379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 310, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 310, 'mg / 100 ml', 20303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 365, 'mg / 100 ml', 20302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 310, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 365, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 310, 'mg / 100 ml', 20289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 365, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 182.5, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 365, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 365, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 425, 'mg / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 425, 'mg / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 350, 'mg / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 425, 'mg / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 425, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 350, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 500, 'mg / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 350, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 425, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 831, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 350, 'mg / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 700, 'mg / 100 ml', 18608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 850, 'mg / 100 ml', 18607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 810, 'mg / 100 ml', 5890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 940, 'mg / 100 ml', 3468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 660, 'mg / 100 ml', 4560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 470, 'mg / 100 ml', 2776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 1.76, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 3.07, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 3.95, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine', NULL, 3.95, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 280, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 300, 'mg / 100 ml', 20278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 300, 'mg / 100 ml', 20279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 255, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 990, 'mg / 100 ml', 19306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 240, 'mg / 100 ml', 19610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 255, 'mg / 100 ml', 20303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 300, 'mg / 100 ml', 20302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 255, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 300, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 300, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 255, 'mg / 100 ml', 20289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 150, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 300, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 300, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 280, 'mg / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 280, 'mg / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 231, 'mg / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 280, 'mg / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 17, 'mg / 100 ml', 20289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 280, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 240, 'mg / 100 ml', 19143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 231, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 330, 'mg / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 231, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 280, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 534, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 231, 'mg / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 660, 'mg / 100 ml', 18644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 660, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 462, 'mg / 100 ml', 18608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 561, 'mg / 100 ml', 18607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 760, 'mg / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 240, 'mg / 100 ml', 18550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 240, 'mg / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 240, 'mg / 100 ml', 14077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 240, 'mg / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 240, 'mg / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 203, 'mg / 100 ml', 14073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 203, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 203, 'mg / 100 ml', 14071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 120, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 240, 'mg / 100 ml', 14067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 240, 'mg / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 203, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 79618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 620, 'mg / 100 ml', 5890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 720, 'mg / 100 ml', 3468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 510, 'mg / 100 ml', 4560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 360, 'mg / 100 ml', 2776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 670, 'mg / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 1.26, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 2.21, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 2.84, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-isoleucine', NULL, 2.84, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcipotriol', NULL, 50, 'µg / g', 68084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcipotriol (calcipotriol monohydrate)', NULL, 50, 'µg / g', 80450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 20, 'mg / 100 ml', 20278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 17, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 20, 'mg / 100 ml', 19610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 20, 'mg / 100 ml', 20302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 17, 'mg / 100 ml', 20303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 17, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 10, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 20, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 20, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 20, 'mg / 100 ml', 20279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 20, 'mg / 100 ml', 19143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 44, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 44, 'mg / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 20, 'mg / 100 ml', 18550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 20, 'mg / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 20, 'mg / 100 ml', 14077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 20, 'mg / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 20, 'mg / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 17, 'mg / 100 ml', 14073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 17, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 17, 'mg / 100 ml', 14071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 10, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 20, 'mg / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 20, 'mg / 100 ml', 14067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 17, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 44, 'mg / 100 ml', 5890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 44, 'mg / 100 ml', 3468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 44, 'mg / 100 ml', 4560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 44, 'mg / 100 ml', 2776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 45, 'mg / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 0.06, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-tyrosine', NULL, 0.11, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', NULL, 0.2, '%', 36721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', NULL, 0.15, '%', 18442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', NULL, 0.5, '%', 15829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', NULL, 0.15, '%', 13617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', NULL, 0.15, '%', 12792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', NULL, 0.15, '%', 7121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', NULL, 0.36, '%', 6675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', NULL, 0.5, '%', 1338);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', NULL, 0.5, '%', 50083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium oxide', NULL, 96.9, 'mg', 48421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium oxide', NULL, 63, 'mg', 48434);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium oxide', NULL, 3.5, 'g / pck', 73995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium oxide', NULL, 3.5, 'g / pck', 78587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium oxide', NULL, 3.5, 'g / pck', 80347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium oxide', NULL, 3.5, 'g / pck', 84334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium oxide', NULL, 3.8, 'mg / ml', 2122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium oxide', NULL, 1.9, 'mg / ml', 744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('human plasma proteins', NULL, 7.5, 'mg / 5.0 ml', 77219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('human plasma proteins', NULL, 15.0, 'mg / 10.0 ml', 77222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril', NULL, 5, 'mg', 44252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', NULL, 5, 'mg', 77051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', NULL, 5, 'mg', 79924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 1.083, 'g / 100 ml', 19306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 307, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 340, 'mg / 100 ml', 20278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 289, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 210, 'mg / 100 ml', 19610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 340, 'mg / 100 ml', 20302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 289, 'mg / 100 ml', 20303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 289, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 340, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 340, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 289, 'mg / 100 ml', 20289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 170, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 340, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 340, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 340, 'mg / 100 ml', 20279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 307, 'mg / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 307, 'mg / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 307, 'mg / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 252, 'mg / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 210, 'mg / 100 ml', 19143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 307, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 252, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 361, 'mg / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 252, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 307, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 570, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 252, 'mg / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 722, 'mg / 100 ml', 18644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 722, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 614, 'mg / 100 ml', 18607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 505, 'mg / 100 ml', 18608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 812, 'mg / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 210, 'mg / 100 ml', 18550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 210, 'mg / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 210, 'mg / 100 ml', 14077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 210, 'mg / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 210, 'mg / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 178, 'mg / 100 ml', 14073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 178, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 178, 'mg / 100 ml', 14071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 105, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 210, 'mg / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 210, 'mg / 100 ml', 14067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 178, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 750, 'mg / 100 ml', 5890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 860, 'mg / 100 ml', 3468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 610, 'mg / 100 ml', 4560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 430, 'mg / 100 ml', 2776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 300, 'mg / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 1.51, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 2.64, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 3.40, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-proline', NULL, 3.40, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 1.527, 'g / 100 ml', 19306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 1.018, 'g / 100 ml', 18644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 1.018, 'g / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 1.227, 'g / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 432, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 575, 'mg / 100 ml', 20278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 489, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 520, 'mg / 100 ml', 19610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 489, 'mg / 100 ml', 20303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 575, 'mg / 100 ml', 20302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 489, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 575, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 575, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 489, 'mg / 100 ml', 20289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 290, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 575, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 575, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 575, 'mg / 100 ml', 20279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 432, 'mg / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 432, 'mg / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 356, 'mg / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 432, 'mg / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 520, 'mg / 100 ml', 19143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 432, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 356, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 509, 'mg / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 356, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 432, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 356, 'mg / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 861, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 713, 'mg / 100 ml', 18608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 865, 'mg / 100 ml', 18607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 520, 'mg / 100 ml', 18550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 520, 'mg / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 520, 'mg / 100 ml', 14077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 520, 'mg / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 520, 'mg / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 440, 'mg / 100 ml', 14073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 440, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 440, 'mg / 100 ml', 14071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 260, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 520, 'mg / 100 ml', 14067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 520, 'mg / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 440, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 850, 'mg / 100 ml', 5890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 980, 'mg / 100 ml', 3468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 690, 'mg / 100 ml', 4560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 490, 'mg / 100 ml', 2776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 840, 'mg / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 2.48, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 4.34, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 5.58, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-arginine', NULL, 5.58, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tyrosine', NULL, 50, 'mg / 100 ml', 43947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tyrosine', NULL, 40, 'mg / 100 ml', 11329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tyrosine', NULL, 44, 'mg / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tyrosine', NULL, 40, 'mg / 100 ml', 4661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tyrosine', NULL, 40, 'mg / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 5.0, '%', 77551);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin (neomycin sulfate)', NULL, 3.5, 'mg / ml', 16624);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin (neomycin sulfate)', NULL, 1.75, 'mg / ml', 13328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin (neomycin sulfate)', NULL, 3.5, 'mg / ml', 11287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin (neomycin sulfate)', NULL, 1.75, 'mg / ml', 10062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin (neomycin sulfate)', NULL, 40, 'mg / ml', 6727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin (neomycin sulfate)', NULL, 3.5, 'mg / ml', 49184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin (neomycin sulfate)', NULL, 3.5, 'mg / ml', 259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin (neomycin sulfate)', NULL, 3.5, 'mg / g', 16650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin (neomycin sulfate)', NULL, 2.5, 'mg / g', 15598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin (neomycin sulfate)', NULL, 2.5, 'mg / g', 12862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin (neomycin sulfate)', NULL, 2.5, 'mg / g', 9448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin (neomycin sulfate)', NULL, 2.5, 'mg / g', 9449);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin (neomycin sulfate)', NULL, 3.5, 'mg / g', 8528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin (neomycin sulfate)', NULL, 5, 'mg / g', 7030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin (neomycin sulfate)', NULL, 3.5, 'mg / g', 2423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin (neomycin sulfate)', NULL, 3.5, 'mg / g', 66223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemagglutinin-strain b', NULL, 15, 'µg / 0.5 ml', 37348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemagglutinin-strain b', NULL, 15, 'µg / 0.5 ml', 14488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemagglutinin-strain b', NULL, 15, 'µg / 0.5 ml', 75489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemagglutinin-strain b', NULL, 15, 'µg / 0.5 ml', 83225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemagglutinin-strain b', NULL, 9, 'µg / 0.1 ml', 83409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemagglutinin-strain a(h3n2)', NULL, 15, 'µg / 0.5 ml', 37348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemagglutinin-strain a(h3n2)', NULL, 15, 'µg / 0.5 ml', 14488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemagglutinin-strain a(h3n2)', NULL, 15, 'µg / 0.5 ml', 75489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemagglutinin-strain a(h3n2)', NULL, 15, 'µg / 0.5 ml', 83225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemagglutinin-strain a(h3n2)', NULL, 9, 'µg / 0.1 ml', 83409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemagglutinin-strain a(h1n1)', NULL, 15, 'µg / 0.5 ml', 37348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemagglutinin-strain a(h1n1)', NULL, 15, 'µg / 0.5 ml', 14488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemagglutinin-strain a(h1n1)', NULL, 15, 'µg / 0.5 ml', 75489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemagglutinin-strain a(h1n1)', NULL, 15, 'µg / 0.5 ml', 83225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemagglutinin-strain a(h1n1)', NULL, 9, 'µg / 0.1 ml', 83409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine hydrochloride', NULL, 310, 'mg / 100 ml', 19610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine hydrochloride', NULL, 310, 'mg / 100 ml', 19143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine hydrochloride', NULL, 310, 'mg / 100 ml', 18550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine hydrochloride', NULL, 310, 'mg / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine hydrochloride', NULL, 310, 'mg / 100 ml', 14077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine hydrochloride', NULL, 310, 'mg / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine hydrochloride', NULL, 310, 'mg / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine hydrochloride', NULL, 263, 'mg / 100 ml', 14073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine hydrochloride', NULL, 263, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine hydrochloride', NULL, 263, 'mg / 100 ml', 14071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine hydrochloride', NULL, 155, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine hydrochloride', NULL, 310, 'mg / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine hydrochloride', NULL, 310, 'mg / 100 ml', 14067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-phenylalanine hydrochloride', NULL, 263, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 5, '%', 19037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 15893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 13954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 13958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 13929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 13930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 51733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.2, '%', 61235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '%', 60497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 64701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 64702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 64225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 67232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '%', 65907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 65424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 65426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 65425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 64883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 64887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 66892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 68325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 68818);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 69344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 68355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.8, '%', 68850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 67949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 68574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 68595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 68117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 68186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '%', 71359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 72275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 70085);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 69552);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 70253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 70881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 70903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 70998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 70999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 71098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 71099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 71100);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 71101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 70541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 72053);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 72068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 76470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '%', 73900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 75172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.50, '%', 76603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.50, '%', 76604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.8, '%', 76634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 76635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 74004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 74039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '%', 75298);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '%', 76744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 75409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 75413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 75414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 73044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 74244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '%', 72332);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 74321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.5, '%', 75527);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.5, '%', 75528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 75557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 75594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '%', 75596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 72392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 75676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 75677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 75697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 75709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 73166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '%', 74434);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 74447);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 74448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 74500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 74548);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 74554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 74651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 74654);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 75989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 75990);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 73324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 74735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 74749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 76004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '%', 76007);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 73436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 76108);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 76146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.06, '%', 73522);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '%', 74916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 76179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 76213);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 76214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 73587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 74918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.44, '%', 74992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 76247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 73755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 73756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 76325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 76328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 73821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 77488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 78164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 77531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 77577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 77578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 77610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 77612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.5, '%', 78218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 5.0, '%', 77613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 77122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 77123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.5, '%', 76897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 76898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '%', 77374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '%', 77629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 77608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 77681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 77682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 77925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.5, '%', 78154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 78156);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 77812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.00, '%', 77383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 78220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 78221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 76869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 78310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 78311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 78317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 76910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 77768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 77926);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 76934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 78014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 78019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 78020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 77617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 78331);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 78343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 78345);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 77287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 82245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 79960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 79018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 78656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.00, '%', 78689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.00, '%', 78690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 79181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 79182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 80443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 78611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 78700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 5.0, '%', 78701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 79265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 78709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 78989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 78990);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 79294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 79798);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 78957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 78958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 78959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.00, '%', 78813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 79295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 79719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 79407);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '%', 80173);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 80438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 78621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 78893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 78894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 78895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 79252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 79253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 79255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 79257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.5, '%', 78604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.00, '%', 78929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.00, '%', 78930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 80565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.00, '%', 79238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 79319);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 79320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.2, '%', 79930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 79931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 79197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 78629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 78635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 0.1, '%', 79982);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '%', 79067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 79226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 79227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 79232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 79233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 79992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 80227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 80110);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 80111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 80641);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 81860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 81861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 78578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 78647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 82839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '%', 82383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 79098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 79184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '%', 79187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 79086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 82622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '%', 80820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 84131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 84132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 84541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '%', 84603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '%', 85091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.50, '% / w/w', 65475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.00, '% / w/w', 69095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.00, '% / w/w', 76605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 74228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 75689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 72549);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '% / w/w', 75980);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 76030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 76200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 76215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 74967);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 74968);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 74969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 74970);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 76204);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '% / w/w', 77368);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '% / w/w', 77389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '% / w/w', 77391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 78219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 76938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 76863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 76891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 77633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 77721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 76941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 78297);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 77340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 77341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 81654);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.50, '% / w/w', 81656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 81144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 81175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 79851);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 81909);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 79531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.85, '% / w/w', 81268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 82780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 79579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80566);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 82206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 82242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 82930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 4.0, '% / w/w', 82931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 82964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 79731);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.00, '% / w/w', 78685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.00, '% / w/w', 78686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 79183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '% / w/w', 80350);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.00, '% / w/w', 79766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 80791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 81406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 79217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 82015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 82016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 82018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '% / w/w', 82269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 79044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 81716);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 79468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 79469);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 79470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 79605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 79747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80027);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 80435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 80436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '% / w/w', 81454);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '% / w/w', 81366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 0.9, '% / w/w', 81367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 81371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '% / w/w', 81370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '% / w/w', 81372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 79971);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '% / w/w', 81337);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80049);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '% / w/w', 80050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '% / w/w', 80051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80052);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.5, '% / w/w', 80055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '% / w/w', 80056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82987);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 80198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 80199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 80200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '% / w/w', 81604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 81605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 81708);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 81709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 77392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 77390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 81457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.8, '% / w/w', 81557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 81779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 81842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82013);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '% / w/w', 82508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 80219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80478);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80568);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 79980);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 79983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80810);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80023);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80022);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 80411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 81076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 79524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 79595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 79989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 80069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '% / w/w', 80070);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.00, '% / w/w', 81829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 81266);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '% / w/w', 82515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 4, '% / w/w', 80393);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '% / w/w', 80858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 81926);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.2, '% / w/w', 81927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 81929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 81930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 81928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 0.7, '% / w/w', 81931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '% / w/w', 81892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '% / w/w', 81893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 81894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82381);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 82415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80362);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 79484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.1, '% / w/w', 81911);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80526);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 81043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 81044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 82367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80670);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 81912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 81913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.5, '% / w/w', 81914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 81915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 81916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '% / w/w', 81919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 81920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 81921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.5, '% / w/w', 82621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80503);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 78222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 83050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 79249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 82373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.5, '% / w/w', 80256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 80539);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '% / w/w', 82063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 80034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 80035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 81069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 82610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 80302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 82543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 78779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 83001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 79868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 80380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 80567);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 82779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.5, '% / w/w', 79784);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 81488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.0, '% / w/w', 82167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 83072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 83098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 83101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.5, '% / w/w', 83388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.5, '% / w/w', 83389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 83391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 83403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 83420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 83564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 83580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 83581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 83677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '% / w/w', 83772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 83773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 83775);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 83785);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 83786);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 83787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.00, '% / w/w', 83859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 83866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 83869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 83881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '% / w/w', 80228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 83902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.85, '% / w/w', 83908);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.7, '% / w/w', 83983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.7, '% / w/w', 83984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.5, '% / w/w', 84032);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1.5, '% / w/w', 84033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.00, '% / w/w', 84034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.80, '% / w/w', 84035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84036);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 0.5, '% / w/w', 84039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.85, '% / w/w', 84042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 84061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 84076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 0.8, '% / w/w', 84118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 0.8, '% / w/w', 84119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '% / w/w', 84257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '% / w/w', 84262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 84424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '% / w/w', 84472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84519);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84520);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / w/w', 84530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 84574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.0, '% / w/w', 84579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84707);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 5.0, '% / w/w', 84715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.00, '% / w/w', 84959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.00, '% / w/w', 84962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '% / w/w', 84974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3.0, '% / w/w', 84975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 18554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 15799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, '%', 50132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2.5, '%', 50134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1, '%', 64736);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1, '%', 64737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1, '%', 64739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1, '%', 64738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 1, '%', 64740);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, '% / 50 ml', 83672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 2, 'g / 100 g', 61313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 3, 'g / 100 g', 62467);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', NULL, 30, 'mg / g', 62885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nonyl phenoxypoly ethoxy ethanol-iodine', NULL, 10.59, '%', 37925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethylene glycol 3350', NULL, 59.00, 'g / pck', 33649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethylene glycol 3350', NULL, 59.55, 'g / pck', 81164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethylene glycol 3350', NULL, 100.0, 'g / pck', 84451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethylene glycol 3350', NULL, 857.69, 'mg / g', 6616);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin e (d-alpha tocopheryl acetate)', NULL, 65, 'unit', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin e (dl-alpha tocopheryl acetate)', NULL, 30, 'unit', 70202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin e (dl-alpha tocopheryl acetate)', NULL, 30, 'unit', 76186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin e (dl-alpha tocopheryl acetate)', NULL, 7, 'unit / vial', 66277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin e (dl-alpha tocopherol)', NULL, 11.86, 'mg / 0.5 ml', 82225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin e', NULL, 2, 'unit / ml', 16462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin e (dl-alpha tocopheryl acetate)', NULL, 1, 'unit / ml', 5613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin e (dl-alpha tocopheryl acetate)', NULL, 2, 'unit / ml', 68684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin d', NULL, 400, 'unit / vial', 66277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin d', NULL, 40, 'unit / ml', 16462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', NULL, 80, 'mg', 75457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin d', NULL, 100, 'unit / ml', 5613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin a (vitamin a palmitate)', NULL, 4000, 'unit', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin a', NULL, 2300, 'unit / vial', 66277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin a', NULL, 660, 'unit / ml', 16462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin a', NULL, 1000, 'unit / ml', 5613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin a', NULL, 660, 'unit / ml', 68684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextran 70', NULL, 6, '%', 21686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextran 70', NULL, 0.1, '%', 73019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextran 70', NULL, 0.1, '% / w/v', 81391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextran 70', NULL, 0.1, '% / w/v', 82979);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', NULL, 25, 'mg', 19075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', NULL, 25, 'mg', 188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', NULL, 125, 'mg', 60618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', NULL, 51.2, 'mg', 63534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', NULL, 60, 'mg', 67414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', NULL, 125, 'mg', 69200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', NULL, 60, 'mg', 71557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', NULL, 25, 'mg / 5 ml', 26833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', NULL, 25, 'mg / 5 ml', 19082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', NULL, 25, 'mg / 5 ml', 187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', NULL, 20, 'mg / 5 ml', 68677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', NULL, 40, 'mg / 5 ml', 68678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', NULL, 40, 'mg / 5 ml', 74304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', NULL, 20, 'mg / 5 ml', 74696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium hydroxide', NULL, 200, 'mg', 19075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium hydroxide', NULL, 100, 'mg', 188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium hydroxide', NULL, 165, 'mg', 66915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium hydroxide', NULL, 200, 'mg / 5 ml', 44552);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium hydroxide', NULL, 200, 'mg / 5 ml', 26833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium hydroxide', NULL, 200, 'mg / 5 ml', 19082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium hydroxide', NULL, 100, 'mg / 5 ml', 18186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium hydroxide', NULL, 200, 'mg / 5 ml', 13074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium hydroxide', NULL, 200, 'mg / 5 ml', 10217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium hydroxide', NULL, 60, 'mg / ml', 1281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium hydroxide', NULL, 200, 'mg / 5 ml', 187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium hydroxide', NULL, 200, 'mg / 5 ml', 68677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium hydroxide', NULL, 400, 'mg / 5 ml', 68678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium hydroxide', NULL, 400, 'mg / 5 ml', 74304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium hydroxide', NULL, 200, 'mg / 5 ml', 74696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3, '%', 37916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4, '%', 19037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.8, '%', 75823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5, '%', 50939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2, '%', 50532);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2, '%', 60497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 0.75, '%', 62357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 0.8, '%', 65907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4, '%', 65423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4, '%', 65427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.2, '%', 64887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.2, '%', 69393);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.0, '%', 69394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.0, '%', 68570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.0, '%', 70904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.2, '%', 70260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 15, '%', 70261);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.6, '%', 70541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 0.75, '%', 72053);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.0, '%', 76449);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.3, '%', 76468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.0, '%', 75229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.15, '%', 76603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.15, '%', 76604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 18.08, '%', 76619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 0.9, '%', 75277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5, '%', 75296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.4, '%', 75392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.2, '%', 75413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.3, '%', 75414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.5, '%', 74217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 6.6, '%', 75513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.81, '%', 73106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 9.0, '%', 74271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.5, '%', 75527);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.3, '%', 75528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.2, '%', 75565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.2, '%', 74412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 7.7, '%', 74430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.84, '%', 74441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 0.95, '%', 74500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.5, '%', 75752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.5, '%', 75755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.5, '%', 75756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2, '%', 72585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.0, '%', 74560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.0, '%', 74589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.05, '%', 75868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.5, '%', 75869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.2, '%', 74655);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.5, '%', 75907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 6.0, '%', 75920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.0, '%', 74735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.0, '%', 73363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.4, '%', 75779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2, '%', 72680);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.3, '%', 73606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2, '%', 73607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.4, '%', 74955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 13.75, '%', 72737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 15.3, '%', 72739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 10.5, '%', 75015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 8.4, '%', 76327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2, '%', 76343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.66, '%', 76379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.6, '%', 73821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 7.8, '%', 78091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.0, '%', 77065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.0, '%', 77512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4, '%', 77476);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.30, '%', 77550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.30, '%', 77551);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 9.37, '%', 77560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.24, '%', 77605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.24, '%', 77606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 0.66, '%', 77610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.0, '%', 77612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.15, '%', 78218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.3, '%', 77613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.15, '%', 78220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5, '%', 78221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.9, '%', 77082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 6.25, '%', 77122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 6.25, '%', 77123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.0, '%', 77410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5, '%', 77692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.65, '%', 78154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.0, '%', 77016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.9, '%', 77820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 6.25, '%', 77383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 0.8, '%', 78156);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.8, '%', 77254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 13, '%', 78256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.2, '%', 78278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.0, '%', 77434);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.75, '%', 76910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.83, '%', 78023);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.83, '%', 78024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.92, '%', 78025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.8, '%', 77322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.5, '%', 77325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.4, '%', 77411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.50, '%', 78047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.3, '%', 78656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.16, '%', 79081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.32, '%', 79221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 7.5, '%', 80443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.15, '%', 78813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.9, '%', 78893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.6, '%', 78895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.3, '%', 78894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.3, '%', 78604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.6, '%', 78605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 11, '%', 78606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.0, '%', 79533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.6, '%', 79913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.1, '%', 80828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.6, '%', 78646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 11.0, '%', 78901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.3, '%', 79098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.7, '%', 79185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 7.8, '%', 80281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 8.5, '%', 80821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.1, '%', 82313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.22, '%', 84130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.22, '%', 84133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.0, '%', 84266);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.6, '%', 84443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.0, '% / w/w', 15968);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.5, '% / w/w', 48991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.00, '% / w/w', 65475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.15, '% / w/w', 76605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.40, '% / w/w', 75591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.1, '% / w/w', 76139);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.2, '% / w/w', 74967);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.0, '% / w/w', 74969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.2, '% / w/w', 74970);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.0, '% / w/w', 77462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.2, '% / w/w', 77394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.1, '% / w/w', 77395);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.5, '% / w/w', 80859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.7, '% / w/w', 80135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.3, '% / w/w', 82154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.7, '% / w/w', 82930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.6, '% / w/w', 82931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.0, '% / w/w', 79674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.0, '% / w/w', 79607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.3, '% / w/w', 80747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.85, '% / w/w', 80435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.6, '% / w/w', 81451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.81, '% / w/w', 80484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.0, '% / w/w', 80977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.4, '% / w/w', 80112);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.2, '% / w/w', 80114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.08, '% / w/w', 81830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 0.5, '% / w/w', 79620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.6, '% / w/w', 80393);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.19, '% / w/w', 80309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.37, '% / w/w', 80312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.79, '% / w/w', 80313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.02, '% / w/w', 80314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.12, '% / w/w', 80315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4, '% / w/w', 82380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.8, '% / w/w', 80382);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.6, '% / w/w', 80383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.0, '% / w/w', 80424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.0, '% / w/w', 79546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 7.5, '% / w/w', 82367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.16, '% / w/w', 81007);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.64, '% / w/w', 81638);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 11.70, '% / w/w', 81639);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.4, '% / w/w', 82062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.4, '% / w/w', 82066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.0, '% / w/w', 80380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 11.7, '% / w/w', 81287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.16, '% / w/w', 82113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.6, '% / w/w', 82523);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 7.5, '% / w/w', 82525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2, '% / w/w', 83116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.0, '% / w/w', 83728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 6.8, '% / w/w', 83737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.0, '% / w/w', 83877);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 6.3, '% / w/w', 83900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.4, '% / w/w', 84038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.81, '% / w/w', 84244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2.0, '% / w/w', 84292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 3.00, '% / w/w', 84344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.8, '% / w/w', 84420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.0, '% / w/w', 84423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 5.0, '% / w/w', 84425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4.0, '% / w/w', 84975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2, '% / w/w', 85096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2, '% / w/w', 85097);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2, '% / w/w', 85098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2, '% / w/w', 85099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1.0, '% / w/w', 85135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 7.8, '% / w/w', 85228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 7.94, '% / w/v', 85515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2, '%', 15799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1, '%', 53424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1, '%', 53425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1, '%', 53426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 1, '%', 60302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4, '%', 64738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 4, '%', 64739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 20, 'mg / ml', 63661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 20, 'mg / ml', 63662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2, 'g / 100 g', 63515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', NULL, 2, 'g / 100 g', 63516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desogestrel', NULL, 0.15, 'mg', 14191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desogestrel', NULL, 0.15, 'mg', 14354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desogestrel', NULL, 0.15, 'mg', 14355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desogestrel', NULL, 0.100, 'mg', 74243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desogestrel', NULL, 0.125, 'mg', 74243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desogestrel', NULL, 0.150, 'mg', 74243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desogestrel', NULL, 0.100, 'mg', 75841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desogestrel', NULL, 0.125, 'mg', 75841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desogestrel', NULL, 0.150, 'mg', 75841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desogestrel', NULL, 0.15, 'mg', 80270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desogestrel', NULL, 0.15, 'mg', 80272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', NULL, 1, '%', 10673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium carbonate', NULL, 200, 'mg', 19075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium carbonate', NULL, 246.2, 'mg', 48421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium carbonate', NULL, 160, 'mg', 48434);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium carbonate', NULL, 350, 'mg', 60637);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium carbonate', NULL, 675, 'mg', 64038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium carbonate', NULL, 400, 'mg', 63534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium carbonate', NULL, 800, 'mg', 66915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium carbonate', NULL, 1000, 'mg', 67414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium carbonate', NULL, 1177, 'mg', 75457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium carbonate', NULL, 350, 'mg', 80534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium carbonate', NULL, 200, 'mg / 5 ml', 19082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 0.015, '%', 14489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 2, '%', 13289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 4, '%', 13290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 0.5, '%', 12861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 0.5, '%', 64391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 0.5, '%', 65180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 1, '%', 71113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 0.5, '%', 71947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 2, '%', 73640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 2.0, '%', 78280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 4, '% / w/w', 77576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 0.05, '% / w/w', 78032);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 2, '% / w/v', 34222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 2.0, '% / w/v', 63898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 0.5, '% / w/v', 77225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 0.5, '%', 30398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 0.5, '%', 19626);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 0.5, '%', 16494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 1, '%', 14568);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 0.5, '%', 64263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 0.5, '%', 66842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', NULL, 0.5, '%', 66843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meradimate', NULL, 4.0, '%', 42376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meradimate', NULL, 4.0, '%', 42377);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meradimate', NULL, 4.8, '%', 42310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meradimate', NULL, 5, '%', 71534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meradimate', NULL, 5.0, '%', 69886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meradimate', NULL, 4.0, '%', 74630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meradimate', NULL, 4.8, '% / w/w', 79440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meradimate', NULL, 4.8, '% / w/w', 79647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meradimate', NULL, 2.5, '%', 42334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meradimate', NULL, 5, '%', 64736);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meradimate', NULL, 4, '%', 64737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meradimate', NULL, 4, '%', 64740);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluticasone propionate', NULL, 100, 'µg / dose', 64426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluticasone propionate', NULL, 250, 'µg / dose', 64427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluticasone propionate', NULL, 500, 'µg / dose', 64428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluticasone propionate', NULL, 125, 'µg / dose', 69136);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluticasone propionate', NULL, 250, 'µg / dose', 69137);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c (ascorbic acid)', NULL, 300, 'mg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c (calcium ascorbate)', NULL, 100, 'mg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c (ascorbic acid)', NULL, 120, 'mg', 70202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c (ascorbic acid)', NULL, 120, 'mg', 76186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c (ascorbic acid)', NULL, 80, 'mg / vial', 66277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c', NULL, 4.700, 'g / pck', 84451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c', NULL, 50, 'mg / pck', 26396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c', NULL, 50, 'mg / pck', 26397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c', NULL, 50, 'mg / pck', 21168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c', NULL, 20, 'mg / ml', 16462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c', NULL, 100, 'mg / ml', 5613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c', NULL, 20, 'mg / ml', 68684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c', NULL, 50, 'mg / 22 mg', 62576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c (ascorbic acid)', NULL, 50, 'mg / 22 g', 31530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c', NULL, 50, 'mg / 23 g', 32780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c', NULL, 50, 'mg / 23 g', 19088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c', NULL, 50, 'mg / 23 g', 62330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c (ascorbic acid)', NULL, 50, 'mg / 22 g', 73067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 62615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dea methoxycinnamate', NULL, 4, '%', 53422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dea methoxycinnamate', NULL, 4, '%', 53423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cynara scolymus', NULL, 250, 'mg', 2981);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2a', NULL, 180, 'µg / ml', 73839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2a', NULL, 180, 'µg / 0.5 ml', 73840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leucine', NULL, 1.08, 'g / 100 ml', 43947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leucine', NULL, 770, 'mg / 100 ml', 44068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leucine', NULL, 880, 'mg / 100 ml', 15493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leucine', NULL, 730, 'mg / 100 ml', 11329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leucine', NULL, 726, 'mg / 100 ml', 7163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leucine', NULL, 810, 'mg / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leucine', NULL, 620, 'mg / 100 ml', 4661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leucine', NULL, 620, 'mg / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', NULL, 45, 'mg', 11341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', NULL, 2, '%', 42159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', NULL, 1, '% / w/w', 81251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', NULL, 1, '% / w/w', 80131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', NULL, 3, '%', 42310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', NULL, 25, 'mg / 5 ml', 44552);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', NULL, 25, 'mg / 5 ml', 13074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', NULL, 25, 'mg / 5 ml', 9572);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', NULL, 25, 'mg / 5 ml', 10217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etonogestrel', NULL, 11.4, 'mg', 73815);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium picosulfate', NULL, 10, 'mg / pck', 73995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium picosulfate', NULL, 10, 'mg / pck', 78587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium picosulfate', NULL, 10, 'mg / pck', 80347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium picosulfate', NULL, 10, 'mg / pck', 84334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium trihydrate)', NULL, 70, 'mg', 76210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium trihydrate)', NULL, 70, 'mg', 80047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('delta-9-tetrahydrocannabinol (cannabis sativa extract)', NULL, 27, 'mg / ml', 75157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('von willebrand factor (human)', NULL, 840, 'unit / 5 ml', 74661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('von willebrand factor (human)', NULL, 1680, 'unit / 10 ml', 74662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('von willebrand factor (human)', NULL, 3360, 'unit / 15 ml', 74663);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('von willebrand factor (human)', NULL, 500, 'unit / 5.0 ml', 77219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('von willebrand factor (human)', NULL, 1000, 'unit / 10.0 ml', 77222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dorzolamide (dorzolamide hydrochloride)', NULL, 20, 'mg / ml', 63627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dorzolamide (dorzolamide hydrochloride)', NULL, 20, 'mg / ml', 74388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dorzolamide (dorzolamide hydrochloride)', NULL, 20, 'mg / ml', 78499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dorzolamide (dorzolamide hydrochloride)', NULL, 20, 'mg / ml', 82984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cannabidiol (cannabis sativa extract)', NULL, 25, 'mg / ml', 75157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naloxone hydrochloride', NULL, 5, 'mg', 82520);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naloxone hydrochloride', NULL, 10, 'mg', 82521);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naloxone hydrochloride', NULL, 20, 'mg', 82522);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 3.00, '%', 76604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('threonine', NULL, 340, 'mg / 100 ml', 44068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('threonine', NULL, 400, 'mg / 100 ml', 15493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('threonine', NULL, 330, 'mg / 100 ml', 7163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('threonine', NULL, 420, 'mg / 100 ml', 4661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', NULL, 375, 'mg', 84676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', NULL, 500, 'mg', 84677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1.0, '%', 64887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1, '%', 70998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 2, '%', 70999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 3, '%', 70541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 3.00, '%', 76603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 3.0, '%', 75413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1.0, '%', 75414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 4.0, '%', 74217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 0.5, '%', 75527);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 0.5, '%', 75528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1, '%', 74500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1.0, '%', 75015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 0.5, '%', 73821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1, '%', 77476);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 0.25, '%', 78218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1, '%', 78220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 2, '%', 78221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 0.5, '%', 78154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 0.25, '%', 78156);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1.0, '%', 78656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 0.5, '%', 78813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1.0, '%', 78893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1.5, '%', 78894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1.0, '%', 78895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 2.0, '%', 78604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 0.53, '%', 79068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1.5, '%', 79098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 2.00, '% / w/w', 76605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1.0, '% / w/w', 82930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1.0, '% / w/w', 82931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1.5, '% / w/w', 80435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1, '% / w/w', 80393);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 4, '% / w/w', 82270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1.0, '% / w/w', 80383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1.5, '% / w/w', 79784);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 2.00, '% / w/w', 84959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 2.00, '% / w/w', 84962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis a vaccine, inactivated', NULL, 720, 'unit / 1.0 ml', 49687);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis a vaccine, inactivated', NULL, 360, 'unit / 0.5 ml', 60885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis a vaccine, inactivated', NULL, 160, 'unit / 0.5 ml', 72706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('articaine hydrochloride', NULL, 40, 'mg / ml', 16851);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('articaine hydrochloride', NULL, 40.0, 'mg / ml', 16850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('articaine hydrochloride', NULL, 40, 'mg / ml', 16508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('articaine hydrochloride', NULL, 40, 'mg / ml', 16511);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('articaine hydrochloride', NULL, 40, 'mg / ml', 72840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('articaine hydrochloride', NULL, 40, 'mg / ml', 72841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('articaine hydrochloride', NULL, 40.0, 'mg / ml', 74608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('articaine hydrochloride', NULL, 40, 'mg / ml', 82513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('articaine hydrochloride', NULL, 40, 'mg / ml', 82514);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iron (ferrous fumarate)', NULL, 35, 'mg', 70202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iron (ferrous fumarate)', NULL, 35, 'mg', 76186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', NULL, 8.0, 'mg', 61969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', NULL, 8.0, 'mg', 80640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', NULL, 0.6, '%', 42607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', NULL, 1, '%', 79467);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', NULL, 0.6, '%', 42334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', NULL, 200, 'mg / 100 ml', 42528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', NULL, 22, 'mg / 5 ml', 50217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', NULL, 15, 'mg / 5 ml', 75087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', NULL, 15, 'mg / 5 ml', 75088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', NULL, 20, 'mg / 5 ml', 76530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', NULL, 15, 'mg / 5 ml', 80637);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 47167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 41753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 42382);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 42082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 41830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 41831);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 37037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 37150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 35047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 34150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 31568);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 33120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 33917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 27225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 25897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 25898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 22846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 22847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 19429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 19624);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 19935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 17887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 17880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 19249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 19250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 19248);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 250, 'mg', 19103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 17235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 16752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 15805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 17113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 15580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 15581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 15579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 15578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 15514);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 16437);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 13120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 13607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 12942);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 14595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 14596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 14509);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 13316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 13312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 14316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 13804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 13259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 13765);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 13761);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 11753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 11741);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 12461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 160, 'mg', 11646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 80, 'mg', 11041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 11427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 11921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 11339);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 9626);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 8250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 8251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 8252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 80, 'mg', 8247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 8249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 7081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 5372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 6516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 5876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 5778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 5780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 6893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 6894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 6346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 7434);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 6824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 6763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 6764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 7288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 2178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 2179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 2180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 49590);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 50062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 52221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 50484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 50547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 51867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 51868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 51869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 62483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 62514);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 62597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 62610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 62614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 61372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 60750);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 60817);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 60162);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 60916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 60917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 63299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 64134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 64135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 63901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 63224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 65178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 65249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 65250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 65859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 66799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 66193);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 66847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 66910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 66916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 66917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 66950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 66958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 65665);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 67104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 67870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 69017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 69018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 68103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 68104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 68230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 80, 'mg', 68231);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg', 72216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg', 72217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 70220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 70284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 70285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 70286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 69738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 250, 'mg', 70399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 71047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 71094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 70470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 69866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 160, 'mg', 76431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 73918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 73920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 75158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 73935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 72935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 250, 'mg', 74005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 250, 'mg', 74007);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 74016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 74017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 75299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 76681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 73003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 74181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 75371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 73064);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 75534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 74414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 74415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 73187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 250, 'mg', 74549);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 250, 'mg', 74550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 75828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 75829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 75894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 75895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 75896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 75929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 75930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 75939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 73359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 76086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 76087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 76130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 76137);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 76138);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 76167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 76168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 76170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 76171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 76172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 73537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 76178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 76185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 76188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 76190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 76189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 76192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 250, 'mg', 76236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 73592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 73655);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 73656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 73677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 73678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 76238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 300, 'mg', 73681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 73702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 73703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 73704);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 73705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325.00, 'mg', 75035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 75038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 250, 'mg', 78062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 77584);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 77593);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 77631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 77849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 77891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 77892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 77787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 77847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 77185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 78348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 250, 'mg', 81657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 250, 'mg', 82152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 79084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 250, 'mg', 79088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 79269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 78913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 79195);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 79278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 81249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 80829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 79146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 79356);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 82241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 81005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 79071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 82084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 250, 'mg', 83056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 160, 'mg', 83258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 83303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 83304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 83344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 83343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg', 84247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg', 84644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / pck', 37051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / pck', 35886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 1000, 'mg / pck', 37105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg / pck', 26397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg / pck', 26396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / pck', 77936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg / pck', 21168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / pck', 10188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 1000, 'mg / pck', 65873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 1000, 'mg / pck', 65633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg / pck', 70790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg / pck', 76387);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / pck', 75146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / pck', 76511);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / pck', 80466);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / pck', 83004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 1, 'g / 30 ml', 37183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 160, 'mg / 5 ml', 30945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 160, 'mg / 5 ml', 26863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 160, 'mg / 5 ml', 19244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / 30 ml', 13960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / 20 ml', 12722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 160, 'mg / 5 ml', 11384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 160, 'mg / 5 ml', 47448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 160, 'mg / 5 ml', 63140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg / 15 ml', 66840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / 30 ml', 66983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / 30 ml', 72095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg / 15 ml', 69814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 160, 'mg / 5 ml', 76432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 160, 'mg / 5 ml', 76469);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg / 5 ml', 76530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 160, 'mg / 5 ml', 26864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / 30 ml', 76233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 80, 'mg / ml', 75558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 1000, 'mg / 30 ml', 75858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 1000, 'mg / 30 ml', 74683);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 1000, 'mg / 30 ml', 74797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / 30 ml', 76164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / 30 ml', 76166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / 30 ml', 76254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg / 15 ml', 73724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 1000, 'mg / 30 ml', 77475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / 30 ml', 77628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 1000, 'mg / 30 ml', 77585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / 30 ml', 77674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 1000, 'mg / 30 ml', 77675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 160, 'mg / 5 ml', 77749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 160, 'mg / 5 ml', 79105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / 30 ml', 78620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / 30 ml', 79002);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 160, 'mg / 5 ml', 79122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 1000, 'mg / 30 ml', 78973);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / 15 ml', 79763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 500, 'mg / 15 ml', 80682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / 22 mg', 62576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg / 22 g', 31530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg / 23 g', 32780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / 23 g', 62330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 650, 'mg / 24 g', 71050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', NULL, 325, 'mg / 22 g', 73067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meglumine ioxitalamate', NULL, 513, 'mg / ml', 17800);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium fluoride', NULL, 0.05, '%', 42480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium fluoride', NULL, 0.05, '%', 42483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium fluoride', NULL, 0.243, '%', 14444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2, '%', 71650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium fluoride', NULL, 0.243, '%', 77106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium fluoride', NULL, 0.243, '% / w/w', 84966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('adapalene', NULL, 0.1, '% / w/w', 85075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 5, 'mg', 15805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 10, 'mg', 5509);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 6.25, 'mg', 69017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 6.25, 'mg', 71047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 6.25, 'mg', 74007);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 6.25, 'mg', 74016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 6.25, 'mg', 74415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 6.25, 'mg', 74550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 6.25, 'mg', 75829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 6.25, 'mg', 75929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 6.25, 'mg', 79269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 6.25, 'mg', 82084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 12.5, 'mg / 30 ml', 37183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 7.5, 'mg / 30 ml', 13960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 1.2, 'mg / ml', 5475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 1.2, 'mg / ml', 4615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 1.2, 'mg / ml', 50030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 6.25, 'mg / 15 ml', 68650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 12.5, 'mg / 30 ml', 75858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 12.5, 'mg / 30 ml', 76254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 12.5, 'mg / 30 ml', 77585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', NULL, 12.5, 'mg / 30 ml', 78973);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 1.05, 'g / 100 ml', 19306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 298, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 600, 'mg / 100 ml', 43947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 298, 'mg / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 298, 'mg / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 245, 'mg / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 298, 'mg / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 298, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 245, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 330, 'mg / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 245, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 298, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 245, 'mg / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 370, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 700, 'mg / 100 ml', 18644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 700, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 490, 'mg / 100 ml', 18608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 527, 'mg / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 595, 'mg / 100 ml', 18607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 600, 'mg / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 0.73, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 1.28, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 1.65, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-aspartic acid', NULL, 1.65, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoin', NULL, 1.8, '%', 13247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoin', NULL, 10, 'g / 100 ml', 41578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinic acid', NULL, 5, 'mg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinic acid', NULL, 500, 'mg', 75581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinic acid', NULL, 1000, 'mg', 75582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 1.02, 'g / 100 ml', 43947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 225, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 500, 'mg / 100 ml', 44068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 250, 'mg / 100 ml', 20278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 212.5, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 795, 'mg / 100 ml', 19306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 250, 'mg / 100 ml', 20302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 212.5, 'mg / 100 ml', 20303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 212.5, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 250, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 250, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 212.5, 'mg / 100 ml', 20289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 125, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 250, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 250, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 250, 'mg / 100 ml', 20279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 225, 'mg / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 225, 'mg / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 185, 'mg / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 225, 'mg / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 225, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 185, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 265, 'mg / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 186, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 225, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 347, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 185, 'mg / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 530, 'mg / 100 ml', 18644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 530, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 371, 'mg / 100 ml', 18608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 450, 'mg / 100 ml', 18607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 495, 'mg / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 500, 'mg / 100 ml', 11329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 370, 'mg / 100 ml', 5890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 370, 'mg / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 420, 'mg / 100 ml', 3468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 300, 'mg / 100 ml', 4560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 210, 'mg / 100 ml', 2776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 400, 'mg / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 1.0, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 1.75, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 2.25, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', NULL, 2.25, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', NULL, 1, '%', 10748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrous oxide', NULL, 50, '%', 18513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrous oxide', NULL, 50, '%', 19102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrous oxide', NULL, 50, '%', 6850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neon', NULL, 0.5, '%', 19100);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neon', NULL, 0.5, '%', 8185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.25, '%', 70253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 50, '%', 19290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 50, '%', 19293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 50, '%', 18513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 21.0, '%', 19100);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 21.0, '%', 19101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 50, '%', 19102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 21.5, '%', 13920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 93, '%', 13910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 19.5, '%', 13885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 24, '%', 13890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 50, '%', 13894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 77, '%', 11059);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 21, '%', 8185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 50, '%', 6850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 20, '%', 5689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 95, '%', 5686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 50, '%', 46353);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 21, '%', 44612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 88, '%', 11058);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', NULL, 50, '%', 11060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('helium', NULL, 50, '%', 19290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('helium', NULL, 10.0, '%', 19101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('helium', NULL, 10.5, '%', 13920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('helium', NULL, 76, '%', 13890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('helium', NULL, 80, '%', 5689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('helium', NULL, 50, '%', 46353);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('helium', NULL, 10, '%', 44612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon dioxide', NULL, 50, '%', 19293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon dioxide', NULL, 7, '%', 13910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon dioxide', NULL, 23, '%', 11059);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon dioxide', NULL, 5, '%', 5686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon dioxide', NULL, 12, '%', 11058);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon dioxide', NULL, 50, '%', 11060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 9, '%', 30927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3.0, '%', 79216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 19037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 75823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7, '%', 50939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 67232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7, '%', 65424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7, '%', 65426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 64887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.5, '%', 66892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5, '%', 68325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2, '%', 68818);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.5, '%', 68355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7, '%', 69420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '%', 68574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '%', 72275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 8, '%', 71649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1, '%', 69552);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 70998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 70999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 70541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3, '%', 72053);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4.0, '%', 76449);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '%', 76450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '%', 75161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3.0, '%', 76518);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '%', 76600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.00, '%', 76603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.00, '%', 76604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4, '%', 75392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '%', 75409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3.5, '%', 75413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3.5, '%', 75414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '%', 74215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '%', 73106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7, '%', 75527);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7, '%', 75528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7, '%', 75557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 8, '%', 75565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1, '%', 75594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '%', 72392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 8.0, '%', 75709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 73166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 74500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1, '%', 74554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7, '%', 75847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '%', 75868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '%', 75869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '%', 74651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '%', 74654);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '%', 74655);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4.0, '%', 75907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 74749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '%', 73436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 76179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.4, '%', 76213);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.4, '%', 76214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '%', 76327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.4, '%', 76328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '%', 72761);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.2, '%', 72762);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '%', 73821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3.0, '%', 77484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3.0, '%', 77485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 8.0, '%', 77488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 9, '%', 78156);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7, '%', 77531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '%', 77533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '%', 77461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 8, '%', 77476);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 77577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 77578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 9.0, '%', 77605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 9.0, '%', 77606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 9, '%', 78218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 78220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 78221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 77122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 77123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '%', 76898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 6.0, '%', 77048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '%', 77517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.00, '%', 77614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '%', 77629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '%', 77608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.5, '%', 78154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.00, '%', 77383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 9.0, '%', 78240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '%', 77299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.4, '%', 78310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.4, '%', 78311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 76910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.0, '%', 78023);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.0, '%', 78024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.7, '%', 76934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '%', 77324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '%', 77326);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.4, '%', 78020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '%', 79960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.8, '%', 79018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 78656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.35, '%', 78690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.35, '%', 78689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '%', 79181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '%', 79182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 6.0, '%', 80443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '%', 78700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4.0, '%', 78701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3.0, '%', 79265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '%', 78989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.35, '%', 79294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '%', 78813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4, '%', 79295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.8, '%', 79719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '%', 80173);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.0, '%', 78621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '%', 78893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '%', 78894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '%', 78895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '%', 79252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '%', 79253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '%', 79255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '%', 79257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 78604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '%', 78605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.79, '%', 78929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.79, '%', 78930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 9.0, '%', 79533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.5, '%', 80565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.00, '%', 79238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.35, '%', 79320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3.55, '%', 79197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2, '%', 78635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '%', 79067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.3, '%', 79226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '%', 80227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '%', 80110);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '%', 80111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 80641);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 6.5, '%', 80828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1, '%', 78647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '%', 82839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2, '%', 82383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '%', 79098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7, '%', 79184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.3, '%', 82622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.3, '%', 80820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 80821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '%', 82313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2, '%', 82530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 84131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '%', 84132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5, '%', 84342);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '%', 84348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.5, '%', 84353);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.7, '%', 84541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.75, '%', 85091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.5, '% / w/w', 48991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.00, '% / w/w', 76605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.25, '% / w/w', 72549);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '% / w/w', 72583);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 8.0, '% / w/w', 75934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 8.0, '% / w/w', 74885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.35, '% / w/w', 76200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.4, '% / w/w', 76215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 12.0, '% / w/w', 74967);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 74968);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 12.0, '% / w/w', 74969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 12.0, '% / w/w', 74970);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 8.0, '% / w/w', 74999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.8, '% / w/w', 76204);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '% / w/w', 72764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 8.0, '% / w/w', 77368);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '% / w/w', 77389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '% / w/w', 77391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 78219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.8, '% / w/w', 76938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '% / w/w', 76863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.35, '% / w/w', 77721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.8, '% / w/w', 76941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.4, '% / w/w', 78222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 9.0, '% / w/w', 80859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4.6, '% / w/w', 81654);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '% / w/w', 81144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.2, '% / w/w', 81175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.35, '% / w/w', 79851);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '% / w/w', 80135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4.5, '% / w/w', 82780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7, '% / w/w', 82843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '% / w/w', 80128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.6, '% / w/w', 80480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.8, '% / w/w', 80566);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.75, '% / w/w', 82206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4.0, '% / w/w', 82242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '% / w/w', 82930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3.5, '% / w/w', 82931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.7, '% / w/w', 82964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.5, '% / w/w', 79731);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.35, '% / w/w', 78685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.35, '% / w/w', 78686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '% / w/w', 79183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.5, '% / w/w', 80487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.5, '% / w/w', 80488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '% / w/w', 80350);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4.00, '% / w/w', 79766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.7, '% / w/w', 80723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.5, '% / w/w', 82834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.7, '% / w/w', 80748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3, '% / w/w', 80791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '% / w/w', 81406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '% / w/w', 82015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 82018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.35, '% / w/w', 82161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.2, '% / w/w', 81716);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 80088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.25, '% / w/w', 79605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 80025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '% / w/w', 80026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '% / w/w', 80027);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.7, '% / w/w', 80174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.7, '% / w/w', 80175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.7, '% / w/w', 80176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '% / w/w', 80435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.8, '% / w/w', 80436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.25, '% / w/w', 80398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.25, '% / w/w', 80400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '% / w/w', 81451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 8.0, '% / w/w', 81454);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '% / w/w', 81366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3.0, '% / w/w', 81367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 81371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.7, '% / w/w', 81370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '% / w/w', 81372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '% / w/w', 81017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4.5, '% / w/w', 81337);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 0.8, '% / w/w', 80050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 0.8, '% / w/w', 80051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '% / w/w', 80052);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.25, '% / w/w', 80055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 0.8, '% / w/w', 80056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5, '% / w/w', 82493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5, '% / w/w', 82494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.7, '% / w/w', 80198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.7, '% / w/w', 80199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.7, '% / w/w', 80200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 8.0, '% / w/w', 81604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.5, '% / w/w', 81708);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.5, '% / w/w', 81709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '% / w/w', 77392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '% / w/w', 77390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2, '% / w/w', 81779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '% / w/w', 81842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.7, '% / w/w', 82013);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.7, '% / w/w', 82014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2, '% / w/w', 82508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 80327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 80328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '% / w/w', 80478);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4.5, '% / w/w', 80568);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4.0, '% / w/w', 79983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3.0, '% / w/w', 80631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.7, '% / w/w', 80810);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 80024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 80022);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 80023);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.6, '% / w/w', 80411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '% / w/w', 81076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.0, '% / w/w', 79524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.25, '% / w/w', 79595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.7, '% / w/w', 80113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '% / w/w', 80577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.7, '% / w/w', 81413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '% / w/w', 81415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4.6, '% / w/w', 81660);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 6.0, '% / w/w', 79618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '% / w/w', 80460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.35, '% / w/w', 80069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 6.0, '% / w/w', 80696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 6, '% / w/w', 81266);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2, '% / w/w', 82515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3.5, '% / w/w', 80393);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 8.0, '% / w/w', 81293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 8.0, '% / w/w', 81892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 8.0, '% / w/w', 81893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 81894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '% / w/w', 82380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.75, '% / w/w', 82381);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '% / w/w', 82415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4.0, '% / w/w', 80362);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '% / w/w', 79484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '% / w/w', 80383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.25, '% / w/w', 80425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '% / w/w', 81911);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 80061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.5, '% / w/w', 80516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.5, '% / w/w', 80517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4.5, '% / w/w', 81043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.8, '% / w/w', 81044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.75, '% / w/w', 82367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '% / w/w', 82017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '% / w/w', 82019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '% / w/w', 82020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.8, '% / w/w', 80669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.8, '% / w/w', 80670);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 81913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.5, '% / w/w', 81914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.25, '% / w/w', 81915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 8.5, '% / w/w', 81916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3.0, '% / w/w', 81921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.75, '% / w/w', 82373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4, '% / w/w', 82462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 80254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.25, '% / w/w', 80256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '% / w/w', 80537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7, '% / w/w', 80539);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.4, '% / w/w', 82060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.4, '% / w/w', 82067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.6, '% / w/w', 80034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.6, '% / w/w', 80035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4.0, '% / w/w', 80177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.25, '% / w/w', 80178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '% / w/w', 81069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.7, '% / w/w', 80302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.7, '% / w/w', 82543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.7, '% / w/w', 78779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.2, '% / w/w', 80864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4, '% / w/w', 79868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.9, '% / w/w', 80380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7, '% / w/w', 80567);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3.0, '% / w/w', 80595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '% / w/w', 79784);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '% / w/w', 81488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.0, '% / w/w', 81490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '% / w/w', 81491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.7, '% / w/w', 83072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '% / w/w', 83098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.35, '% / w/w', 83101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 8.0, '% / w/w', 83168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.25, '% / w/w', 83388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.25, '% / w/w', 83389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '% / w/w', 83391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5, '% / w/w', 83403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.8, '% / w/w', 83420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 6, '% / w/w', 83564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 6.0, '% / w/w', 83580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 6, '% / w/w', 83581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '% / w/w', 83677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5, '% / w/w', 83772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 6, '% / w/w', 83773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 6, '% / w/w', 83775);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4.00, '% / w/w', 83859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4, '% / w/w', 83866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.8, '% / w/w', 83869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.0, '% / w/w', 83877);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '% / w/w', 83881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 9.0, '% / w/w', 83983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 9.0, '% / w/w', 83984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 84003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 8.0, '% / w/w', 84004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 84006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '% / w/w', 84032);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '% / w/w', 84033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.80, '% / w/w', 84034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.50, '% / w/w', 84035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '% / w/w', 84036);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 84041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.0, '% / w/w', 84039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.56, '% / w/w', 84042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 1.7, '% / w/w', 84061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '% / w/w', 84076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 84092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '% / w/w', 84118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '% / w/w', 84119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.6, '% / w/w', 84207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5, '% / w/w', 84257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3, '% / w/w', 84262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.75, '% / w/w', 84291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10.0, '% / w/w', 84292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.75, '% / w/w', 84403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '% / w/w', 84415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.75, '% / w/w', 84423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.75, '% / w/w', 84424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.75, '% / w/w', 84431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.75, '% / w/w', 84472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4.0, '% / w/w', 84640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '% / w/w', 84706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '% / w/w', 84707);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.0, '% / w/w', 84715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.00, '% / w/w', 84959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.00, '% / w/w', 84962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.5, '% / w/w', 84975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '% / w/w', 85096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7.5, '% / w/w', 85097);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '% / w/w', 85098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, '% / w/w', 85099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2, '%', 53419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3.5, '%', 53422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 3.5, '%', 53423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4, '%', 53424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 4, '%', 53425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 9, '%', 53426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7, '%', 61380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7, '%', 64737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 7, '%', 64740);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 5.0, '%', 81034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 2.7, '% / 50 ml', 83672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', NULL, 10, 'g / 100 g', 62467);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenoterol hydrobromide', NULL, 0.3125, 'mg / ml', 18210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('egg phospholipids', NULL, 0.9, '%', 8198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('egg phospholipids', NULL, 1.2, '%', 8197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('egg phospholipids', NULL, 1.2, 'g / 100 ml', 43172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('egg phospholipids', NULL, 1.2, 'g / 100 ml', 19284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('egg phospholipids', NULL, 1.2, 'g / 100 ml', 19285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('egg phospholipids', NULL, 1.2, 'g / 100 ml', 18484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('egg phospholipids', NULL, 1.2, 'g / 100 ml', 18647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('egg phospholipids', NULL, 700, 'mg / 100 ml', 47094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('theophylline', NULL, 7, 'mg / ml', 1980);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perindopril erbumine', NULL, 2, 'mg', 70751);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perindopril erbumine', NULL, 4, 'mg', 70752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perindopril erbumine', NULL, 8.0, 'mg', 80705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethylene glycol 400', NULL, 1.0, '%', 73019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethylene glycol 400', NULL, 1.0, '% / w/v', 82979);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethylene glycol 400', NULL, 1.0, '% / v/v', 81391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (lysine acetate)', NULL, 1.575, 'g / 100 ml', 19306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 1.05, 'g / 100 ml', 18644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 1.05, 'g / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine', NULL, 1.1, 'g / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine hydrochloride)', NULL, 145, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 446, 'mg / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 446, 'mg / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 368, 'mg / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 446, 'mg / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (lysine acetate)', NULL, 446, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine hydrochloride)', NULL, 290, 'mg / 100 ml', 19143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 368, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 525, 'mg / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 368, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 446, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 475, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 368, 'mg / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 735, 'mg / 100 ml', 18608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 893, 'mg / 100 ml', 18607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 677, 'mg / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine hydrochloride)', NULL, 580, 'mg / 100 ml', 11329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 624, 'mg / 100 ml', 5890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 720, 'mg / 100 ml', 3468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 510, 'mg / 100 ml', 4560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine hydrochloride)', NULL, 580, 'mg / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine (l-lysine acetate)', NULL, 360, 'mg / 100 ml', 2776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', NULL, 10, '%', 16053);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', NULL, 0.8, '%', 8428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', NULL, 4.5, '%', 8429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamivudine', NULL, 150, 'mg', 62673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', NULL, 0.12, '% / w/w', 71907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', NULL, 1, 'mg / g', 13766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 42161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 330, 'mg', 23669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 330, 'mg', 23671);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 330, 'mg', 23672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 23354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 23355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 22274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 13699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 12946);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 12943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 12944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 14508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 500, 'mg', 11158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 375, 'mg', 11065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 375, 'mg', 5371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 330, 'mg', 6479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 330, 'mg', 6480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 330, 'mg', 6419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 330, 'mg', 5779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 5777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 330, 'mg', 1233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 400, 'mg', 2918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 375, 'mg', 1025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 375, 'mg', 876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 330, 'mg', 872);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 330, 'mg', 873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 330, 'mg', 47953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 330, 'mg', 47954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 330, 'mg', 47955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 330, 'mg', 47956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 500, 'mg', 48421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 48434);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 500, 'mg', 50227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 375, 'mg', 55849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 375, 'mg', 62074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 350, 'mg', 62075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 62101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 61576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 60919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 60918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 500, 'mg', 63223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 25, 'mg', 65795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 330, 'mg', 66118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 500, 'mg', 66818);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 500, 'mg', 66913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 69406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 375, 'mg', 70240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 81, 'mg', 75794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 81, 'mg', 75795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 81, 'mg', 75796);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 500, 'mg', 73680);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 73709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 500, 'mg', 73710);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 375, 'mg', 78862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 81, 'mg', 79926);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 81, 'mg', 79927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 81, 'mg', 79928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg', 81810);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 500, 'mg', 81813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', NULL, 325, 'mg / evt', 42652);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lansoprazole', NULL, 30, 'mg / cap', 61948);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 12.5, 'mg', 47167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 25, 'mg', 37037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 25, 'mg', 19429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 25, 'mg', 696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 25, 'mg', 60817);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 12.5, 'mg', 65665);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 25, 'mg', 69018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 50, 'mg', 72217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 25, 'mg', 76427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 25, 'mg', 74181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 25, 'mg', 73064);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 25, 'mg', 75939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 25, 'mg', 73592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 25, 'mg', 78348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 25, 'mg', 79084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 25, 'mg', 78913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 25, 'mg', 84104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 25, 'mg / pck', 80466);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 12.5, 'mg / 5 ml', 11229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 12.5, 'mg / 5 ml', 6844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 12.5, 'mg / 5 ml', 4469);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 12.5, 'mg / 5 ml', 50217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 12.5, 'mg / 5 ml', 66839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 12.5, 'mg / 5 ml', 67953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 12.5, 'mg / 5 ml', 69689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 6.25, 'mg / 5 ml', 76469);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 6.25, 'mg / 5 ml', 76376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 25, 'mg / 30 ml', 76164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 6.25, 'mg / 5 ml', 79122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', NULL, 6.25, 'mg / 5 ml', 80939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamivudine', NULL, 150, 'mg', 68746);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamivudine', NULL, 300, 'mg', 75473);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 3 saukett', NULL, 32, 'unit / 0.5 ml', 50574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 3 saukett', NULL, 32, 'unit / 0.5 ml', 50651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 3 saukett', NULL, 32, 'unit / 0.5 ml', 50224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 3 saukett', NULL, 32, 'unit / 0.5 ml', 67042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 3 saukett', NULL, 32, 'unit / 0.5 ml', 5907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 2 m.e.f.1', NULL, 8, 'unit / 0.5 ml', 50574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 2 m.e.f.1', NULL, 8, 'unit / 0.5 ml', 50651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 2 m.e.f.1', NULL, 8, 'unit / 0.5 ml', 50224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 2 m.e.f.1', NULL, 8, 'unit / 0.5 ml', 67042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 2 m.e.f.1', NULL, 8, 'unit / 0.5 ml', 5907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 2 m.e.f.1', NULL, 8, 'unit / 0.5 ml', 83726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 1 mahoney', NULL, 40, 'unit / 0.5 ml', 50574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 1 mahoney', NULL, 40, 'unit / 0.5 ml', 50651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 1 mahoney', NULL, 40, 'unit / 0.5 ml', 50224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 1 mahoney', NULL, 40, 'unit / 0.5 ml', 67042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 1 mahoney', NULL, 40, 'unit / 0.5 ml', 5907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('losartan potassium', NULL, 50, 'mg', 48580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('losartan potassium', NULL, 100, 'mg', 64599);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('losartan potassium', NULL, 100, 'mg', 78318);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', NULL, 43, '%', 63342);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', NULL, 9.88, '%', 76990);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', NULL, 49.5, '% / w/w', 72398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol denatured', NULL, 5.0, '% / w/w', 81365);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drospirenone', NULL, 1.0, 'mg', 75422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drospirenone', NULL, 3.0, 'mg', 74710);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drospirenone', NULL, 3.0, 'mg', 74711);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drospirenone', NULL, 3, 'mg', 80656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium sulfate', NULL, 20, 'mg / ml', 36412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium sulfate', NULL, 20, 'mg / 100 ml', 10939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ribavirin', NULL, 200, 'mg / tab', 73839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ribavirin', NULL, 200, 'mg / tab', 73840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ribavirin', NULL, 200, 'mg / cap', 70155);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ribavirin', NULL, 200, 'mg / cap', 70156);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ribavirin', NULL, 200, 'mg / cap', 70157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ribavirin', NULL, 200, 'mg / cap', 70158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ribavirin', NULL, 200, 'mg / cap', 70159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ribavirin', NULL, 200, 'mg / cap', 73948);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ribavirin', NULL, 200, 'mg / cap', 73950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ribavirin', NULL, 200, 'mg / cap', 73951);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ribavirin', NULL, 200, 'mg / cap', 73952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ribavirin', NULL, 200, 'mg / cap', 85660);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ribavirin', NULL, 200, 'mg / cap', 85661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ribavirin', NULL, 200, 'mg / cap', 85662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ribavirin', NULL, 200, 'mg / cap', 85663);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetrimide', NULL, 0.15, '%', 14489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetrimide', NULL, 150, 'mg / 100 g', 37164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan (dextromethorphan hydrobromide)', NULL, 7.5, 'mg / 5 ml', 10675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 200, 'mg', 5151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', NULL, 6.6, '%', 42159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', NULL, 8, '%', 60920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', NULL, 8, '%', 68743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', NULL, 8.0, '%', 74215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', NULL, 8, '%', 73489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', NULL, 8.0, '%', 78311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', NULL, 6.0, '%', 78019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', NULL, 7.0, '%', 78020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', NULL, 1.4, '% / w/w', 66357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', NULL, 6.6, '% / w/w', 79439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', NULL, 6.6, '% / w/w', 81016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', NULL, 6.6, '% / w/w', 79646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', NULL, 6.6, '% / w/w', 83906);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', NULL, 6.6, '%', 42334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', NULL, 7, '%', 16893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', NULL, 8, '%', 16896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('charcoal activated', NULL, 140, 'mg', 11341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coagulation factor ix (human)', NULL, 620, 'unit', 84428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coagulation factor ix (human)', NULL, 620, 'unit / vial', 78001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2, '%', 41935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', NULL, 0.3, '%', 73758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('anti-inhibitor coagulant complex', NULL, 1200, 'unit / vial', 42981);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('anti-inhibitor coagulant complex', NULL, 3250, 'unit / vial', 83912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ritonavir', NULL, 50, 'mg', 77104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ritonavir', NULL, 25, 'mg', 79781);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ritonavir', NULL, 20, 'mg / ml', 67570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertactin', NULL, 3, 'µg / 0.5 ml', 43396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertactin', NULL, 3, 'µg / 0.5 ml', 50651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertactin', NULL, 3, 'µg / 0.5 ml', 50224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertactin', NULL, 3, 'µg / 0.5 ml', 63789);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertactin', NULL, 3, 'µg / 0.5 ml', 67042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertactin', NULL, 2.5, 'µg / 0.5 ml', 71860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertactin', NULL, 8, 'µg / 0.5 ml', 73878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertactin', NULL, 3, 'µg / 0.5 ml', 83726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fimbriae', NULL, 5, 'µg / 0.5 ml', 43396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fimbriae', NULL, 5, 'µg / 0.5 ml', 50651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fimbriae', NULL, 5, 'µg / 0.5 ml', 50224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fimbriae', NULL, 5, 'µg / 0.5 ml', 67042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('filamentous haemagglutinin', NULL, 20, 'µg / 0.5 ml', 43396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('filamentous haemagglutinin', NULL, 20, 'µg / 0.5 ml', 50651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('filamentous haemagglutinin', NULL, 20, 'µg / 0.5 ml', 50224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('filamentous haemagglutinin', NULL, 5, 'µg / 0.5 ml', 63789);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('filamentous haemagglutinin', NULL, 20, 'µg / 0.5 ml', 67042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('filamentous haemagglutinin', NULL, 8, 'µg / 0.5 ml', 71860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('filamentous haemagglutinin', NULL, 25, 'µg / 0.5 ml', 73878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('filamentous haemagglutinin', NULL, 5, 'µg / 0.5 ml', 83726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertussis toxoid', NULL, 20, 'µg / 0.5 ml', 43396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertussis toxoid', NULL, 20, 'µg / 0.5 ml', 50651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertussis toxoid', NULL, 20, 'µg / 0.5 ml', 50224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertussis toxoid', NULL, 2.5, 'µg / 0.5 ml', 63789);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertussis toxoid', NULL, 20, 'µg / 0.5 ml', 67042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertussis toxoid', NULL, 8, 'µg / 0.5 ml', 71860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertussis toxoid', NULL, 25, 'µg / 0.5 ml', 73878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertussis toxoid', NULL, 2.5, 'µg / 0.5 ml', 83726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.2, '%', 42310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '%', 42159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 79255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.5, '%', 42607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 37913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.5, '%', 32792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '%', 33490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 30927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2, '%', 19330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 18691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 15869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.5, '%', 47540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 48123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 50605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 50939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 53823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 60497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 61295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 61296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 60890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.5, '%', 60920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 60325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 62463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.7, '%', 63261);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 63263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.8, '%', 63264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 64081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '%', 63342);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 63348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 63350);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 64701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 64702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.5, '%', 64150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 64225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 64289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.9, '%', 63102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 65907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 65423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 65427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.25, '%', 66706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 66828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.5, '%', 66892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 66974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 68325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 68818);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 68850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 69344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.5, '%', 68355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 69420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 67949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '%', 67987);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 68570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 68574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 68594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.5, '%', 68186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 68743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '%', 67743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 71383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 71382);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 71384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 71386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 72270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 72271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 72275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 70085);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 70087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2, '%', 70111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 71534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2, '%', 70856);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 71649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 70878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2, '%', 70879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 70880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 70881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 70903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '%', 70904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 71650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2, '%', 70261);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 69791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 69886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 1.25, '%', 71277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 0.4, '%', 72068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 76449);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 76450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 76470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 73900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 75172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 76518);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 75229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 76634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 74004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 75350);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 76711);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '%', 74176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2, '%', 75392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 75409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 75413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 75414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 75777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 76744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 73042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 73044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 74215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 74244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 75450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.25, '%', 75512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 72336);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 72339);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 73106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 74271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.7, '%', 74321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 75531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 75596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 72406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 75641);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 75676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 75677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2, '%', 75697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 73166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 74441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 75752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 75755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 75756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 75768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 72581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 72582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 74564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 75847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 74630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 74651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 74654);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 74655);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 75989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.50, '%', 73308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 73323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 74735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 73436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 76146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 73489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 74916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 76213);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 76214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 73607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.4, '%', 73657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 74918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 73755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 73756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 74998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2, '%', 76206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 76325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 76328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 1.75, '%', 76349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 72761);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 0.9, '%', 72762);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 78108);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 78385);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2, '%', 78402);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 77441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 77461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 77512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 77550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 77551);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 77577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 77578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 77612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 77613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 77374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 77083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 77439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 77517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 77611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.00, '%', 77614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 77630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 77608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 76890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 77681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 77682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 77883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 78157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 77299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 78301);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.5, '%', 78304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 78317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 77927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 77928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 77581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 78023);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 78024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 76934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.5, '%', 77321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 77322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 77323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 77324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.5, '%', 77325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 77326);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.10, '%', 78047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 77513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 77515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 77617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 77618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 79423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 79215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 82245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 79960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 79018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.00, '%', 78689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.00, '%', 78690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.5, '%', 79082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 79181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 79182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 80443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 78611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 78700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 78701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 79256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 79262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 79263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '%', 79420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 78709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '%', 79271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 79294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 79798);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '%', 79415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.5, '%', 79416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '%', 79417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 79719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 79407);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 81450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 79252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 79253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 79257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.00, '%', 78929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.00, '%', 78930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 80565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.00, '%', 79238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 79319);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 79320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 79321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 79322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 79931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 79197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 78629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 78635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 79982);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 79226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 79228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 79232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 79233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 79992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 80227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 80110);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 80111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 79026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.4, '%', 79168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '%', 82839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 82382);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 79421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 79090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 79092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 79185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 79086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 78589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '%', 79251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 82461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '%', 80800);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '%', 80457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '%', 82313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 82530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 83915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 83916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 84120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2, '%', 84130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 84131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 84133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 84342);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 84347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 84348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 84353);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '%', 84379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '%', 84553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.5, '%', 84603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '%', 84818);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 1.0, '%', 84903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 85091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 16229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 15968);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.5, '% / w/w', 48991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '% / w/w', 50232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '% / w/w', 60006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.00, '% / w/w', 65475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 65639);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 67685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 70086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.5, '% / w/w', 70588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.25, '% / w/w', 75370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 75634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 72583);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 75934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 74849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 74883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 74884);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 74885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 76200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 76215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 1.0, '% / w/w', 74967);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 74968);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 74969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 1.0, '% / w/w', 74970);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 74999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 76204);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 76351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.5, '% / w/w', 77368);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.00, '% / w/w', 78398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.00, '% / w/w', 78399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 77463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 77389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 77390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 77391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 77392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 77473);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 78219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2, '% / w/w', 77288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 76938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 76894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 76863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 77470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 76891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '% / w/w', 76892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 77633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 77721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 76941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 78297);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 77340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 77341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '% / w/w', 79439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.2, '% / w/w', 79440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 80859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.00, '% / w/w', 81656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 81144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 81175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 81252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2, '% / w/w', 82350);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 79851);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 80135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 81909);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 79849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 79850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 81268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 82780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '% / w/w', 82843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 79579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 79748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 80566);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 82206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 82210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 80985);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 82242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 79731);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.00, '% / w/w', 78685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.00, '% / w/w', 78686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 79183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 80487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 80488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 80350);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.00, '% / w/w', 79766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 80527);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 80531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '% / w/w', 82834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 81406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 82015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 82016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 82018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 82161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '% / w/w', 82592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 81707);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 81716);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 79460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 80088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '% / w/w', 82602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 80025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 80026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 80027);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 80175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 80176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '% / w/w', 80436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.5, '% / w/w', 81454);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 81366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 81367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 81371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 81370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 81372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '% / w/w', 81016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 81017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 81337);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 80049);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 80050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 80051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 80052);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 80055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 80056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 82493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 82494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '% / w/w', 80198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '% / w/w', 80199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.5, '% / w/w', 81604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 81605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '% / w/w', 81708);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '% / w/w', 81709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.4, '% / w/w', 81557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 81842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '% / w/w', 82013);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 82508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 82617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 80327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 80328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 80478);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 80568);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 79983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 80631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '% / w/w', 80810);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 80023);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 80024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 80022);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 81076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '% / w/w', 79645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '% / w/w', 79646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.2, '% / w/w', 79647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '% / w/w', 79648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 79989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '% / w/w', 80228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 80580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 81301);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 81413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 1.5, '% / w/w', 81415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 79618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.5, '% / w/w', 79620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 80460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 80069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 81266);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.4, '% / w/w', 79169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 82515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 81635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 81926);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 81928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 81929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 81930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.5, '% / w/w', 81892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.5, '% / w/w', 81893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 81894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 82380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '% / w/w', 82381);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 80362);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 79484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 80392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.2, '% / w/w', 81911);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 80061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 80515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 80516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 80517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 80525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 80524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 80526);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 81043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 81044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 82368);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 82372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 79871);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 82017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 82019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 82020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 80671);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 81912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 81913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 81914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.5, '% / w/w', 81915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 81916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 81919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 81920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 81921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 82621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 80504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 80503);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '% / w/w', 83050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 79249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '% / w/w', 80707);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 82373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '% / w/w', 82462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 80254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 80256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 80537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '% / w/w', 80539);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.00, '% / w/w', 81639);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '% / w/w', 82063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 82065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 81069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 80099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 80302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 78779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 80864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 80865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 80879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '% / w/w', 82484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 83001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '% / w/w', 79868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 80380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 80595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 81287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 82779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 79540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '% / w/w', 81488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 0.5, '% / w/w', 81490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 1.5, '% / w/w', 81491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '% / w/w', 83072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 83101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '% / w/w', 83278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 83388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 83389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 83391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 83403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 83420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 83564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 83580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 83581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '% / w/w', 83772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '% / w/w', 83773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '% / w/w', 83775);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.00, '% / w/w', 83859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '% / w/w', 83866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 83869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 83903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '% / w/w', 83906);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 83908);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 1.40, '% / w/w', 83964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.4, '% / w/w', 83983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.4, '% / w/w', 83984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 84003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 84004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 84006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.00, '% / w/w', 84034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.75, '% / w/w', 84035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 1.5, '% / w/w', 84039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 84041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.75, '% / w/w', 84042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 1.40, '% / w/w', 84055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '% / w/w', 84061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '% / w/w', 84076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 84092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 84209);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '% / w/w', 84257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '% / w/w', 84262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 84291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 84292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.5, '% / w/w', 84399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.0, '% / w/w', 84403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.0, '% / w/w', 84415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 84424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.0, '% / w/w', 84431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '% / w/w', 84465);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '% / w/w', 84503);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 84574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 84576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 84579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5.0, '% / w/w', 84580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 1.0, '% / w/w', 84664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.0, '% / w/w', 84706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3.5, '% / w/w', 84886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.00, '% / w/w', 84959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6.00, '% / w/w', 84962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 42332);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 42329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 18554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 16893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.5, '%', 16896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.5, '%', 50132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 1.5, '%', 53416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 53417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 53421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 53422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 53423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 53424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 53425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 53426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, '%', 61886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 61896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 1, '%', 60506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4.5, '%', 60302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 60326);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 60327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 60328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 63346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 4, '%', 63347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 63349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 5, '%', 63351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2, '%', 64334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 64738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 6, '%', 64739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2.5, '%', 65601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 2, 'g / 100 g', 61299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', NULL, 3, 'g / 100 g', 71227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, '%', 21688);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 20, 'g / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 36794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 36795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 23494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 21767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 21764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 21753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 21754);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 21755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 2.5, 'g / 100 ml', 21756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 21752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 21713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 21715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 21998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 20, 'g / 100 ml', 20279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 16.6, 'g / 100 ml', 20278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 10, 'g / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 10, 'g / 100 ml', 19610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 25, 'g / 100 ml', 20303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 10, 'g / 100 ml', 20302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 25, 'g / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 10, 'g / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 10, 'g / 100 ml', 20289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 16.6, 'g / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 10, 'g / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 25, 'g / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 20, 'g / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 20, 'g / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 25, 'g / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 10, 'g / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 25, 'g / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 16.6, 'g / 100 ml', 19143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 25, 'g / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 25, 'g / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 10, 'g / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 18991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 25, 'g / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 20, 'g / 100 ml', 18550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 20, 'g / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 16794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 4.25, 'g / 100 ml', 15772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 1.5, 'g / 100 ml', 15778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 1.5, 'g / 100 ml', 15768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 2.5, 'g / 100 ml', 15769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 2.5, 'g / 100 ml', 15763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 4.25, 'g / 100 ml', 15764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 13033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 3.3, 'g / 100 ml', 13034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 14077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 16.6, 'g / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 10, 'g / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 10, 'g / 100 ml', 14073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 25, 'g / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 25, 'g / 100 ml', 14071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 10, 'g / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 25, 'g / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 25, 'g / 100 ml', 14067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 14578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50, 'mg / ml', 6769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 10, 'g / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 14250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 3.3, 'g / 100 ml', 10515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 10, 'g / 100 ml', 10441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 11038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 3.3, 'g / 100 ml', 12711);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10937);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10932);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 10, 'g / 100 ml', 12787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 2.5, 'g / 100 ml', 10925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10926);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 2.5, 'g / 100 ml', 10861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 10045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50, 'g / 100 ml', 3820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 3.3, 'g / 100 ml', 3132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 3.3, 'g / 100 ml', 3133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 1673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5, 'g / 100 ml', 1623);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5.0, 'g / 100 ml', 78452);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 5.0, 'g / 100 ml', 78453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50, 'mg / ml', 36412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50, 'mg / ml', 13288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 250, 'mg / ml', 14183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50, 'mg / ml', 11624);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50, 'mg / ml', 11625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50, 'mg / ml', 12256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 200, 'mg / 100 ml', 12171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50, 'mg / ml', 12681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50, 'mg / ml', 6400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50, 'mg / ml', 6768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50.0, 'mg / ml', 6228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50.0, 'mg / ml', 3534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50.0, 'mg / ml', 3535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50.0, 'mg / ml', 3536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 33.3, 'mg / ml', 3537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 33.3, 'mg / ml', 3538);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 33.3, 'mg / ml', 2575);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50, 'mg / ml', 1750);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50, 'mg / ml', 1751);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50, 'mg / ml', 1739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50, 'mg / ml', 1744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50, 'mg / ml', 1747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50.0, 'mg / ml', 1749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50, 'mg / ml', 1732);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 50, 'mg / ml', 1737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 25, 'mg / ml', 1548);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 16.5, 'g / l', 74647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 46.75, 'g / l', 74648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 25.0, 'g / l', 74649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 82.50, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 154, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 121, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', NULL, 121, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 0.74, 'g / pck', 33649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 3.05, 'g / pck', 9351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 0.76, 'g / pck', 81164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 1.015, 'g / pck', 84451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 2.46, 'g / 25 ml', 23184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 0.15, 'g / 100 ml', 78450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 7.46, 'g / 100 ml', 9833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 0.3, 'g / 100 ml', 78451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 0.15, 'g / 100 ml', 78452);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 0.3, 'g / 100 ml', 78453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 22, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 300, 'mg / 100 ml', 23494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 150, 'mg / 100 ml', 21767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 120, 'mg / 100 ml', 21764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 150, 'mg / 100 ml', 21753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 150, 'mg / 100 ml', 21754);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 150, 'mg / 100 ml', 21755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 15, 'mg / 100 ml', 21756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 37, 'mg / 100 ml', 21757);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 300, 'mg / 100 ml', 21752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 150, 'mg / 100 ml', 21713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 30, 'mg / 100 ml', 21999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 37, 'mg / 100 ml', 21998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 22, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 22, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 97, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 97, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 150, 'mg / 100 ml', 18991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 45, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 0.75, 'mg / ml', 18029);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 150, 'mg / 100 ml', 13034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 97, 'mg / 100 ml', 14578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 30, 'mg / 100 ml', 14250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 179, 'mg / 100 ml', 10936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 328, 'mg / 100 ml', 10937);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 75, 'mg / 100 ml', 10938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 40, 'mg / 100 ml', 10939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 75, 'mg / 100 ml', 10929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 224, 'mg / 100 ml', 10930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 300, 'mg / 100 ml', 10931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 150, 'mg / 100 ml', 10932);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 224, 'mg / 100 ml', 10933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 37, 'mg / 100 ml', 12741);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 30, 'mg / 100 ml', 12186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 300, 'mg / 100 ml', 10934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 224, 'mg / 100 ml', 10935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 75, 'mg / 100 ml', 10927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 224, 'mg / 100 ml', 10928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 150, 'mg / 100 ml', 10866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 300, 'mg / 100 ml', 10867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 30, 'mg / 100 ml', 10862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 30, 'mg / 100 ml', 9830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 150, 'mg / 100 ml', 9826);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 300, 'mg / 100 ml', 9827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 0.75, 'mg / ml', 8169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 30, 'mg / 100 ml', 8601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 150, 'mg / 100 ml', 10041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 300, 'mg / 100 ml', 10042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 150, 'mg / 100 ml', 10043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 150, 'mg / 100 ml', 10044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 300, 'mg / 100 ml', 10045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 1.193, 'mg / ml', 5950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 3, 'mg / ml', 6400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 0.75, 'mg / ml', 6360);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 3.0, 'mg / ml', 6228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 74.55, 'mg / ml', 5535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 239, 'mg / 100 ml', 3820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 150, 'mg / 100 ml', 3132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 300, 'mg / 100 ml', 3133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 1.49, 'mg / ml', 3534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 1.49, 'mg / ml', 3535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 1.49, 'mg / ml', 3536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 2.98, 'mg / ml', 3537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 1.49, 'mg / ml', 3538);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 0.3, 'mg / ml', 1749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 0.37, 'mg / ml', 1738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 0.3, 'mg / ml', 1745);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 0.37, 'mg / ml', 1737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 30, 'mg / 100 ml', 1673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 37, 'mg / 100 ml', 1623);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 30, 'mg / 100 ml', 1628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 37, 'mg / 100 ml', 1622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 0.3, 'mg / ml', 745);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 179, 'mg / 100 ml', 67329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 328, 'mg / 100 ml', 70277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 150, 'mg / 100 ml', 75479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 37, 'mg / 100 ml', 82495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 2.97, 'g / 4 l', 6370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 1.19, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 2.24, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 2.24, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 760, 'mg / l', 9631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', NULL, 10.65, 'mg / g', 6616);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 0.9, '%', 21686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 0.9, '%', 14249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 0.9, '%', 1743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 0.9, '% / vial', 19030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 0.9, '% / vial', 16878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 1.46, 'g / pck', 33649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 5.85, 'g / pck', 9351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 1.46, 'g / pck', 81164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 2.691, 'g / pck', 84451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 0.9, 'g / 100 ml', 78450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 1.17, 'g / 20 ml', 21691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 7.31, 'g / 100 ml', 9833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 0.9, 'g / 100 ml', 78451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 0.9, 'g / 100 ml', 78452);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 0.9, 'g / 100 ml', 78453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 205, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 91, 'mg / 100 ml', 21767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 88, 'mg / 100 ml', 21764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 200, 'mg / 100 ml', 21753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 330, 'mg / 100 ml', 21754);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 900, 'mg / 100 ml', 21755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 300, 'mg / 100 ml', 21756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 530, 'mg / 100 ml', 21757);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 450, 'mg / 100 ml', 21752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 200, 'mg / 100 ml', 21715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 860, 'mg / 100 ml', 21999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 900, 'mg / 100 ml', 21993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 530, 'mg / 100 ml', 21998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 77, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 77, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 58.5, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 58.5, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 29.3, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 58.5, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 58.5, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 205, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 205, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 120, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 120, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 450, 'mg / 100 ml', 18991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 410, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 6.4, 'mg / ml', 18029);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 9, 'mg / ml', 17227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 58.5, 'mg / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 538, 'mg / 100 ml', 15772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 567, 'mg / 100 ml', 15778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 538, 'mg / 100 ml', 15769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 538, 'mg / 100 ml', 15768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 567, 'mg / 100 ml', 15763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 567, 'mg / 100 ml', 15764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 450, 'mg / 100 ml', 13033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 300, 'mg / 100 ml', 13034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 58.5, 'mg / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 58.5, 'mg / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 77, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 29.3, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 58.5, 'mg / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 77, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 140, 'mg / 100 ml', 14578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 9, 'mg / ml', 13288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 600, 'mg / 100 ml', 14250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 100, 'mg / ml', 14183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 9, 'mg / ml', 10521);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 300, 'mg / 100 ml', 10515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 200, 'mg / 100 ml', 10438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 450, 'mg / 100 ml', 10439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 900, 'mg / 100 ml', 10440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 900, 'mg / 100 ml', 10441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 234, 'mg / 100 ml', 11038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 300, 'mg / 100 ml', 12711);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 600, 'mg / 100 ml', 10936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 600, 'mg / 100 ml', 10937);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 450, 'mg / 100 ml', 10938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 800, 'mg / 100 ml', 10939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 200, 'mg / 100 ml', 10929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 200, 'mg / 100 ml', 10930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 200, 'mg / 100 ml', 10931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 330, 'mg / 100 ml', 10932);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 330, 'mg / 100 ml', 10933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 900, 'mg / 100 ml', 12787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 530, 'mg / 100 ml', 12741);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 600, 'mg / 100 ml', 12186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 900, 'mg / 100 ml', 12171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 330, 'mg / 100 ml', 10934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 450, 'mg / 100 ml', 10935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 450, 'mg / 100 ml', 10925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 330, 'mg / 100 ml', 10926);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 900, 'mg / 100 ml', 10866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 900, 'mg / 100 ml', 10867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 300, 'mg / 100 ml', 10861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 860, 'mg / 100 ml', 10862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 600, 'mg / 100 ml', 9830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 900, 'mg / 100 ml', 9826);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 900, 'mg / 100 ml', 9827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 6.4, 'mg / ml', 8169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 600, 'mg / 100 ml', 8601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 200, 'mg / 100 ml', 10043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 450, 'mg / 100 ml', 10044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 450, 'mg / 100 ml', 10045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 6.43, 'mg / ml', 5950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 410, 'mg / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 6.4, 'mg / ml', 6360);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 4.5, 'mg / ml', 6228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 16.05, 'mg / ml', 5535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 374, 'mg / 100 ml', 3820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 300, 'mg / 100 ml', 3132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 300, 'mg / 100 ml', 3133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 4.5, 'mg / ml', 3534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 2.25, 'mg / ml', 3535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 3.00, 'mg / ml', 3537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 3.0, 'mg / ml', 3538);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 3.0, 'mg / ml', 2575);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 117, 'mg / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 4.5, 'mg / ml', 1750);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 2.25, 'mg / ml', 1751);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 2.34, 'mg / ml', 1739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 6, 'mg / ml', 1745);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 9, 'mg / ml', 1747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 6.0, 'mg / ml', 1749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 9, 'mg / ml', 1733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 5.26, 'mg / ml', 1737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 5.26, 'mg / ml', 1738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 600, 'mg / 100 ml', 1673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 600, 'mg / 100 ml', 1628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 526, 'mg / 100 ml', 1622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 526, 'mg / 100 ml', 1623);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 3, 'mg / ml', 1548);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 8.6, 'mg / ml', 745);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 600, 'mg / 100 ml', 67329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 600, 'mg / 100 ml', 70277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 450, 'mg / 100 ml', 75479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 526, 'mg / 100 ml', 82495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 1.46, 'g / l', 9631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 5.86, 'g / 4 l', 6370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 5.4, 'g / l', 64397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 5.640, 'g / l', 74647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 5.640, 'g / l', 74648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 5.640, 'g / l', 74649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', NULL, 20.87, 'mg / g', 6616);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfur', NULL, 5, '%', 37254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfur', NULL, 3, '%', 5634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfur', NULL, 3, '%', 5635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfur', NULL, 50, 'mg / ml', 1394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfur', NULL, 50, 'mg / ml', 1527);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rosiglitazone (rosiglitazone maleate)', NULL, 1, 'mg', 71322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rosiglitazone (rosiglitazone maleate)', NULL, 2, 'mg', 71323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rosiglitazone (rosiglitazone maleate)', NULL, 4, 'mg', 71324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rosiglitazone (rosiglitazone maleate)', NULL, 2.00, 'mg', 72791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rosiglitazone (rosiglitazone maleate)', NULL, 4.00, 'mg', 72792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliovirus type i', NULL, 40, 'unit / 0.5 ml', 73878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliovirus type i', NULL, 40, 'd / 0.5 ml', 79806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliovirus type ii', NULL, 8, 'unit / 0.5 ml', 73878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliovirus type ii', NULL, 8, 'd / 0.5 ml', 79806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliovirus type iii', NULL, 32, 'unit / 0.5 ml', 73878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliovirus type iii', NULL, 32, 'd / 0.5 ml', 79806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', NULL, 4, '%', 13289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', NULL, 4, '%', 13290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', NULL, 70, '%', 12861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', NULL, 70, '%', 65180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', NULL, 70, '%', 71947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', NULL, 70, '%', 73640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', NULL, 70, '%', 78280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', NULL, 70, '% / v/v', 63898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', NULL, 70, '% / v/v', 34222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', NULL, 70, '%', 30398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', NULL, 70, '%', 19626);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', NULL, 70, '%', 16494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', NULL, 70.0, '%', 64263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', NULL, 70, '%', 66842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', NULL, 70, '%', 66843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium carbonate', NULL, 52.3, 'mg', 48421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium carbonate', NULL, 34, 'mg', 48434);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', NULL, 64.5, '%', 5569);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', NULL, 0.25, 'ml / ml', 1281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', NULL, 1.6, 'ml / 5 ml', 60965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrogen', NULL, 78.2, '%', 19100);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrogen', NULL, 68.7, '%', 19101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrogen', NULL, 67.7, '%', 13920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrogen', NULL, 50, '%', 13894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrogen', NULL, 80.5, '%', 13885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrogen', NULL, 78.2, '%', 8185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrogen', NULL, 68.9, '%', 44612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dichlorobenzyl alcohol', NULL, 1.2, 'mg', 61969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dichlorobenzyl alcohol', NULL, 1.2, 'mg', 59951);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dichlorobenzyl alcohol', NULL, 1.2, 'mg', 81250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dichlorobenzyl alcohol', NULL, 1.2, 'mg', 80640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium citrate', NULL, 90, 'mg / ml', 18290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium citrate', NULL, 1.7, 'mg / ml', 18029);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium citrate', NULL, 1.49, 'mg / ml', 8169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium citrate', NULL, 40, 'mg / ml', 5475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium citrate', NULL, 1.7, 'mg / ml', 6360);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium citrate', NULL, 40, 'mg / ml', 4615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium citrate', NULL, 40, 'mg / ml', 50030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('soybean oil', NULL, 5, '%', 8198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('soybean oil', NULL, 10, '%', 8197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('soybean oil', NULL, 5.0, 'g / 100 ml', 47094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('soybean oil', NULL, 30, 'g / 100 ml', 43172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('soybean oil', NULL, 10, 'g / 100 ml', 19284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('soybean oil', NULL, 20, 'g / 100 ml', 19285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('soybean oil', NULL, 10, 'g / 100 ml', 18484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('soybean oil', NULL, 20, 'g / 100 ml', 18647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('soybean oil', NULL, 6, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('soybean oil', NULL, 8, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('soybean oil', NULL, 8, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('soybean oil', NULL, 8, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyl salicylate', NULL, 2.5, 'ml / 100 ml', 1291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('povidone', NULL, 1.0, '%', 73019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('povidone', NULL, 0.6, '%', 78699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('povidone', NULL, 1.0, '% / w/v', 81391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('povidone', NULL, 1.0, '% / w/v', 82979);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aluminum chlorohydrate', NULL, 100, 'mg / ml', 1394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aluminum chlorohydrate', NULL, 100, 'mg / ml', 1527);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 1.19, 'g / 100 ml', 44068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 2.06, 'g / 100 ml', 43947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 1.04, 'g / 100 ml', 19610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 1.04, 'g / 100 ml', 18550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 1.04, 'g / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 1.04, 'g / 100 ml', 14077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 1.04, 'g / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 1.04, 'g / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 1.04, 'g / 100 ml', 14067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 1.04, 'g / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 1.03, 'g / 100 ml', 11329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 1.1, 'g / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 1.1, 'g / 100 ml', 5890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 2.08, 'g / 100 ml', 4661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 1.28, 'g / 100 ml', 3468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 2.08, 'g / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 212, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 515, 'mg / 100 ml', 20278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 438, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 750, 'mg / 100 ml', 19306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 515, 'mg / 100 ml', 20302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 438, 'mg / 100 ml', 20303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 438, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 515, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 515, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 438, 'mg / 100 ml', 20289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 260, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 515, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 515, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 515, 'mg / 100 ml', 20279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 212, 'mg / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 212, 'mg / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 175, 'mg / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 212, 'mg / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 1040, 'mg / 100 ml', 19143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 212, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 175, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 250, 'mg / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 175, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 212, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 270, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 175, 'mg / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 500, 'mg / 100 ml', 18644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 500, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 425, 'mg / 100 ml', 18607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 350, 'mg / 100 ml', 18608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 385, 'mg / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 880, 'mg / 100 ml', 14073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 880, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 880, 'mg / 100 ml', 14071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 520, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 880, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 900, 'mg / 100 ml', 4560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 640, 'mg / 100 ml', 2776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 400, 'mg / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 1.76, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 3.07, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 3.95, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', NULL, 3.95, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium phosphate dibasic', NULL, 12, 'mg / 100 ml', 21757);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium phosphate dibasic', NULL, 430, 'mg / 100 ml', 21993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium phosphate dibasic', NULL, 49, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium phosphate dibasic', NULL, 49, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium phosphate dibasic', NULL, 410, 'mg / 100 ml', 16794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium phosphate dibasic', NULL, 268, 'mg / ml', 11258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 255, 'mg / 100 ml', 18607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium phosphate dibasic', NULL, 8.75, 'mg / 100 ml', 10939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium phosphate dibasic', NULL, 35.69575, 'kg / 576 l', 1958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium phosphate monobasic', NULL, 276, 'mg / ml', 11258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium ascorbate', NULL, 5.900, 'g / pck', 84451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyvinyl alcohol', NULL, 1.4, '%', 17733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyvinyl alcohol', NULL, 0.5, '%', 78699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aluminum hydroxide', NULL, 200, 'mg / 5 ml', 44552);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aluminum hydroxide', NULL, 228, 'mg / 5 ml', 26833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aluminum hydroxide', NULL, 300, 'mg / 5 ml', 18186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aluminum hydroxide', NULL, 200, 'mg / 5 ml', 13074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aluminum hydroxide', NULL, 200, 'mg / 5 ml', 10217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aluminum hydroxide (dried aluminum hydroxide gel)', NULL, 165, 'mg / 5 ml', 187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aluminum hydroxide', NULL, 200, 'mg / 5 ml', 68677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aluminum hydroxide', NULL, 400, 'mg / 5 ml', 68678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aluminum hydroxide', NULL, 400, 'mg / 5 ml', 74304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aluminum hydroxide', NULL, 200, 'mg / 5 ml', 74696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 1.18, 'g / 100 ml', 43947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 128, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 240, 'mg / 100 ml', 44068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 240, 'mg / 100 ml', 20278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 240, 'mg / 100 ml', 20279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 204, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 450, 'mg / 100 ml', 19306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 220, 'mg / 100 ml', 19610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 204, 'mg / 100 ml', 20303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 240, 'mg / 100 ml', 20302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 204, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 240, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 240, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 204, 'mg / 100 ml', 20289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 120, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 240, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 240, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 128, 'mg / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 128, 'mg / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 128, 'mg / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 105, 'mg / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 220, 'mg / 100 ml', 19143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 128, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 105, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 150, 'mg / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 105, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('starch', 'D02AC', 49.95, '%', 60869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 128, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 220, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 105, 'mg / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 300, 'mg / 100 ml', 18644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 300, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 210, 'mg / 100 ml', 18608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 312, 'mg / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 220, 'mg / 100 ml', 18550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 220, 'mg / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 250, 'mg / 100 ml', 15493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 220, 'mg / 100 ml', 14077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 220, 'mg / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 220, 'mg / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 186, 'mg / 100 ml', 14073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 186, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 186, 'mg / 100 ml', 14071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 110, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 220, 'mg / 100 ml', 14067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 220, 'mg / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 186, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 480, 'mg / 100 ml', 11329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 429, 'mg / 100 ml', 7163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 260, 'mg / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 260, 'mg / 100 ml', 5890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 440, 'mg / 100 ml', 4661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 300, 'mg / 100 ml', 3468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 210, 'mg / 100 ml', 4560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 440, 'mg / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 150, 'mg / 100 ml', 2776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 380, 'mg / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 1.51, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 2.64, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 3.40, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', NULL, 3.40, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chromium (chromium hvp chelate)', NULL, 20, 'µg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chromium (chromic chloride)', NULL, 4, 'µg / ml', 20314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chromium (chromic chloride)', NULL, 4, 'µg / ml', 19923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chromium (chromic chloride)', NULL, 10, 'µg / ml', 16225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chromium (chromic chloride)', NULL, 4, 'µg / ml', 16226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chromium (chromic chloride)', NULL, 10, 'µg / ml', 16227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chromium (chromic chloride)', NULL, 10, 'µg / ml', 16224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', NULL, 0.125, 'mg / ml', 18210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide (ipratropium bromide monohydrate)', NULL, 0.2, 'mg / ml', 51050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', NULL, 0.5, 'mg / 2.5 ml', 67727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide (ipratropium bromide monohydrate)', NULL, 0.5, 'mg / 2.5 ml', 75181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', NULL, 0.5, 'mg / 2.5 ml', 75820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', NULL, 0.625, 'mg', 70751);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', NULL, 1.25, 'mg', 70752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', NULL, 2.5, 'mg', 80705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nifedipine', NULL, 20, 'mg', 79926);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nifedipine', NULL, 30, 'mg', 79927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nifedipine', NULL, 60, 'mg', 79928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('misoprostol', NULL, 200, 'µg', 13636);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('misoprostol', NULL, 200, 'µg', 48191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2, '%', 62357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 47227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin lispro protamine suspension', NULL, 75, 'unit / ml', 63832);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin lispro protamine suspension', NULL, 50, 'unit / ml', 63835);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buprenorphine (buprenorphine hydrochloride)', NULL, 2, 'mg', 78104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buprenorphine (buprenorphine hydrochloride)', NULL, 8, 'mg', 78105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2b', NULL, 50, 'µg / 0.5 ml', 70155);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2b', NULL, 80, 'µg / 0.5 ml', 70156);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2b', NULL, 100, 'µg / 0.5 ml', 70157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2b', NULL, 120, 'µg / 0.5 ml', 70158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2b', NULL, 150, 'µg / 0.5 ml', 70159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2b', NULL, 80, 'µg / 0.5 ml', 73948);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2b', NULL, 100, 'µg / 0.5 ml', 73950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2b', NULL, 120, 'µg / 0.5 ml', 73951);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2b', NULL, 150, 'µg / 0.5 ml', 73952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2b', NULL, 80, 'µg / 0.5 ml', 85660);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2b', NULL, 100, 'µg / 0.5 ml', 85661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2b', NULL, 120, 'µg / 0.5 ml', 85662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2b', NULL, 150, 'µg / 0.5 ml', 85663);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin phosphate', NULL, 1.200, '% / w/w', 84468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 42310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 30927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2, '%', 18691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 15869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3, '%', 50532);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4, '%', 53823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 61295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 61296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 60325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 62463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.8, '%', 63264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 64081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 63348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3, '%', 64701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 64702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 64225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '%', 64289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 65907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4, '%', 65424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4, '%', 65426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 65425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 64883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 66706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 66828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 66892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 66974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 68325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 68818);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 68355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 69420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2, '%', 68051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 68574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4, '%', 71359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 71383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 71384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 71386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 72275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 70085);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 71534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3, '%', 70856);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4, '%', 69552);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4, '%', 70253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 70878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 70880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4, '%', 71649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 71650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 71098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 71099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 71101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.5, '%', 71148);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 69886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2, '%', 71277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 75172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.0, '%', 75229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 76634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '%', 76635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 74004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.5, '%', 75271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '%', 75298);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 76711);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 74106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 1.5, '%', 75404);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 75409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 75413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 75414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 74244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 75512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2, '%', 75513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '%', 72332);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 72336);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 72339);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 74321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 75531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 75557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4, '%', 75594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 72392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 75697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '%', 75709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 73166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 1.0, '%', 74441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3, '%', 74447);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3, '%', 74448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 72581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.8, '%', 72582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3, '%', 72585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2, '%', 74548);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4, '%', 74554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 74559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 74560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 74591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 75847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 74651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 74654);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 75919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2, '%', 73323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3, '%', 73324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 74749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.5, '%', 76004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 73436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 75779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2, '%', 73522);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 6.0, '%', 74916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 76179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 76213);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 76214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.0, '%', 73587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 74918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '%', 74992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 73755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 73756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 74998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 76325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.6, '%', 76328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 76349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 73821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '%', 77488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 78108);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 78156);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 78164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '%', 77065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4, '%', 77531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '%', 77533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 77441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 77461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 6.0, '%', 77550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 6.0, '%', 77551);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 77577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 77578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '%', 77610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '%', 77612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 6.0, '%', 77613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 78220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 76897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 76898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.0, '%', 77058);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.0, '%', 77436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 77517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 77611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.00, '%', 77614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 77629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '%', 77630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 77608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 76890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 77681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 77682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 77812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 77883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 78240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.0, '%', 77076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 76869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2, '%', 77299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '%', 78310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 78311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 78317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 77768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '%', 77927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '%', 77928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 77581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 76934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.0, '%', 77321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.0, '%', 77322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.0, '%', 77323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.0, '%', 77324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.0, '%', 77325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '%', 77326);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '%', 78014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 6.0, '%', 78019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '%', 78020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.50, '%', 78047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 77513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 77515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 77617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 77618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '%', 78331);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 77287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 82245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '%', 78658);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.00, '%', 78689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.00, '%', 78690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '%', 79082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 78611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 78700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 6.0, '%', 78701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '%', 79265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 78709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 78989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '%', 79294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 79798);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 78959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79407);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 80173);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '%', 78621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 78895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 78605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 78606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.00, '%', 78929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.00, '%', 78930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 80565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.00, '%', 79238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79319);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 78629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 78635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 0.5, '%', 79982);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 80227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 80110);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '%', 80111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 80045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4, '%', 78647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 82839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 82383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '%', 79090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 79184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 78589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 79251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 82461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '%', 82622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 80457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 80820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 83915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 83916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '%', 84348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 84347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 0.49, '%', 84353);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 84379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 84541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 84553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '%', 84603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '%', 84903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 85091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '% / w/w', 16229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 67685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.0, '% / w/w', 70086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.00, '% / w/w', 75370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 75591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 72583);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 75934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '% / w/w', 75980);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 74849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '% / w/w', 74883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 74884);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 74885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 76200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 76215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 74999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 76204);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 76351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.5, '% / w/w', 72764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 77462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 77463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 77389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 77390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 77391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 77392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 77473);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 77288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 76938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 76894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 76863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 76891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 76892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 77633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 77721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 76941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 78222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 79440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.3, '% / w/w', 81654);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.50, '% / w/w', 81656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '% / w/w', 79851);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81909);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.5, '% / w/w', 79531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 79849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 79850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.75, '% / w/w', 81268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4, '% / w/w', 82154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 82780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '% / w/w', 79579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80566);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 82206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 82210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 1.0, '% / w/w', 80985);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 82242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 82930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 82931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.0, '% / w/w', 82964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '% / w/w', 79731);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.00, '% / w/w', 78685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.00, '% / w/w', 78686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 79183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.00, '% / w/w', 79766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '% / w/w', 80527);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 79773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 80791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 82015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 82016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 82018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4, '% / w/w', 82592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81716);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '% / w/w', 79466);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 79468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 79469);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 79470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80027);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 80435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4, '% / w/w', 80436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '% / w/w', 80398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '% / w/w', 80400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.0, '% / w/w', 81451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80049);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80052);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82987);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 80198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 80199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 80200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 81605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 81708);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 81709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4, '% / w/w', 81779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82013);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 82617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 80219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80478);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80568);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 79980);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 79983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80022);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80023);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 80411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 81076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 79647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 79989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 80228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.5, '% / w/w', 80114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81301);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.3, '% / w/w', 81660);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 79618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 80069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 80070);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.5, '% / w/w', 80696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.75, '% / w/w', 81829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 80393);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 80858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81926);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82381);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 82415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 79484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '% / w/w', 80382);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.5, '% / w/w', 80424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '% / w/w', 80425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.5, '% / w/w', 81911);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80526);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '% / w/w', 82368);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 82367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 82372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '% / w/w', 79871);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80670);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '% / w/w', 80671);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 81921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.75, '% / w/w', 82621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80503);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4, '% / w/w', 83050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '% / w/w', 79249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 82373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 80539);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 80034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 80035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '% / w/w', 80178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 81069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 82543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 78779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 83001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 79868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '% / w/w', 80380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 80567);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 80595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3.0, '% / w/w', 82779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 83072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 83098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 83101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 83111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.0, '% / w/w', 83112);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 0.3, '% / w/w', 83116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 83168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 83278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 83388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 83389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 83391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 83403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 83420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 83580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 83581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 83677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 83737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 83786);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 83785);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 83787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.00, '% / w/w', 83859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 83866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 83869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 83881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.9, '% / w/w', 83902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 83903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.75, '% / w/w', 83908);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.5, '% / w/w', 83983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.5, '% / w/w', 83984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.0, '% / w/w', 84004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.75, '% / w/w', 84034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.75, '% / w/w', 84035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84036);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.75, '% / w/w', 84042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 84061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 84076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4.5, '% / w/w', 84207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 84257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 2.0, '% / w/w', 84414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 84472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84519);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84520);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 84530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84707);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.00, '% / w/w', 84959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.00, '% / w/w', 84962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 84974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5.0, '% / w/w', 84975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 85096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 85097);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 85098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 85099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 85341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '% / w/w', 85343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 4, '%', 15799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 53421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 53422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 53423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 53424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 53425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 53426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 61886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 60302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 60326);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 60327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 60328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 63346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 63349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, '%', 63351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 50, 'mg / ml', 63661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 50, 'mg / ml', 63662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3, '% / 50 ml', 83672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 5, 'g / 100 g', 62467);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 3, 'g / 100 g', 71227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octisalate', NULL, 20, 'mg / g', 62885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mequinol', NULL, 2, '% / w/v', 67151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ammonium chloride', NULL, 125, 'mg / 5 ml', 11229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ammonium chloride', NULL, 125, 'mg / 5 ml', 6844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ammonium chloride', NULL, 125, 'mg / 5 ml', 4469);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ammonium chloride', NULL, 125, 'mg / 5 ml', 66839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ammonium chloride', NULL, 125, 'mg / 5 ml', 67953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ammonium chloride', NULL, 125, 'mg / 5 ml', 69689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxyquinoline sulfate', NULL, 100, 'mg / 100 ml', 2645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 2.72, 'g / 25 ml', 23184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 13.6, 'g / 100 ml', 9833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 280, 'mg / 100 ml', 21767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 330, 'mg / 100 ml', 21764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 370, 'mg / 100 ml', 21757);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 680, 'mg / 20 ml', 21691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 370, 'mg / 100 ml', 21998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 297, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 297, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 340, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 340, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 170, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 340, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 340, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 3.9, 'mg / ml', 18029);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 340, 'mg / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 340, 'mg / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 340, 'mg / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 297, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 170, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 340, 'mg / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 297, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 220, 'mg / 100 ml', 14578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 370, 'mg / 100 ml', 12741);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 2.36, 'mg / ml', 8169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 3.9, 'mg / ml', 6360);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 121, 'mg / ml', 5535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 295, 'mg / 100 ml', 3820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 680, 'mg / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 2.22, 'mg / ml', 1737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 2.22, 'mg / ml', 1738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 368, 'mg / 100 ml', 1622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 368, 'mg / 100 ml', 1623);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', NULL, 368, 'mg / 100 ml', 82495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulisobenzone', NULL, 0.5, '%', 78024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('myroxylon balsamum', NULL, 4, 'g / 100 ml', 41578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('disodium edetate', NULL, 15, 'g / 100 g', 1248);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aloe (aloe ferox)', NULL, 83, 'mg', 60180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aloe', NULL, 2, 'g / 100 ml', 41578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetylpyridinium chloride', NULL, 2, 'mg', 78568);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetylpyridinium chloride', NULL, 0.05, '%', 42480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetylpyridinium chloride', NULL, 0.05, '%', 42483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetylpyridinium chloride', NULL, 0.1, '%', 15550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cinnamon oil', NULL, 5, 'ml / 100 ml', 1291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', NULL, 0.023, '%', 6345);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', NULL, 0.03, '%', 6696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', NULL, 0.2, '% / w/w', 73832);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('macrogol', NULL, 238.18, 'g / pck', 9351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('macrogol', NULL, 59.55, 'g / l', 9631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('macrogol', NULL, 236, 'g / 4 l', 6370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulisobenzone', NULL, 0.5, '%', 78023);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', NULL, 10, 'mg', 5156);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', NULL, 10, 'mg', 5157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '% / w/w', 76938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', NULL, 50, 'mg', 13636);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', NULL, 75, 'mg', 48191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chromic chloride', NULL, 6.0, 'µg / ml', 5708);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', NULL, 100, 'mg', 17904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', NULL, 50, 'mg', 18139);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', NULL, 50, 'mg', 73131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', NULL, 100, 'mg', 73132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', NULL, 50, 'mg', 78821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', NULL, 100, 'mg', 78822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 4.5, '%', 42310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9.0, '%', 77513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '%', 15869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '%', 76600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5, '%', 62463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5, '%', 63264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9.0, '%', 63348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.0, '%', 64225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 14.5, '%', 63102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5, '%', 66706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9.0, '%', 66828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8, '%', 66974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8, '%', 68325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 13, '%', 68818);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '%', 67949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 12.0, '%', 68574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 3.5, '%', 68117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5, '%', 71383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8, '%', 71384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9, '%', 71386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 3.5, '%', 71100);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9.0, '%', 75172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.0, '%', 74004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.5, '%', 75409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '%', 75450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '%', 73044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5, '%', 75512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 2.0, '%', 75709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9, '%', 72581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 6.0, '%', 74630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '%', 75779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '%', 76213);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '%', 76214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.0, '%', 74918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.0, '%', 73755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.0, '%', 73756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 6.0, '%', 74998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 7.0, '%', 76325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 2.0, '%', 77488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '%', 78108);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '%', 77461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '%', 77550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '%', 77551);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 3.0, '%', 77610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 4.0, '%', 77612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '%', 77613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 6.5, '%', 77611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.50, '%', 77614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.0, '%', 77608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5, '%', 76890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '%', 77681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '%', 77682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9.0, '%', 77883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '%', 77581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 12.0, '%', 76934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9.0, '%', 77515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9.0, '%', 77618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '%', 82245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '%', 79960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '%', 79018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.00, '%', 78689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.00, '%', 78690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '%', 78611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '%', 78700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '%', 78701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.0, '%', 79262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.0, '%', 79263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '%', 78709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '%', 78990);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.0, '%', 79294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '%', 79798);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '%', 78957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '%', 78958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '%', 79719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '%', 79252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '%', 79253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '%', 79255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9.0, '%', 79256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.5, '%', 79257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '%', 78605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 4.0, '%', 78606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.00, '%', 78929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.00, '%', 78930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9.0, '%', 80565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.50, '%', 79238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '%', 79319);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '%', 79320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9.0, '%', 79321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9.0, '%', 79322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 7.5, '%', 79930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '%', 79931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '%', 79197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '%', 78629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 13, '%', 78635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '%', 79992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '%', 80227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '%', 82839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 2.0, '%', 79187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.0, '%', 79086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '%', 79251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 7.0, '%', 83915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 7.0, '%', 83916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '%', 84541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 6.0, '%', 84553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '%', 85091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.00, '% / w/w', 75370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 75591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8, '% / w/w', 72549);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 6.0, '% / w/w', 74849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 6.0, '% / w/w', 74884);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 76200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '% / w/w', 76215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '% / w/w', 76204);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 6.5, '% / w/w', 77463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '% / w/w', 77389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.78, '% / w/w', 77390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '% / w/w', 77391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.78, '% / w/w', 77392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9.0, '% / w/w', 77473);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 78222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '% / w/w', 76894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 13.0, '% / w/w', 76863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 76891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5, '% / w/w', 76892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 12, '% / w/w', 77721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '% / w/w', 76941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 4.5, '% / w/w', 79440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.0, '% / w/w', 79851);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '% / w/w', 81909);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '% / w/w', 79849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '% / w/w', 79850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 13, '% / w/w', 82843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.0, '% / w/w', 80128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 3.0, '% / w/w', 80480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 80566);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '% / w/w', 82206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '% / w/w', 82210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 82242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 7.0, '% / w/w', 79731);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.00, '% / w/w', 78685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.00, '% / w/w', 78686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9.0, '% / w/w', 80488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.00, '% / w/w', 79766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 2.9, '% / w/w', 80723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '% / w/w', 82834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '% / w/w', 80747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 13.0, '% / w/w', 81406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '% / w/w', 82015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '% / w/w', 82016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 82018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 12, '% / w/w', 82161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8, '% / w/w', 82592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 80088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8, '% / w/w', 79605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 80025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '% / w/w', 80026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.78, '% / w/w', 80027);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '% / w/w', 80175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '% / w/w', 80176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 2, '% / w/w', 80436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 80055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 6.0, '% / w/w', 80050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '% / w/w', 80056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '% / w/w', 80051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.78, '% / w/w', 80052);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 13, '% / w/w', 82493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 13, '% / w/w', 82494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5, '% / w/w', 80198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5, '% / w/w', 80199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '% / w/w', 80200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 81605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '% / w/w', 81708);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '% / w/w', 81709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5, '% / w/w', 81779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 13.0, '% / w/w', 81842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 82508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5, '% / w/w', 80219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '% / w/w', 80478);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 80568);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 79983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 80022);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 80023);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 80024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5, '% / w/w', 80411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 81076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8, '% / w/w', 79595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 4.5, '% / w/w', 79647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '% / w/w', 80228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 2.0, '% / w/w', 80113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.5, '% / w/w', 81301);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 7.5, '% / w/w', 80460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 4, '% / w/w', 80069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 81266);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 82515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 81926);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 7.5, '% / w/w', 81927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '% / w/w', 81928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 81929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 81930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 82381);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '% / w/w', 79484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.5, '% / w/w', 81911);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 80061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9.0, '% / w/w', 80517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 80525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '% / w/w', 80524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 80526);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 81043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 81044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 82017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 82019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 82020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 81913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 7.0, '% / w/w', 81914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.5, '% / w/w', 81915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 13.0, '% / w/w', 81916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '% / w/w', 81919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 81921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 81920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 80503);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 80504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8, '% / w/w', 83050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '% / w/w', 82373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 82462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 80256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 12.5, '% / w/w', 80537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 13, '% / w/w', 80539);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 82060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 82062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 82063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 82065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 82066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 82067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 3, '% / w/w', 80034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 3, '% / w/w', 80035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 81069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 80099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5, '% / w/w', 82543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 12.0, '% / w/w', 78779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 83001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 79868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 4.0, '% / w/w', 80380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.0, '% / w/w', 80595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 82780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 12, '% / w/w', 83072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 4.7, '% / w/w', 83098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 12.0, '% / w/w', 83101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 83388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 83389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 83391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 83403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 83420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 83564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '% / w/w', 83581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 2, '% / w/w', 83787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.00, '% / w/w', 83859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '% / w/w', 83866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 83869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '% / w/w', 83881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 2, '% / w/w', 83902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9.6, '% / w/w', 83903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 13.5, '% / w/w', 83983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 13.5, '% / w/w', 83984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 84003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.0, '% / w/w', 84004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 84006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9.50, '% / w/w', 84034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.00, '% / w/w', 84035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 2.7, '% / w/w', 84036);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 8.0, '% / w/w', 84042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 12, '% / w/w', 84061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 84076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 84092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 3.0, '% / w/w', 84207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 12.5, '% / w/w', 84291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 84292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '% / w/w', 84403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 12.0, '% / w/w', 84415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 7.5, '% / w/w', 84424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.0, '% / w/w', 84431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 84519);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 84520);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '% / w/w', 84574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '% / w/w', 84576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '% / w/w', 84579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 5.0, '% / w/w', 84580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 84706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 4.7, '% / w/w', 84707);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 84715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.00, '% / w/w', 84959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10.00, '% / w/w', 84962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15, '% / w/w', 84974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 15.0, '% / w/w', 84975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '% / w/w', 85096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 7.5, '% / w/w', 85097);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '% / w/w', 85099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 10, '% / w/w', 85098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', NULL, 9, '%', 63351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lopinavir', NULL, 200, 'mg', 77104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lopinavir', NULL, 100, 'mg', 79781);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lopinavir', NULL, 80, 'mg / ml', 67570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white petrolatum', NULL, 88.7, '%', 82792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white petrolatum', NULL, 38.55, '%', 83796);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white petrolatum', NULL, 80.3, '% / w/w', 82304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('entacapone', NULL, 200, 'mg', 82347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('entacapone', NULL, 200, 'mg', 82348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('entacapone', NULL, 200, 'mg', 79150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('entacapone', NULL, 200, 'mg', 79151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('entacapone', NULL, 200, 'mg', 79152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal group c oligosaccharide', NULL, 10, 'µg / 0.5 ml', 67759);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal group c oligosaccharide', NULL, 10, 'µg / 0.5 ml', 73006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal group c oligosaccharide', NULL, 5, 'µg / 0.5 ml', 83276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('corynebacterium diphtheriae crm-197 protein', NULL, 25, 'µg / 0.5 ml', 67759);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('corynebacterium diphtheriae crm-197 protein', NULL, 15, 'µg / 0.5 ml', 73006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('corynebacterium diphtheriae crm-197 protein', NULL, 47, 'µg / 0.5 ml', 83276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norelgestromin', NULL, 6, 'mg', 72637);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium iodide', NULL, 16, 'mg / ml', 1980);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('silver (silver gluconate)', NULL, 0.06, 'mg / 2 ml', 15975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 10, 'mg', 36799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 10, 'mg', 12763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 10, 'mg', 6418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 10, 'mg', 4629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 10, 'mg', 4630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 10, 'mg', 59873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 10, 'mg', 64442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 10, 'mg', 66620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 10, 'mg', 66621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 0.25, '%', 42685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 1.05, '%', 72053);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 0.5, '%', 18240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 0.5, '%', 12764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 0.5, '%', 6417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 0.5, '%', 4390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 0.5, '%', 4389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 0.5, '%', 55837);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 0.5, '%', 61410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 0.25, '%', 72379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 0.5, '%', 73264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 0.5, '%', 73689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 0.25, '%', 77592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 0.5, '% / w/w', 37185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 10, 'mg / sup', 63617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 0.5, '%', 34945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 5, 'mg / g', 71955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 5, 'mg / g', 71956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc sulfate', NULL, 5, 'mg / g', 72775);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 4.07, 'g / 100 ml', 9833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 51, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 31, 'mg / 100 ml', 21764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 30, 'mg / 100 ml', 21757);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 510, 'mg / 20 ml', 21691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 30, 'mg / 100 ml', 21998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 51, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 51, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 51, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 51, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 25.5, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 51, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 51, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 51, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 51, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 30, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 30, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 102, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 0.3, 'mg / ml', 18029);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 51, 'mg / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 15.2, 'mg / 100 ml', 15778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 5.08, 'mg / 100 ml', 15769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 5.08, 'mg / 100 ml', 15772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 5.08, 'mg / 100 ml', 15768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 15.2, 'mg / 100 ml', 15763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 15.2, 'mg / 100 ml', 15764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 51, 'mg / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 51, 'mg / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 51, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 25.5, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 51, 'mg / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 51, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 30, 'mg / 100 ml', 14578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 30, 'mg / 100 ml', 12741);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 0.14, 'mg / ml', 8169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 3.253, 'mg / ml', 5950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 102, 'mg / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 0.3, 'mg / ml', 6360);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 25.4, 'mg / ml', 5535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 169.6, 'mg / 100 ml', 3820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 102, 'mg / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 0.14, 'mg / ml', 1738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 0.14, 'mg / ml', 1737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 30, 'mg / 100 ml', 1623);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 30, 'mg / 100 ml', 1622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 0.116, 'mg / ml', 745);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 30, 'mg / 100 ml', 82495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', NULL, 50, 'mg', 71178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 0.1017, 'g / l', 74647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 0.1017, 'g / l', 74648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 0.1017, 'g / l', 74649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 0.45, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 0.81, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 0.81, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', NULL, 51, 'mg / l', 64397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 1.84, 'g / 100 ml', 9833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 37, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 37, 'mg / 100 ml', 21764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 10, 'mg / 100 ml', 21756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 370, 'mg / 20 ml', 21691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 33, 'mg / 100 ml', 21999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 37, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 37, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 0.48, 'mg / ml', 18029);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 25.7, 'mg / 100 ml', 15778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 18.4, 'mg / 100 ml', 15769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 18.4, 'mg / 100 ml', 15772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 18.4, 'mg / 100 ml', 15768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 25.7, 'mg / 100 ml', 15763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 25.7, 'mg / 100 ml', 15764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 20, 'mg / 100 ml', 14250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 20, 'mg / 100 ml', 10936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 20, 'mg / 100 ml', 10937);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 20, 'mg / 100 ml', 12186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 33, 'mg / 100 ml', 10862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 20, 'mg / 100 ml', 9830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 0.36, 'mg / ml', 8169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 20, 'mg / 100 ml', 8601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 0.176, 'mg / ml', 5950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 0.48, 'mg / ml', 6360);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 16.55, 'mg / ml', 5535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 0.2, 'mg / ml', 1749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 0.2, 'mg / ml', 1745);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 20, 'mg / 100 ml', 1673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 20, 'mg / 100 ml', 1628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 0.2, 'mg / ml', 745);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 20, 'mg / 100 ml', 67329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 20, 'mg / 100 ml', 70277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 40, 'µmol / 1 ml', 53282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 200, 'µmol / 5 ml', 53284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 40, 'µmol / ml', 81151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 0.1838, 'g / l', 74647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 0.1838, 'g / l', 74648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 0.1838, 'g / l', 74649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 0.30, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 0.52, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 0.52, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', NULL, 257, 'mg / l', 64397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', NULL, 1000, 'mg', 69406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', NULL, 1, 'g / evt', 42652);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', NULL, 12, 'g / pck', 73995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', NULL, 12, 'g / pck', 78587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', NULL, 12, 'g / pck', 80347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', NULL, 12, 'g / pck', 84334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', NULL, 37, 'mg / 100 ml', 21993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', NULL, 93, 'mg / 100 ml', 16794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', NULL, 32.4, 'mg / ml', 2122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', NULL, 148, 'mg / ml', 744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium thiosulfate', NULL, 8, '%', 2072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate monobasic', NULL, 820, 'µg / 100 ml', 21757);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate monobasic', NULL, 6.25, 'mg / 100 ml', 10939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate monobasic', NULL, 34.3905, 'kg / 576 l', 1958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carboxymethyl cellulose', NULL, 13.3, '%', 42486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('taurine', NULL, 50, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levobunolol hydrochloride', NULL, 0.5, '%', 43034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril maleate', NULL, 5.0, 'mg', 83816);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril maleate', NULL, 10.0, 'mg', 83817);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desloratadine', NULL, 2.5, 'mg', 79491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tenofovir disoproxil fumarate', NULL, 300, 'mg', 76043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tenofovir disoproxil fumarate', NULL, 300, 'mg', 78602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salmonella typhi vi capsular polysaccharide vaccine', NULL, 25, 'µg / 0.5 ml', 72706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('belladonna', NULL, 15, 'mg', 11257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('belladonna', NULL, 15, 'mg', 11124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('belladonna', NULL, 0.2, 'mg', 48361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flutamide', 'L02BB01', 250, 'mg', 43664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin aspart', NULL, 30, '%', 75090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vibrio cholerae inaba 6973 e1 tor biotype, formalin inactivated', NULL, 25000000000, 'unit / dose', 71450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vibrio cholerae inaba 48 classical biotype, heat inactivated', NULL, 25000000000, 'unit / dose', 71450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vibrio cholerae ogawa 50 classical biotype, heat inactivated', NULL, 25000000000, 'unit / dose', 71450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vibrio cholerae ogawa 50 classical biotype, formalin inactivated', NULL, 25000000000, 'unit / dose', 71450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('recombinant cholera toxin b subunit', NULL, 1, 'mg / dose', 71450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esomeprazole (esomeprazole magnesium trihydrate)', NULL, 20, 'mg', 84676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esomeprazole (esomeprazole magnesium trihydrate)', NULL, 20, 'mg', 84677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hypromellose', NULL, 0.8, '%', 78028);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allantoin', NULL, 0.2, '%', 36721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', NULL, 10, 'mg', 66915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('taurine', NULL, 70, 'mg / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('taurine', NULL, 60, 'mg / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n-acetyl-l-tyrosine', NULL, 405, 'mg / 100 ml', 19306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n-acetyl-l-tyrosine', NULL, 115, 'mg / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n-acetyl-l-tyrosine', NULL, 115, 'mg / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n-acetyl-l-tyrosine', NULL, 94, 'mg / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n-acetyl-l-tyrosine', NULL, 115, 'mg / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n-acetyl-l-tyrosine', NULL, 135, 'mg / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n-acetyl-l-tyrosine', NULL, 94, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n-acetyl-l-tyrosine', NULL, 115, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n-acetyl-l-tyrosine', NULL, 94, 'mg / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n-acetyl-l-tyrosine', NULL, 270, 'mg / 100 ml', 18644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n-acetyl-l-tyrosine', NULL, 270, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n-acetyl-l-tyrosine', NULL, 189, 'mg / 100 ml', 18608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n-acetyl-l-tyrosine', NULL, 230, 'mg / 100 ml', 18607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('travoprost', NULL, 0.004, '%', 76384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', NULL, 50, 'mg', 2133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', NULL, 50, 'mg', 71374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', NULL, 50, 'mg', 71635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', NULL, 50, 'mg', 77658);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etidronate disodium', NULL, 400, 'mg', 19304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etidronate disodium', NULL, 400, 'mg', 71566);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etidronate disodium', NULL, 400, 'mg', 74925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etidronate disodium', NULL, 400, 'mg', 80967);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etidronate disodium', NULL, 400, 'mg', 83843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 261, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 130, 'mg / 100 ml', 21767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 261, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 261, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 261, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 261, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 130.5, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 261, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 261, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 261, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 261, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 522, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 261, 'mg / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 261, 'mg / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 261, 'mg / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 261, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 130.5, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 261, 'mg / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 261, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 522, 'mg / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 418, 'mg / 100 ml', 3820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', NULL, 522, 'mg / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 73, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 200, 'mg / 100 ml', 20278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 200, 'mg / 100 ml', 20279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 170, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 258, 'mg / 100 ml', 19306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 290, 'mg / 100 ml', 19610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 170, 'mg / 100 ml', 20303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 200, 'mg / 100 ml', 20302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 170, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 200, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 200, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 170, 'mg / 100 ml', 20289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 100, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 200, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 200, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 73, 'mg / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 73, 'mg / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 60, 'mg / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 73, 'mg / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 73, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 290, 'mg / 100 ml', 19143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 60, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 85, 'mg / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 60, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 73, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 125, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 60, 'mg / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 172, 'mg / 100 ml', 18644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 172, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 120, 'mg / 100 ml', 18608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 146, 'mg / 100 ml', 18607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 180, 'mg / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 290, 'mg / 100 ml', 18550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 290, 'mg / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 290, 'mg / 100 ml', 14077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 290, 'mg / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 290, 'mg / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 246, 'mg / 100 ml', 14073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 246, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 246, 'mg / 100 ml', 14071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 145, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 290, 'mg / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 246, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 290, 'mg / 100 ml', 14067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 400, 'mg / 100 ml', 11329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 726, 'mg / 100 ml', 7163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 340, 'mg / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 340, 'mg / 100 ml', 5890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 580, 'mg / 100 ml', 4661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 400, 'mg / 100 ml', 3468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 280, 'mg / 100 ml', 4560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 580, 'mg / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 200, 'mg / 100 ml', 2776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 240, 'mg / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 1.26, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 2.21, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 2.84, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-methionine', NULL, 2.84, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine hydrochloride', NULL, 290, 'mg / 100 ml', 19610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine hydrochloride', NULL, 290, 'mg / 100 ml', 18550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine hydrochloride', NULL, 290, 'mg / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine hydrochloride', NULL, 290, 'mg / 100 ml', 14077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine hydrochloride', NULL, 290, 'mg / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine hydrochloride', NULL, 290, 'mg / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine hydrochloride', NULL, 246, 'mg / 100 ml', 14073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine hydrochloride', NULL, 246, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine hydrochloride', NULL, 246, 'mg / 100 ml', 14071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine hydrochloride', NULL, 145, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine hydrochloride', NULL, 290, 'mg / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine hydrochloride', NULL, 290, 'mg / 100 ml', 14067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine hydrochloride', NULL, 246, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-lysine hydrochloride', NULL, 580, 'mg / 100 ml', 4661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polysorbate 80', NULL, 4.86, 'mg / 0.5 ml', 82225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium (calcium carbonate)', NULL, 500, 'mg', 19304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium (calcium carbonate)', NULL, 270, 'mg', 71557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium (calcium carbonate)', NULL, 500, 'mg', 71566);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium (calcium carbonate)', NULL, 300, 'mg', 70202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium (calcium carbonate)', NULL, 500, 'mg', 76526);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium (calcium carbonate)', NULL, 300, 'mg', 76186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium (calcium carbonate)', NULL, 500, 'mg', 74925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium (calcium carbonate)', NULL, 500, 'mg', 80967);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium (calcium carbonate)', NULL, 500, 'mg', 83843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', NULL, 20, 'mg', 75581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', NULL, 20, 'mg', 75582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loratadine', NULL, 5, 'mg', 12955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loratadine', NULL, 5, 'mg', 11974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loratadine', NULL, 10, 'mg', 68939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loratadine', NULL, 10, 'mg', 74601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('felodipine', NULL, 5, 'mg', 63844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('felodipine', NULL, 2.5, 'mg', 63845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', NULL, 20, 'mg', 17903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', NULL, 10, 'mg', 16709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', NULL, 10, 'mg', 16636);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', NULL, 20, 'mg', 16903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', NULL, 20, 'mg', 13431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.5, '%', 71277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', NULL, 10, 'mg', 74732);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', NULL, 20, 'mg', 74733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', NULL, 20, 'mg', 74734);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', NULL, 10, 'mg', 78307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', NULL, 20, 'mg', 78308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', NULL, 20, 'mg', 78309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', NULL, 10, 'mg', 78744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', NULL, 20, 'mg', 78745);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', NULL, 20, 'mg', 78746);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', NULL, 10, 'mg', 78710);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', NULL, 20, 'mg', 78711);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', NULL, 20, 'mg', 78712);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', NULL, 10, 'mg', 78769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', NULL, 20, 'mg', 78770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', NULL, 20, 'mg', 78771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', NULL, 10, 'mg', 84793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', NULL, 20, 'mg', 84794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', NULL, 20, 'mg', 84795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.5, '% / w/w', 83899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zidovudine', NULL, 300, 'mg', 62673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zidovudine', NULL, 300, 'mg', 68746);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('formoterol fumarate dihydrate', NULL, 6, 'µg / dose', 69428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('formoterol fumarate dihydrate', NULL, 6, 'µg / dose', 69429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('formoterol fumarate dihydrate', NULL, 5, 'µg / dose', 84679);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('formoterol fumarate dihydrate', NULL, 5, 'µg / dose', 84680);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('formoterol fumarate dihydrate', NULL, 5, 'µg / dose', 84681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2.0, '%', 42377);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2.0, '%', 42376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1, '%', 66106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1, '%', 69552);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1, '%', 70253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.5, '%', 70998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2, '%', 70999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 3.0, '%', 76600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.8, '%', 76707);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2, '%', 75392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1, '%', 75594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.8, '%', 74357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.8, '%', 74358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1, '%', 74554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 3.0, '%', 75869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1, '%', 76206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.0, '%', 77484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.0, '%', 77485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2.0, '%', 77540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.7, '%', 77554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 3.0, '%', 77606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2.0, '%', 77440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.8, '%', 77619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.7, '%', 78110);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 3.0, '%', 78240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 3.5, '%', 80443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.7, '%', 78955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2.0, '%', 79216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2, '%', 80438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2.0, '%', 81450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.0, '%', 78621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.0, '%', 79252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.0, '%', 79253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.0, '%', 79255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.8, '%', 78890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2, '%', 78891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 3.0, '%', 79533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.8, '%', 79068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1, '%', 78647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2, '%', 82382);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2, '%', 84120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2, '% / w/w', 72549);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2.0, '% / w/w', 74968);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 4, '% / w/w', 77288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2, '% / w/w', 79605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.0, '% / w/w', 80398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.0, '% / w/w', 80400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2, '% / w/w', 79595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.8, '% / w/w', 80230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1, '% / w/w', 82270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.0, '% / w/w', 80425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.8, '% / w/w', 80252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2.0, '% / w/w', 81034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.0, '% / w/w', 80178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.8, '% / w/w', 81066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.7, '% / w/w', 83240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.7, '% / w/w', 83494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2.0, '% / w/w', 84032);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2.0, '% / w/w', 84033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.7, '% / w/w', 84099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2, '%', 50134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1.7, '%', 61380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 1, '%', 62732);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ensulizole', NULL, 2, 'g / 100 g', 60001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', NULL, 0.625, 'mg', 66710);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', NULL, 0.625, 'mg', 66711);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', NULL, 0.5, 'ml', 62666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', NULL, 20, 'ml / vial', 42981);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', NULL, 20, 'ml / vial', 64277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', NULL, 5, 'ml / vial', 63758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', NULL, 50, 'ml / vial', 83912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tramadol hydrochloride', NULL, 37.50, 'mg', 75035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tramadol hydrochloride', NULL, 37.5, 'mg', 82241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 47227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 42377);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 42376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.4, '%', 42310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7, '%', 41935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.3, '%', 42607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 37913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3, '%', 37916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 32792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 33490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 30927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 19330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 8.5, '%', 19037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5, '%', 18691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 15893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 15869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 13954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 13958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 13929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 13930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 47540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7, '%', 48123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 50605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 50939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 51733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3, '%', 50532);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 53823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 61235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 60497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 61295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 61296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 60890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4, '%', 62357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4, '%', 60920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 60325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 62463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.3, '%', 63261);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.3, '%', 63263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.3, '%', 63264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.0, '%', 64081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 63342);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 63348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 63350);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 64701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 64702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 64150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 64225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 64289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.4, '%', 63102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 65907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 65423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 65424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 65425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 65427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 65426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 64883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 66706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 66106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 66828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 66974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 68850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 8.5, '%', 69344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 69393);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 69394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 69420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 67949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 67987);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5, '%', 68051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 68570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 68594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.0, '%', 68595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 68117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 68186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 67743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 72102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 71359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 71382);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 71383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 71384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 71386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 72271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 72270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 70085);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 70087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 72290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 70111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 71534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6, '%', 71649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6, '%', 70878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5, '%', 70879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 8, '%', 70880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6, '%', 70881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7, '%', 70903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 70904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 71650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3, '%', 70260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6, '%', 70261);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 70373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 71098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 71099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 71100);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 71101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 8.5, '%', 69791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 71148);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 69886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7, '%', 72068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76449);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3.5, '%', 76468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.4, '%', 76470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 73900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3.0, '%', 75161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76518);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.0, '%', 75229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.49, '%', 76619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.0, '%', 74039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 2, '%', 75296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75298);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75350);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76707);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76711);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3.5, '%', 76743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 2.5, '%', 75404);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 73042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 73044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '%', 74215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 72332);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 72336);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 72339);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 73106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 72406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75641);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.4, '%', 75676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.4, '%', 75677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.4, '%', 75697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 73157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 73158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 73159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 73161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3.5, '%', 74430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74434);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '%', 74441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7, '%', 74447);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7, '%', 74448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.50, '%', 74458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.2, '%', 75756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 72581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 72582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3, '%', 72585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74548);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3.5, '%', 74589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74655);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.0, '%', 75990);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3.5, '%', 73304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.30, '%', 73308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 73323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 73324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '%', 76007);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.0, '%', 73363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 73436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 75779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.0, '%', 76108);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7, '%', 76146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5, '%', 72680);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 73522);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 8.5, '%', 74916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 73587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6, '%', 73606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 73607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 1.7, '%', 73654);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.4, '%', 73657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3.5, '%', 73674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.1, '%', 74955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.4, '%', 74992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.9, '%', 76247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.4, '%', 72724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.4, '%', 72726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.9, '%', 72727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 2.9, '%', 72737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.9, '%', 72739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 73755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 73756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 74998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6, '%', 76206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5, '%', 76343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.50, '%', 76379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 72761);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3.4, '%', 72762);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.9, '%', 77484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.9, '%', 77485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78108);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.5, '%', 77540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78385);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4, '%', 78402);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 2.5, '%', 77560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '%', 77082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.0, '%', 77223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.9, '%', 77186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.0, '%', 76897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77375);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.0, '%', 77048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77058);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.0, '%', 77439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77632);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 1.2, '%', 77016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '%', 77820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78110);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 2, '%', 78256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '%', 78278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3.0, '%', 77076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.75, '%', 77434);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.0, '%', 78301);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 8.0, '%', 78304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 76910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77926);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '%', 77927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '%', 77928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78023);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.0, '%', 78025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.0, '%', 77321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '%', 77322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.0, '%', 77326);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.1, '%', 77411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.0, '%', 78014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.25, '%', 78047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.0, '%', 78331);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78345);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 77287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79021);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7, '%', 70856);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78658);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.32, '%', 79081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.1, '%', 80443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '%', 78990);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '%', 78957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '%', 78958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '%', 79216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.3, '%', 79416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79407);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 80173);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6, '%', 80438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 8.0, '%', 81450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 80565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.0, '%', 79276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79982);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.0, '%', 80110);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '%', 80111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 80641);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '%', 80828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 80045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 81860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 81861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.4, '%', 79168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 8, '%', 82382);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 82383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '%', 79090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 80673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 78589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 79251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 82461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.00, '%', 81642);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.00, '%', 81643);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 80281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 80800);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 82622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 80457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 80820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 80821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 82530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 83915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 83916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 8, '%', 84120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4, '%', 84130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 2, '%', 84131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.2, '%', 84246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.0, '%', 84266);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5, '%', 84342);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 84347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 84348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 84353);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '%', 84379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.0, '%', 84443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 84553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 84603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.5, '%', 84818);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 84903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 16229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 15968);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 48991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6, '% / w/w', 50232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6, '% / w/w', 60006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 2.0, '% / w/w', 66357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.50, '% / w/w', 65475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 65639);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.50, '% / w/w', 69095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 67685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 70086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6, '% / w/w', 71503);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 70588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.50, '% / w/w', 75370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 74228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.50, '% / w/w', 75591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.0, '% / w/w', 75634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 75689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 72583);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 75934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 75980);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 76030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 1.3, '% / w/w', 76139);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 74849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.5, '% / w/w', 74883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 74884);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 74885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 74999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 76351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 72764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.50, '% / w/w', 78398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.50, '% / w/w', 78399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 77462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 77463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 77390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 77392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 77473);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 77288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 76894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.0, '% / w/w', 77470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 76892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 77633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 78222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.5, '% / w/w', 78297);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 77340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 77341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 8.5, '% / w/w', 77394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 77395);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 77396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.4, '% / w/w', 79440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.11, '% / w/w', 81656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 81144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 81175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 81252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4, '% / w/w', 82350);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 81909);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.0, '% / w/w', 79531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.11, '% / w/w', 81268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6, '% / w/w', 82154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80985);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.5, '% / w/w', 82964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.0, '% / w/w', 79674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80527);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.5, '% / w/w', 79217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5, '% / w/w', 82269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.5, '% / w/w', 79044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '% / w/w', 81707);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 81714);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 81715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.0, '% / w/w', 79460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79466);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.0, '% / w/w', 79747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '% / w/w', 80026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '% / w/w', 80027);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.0, '% / w/w', 81451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.994, '% / w/w', 80484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 81017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79971);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80049);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '% / w/w', 80052);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82987);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 81457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 81557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82013);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.2, '% / w/w', 80977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79980);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '% / w/w', 80631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80810);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.0, '% / w/w', 79524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.4, '% / w/w', 79647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.0, '% / w/w', 80226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80112);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 81301);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.0, '% / w/w', 81661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.00, '% / w/w', 81830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 81379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80070);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.11, '% / w/w', 81829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.4, '% / w/w', 79169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80775);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 81635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.0, '% / w/w', 81931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 2.0, '% / w/w', 82415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80382);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 81912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.9, '% / w/w', 81034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '% / w/w', 82368);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79871);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3.00, '% / w/w', 81007);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80670);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80671);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.12, '% / w/w', 82621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 79249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80707);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.00, '% / w/w', 81638);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.00, '% / w/w', 81639);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 81066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5, '% / w/w', 82484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 80595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.0, '% / w/w', 81287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3.00, '% / w/w', 82113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.0, '% / w/w', 79540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 2, '% / w/w', 82523);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 82525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3.0, '% / w/w', 82167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.5, '% / w/w', 83111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3.0, '% / w/w', 83112);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7, '% / w/w', 83116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 83240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 83278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 83494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 83580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 83677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 83705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 83706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 83710);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.0, '% / w/w', 83728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 2.8, '% / w/w', 83737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 83877);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 83899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3.0, '% / w/w', 83900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 83903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 83908);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.09, '% / w/w', 83964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 2.0, '% / w/w', 84038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 84042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.09, '% / w/w', 84055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 84099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.9, '% / w/w', 84118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.9, '% / w/w', 84119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 84209);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.99, '% / w/w', 84244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7, '% / w/w', 84257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 84292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.34, '% / w/w', 84344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 84399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 84414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3.5, '% / w/w', 84420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 0.5, '% / w/w', 84425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6, '% / w/w', 84465);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5, '% / w/w', 84503);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 84519);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 84520);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 84530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 84574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 84576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 84579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 84580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.0, '% / w/w', 84640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 84664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 84713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.00, '% / w/w', 84853);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.00, '% / w/w', 84858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 84886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 85096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 85098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 85099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3.4, '% / w/w', 85135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 3.6, '% / w/w', 85228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 85341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '% / w/w', 85343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7, '% / w/v', 85515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 42332);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 42329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 18554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 15799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.5, '%', 16893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5, '%', 16896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 50132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.5, '%', 50134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4.5, '%', 53416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 53417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 53419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 53421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 53422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 53423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5, '%', 53424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 53425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 53426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 61886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 61896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 5.5, '%', 60506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 60302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 60326);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 60327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 60328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 63346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 63347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 63349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 63351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6, '%', 62732);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6, '%', 62743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 64334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 64736);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 64737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 64738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 64739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 64740);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, '%', 65601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 75, 'mg / ml', 63661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 75, 'mg / ml', 63662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7, 'g / 100 g', 60001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 4, 'g / 100 g', 61299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6, 'g / 100 g', 61313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.5, 'g / 100 g', 63515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.5, 'g / 100 g', 63516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 6.5, 'g / 100 g', 66124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, 'g / 100 g', 72236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 7.5, 'g / 100 g', 71227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', NULL, 60, 'mg / g', 62885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', NULL, 10, 'mg', 75794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', NULL, 20, 'mg', 75795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', NULL, 40, 'mg', 75796);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium ioxitalamate', NULL, 255, 'mg / ml', 17800);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bisulfite', NULL, 40, 'mg / 100 ml', 15493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 160, 'mg / 100 ml', 21756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 448, 'mg / 100 ml', 15769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 448, 'mg / 100 ml', 15772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 392, 'mg / 100 ml', 15778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 448, 'mg / 100 ml', 15768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 392, 'mg / 100 ml', 15763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 392, 'mg / 100 ml', 15764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 310, 'mg / 100 ml', 14250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 310, 'mg / 100 ml', 10936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 310, 'mg / 100 ml', 10937);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 310, 'mg / 100 ml', 12186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 310, 'mg / 100 ml', 10861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 310, 'mg / 100 ml', 9830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 310, 'mg / 100 ml', 8601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 3.1, 'mg / ml', 1749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 3.1, 'mg / ml', 1745);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 310, 'mg / 100 ml', 1673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 310, 'mg / 100 ml', 1628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 3.1, 'mg / ml', 1548);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 310, 'mg / 100 ml', 67329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 310, 'mg / 100 ml', 70277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 4.5, 'g / l', 64397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 3.925, 'g / l', 74647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 3.925, 'g / l', 74648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', NULL, 3.925, 'g / l', 74649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium acetate', NULL, 1.96, 'g / 20 ml', 21691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium acetate', NULL, 690, 'mg / 25 ml', 23184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium acetate', NULL, 128, 'mg / 100 ml', 11038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium acetate', NULL, 1.28, 'mg / ml', 1739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butanediol', NULL, 5.7, '%', 72560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cocillana', NULL, 1.36, 'mg / 1 ml', 5504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexpanthenol', NULL, 5, 'mg / vial', 66277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexpanthenol', NULL, 3, 'mg / ml', 16462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexpanthenol', NULL, 10, 'mg / ml', 3497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexpanthenol', NULL, 10, 'mg / ml', 31);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexpanthenol (panthenol)', NULL, 3, 'mg / ml', 68684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 33, 'mg', 42161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 35047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 31568);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 33917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 40, 'mg', 23669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 40, 'mg', 23671);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 40, 'mg', 23672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 19935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 19248);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 19249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 15579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 15578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 13699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 14596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 14595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 65, 'mg', 14316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 13259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 11741);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 32, 'mg', 11158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 11065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 30, 'mg', 5371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 30, 'mg', 5372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 6516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 40, 'mg', 6479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 40, 'mg', 6480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 5876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 40, 'mg', 6419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 40, 'mg', 5779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 6893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 6894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 6346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 7434);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 6763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 6764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 40, 'mg', 1233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 2918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 1025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 40, 'mg', 872);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 40, 'mg', 873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 40, 'mg', 47953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 40, 'mg', 47954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 40, 'mg', 47955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 40, 'mg', 47956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 100, 'mg', 413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine (caffeine citrate)', NULL, 15, 'mg', 62075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 62101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 60750);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 40, 'mg', 66118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 70220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 70240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 65, 'mg', 73935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 65, 'mg', 75299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 65, 'mg', 75534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 73187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 60, 'mg', 75894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 60, 'mg', 76086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 73681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 65, 'mg', 75038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 65, 'mg', 77631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 15, 'mg', 78862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 32, 'mg', 81810);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caffeine', NULL, 32, 'mg', 81813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextran', NULL, 10, '%', 1743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextran', NULL, 100, 'mg / ml', 1744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextran', NULL, 60, 'mg / ml', 1732);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextran', NULL, 60, 'mg / ml', 1733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aluminum diacetate', NULL, 0.35, '%', 6345);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextran 40', NULL, 10, '%', 14249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextran 40', NULL, 10, '%', 21688);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal polysaccharide-diphtheria toxoid conjugate, group a', NULL, 4.0, 'µg / 0.5 ml', 76550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal polysaccharide-diphtheria toxoid conjugate, group c', NULL, 4.0, 'µg / 0.5 ml', 76550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal polysaccharide-diphtheria toxoid conjugate, group y', NULL, 4.0, 'µg / 0.5 ml', 76550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal polysaccharide-diphtheria toxoid conjugate, group w 135', NULL, 4.0, 'µg / 0.5 ml', 76550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tropicamide', NULL, 0.8, '%', 16632);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tropicamide', NULL, 0.8, '%', 6057);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('factor xiii', NULL, 50, 'unit / 1 ml', 53282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('factor xiii', NULL, 250, 'unit / 5 ml', 53284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', NULL, 4000, 'unit / 100 ml', 36794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', NULL, 10000, 'unit / 100 ml', 36795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', NULL, 200, 'unit / 100 ml', 21993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', NULL, 2, 'unit / ml', 17227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', NULL, 5000, 'unit / 100 ml', 16794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium saccharate', NULL, 4.5, 'mg / ml', 18936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flumethasone pivalate', NULL, 0.02, '%', 631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flumethasone pivalate', NULL, 0.02, '%', 868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 25, 'mg', 20239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 10, 'mg', 20189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 25, 'mg', 20190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 25, 'mg', 19758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 10, 'mg', 19766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 25, 'mg', 19767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 25, 'mg', 14082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 50, 'mg', 11481);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 25, 'mg', 4008);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 10, 'mg', 3331);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 25, 'mg', 2142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 10, 'mg', 68470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 25, 'mg', 68471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 25, 'mg', 68472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 50, 'mg', 69226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 25, 'mg', 71866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 25, 'mg', 75839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 18.75, 'mg', 82347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 31.25, 'mg', 82348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 12.5, 'mg', 79150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 25, 'mg', 79151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 37.5, 'mg', 79152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa', NULL, 25, 'mg', 79676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbidopa (carbidopa monohydrate)', NULL, 5, 'mg / ml', 77753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prilocaine', NULL, 2.5, '%', 16733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prilocaine', NULL, 2.5, '%', 81134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prilocaine', NULL, 25, 'mg / g', 11440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 212, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 290, 'mg / 100 ml', 20278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 290, 'mg / 100 ml', 20279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 246.5, 'mg / 100 ml', 20276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 750, 'mg / 100 ml', 19306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 230, 'mg / 100 ml', 19610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 246.5, 'mg / 100 ml', 20303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 290, 'mg / 100 ml', 20302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 246.5, 'mg / 100 ml', 20292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 290, 'mg / 100 ml', 20291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 290, 'mg / 100 ml', 20290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 246.5, 'mg / 100 ml', 20289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 145, 'mg / 100 ml', 20288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 290, 'mg / 100 ml', 20282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 290, 'mg / 100 ml', 20281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 212, 'mg / 100 ml', 18729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 212, 'mg / 100 ml', 18727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 175, 'mg / 100 ml', 18703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 212, 'mg / 100 ml', 18702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 212, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 230, 'mg / 100 ml', 19143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 175, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 230, 'mg / 100 ml', 18699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 175, 'mg / 100 ml', 18698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 212, 'mg / 100 ml', 18697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 452, 'mg / 100 ml', 18646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 500, 'mg / 100 ml', 18644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 175, 'mg / 100 ml', 18645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 500, 'mg / 100 ml', 18628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 350, 'mg / 100 ml', 18608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 425, 'mg / 100 ml', 18607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 673, 'mg / 100 ml', 18606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 230, 'mg / 100 ml', 18550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 230, 'mg / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 230, 'mg / 100 ml', 14077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 230, 'mg / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 230, 'mg / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 195, 'mg / 100 ml', 14073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 195, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 195, 'mg / 100 ml', 14071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 115, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 230, 'mg / 100 ml', 14067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 230, 'mg / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 195, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 680, 'mg / 100 ml', 5890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 800, 'mg / 100 ml', 3468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 560, 'mg / 100 ml', 4560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 400, 'mg / 100 ml', 2776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 760, 'mg / 100 ml', 60165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 1.62, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 2.83, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 3.64, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-valine', NULL, 3.64, 'g / l', 83780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('emtricitabine', NULL, 200, 'mg', 76043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('emtricitabine', NULL, 200, 'mg', 78602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 3.00, '%', 76603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 3.00, '%', 76604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 2, '%', 77476);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 0.75, '%', 78218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 1, '%', 78220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 3, '%', 78221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 2, '%', 77122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 2, '%', 77123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 1, '%', 78154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 2.00, '%', 77383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 0.75, '%', 78156);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 1.0, '%', 78656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 2.5, '%', 78813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 4.0, '%', 78893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 4.0, '%', 78894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 4.5, '%', 78895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 3.0, '%', 78604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 0.5, '%', 78646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 4.0, '%', 79098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 3.00, '% / w/w', 76605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 1.0, '% / w/w', 81654);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 0.5, '% / w/w', 82930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 1.5, '% / w/w', 82931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 4.5, '% / w/w', 80435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 1.0, '% / w/w', 81660);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 6.0, '% / w/w', 81661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 1.5, '% / w/w', 80393);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 3, '% / w/w', 82270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 4.5, '% / w/w', 80383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 3.0, '% / w/w', 79784);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drometrizole trisiloxane', NULL, 2.0, '% / w/w', 84715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('recombinant human papillomavirus type 6 l1 protein', NULL, 20, 'µg / 0.5 ml', 76882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('recombinant human papillomavirus type 11 l1 protein', NULL, 40, 'µg / 0.5 ml', 76882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('recombinant human papillomavirus type 16 l1 protein', NULL, 40, 'µg / 0.5 ml', 76882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('recombinant human papillomavirus type 16 l1 protein', NULL, 20, 'µg / 0.5 ml', 82773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('recombinant human papillomavirus type 18 l1 protein', NULL, 20, 'µg / 0.5 ml', 76882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('recombinant human papillomavirus type 18 l1 protein', NULL, 20, 'µg / 0.5 ml', 82773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyldopa', NULL, 250, 'mg', 5862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyldopa', NULL, 250, 'mg', 5820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyldopa', NULL, 250, 'mg', 5821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyldopa', NULL, 250, 'mg', 6163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenoxyisopropanol', NULL, 0.84, '%', 6675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxtriphylline', NULL, 20, 'mg / ml', 12803);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxtriphylline', NULL, 100, 'mg / 5 ml', 4258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', NULL, 150, 'µg', 18754);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', NULL, 150, 'µg', 18755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', NULL, 125, 'µg', 8123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', NULL, 50, 'µg', 8124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', NULL, 75, 'µg', 8124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', NULL, 125, 'µg', 8124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', NULL, 50, 'µg', 8123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', NULL, 75, 'µg', 8123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', NULL, 100, 'µg', 60269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', NULL, 100, 'µg', 60270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', NULL, 100, 'µg', 78383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', NULL, 100, 'µg', 78384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', NULL, 1.39, 'mg', 73542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', NULL, 0.15, 'mg', 78129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', NULL, 0.15, 'mg', 78130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', NULL, 0.15, 'mg', 78201);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', NULL, 0.15, 'mg', 83160);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fibrinogen (human)', NULL, 110, 'mg / 1 ml', 53282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fibrinogen (human)', NULL, 550, 'mg / 5 ml', 53284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fibrinogen (human)', NULL, 90, 'mg / ml', 83385);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipenem', NULL, 250, 'mg / vial', 84339);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', NULL, 0.8, '%', 8428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', NULL, 4.5, '%', 8429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipenem', NULL, 500, 'mg / vial', 84340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoleucine', NULL, 1.08, 'g / 100 ml', 43947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoleucine', NULL, 590, 'mg / 100 ml', 44068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoleucine', NULL, 560, 'mg / 100 ml', 15493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoleucine', NULL, 600, 'mg / 100 ml', 11329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoleucine', NULL, 462, 'mg / 100 ml', 7163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoleucine', NULL, 620, 'mg / 100 ml', 5891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoleucine', NULL, 480, 'mg / 100 ml', 4661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoleucine', NULL, 480, 'mg / 100 ml', 1888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diatrizoate sodium', NULL, 10, '%', 37570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (v.c.o.) type 1 mahoney', NULL, 40, 'unit / 0.5 ml', 44019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (v.c.o.) type 1 mahoney', NULL, 40, 'unit / 0.5 ml', 83726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (v.c.o.) type 3 saukett', NULL, 32, 'unit / 0.5 ml', 44019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inactivated poliomyelitis vaccine (v.c.o.) type 3 saukett', NULL, 32, 'unit / 0.5 ml', 83726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloramphenicol', NULL, 2, 'mg / ml', 13383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloramphenicol', NULL, 10, 'mg / g', 13682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('manganese (manganese gluconate)', NULL, 0.5, 'mg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('manganese (manganese sulfate)', NULL, 0.1, 'mg / ml', 20314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('manganese (manganese sulfate)', NULL, 0.1, 'mg / ml', 19923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('manganese (manganese sulfate)', NULL, 0.5, 'mg / ml', 16225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('manganese (manganese sulfate)', NULL, 0.1, 'mg / ml', 16226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('manganese (manganese sulfate)', NULL, 0.5, 'mg / ml', 16227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('manganese (manganese sulfate)', NULL, 0.5, 'mg / ml', 16224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', NULL, 8, 'mg', 10913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', NULL, 4, 'mg', 78554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', NULL, 8, 'mg', 78555);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('opium', NULL, 65, 'mg', 11257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('opium', NULL, 65, 'mg', 11124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('storax', NULL, 8, 'g / 100 ml', 41578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cascara sagrada', NULL, 100, 'mg', 60180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b6 (pyridoxine hydrochloride)', NULL, 15, 'mg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b6 (pyridoxine hydrochloride)', NULL, 10, 'mg', 70202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b6 (pyridoxine hydrochloride)', NULL, 10, 'mg', 76186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b6 (pyridoxine hydrochloride)', NULL, 1.2, 'mg / ml', 5613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('deoxycholic acid', NULL, 30, 'mg', 5276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetirizine hydrochloride', NULL, 5, 'mg', 70312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mometasone furoate', NULL, 50, 'µg / dose', 84679);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mometasone furoate', NULL, 100, 'µg / dose', 84680);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mometasone furoate', NULL, 200, 'µg / dose', 84681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sitagliptin (sitagliptin phosphate monohydrate)', NULL, 50, 'mg', 81954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sitagliptin (sitagliptin phosphate monohydrate)', NULL, 50, 'mg', 81956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sitagliptin (sitagliptin phosphate monohydrate)', NULL, 50, 'mg', 81955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium (potassium chloride, potassium citrate)', NULL, 40, 'mg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gold', NULL, 1.4, 'µg / 2 ml', 15975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc (zinc gluconate)', NULL, 3, 'mg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc (zinc oxide)', NULL, 15, 'mg', 70202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc (zinc oxide)', NULL, 15, 'mg', 76186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc (zinc sulfate)', NULL, 1, 'mg / ml', 20314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc (zinc sulfate)', NULL, 1, 'mg / ml', 19923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc (zinc sulfate)', NULL, 3, 'mg / ml', 16226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc (zinc sulfate)', NULL, 5, 'mg / ml', 16227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc (zinc sulfate)', NULL, 5, 'mg / ml', 16224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc (zinc sulfate)', NULL, 5, 'mg / ml', 16225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipenem', NULL, 500, 'mg', 84256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipenem', NULL, 250, 'mg / vial', 8348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipenem', NULL, 500, 'mg / vial', 8054);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipenem', NULL, 250, 'mg / vial', 83695);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipenem', NULL, 500, 'mg / vial', 83696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine sulfate', NULL, 120, 'mg', 12955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine sulfate', NULL, 60, 'mg', 3717);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine sulfate', NULL, 60, 'mg', 33922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine sulfate', NULL, 120, 'mg', 33922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine sulfate', NULL, 120, 'mg', 11974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine sulfate', NULL, 120, 'mg', 2048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine sulfate', NULL, 240, 'mg', 68939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine sulfate', NULL, 240, 'mg', 74601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine sulfate', NULL, 120, 'mg', 79491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pseudoephedrine sulfate', NULL, 30, 'mg / 5 ml', 20066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodoform', NULL, 15.8, 'g / 100 g', 4875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine hydrochloride', NULL, 310, 'mg / 100 ml', 19610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine hydrochloride', NULL, 310, 'mg / 100 ml', 19143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine hydrochloride', NULL, 310, 'mg / 100 ml', 18550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine hydrochloride', NULL, 310, 'mg / 100 ml', 15868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine hydrochloride', NULL, 310, 'mg / 100 ml', 14077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine hydrochloride', NULL, 310, 'mg / 100 ml', 14076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine hydrochloride', NULL, 310, 'mg / 100 ml', 14075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine hydrochloride', NULL, 263, 'mg / 100 ml', 14073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine hydrochloride', NULL, 263, 'mg / 100 ml', 14072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine hydrochloride', NULL, 263, 'mg / 100 ml', 14071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine hydrochloride', NULL, 155, 'mg / 100 ml', 14069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine hydrochloride', NULL, 310, 'mg / 100 ml', 14068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine hydrochloride', NULL, 310, 'mg / 100 ml', 14067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-leucine hydrochloride', NULL, 263, 'mg / 100 ml', 14066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enzacamene', NULL, 3.0, '%', 61235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enzacamene', NULL, 2.0, '%', 77540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enzacamene', NULL, 3, '%', 80438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enzacamene', NULL, 4, '% / w/w', 77394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enzacamene', NULL, 4, '% / w/w', 77395);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enzacamene', NULL, 4, '% / w/w', 77396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enzacamene', NULL, 2, '%', 50134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin aspart protamine', NULL, 70, '%', 75090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyl nicotinate', NULL, 0.75, '%', 50027);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butamben', NULL, 2, '%', 26564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butamben', NULL, 2, '%', 16688);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butamben', NULL, 25.7, 'g / 100 g', 4875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('folic acid', NULL, 0.04, 'mg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('folic acid', NULL, 1.1, 'mg', 70202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('folic acid', NULL, 5, 'mg', 76186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('folic acid', NULL, 140, 'µg / vial', 66277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('folic acid', NULL, 80, 'µg / ml', 16462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('folic acid', NULL, 80, 'µg / ml', 68684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b12 (cyanocobalamin)', NULL, 25, 'µg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b12 (cyanocobalamin)', NULL, 12, 'µg', 70202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b12 (cyanocobalamin)', NULL, 12, 'µg', 76186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b12 (cyanocobalamin)', NULL, 1, 'µg / vial', 66277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b12 (vitamin b12)', NULL, 1, 'µg / ml', 16462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b12', NULL, 100, 'µg / ml', 3497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b12 (cyanocobalamin)', NULL, 1, 'µg / ml', 68684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aliskiren (aliskiren fumarate)', NULL, 150, 'mg', 81838);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aliskiren (aliskiren fumarate)', NULL, 150, 'mg', 81839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aliskiren (aliskiren fumarate)', NULL, 300, 'mg', 81840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aliskiren (aliskiren fumarate)', NULL, 300, 'mg', 81841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', NULL, 5, 'mg', 37335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone (hydrocortisone acetate)', NULL, 5, 'mg', 37455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', NULL, 5, 'mg', 66276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', NULL, 5, 'mg', 72190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone (hydrocortisone acetate)', NULL, 1, '%', 15948);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', NULL, 1, '%', 10052);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', NULL, 1, '%', 5634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', NULL, 1, '%', 5635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', NULL, 1, '% / w/w', 810);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', NULL, 10, 'mg / ml', 11287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', NULL, 10, 'mg / ml', 12843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', NULL, 10, 'mg / ml', 49184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', NULL, 5, 'mg / g', 37334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone (hydrocortisone acetate)', NULL, 5, 'mg / g', 37454);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', NULL, 10, 'mg / g', 7030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', NULL, 10, 'mg / g', 66223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', NULL, 5, 'mg / g', 66275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', NULL, 5, 'mg / g', 71565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorthalidone', NULL, 25, 'mg', 17904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorthalidone', NULL, 25, 'mg', 18139);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorthalidone', NULL, 25, 'mg', 73131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorthalidone', NULL, 25, 'mg', 73132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorthalidone', NULL, 25, 'mg', 78821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorthalidone', NULL, 25, 'mg', 78822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('selenium (selenium hvp chelate)', NULL, 25, 'µg', 64976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('selenium (selenious acid)', NULL, 20, 'µg / ml', 20314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('selenium (selenious acid)', NULL, 60, 'µg / ml', 16225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('selenium (selenious acid)', NULL, 20, 'µg / ml', 16226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('selenium (selenious acid)', NULL, 60, 'µg / ml', 16227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rimexolone', 'S01BA13', 1, '%', 44105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 1.0, 'mg', 76288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 2, 'mg / 5 ml', 67912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 2, 'mg / 5 ml', 67924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 2, 'mg / 5 ml', 68031);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 2, 'mg / 5 ml', 68034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 2, 'mg / 5 ml', 68035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 4, 'mg / 5 ml', 69079);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 4, 'mg / 5 ml', 69080);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 2, 'mg / 5 ml', 75162);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 4, 'mg / 5 ml', 75163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 2, 'mg / 5 ml', 75189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 4, 'mg / 5 ml', 75190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 2.0, 'mg / 5 ml', 75283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 2.0, 'mg / 5 ml', 75285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 4.0, 'mg / 5 ml', 75286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 1.0, 'mg / 5 ml', 81416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 2, 'mg / 5 ml', 80101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 2, 'mg / 5 ml', 80102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brompheniramine maleate', NULL, 4, 'mg / 5 ml', 80103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiloride hydrochloride', NULL, 5, 'mg', 10494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiloride hydrochloride', NULL, 5, 'mg', 12430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiloride hydrochloride', NULL, 5, 'mg', 10806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiloride hydrochloride', NULL, 5, 'mg', 11966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiloride hydrochloride', NULL, 5, 'mg', 74257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine bitartrate', NULL, 9.1, 'µg / ml', 65585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine bitartrate', NULL, 9.1, 'µg / ml', 65586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine bitartrate', NULL, 0.01, 'mg / ml', 75640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine bitartrate', NULL, 0.02, 'mg / ml', 75645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine bitartrate', NULL, 0.0091, 'mg / ml', 79742);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine bitartrate', NULL, 0.0091, 'mg / ml', 79063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine bitartrate', NULL, 0.009, 'mg / ml', 82513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine bitartrate', NULL, 0.018, 'mg / ml', 82514);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone acetate', NULL, 2.5, 'mg / ml', 1394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone acetate', NULL, 40, 'mg / ml', 1619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone acetate', NULL, 2.5, 'mg / ml', 1527);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetyl-l-tyrosine', NULL, 115, 'mg / 100 ml', 47126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetyl-l-tyrosine', NULL, 115, 'mg / 100 ml', 18701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetyl-l-tyrosine', NULL, 94, 'mg / 100 ml', 18700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paraformaldehyde', NULL, 2.2, 'g / 100 g', 1251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tobramycin', NULL, 0.3, '%', 11068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tobramycin', NULL, 0.3, '%', 10971);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocodone bitartrate', NULL, 5, 'mg / 5 ml', 16635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocodone bitartrate', NULL, 1.7, 'mg / 5 ml', 16640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocodone bitartrate', NULL, 0.33, 'mg / ml', 5475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocodone bitartrate', NULL, 5, 'mg / 5 ml', 7082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocodone bitartrate', NULL, 2.5, 'mg / 5 ml', 4124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocodone bitartrate', NULL, 0.33, 'mg / ml', 4615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocodone bitartrate', NULL, 0.33, 'mg / ml', 50030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocodone bitartrate', NULL, 1.8, 'mg / 5 ml', 68035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', NULL, 2, 'mg', 60618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', NULL, 2, 'mg', 69200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('varicella-zoster virus vaccine live attenuated (oka/merck strain)', NULL, 1995.2623, 'unit / 0.5 ml', 78322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenoxylate hydrochloride', NULL, 2.5, 'mg', 937);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('auranofin', 'M01CB03', 3, 'mg', 15902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', NULL, 15, 'mg', 5717);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', NULL, 25, 'mg', 5726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', NULL, 25, 'mg', 5727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaiacol carbonate', NULL, 600, 'mg', 2148);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaiacol carbonate', NULL, 100, 'mg', 2149);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaiacol carbonate', NULL, 200, 'mg', 2150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertussis toxoid adsorbed', NULL, 8, 'µg / 0.5 ml', 79806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('filamentous haemagglutinin adsorbed', NULL, 8, 'µg / 0.5 ml', 79806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pertactin adsorbed', NULL, 2.5, 'µg / 0.5 ml', 79806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 30, 'µg', 43160);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 30, 'µg', 18754);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 30, 'µg', 18755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 30, 'µg', 8123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 30, 'µg', 8124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 40, 'µg', 8124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 30, 'µg', 8124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 40, 'µg', 8123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 30, 'µg', 8123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 30, 'µg', 3633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 30, 'µg', 3374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 30, 'µg', 1922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 30, 'µg', 2386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 20, 'µg', 2254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 20, 'µg', 2255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 35, 'µg', 53444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 20, 'µg', 60269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 20, 'µg', 60270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 5, 'µg', 66279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 20, 'µg', 78383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 20, 'µg', 78384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 42921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 42922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 42890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 42960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 42952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 42888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 42889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 42889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 42890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 20162);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.03, 'mg', 14191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 12988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 12998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.03, 'mg', 14355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.03, 'mg', 14354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 14199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 14199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 14199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 14197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 14197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 14197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 5482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 5482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 5482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 5483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 5483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 5483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 5103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 5104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 5105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 5106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.025, 'mg', 74243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.025, 'mg', 74243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.025, 'mg', 74243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.025, 'mg', 74376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.025, 'mg', 74376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.025, 'mg', 74376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.025, 'mg', 74378);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.025, 'mg', 74378);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.025, 'mg', 74378);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.025, 'mg', 75841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.025, 'mg', 75841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.025, 'mg', 75841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.030, 'mg', 74710);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.030, 'mg', 74711);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.60, 'mg', 72637);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 2.6, 'mg', 73815);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.03, 'mg', 78129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.03, 'mg', 78130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 77558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.03, 'mg', 78201);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.03, 'mg', 80270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg', 79517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.02, 'mg', 80656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.03, 'mg', 80272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.01, 'mg', 83160);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethinyl estradiol', NULL, 0.03, 'mg', 83160);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dipyridamole', NULL, 200, 'mg', 65795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('proxymetacaine hydrochloride', NULL, 0.5, '%', 6721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocodone', NULL, 5, 'mg', 12217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocodone', NULL, 5, 'mg / 5 ml', 12216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ioxaglate meglumine', NULL, 246, 'mg / ml', 9362);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ioxaglate meglumine', NULL, 393, 'mg / ml', 5554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atropine sulfate', NULL, 0.025, 'mg', 937);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 100, 'mg', 20239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 100, 'mg', 20189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 250, 'mg', 20190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 100, 'mg', 19767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 250, 'mg', 19758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 100, 'mg', 19766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 100, 'mg', 14082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 200, 'mg', 11481);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 100, 'mg', 4008);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 100, 'mg', 3331);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 50, 'mg', 4459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 100, 'mg', 2723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 200, 'mg', 2724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 250, 'mg', 2142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 100, 'mg', 68470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 100, 'mg', 68471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 250, 'mg', 68472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 200, 'mg', 69226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 100, 'mg', 71866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 100, 'mg', 75839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 75, 'mg', 82347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 125, 'mg', 82348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 50, 'mg', 79150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 100, 'mg', 79151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 150, 'mg', 79152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 100, 'mg', 79676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levodopa', NULL, 20, 'mg / ml', 77753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amphetamine sulfate', NULL, 1.25, 'mg', 73177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amphetamine sulfate', NULL, 2.5, 'mg', 73178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amphetamine sulfate', NULL, 3.75, 'mg', 73179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amphetamine sulfate', NULL, 5.00, 'mg', 73180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amphetamine sulfate', NULL, 6.25, 'mg', 73181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amphetamine sulfate', NULL, 7.5, 'mg', 73182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antipyrine', NULL, 10, 'mg / ml', 3546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antipyrine', NULL, 54, 'mg / ml', 81814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 5, '%', 79467);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 0.75, 'mg', 23260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride (lidocaine hydrochloride monohydrate)', NULL, 2, '% / w/w', 78032);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 2.0, '% / w/v', 31);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 20, 'mg / ml', 17901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 50, 'mg / ml', 10912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 20, 'mg / ml', 12648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 10, 'mg / ml', 12649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 15, 'mg / ml', 9802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 20, 'mg / ml', 635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 20, 'mg / ml', 636);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 36, 'mg / 1.8 ml', 2541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 36, 'mg / 1.8 ml', 2506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 20, 'mg / ml', 1830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 10, 'mg / ml', 589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 10, 'mg / ml', 590);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 15, 'mg / ml', 591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 20, 'mg / ml', 592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 20, 'mg / ml', 593);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 10, 'mg / ml', 1619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 50, 'mg / ml', 62611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 20, 'mg / ml', 68622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 20, 'mg / ml', 75645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 20, 'mg / ml', 75640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 20, 'mg / ml', 78332);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 20.00, 'mg / ml', 81732);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 20, 'mg / ml', 83052);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 50, 'mg / g', 62658);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 40, 'mg / g', 60209);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 50, 'mg / g', 72525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 50, 'mg / g', 80057);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 50, 'mg / g', 78974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', NULL, 50, 'mg / g', 80335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate trihydrate', NULL, 1.16, 'g / l', 83774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate trihydrate', NULL, 1.50, 'g / l', 83777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate trihydrate', NULL, 1.50, 'g / l', 83779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triprolidine hydrochloride', NULL, 4, 'mg', 955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triprolidine hydrochloride', NULL, 2.5, 'mg', 62610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triprolidine hydrochloride', NULL, 2.5, 'mg', 61704);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triprolidine hydrochloride', NULL, 2, 'mg / 5 ml', 20329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triprolidine hydrochloride', NULL, 2, 'mg / 5 ml', 15618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triprolidine hydrochloride', NULL, 2, 'mg / 5 ml', 956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triprolidine hydrochloride', NULL, 2, 'mg / 5 ml', 957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triprolidine hydrochloride', NULL, 2, 'mg / 5 ml', 66929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naloxone (naloxone hydrochloride dihydrate)', NULL, 0.5, 'mg', 78104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naloxone (naloxone hydrochloride dihydrate)', NULL, 2, 'mg', 78105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ergotamine tartrate', NULL, 1, 'mg', 696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ergotamine tartrate', NULL, 1, 'mg', 413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ergotamine tartrate', NULL, 0.6, 'mg', 48361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olmesartan  medoxomil', NULL, 20, 'mg', 80508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olmesartan  medoxomil', NULL, 40, 'mg', 80509);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olmesartan  medoxomil', NULL, 40, 'mg', 80510);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dopamine hydrochloride', NULL, 3.2, 'mg / ml', 11624);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dopamine hydrochloride', NULL, 1.6, 'mg / ml', 11625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dopamine hydrochloride', NULL, 0.8, 'mg / ml', 12256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dopamine hydrochloride', NULL, 3.2, 'mg / ml', 12681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dopamine hydrochloride', NULL, 1.6, 'mg / ml', 6768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dopamine hydrochloride', NULL, 0.8, 'mg / ml', 6769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon monoxide', NULL, 0.3, '%', 19100);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon monoxide', NULL, 0.3, '%', 19101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon monoxide', NULL, 0.3, '%', 13920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon monoxide', NULL, 0.3, '%', 8185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon monoxide', NULL, 0.1, '%', 44612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoctrizole', NULL, 3, '% / w/w', 77394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoctrizole', NULL, 2.5, '% / w/w', 77395);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoctrizole', NULL, 1.5, '% / w/w', 77396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoctrizole', NULL, 3.0, '% / w/w', 83705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoctrizole', NULL, 6.0, '% / w/w', 83706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoctrizole', NULL, 6.0, '% / w/w', 83710);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bemotrizinol', NULL, 2, '% / w/w', 77394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bemotrizinol', NULL, 2, '% / w/w', 77395);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bemotrizinol', NULL, 2, '% / w/w', 77396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bemotrizinol', NULL, 0.5, '% / w/w', 82930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bemotrizinol', NULL, 3.0, '% / w/w', 82931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bemotrizinol', NULL, 2.0, '% / w/w', 83705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bemotrizinol', NULL, 4.5, '% / w/w', 83706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bemotrizinol', NULL, 3.5, '% / w/w', 83710);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aprotinin (synthetic)', NULL, 3000, 'kiu / ml', 81151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sealer protein (human)', NULL, 125, 'mg / ml', 81151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('human-bovine rotavirus reassortant type g1', NULL, 2210000, 'unit / dose', 76999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('human-bovine rotavirus reassortant type g2', NULL, 2840000, 'unit / dose', 76999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('human-bovine rotavirus reassortant type g3', NULL, 2220000, 'unit / dose', 76999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('human-bovine rotavirus reassortant type g4', NULL, 2040000, 'unit / dose', 76999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('human-bovine rotavirus reassortant type p1(8)', NULL, 2290000, 'unit / dose', 76999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dipivefrin hydrochloride', NULL, 0.1, '%', 43034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', NULL, 5, 'mg', 63844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', NULL, 2.5, 'mg', 63845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', NULL, 10.0, 'mg', 76878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', NULL, 2.5, 'mg', 76876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', NULL, 5.0, 'mg', 76877);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', NULL, 5.0, 'mg', 76879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', NULL, 10.0, 'mg', 76880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', NULL, 2.5, 'mg', 82763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', NULL, 5.0, 'mg', 82764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', NULL, 10.0, 'mg', 82765);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', NULL, 5.0, 'mg', 82766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', NULL, 10.0, 'mg', 82767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 5, 'mg', 43310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haemagglutinin from a/california/7/2009 (h1n1)v-like strain (x-179a)', NULL, 3.75, 'µg / 0.5 ml', 82225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('plasminogen', NULL, 120, 'µg / 1 ml', 53282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('plasminogen', NULL, 600, 'µg / 5 ml', 53284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('parachlorophenol', NULL, 35, '%', 10065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('parachlorophenol', NULL, 300, 'mg / 1 g', 2977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protein c', NULL, 820, 'unit', 84428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protein c', NULL, 620, 'unit / vial', 78001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protein s', NULL, 680, 'unit', 84428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protein s', NULL, 640, 'unit / vial', 78001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzophenone', NULL, 3.0, '%', 77065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 37150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 22846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 22847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 17887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 17880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 19103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 16437);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 7.5, 'mg', 11646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 3.75, 'mg', 11041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 8249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 8250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 8251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 8252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg', 62614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 5, 'mg', 63999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 65178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 65249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 65250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 67104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 68103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg', 72216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 70285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 70286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg', 69737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 69738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 70399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 71091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20, 'mg', 76429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 5, 'mg', 76431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 72935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 74005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 74007);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 76681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 74414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 74415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 5, 'mg', 75728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 74549);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 74550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 75828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 75829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 76130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 76138);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 76167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 76171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 76178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 76185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 76190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 76189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 76192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 73702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 73703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 78062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 77849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 77891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 77892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 0.5, 'mg', 23261);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 77847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 77185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 81657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 82152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 79088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 79269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 79278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg', 79504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 80829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 79146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 79071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 82084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg', 83056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 7.5, 'mg', 83258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 83303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg', 83304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20, 'mg', 83878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20, 'mg / pck', 35886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / pck', 37105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / pck', 21167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / pck', 11901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / pck', 65873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / pck', 65633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20, 'mg / pck', 75146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20, 'mg / pck', 77936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20, 'mg / pck', 83004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 36293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 36232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / 30 ml', 37183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 7.5, 'mg / 5 ml', 31502);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 7.5, 'mg / 5 ml', 30945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 30826);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 27462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 27463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 7.5, 'mg / 5 ml', 26864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg / 5 ml', 19772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 19060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 19129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 19026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20, 'mg / 15 ml', 18910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 16698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 12.5, 'mg / 5 ml', 16177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 16662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 13565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 7.5, 'mg / 5 ml', 14551);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 28.5, 'mg / 30 ml', 13479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 13440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 14485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / 30 ml', 13960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 7.5, 'mg / 5 ml', 13361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 13296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 11229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 12449);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 12410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 15 ml', 12719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / 20 ml', 12722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg / 15 ml', 12717);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 15 ml', 12718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 12192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 7.5, 'mg / 5 ml', 12504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 8324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 5, 'mg / 5 ml', 5431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg / 5 ml', 4252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg / 5 ml', 1498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 52513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 52514);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 60207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 7.5, 'mg / 5 ml', 63140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 7.5, 'mg / 5 ml', 66361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 66839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 15 ml', 66840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 66851);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 7.5, 'mg / 5 ml', 66928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 66947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / 30 ml', 66983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 65129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 65130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 65131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 7.5, 'mg / 5 ml', 65132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 65133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg / 5 ml', 67912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 15 ml', 68650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20, 'mg / 5 ml', 69080);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 5, 'mg / 5 ml', 67672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / 30 ml', 72095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 15 ml', 69814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 5, 'mg / 5 ml', 76432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 5, 'mg / 5 ml', 76469);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 75087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 75088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg / 5 ml', 75189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20, 'mg / 5 ml', 75190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg / 5 ml', 72923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10.0, 'mg / 5 ml', 75285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20.0, 'mg / 5 ml', 75286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20, 'mg / 30 ml', 76233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 75515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 75516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 2.5, 'mg / ml', 75558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 5, 'mg / ml', 75559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 74432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20.0, 'mg / 15 ml', 75827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / 30 ml', 75858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 15 ml', 75882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / 30 ml', 74683);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / 30 ml', 74797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 7.5, 'mg / 5 ml', 74799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20, 'mg / 30 ml', 76166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 74852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 74853);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20, 'mg / 30 ml', 76254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 15 ml', 73724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 5, 'mg / 5 ml', 76366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / 30 ml', 77475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20, 'mg / 30 ml', 77628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / 30 ml', 77585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / 30 ml', 77674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / 30 ml', 77675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 5, 'mg / 5 ml', 77749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 7.5, 'mg / 5 ml', 81390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 5 ml', 80637);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 5, 'mg / 5 ml', 81394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 7.5, 'mg / 5 ml', 79105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20, 'mg / 30 ml', 78620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 5, 'mg / 5 ml', 79122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 5.0, 'mg / 5 ml', 81416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / 30 ml', 78973);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / 15 ml', 79763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg / 5 ml', 80102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20, 'mg / 5 ml', 80103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 15, 'mg / 15 ml', 80682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 10, 'mg / 15 ml', 80938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / 23 g', 19088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 30, 'mg / 22 g', 65060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', NULL, 20, 'mg / 24 g', 71050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ticarcillin (ticarcillin disodium)', NULL, 3, 'g / vial', 15224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ticarcillin (ticarcillin disodium)', NULL, 30, 'g / vial', 72188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal group a oligosaccharide', NULL, 10, 'µg / 0.5 ml', 83276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal group y oligosaccharide', NULL, 5, 'µg / 0.5 ml', 83276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meningococcal group w-135 oligosaccharide', NULL, 5, 'µg / 0.5 ml', 83276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fimbriae types 2 and 3 (fim)', NULL, 5, 'µg / 0.5 ml', 63789);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fimbriae types 2 and 3 (fim)', NULL, 5, 'µg / 0.5 ml', 83726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('influenza virus type a (h1n1)', NULL, 7, 'unit / 0.2 ml', 83789);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('influenza virus type a (h3n2)', NULL, 7, 'unit / 0.2 ml', 83789);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('influenza virus type b', NULL, 7, 'unit / 0.2 ml', 83789);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium sulfate anhydrous', NULL, 7.500, 'g / pck', 84451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 4, 'mg', 23194);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('boceprevir', NULL, 200, 'mg', 85593);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('boceprevir', NULL, 200, 'mg / cap', 85660);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('boceprevir', NULL, 200, 'mg / cap', 85661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('boceprevir', NULL, 200, 'mg / cap', 85662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('boceprevir', NULL, 200, 'mg / cap', 85663);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meglumine iodipamide', 'V08AC04', 52, '%', 37569);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eugenol', 'V04CL', 0.034, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isosorbide dinitrate', 'C01DA08', 10, 'mg', 11456);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isosorbide dinitrate', 'C01DA08', 30, 'mg', 11457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isosorbide dinitrate', 'C01DA08', 5, 'mg', 6550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isosorbide dinitrate', 'C01DA08', 10, 'mg', 4730);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isosorbide dinitrate', 'C01DA08', 30, 'mg', 4731);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isosorbide dinitrate', 'C01DA08', 30, 'mg', 5180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isosorbide dinitrate', 'C01DA08', 10, 'mg', 5179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guanethidine sulfate', 'C02CC02', 10, 'mg', 2748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guanethidine sulfate', 'C02CC02', 25, 'mg', 2749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 400, 'mg', 83879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 200, 'mg', 83880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 100, 'mg / 5 ml', 41988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 100, 'mg / 5 ml', 41989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 200, 'mg / 5 ml', 42606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 100, 'mg / 5 ml', 30557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 100, 'mg / 5 ml', 27461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 200, 'mg / 5 ml', 19044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 100, 'mg / 5 ml', 14486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 100, 'mg / 5 ml', 11001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 5.45, '%', 70443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 100, 'mg / 5 ml', 12620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 100, 'mg / 5 ml', 11918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.55, '%', 73982);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 200, 'mg / 5 ml', 66724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 200, 'mg / 15 ml', 65015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 100, 'mg / 5 ml', 65128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 200, 'mg / 5 ml', 75089);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 100, 'mg / 5 ml', 77454);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 200, 'mg / 5 ml', 80636);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 100, 'mg / 5 ml', 80928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 200, 'mg / 15 ml', 80935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('guaifenesin', 'R05CA03', 100, 'mg / 5 ml', 83190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline hydrochloride', 'S01GA01', 0.012, '%', 72380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline hydrochloride', 'S01GA01', 0.1, '%', 80143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline hydrochloride', 'S01GA01', 0.012, '% / w/v', 8526);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline hydrochloride', 'S01GA01', 0.1, '%', 17734);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline hydrochloride', 'S01GA01', 0.1, '%', 6772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline hydrochloride', 'S01GA01', 0.1, '%', 934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline hydrochloride', 'S01GA01', 0.1, '%', 2634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methacholine chloride', 'V04CX', 100, 'mg / vial', 63128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methacholine chloride', 'V04CX', 1280, 'mg / vial', 67775);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methacholine chloride', 'V04CX', 160, 'mg / vial', 70667);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methacholine chloride', 'V04CX', 320, 'mg / vial', 70668);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methacholine chloride', 'V04CX', 100, 'mg / vial', 74930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methacholine chloride', 'V04CX', 480, 'mg / vial', 74931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methacholine chloride', 'V04CX', 1600, 'mg / vial', 74932);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methacholine chloride', 'V04CX', 1600, 'mg / vial', 77421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mannitol', 'B05BC01', 20, 'g / 100 ml', 10516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mannitol', 'B05BC01', 10, 'g / 100 ml', 10517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mannitol', 'B05BC01', 200, 'mg / ml', 1740);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mannitol', 'B05BC01', 250, 'mg / ml', 1181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mannitol', 'B05BC01', 250, 'mg / ml', 67055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('busulfan', 'L01AB01', 2, 'mg', 959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('busulfan', 'L01AB01', 6, 'mg / ml', 64173);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolbutamide', 'A10BB03', 500, 'mg', 2092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 3.75, '%', 70553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dolichovespula arenaria venom protein extract', 'V01AA07', 120, 'µg / vial', 13952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dolichovespula arenaria venom protein extract', 'V01AA07', 1.1, 'mg / vial', 46470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vespula spp venom protein extract', 'V01AA07', 120, 'µg / vial', 13951);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vespula spp venom protein extract', 'V01AA07', 1300, 'µg / vial', 50137);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vespula spp venom protein extract', 'V01AA07', 1.1, 'mg / vial', 14598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dolichovespula maculata venom protein extract', 'V01AA07', 120, 'µg / vial', 15874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dolichovespula maculata venom protein extract', 'V01AA07', 1.1, 'mg / vial', 46471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polistes spp venom protein extract', 'V01AA07', 120, 'µg / vial', 13950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polistes spp venom protein extract', 'V01AA07', 1300, 'µg / vial', 50138);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polistes spp venom protein extract', 'V01AA07', 1.1, 'mg / vial', 14597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('apis mellifera venom protein extract', 'V01AA07', 120, 'µg / vial', 14601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('apis mellifera venom protein extract', 'V01AA07', 1300, 'µg / vial', 50133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 4, 'mg', 3661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('apis mellifera venom protein extract', 'V01AA07', 1.1, 'mg / vial', 14602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('porfimer sodium', 'L01XD01', 75, 'mg / vial', 19685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('porfimer sodium', 'L01XD01', 15, 'mg / vial', 19686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lymphocyte immune globulin anti-thymocyte globulin (equine)', 'L04AA03', 50, 'mg / ml', 55838);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin isophane injection pork', 'A10AC03', 100, 'unit / ml', 76152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('filgrastim (r-methug-csf)', 'L03AA02', 300, 'µg / ml', 12474);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin injection pork', 'A10AB03', 100, 'unit / ml', 76153);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dermatophagoides farinae', 'V01AA07', 10000, 'unit / ml', 43205);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dermatophagoides farinae', 'V01AA03', 10000, 'unit / ml', 37351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dermatophagoides farinae', 'V01AA07', 30000, 'unit / ml', 37352);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dermatophagoides farinae', 'V01AA03', 15000, 'unit / ml', 37353);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dermatophagoides farinae', 'V01AA03', 5000, 'unit / ml', 37354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dermatophagoides farinae', 'V01AA07', 10000, 'unit / ml', 50628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dermatophagoides farinae', 'V01AA03', 5000, 'unit / ml', 75630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone valerate)', 'D07AC01', 0.1, '%', 19225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', 'D07AC01', 0.05, '%', 13888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', 'D07AC01', 0.05, '%', 13889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', 'D07AC01', 0.05, '%', 10941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone valerate)', 'D07AC01', 0.05, '%', 8972);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone valerate)', 'D07AC01', 0.1, '%', 6620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone valerate)', 'D07AC01', 0.05, '%', 6822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone valerate)', 'D07AC01', 0.1, '%', 1147);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone valerate)', 'D07AC01', 0.1, '%', 14132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', 'D07AC01', 0.05, '%', 13005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone sodium phosphate)', 'A07EA04', 5, 'mg / 100 ml', 27517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', 'D07AC01', 0.5, 'mg / g', 13690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', 'D07AC01', 0.5, 'mg / g', 14445);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', 'D07AC01', 0.5, 'mg / g', 10940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone valerate)', 'D07AC01', 0.5, 'mg / g', 9270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', 'D07AC01', 0.5, 'mg / g', 10211);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', 'D07AC01', 0.5, 'mg / g', 8190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone (betamethasone dipropionate)', 'D07AC01', 0.5, 'mg / g', 6529);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisolone acetate', 'S01BA04', 1, '%', 16234);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisolone acetate', 'S01BA04', 0.12, '%', 14126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisolone acetate', 'S01BA04', 1, '%', 13946);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisolone acetate', 'S01BA04', 1, '%', 7042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisolone acetate', 'S01BA04', 0.12, '%', 1936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisolone acetate', 'S01BA04', 1, '%', 1937);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone', 'H02AB04', 16, 'mg', 1396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone', 'H02AB04', 4, 'mg', 1397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone (methylprednisolone sodium succinate)', 'H02AB04', 1, 'g / vial', 16743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone (methylprednisolone sodium succinate)', 'H02AB04', 1, 'g / vial', 1130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone', 'H02AB04', 1, 'g / vial', 52242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone (methylprednisolone sodium succinate)', 'H02AB04', 500, 'mg / vial', 19021);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone (methylprednisolone sodium succinate)', 'H02AB04', 40, 'mg / vial', 16742);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone (methylprednisolone sodium succinate)', 'H02AB04', 125, 'mg / vial', 16710);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone (methylprednisolone sodium succinate)', 'H02AB04', 500, 'mg / vial', 1132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone (methylprednisolone sodium succinate)', 'H02AB04', 40, 'mg / vial', 51346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone (methylprednisolone sodium succinate)', 'H02AB04', 125, 'mg / vial', 51347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone (methylprednisolone sodium succinate)', 'H02AB04', 500, 'mg / vial', 51348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone', 'H02AB04', 500, 'mg / vial', 52240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone (methylprednisolone sodium succinate)', 'H02AB04', 1000, 'mg / vial', 64837);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisolone sodium phosphate', 'S01BA04', 0.5, '%', 18750);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisolone sodium phosphate', 'S01BA04', 1, '%', 13075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorometholone', 'S01BA07', 0.25, '%', 7626);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorometholone', 'S01BA07', 0.1, '%', 1470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorometholone', 'S01BA07', 0.1, '%', 61995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorometholone acetate', 'S01BA07', 0.1, '%', 8229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('budesonide', 'A07EA06', 3, 'mg', 43534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('budesonide', 'A07EA06', 2.3, 'mg', 16264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('budesonide', 'R01AD05', 100, 'µg / act', 14570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('budesonide', 'R03BA02', 400, 'µg / act', 12182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('budesonide', 'R03BA02', 200, 'µg / act', 10666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('budesonide', 'R03BA02', 100, 'µg / act', 10667);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('budesonide', 'R01AD05', 64, 'µg / act', 51375);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('budesonide', 'R01AD05', 100, 'µg / act', 49895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('budesonide', 'R01AD05', 64, 'µg / act', 64595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('budesonide', 'R03BA02', 0.125, 'mg / ml', 43511);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('budesonide', 'R03BA02', 0.25, 'mg / ml', 13191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('budesonide', 'R03BA02', 0.5, 'mg / ml', 13190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone hexacetonide', 'H02AB08', 20, 'mg / ml', 35794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 5.32, '%', 70589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone diacetate', 'H02AB08', 40, 'mg / ml', 13276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', 'D07AB09', 0.1, '%', 35783);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', 'D07AB09', 0.1, '%', 35784);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', 'D07AB09', 0.5, '%', 35785);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', 'D07AB09', 0.025, '%', 9278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', 'D07AB09', 0.1, '%', 8573);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', 'R01AD11', 55, 'µg / dose', 19807);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', 'R01AD11', 100, 'µg / dose', 13157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '%', 75280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', 'A01AC01', 0.1, '%', 13360);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', 'H02AB08', 40, 'mg / ml', 15481);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', 'H02AB08', 10, 'mg / ml', 15482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', 'H02AB08', 40, 'mg / ml', 13998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', 'H02AB08', 10, 'mg / ml', 47450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', 'H02AB08', 40, 'mg / ml', 47461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triamcinolone acetonide', 'D07AB09', 1, 'mg / g', 9280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desoximetasone', 'D07AC03', 0.25, '%', 43314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desoximetasone', 'D07AC03', 0.05, '%', 43315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desoximetasone', 'D07AC03', 0.25, '%', 43317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desoximetasone', 'D07AC03', 0.05, '%', 62520);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desoximetasone', 'D07AC03', 0.25, '%', 62523);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desoximetasone', 'D07AC03', 0.05, '%', 65557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desoximetasone', 'D07AC03', 0.05, '%', 43316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone sodium phosphate', 'S03BA01', 0.1, '%', 16262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone sodium phosphate', 'S03BA01', 0.1, '%', 6364);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone sodium phosphate', 'S03BA01', 1, 'mg / ml', 12640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 0.75, 'mg', 1899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 0.5, 'mg', 1887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 4, 'mg', 60349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 0.5, 'mg', 60347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 0.75, 'mg', 60348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 0.5, 'mg', 64268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 4, 'mg', 64271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 4, 'mg', 63010);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 2, 'mg', 76497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 0.5, 'mg', 74650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 4, 'mg', 73487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 4, 'mg', 79685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'S01BA01', 0.1, '%', 4591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'S01BA01', 0.1, '%', 2620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 0.5, 'mg / 5 ml', 12967);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone (dexamethasone sodium phosphate)', 'H02AB02', 10, 'mg / ml', 12208);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone', 'H02AB02', 0.5, 'mg / 5 ml', 74552);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone dipropionate', 'D07AC01', 0.05, '%', 2272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone dipropionate', 'D07AC01', 0.05, '%', 2870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 150, 'µg', 36947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone dipropionate', 'D07AC01', 0.05, '%', 2071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone dipropionate', 'D07AC01', 0.05, '%', 18006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone dipropionate', 'D07AC01', 0.05, '%', 18007);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone dipropionate', 'D07AC01', 0.05, '%', 18008);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone dipropionate', 'D07AC01', 0.05, '%', 18009);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone dipropionate', 'D07AC01', 0.05, '%', 17992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone dipropionate', 'D07AC01', 0.05, '%', 17968);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone dipropionate', 'D07AC01', 0.5, 'mg / g', 12272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 2.5, 'mg', 43299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 5, 'mg', 43300);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 10, 'mg', 43301);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 2.5, 'mg', 13037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 10, 'mg', 13592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 5, 'mg', 14529);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 10, 'mg', 7480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 100, 'mg', 675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 5, 'mg', 430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 2.5, 'mg', 68715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 5, 'mg', 68716);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 2.5, 'mg', 70819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 5, 'mg', 70820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 10, 'mg', 70821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 2.5, 'mg', 71837);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 5, 'mg', 71839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 10, 'mg', 71840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 100, 'mg', 75305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 10, 'mg', 76294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 2.5, 'mg', 73852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03DA02', 5, 'mg', 73853);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03AC06', 150, 'mg / ml', 19667);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03AC06', 50, 'mg / ml', 441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('medroxyprogesterone acetate', 'G03AC06', 150, 'mg / ml', 80771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 10.6, '%', 36549);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 3.15, '%', 19364);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 4, '%', 20271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 3.6, '%', 19302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 8.5, '%', 19768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 2.75, '%', 18412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 0.7, '%', 17426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 3.56, '%', 16133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 3.75, '%', 14368);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 1, '%', 12396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 1, '%', 12247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 8.5, '%', 11343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 8.5, '%', 6212);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 1.72, '%', 3829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 4, '%', 4201);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 3.225, '%', 3629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 1.72, '%', 3879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 3.37, '%', 3093);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 0.03, '%', 50814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 1.7, '%', 60158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 10.8, '%', 62881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene', 'V07AV', 5.32, '%', 66340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 50, 'µg', 36945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 100, 'µg', 36946);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 200, 'µg', 36948);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 300, 'µg', 36949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 50, 'µg', 19587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 25, 'µg', 19588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 112, 'µg', 19589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 125, 'µg', 19594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 75, 'µg', 19595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 300, 'µg', 19596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 200, 'µg', 19597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 150, 'µg', 19598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 88, 'µg', 19599);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 175, 'µg', 19600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 100, 'µg', 19601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 137, 'µg', 53868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 25, 'µg', 74978);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 50, 'µg', 74979);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 75, 'µg', 74980);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 88, 'µg', 74981);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 100, 'µg', 74982);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 112, 'µg', 74984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 125, 'µg', 74985);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 137, 'µg', 74986);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 150, 'µg', 74987);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 175, 'µg', 74988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 200, 'µg', 74989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 300, 'µg', 74991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levothyroxine sodium', 'H03AA01', 500, 'µg / vial', 70072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cytarabine', 'L01BC01', 1, 'g / vial', 19582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cytarabine', 'L01BC01', 2, 'g / vial', 19583);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cytarabine', 'L01BC01', 100, 'mg / vial', 19581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cytarabine', 'L01BC01', 500, 'mg / vial', 19578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cytarabine', 'L01BC01', 100, 'mg / ml', 43843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cytarabine', 'L01BC01', 100, 'mg / 5 ml', 2792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cytarabine', 'L01BC01', 10, 'mg / ml', 64756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracaine (tetracaine hydrochloride)', 'D04AB06', 40, 'mg / g', 49664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alanine', 'B05ZA', 95.1, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('melphalan', 'L01AA03', 2, 'mg', 1195);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('melphalan (melphalan hydrochloride)', 'L01AA03', 50, 'mg / vial', 18786);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prilocaine hydrochloride', 'N01BB04', 40, 'mg / ml', 4203);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lysine (lysine monohydrochloride)', 'B05ZA', 95.5, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cellulase', 'A09AA02', 2, 'mg', 3189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', 'D05AA', 2.0, '%', 41889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', 'D05AA', 2.0, '%', 15950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', 'D05AA', 1.8, '%', 13013);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', 'D05AA', 1.8, '%', 13014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', 'D05AA', 2, '%', 10142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', 'D05AA', 4, '%', 6848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', 'D05AA', 3, '%', 4037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', 'D05AA', 2, '%', 3320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', 'D05AA', 2.0, '%', 1667);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', 'D05AA', 1, '%', 48713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', 'V07AV', 0.5, '%', 70547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', 'D05AA', 3, '% / w/v', 10674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salicylic acid', 'D05AA', 4, '% / w/v', 10141);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 50, 'mg', 25821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 15, 'mg', 16428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 25, 'mg', 9585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 50, 'mg', 5885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 50, 'mg', 5572);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 50, 'mg', 3491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 15, 'mg', 3943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 50, 'mg', 3944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 50, 'mg', 577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 100, 'mg', 2890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 50, 'mg', 2891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 50, 'mg', 2701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 100, 'mg', 193);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 50.0, 'mg', 63745);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 50, 'mg', 65184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 50, 'mg', 69289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 50, 'mg', 69468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 50, 'mg', 69984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 100, 'mg', 73930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 50, 'mg', 74882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 3, 'mg / ml', 40419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 15, 'mg / 5 ml', 20059);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'A04AD', 50, 'mg / ml', 16994);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 10, 'mg / ml', 3595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'A04AD', 50, 'mg / ml', 3397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 15, 'mg / 5 ml', 1256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 50, 'mg / ml', 197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimenhydrinate', 'R06AA02', 50, 'mg / ml', 78595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium salicylate', 'C05BB', 570, 'mg / ml', 6261);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clomiphene citrate', 'G03GB02', 50, 'mg', 19347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clomiphene citrate', 'G03GB02', 50, 'mg', 11805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clomiphene citrate', 'G03GB02', 50, 'mg', 6391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycol salicylate', 'M02AC', 1.25, 'g / 100 g', 61438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('halothane', 'N01AB01', 99.99, '%', 2226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('progesterone', 'G03DA04', 100, 'mg', 18500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('progesterone', 'G03DA04', 100, 'mg', 82061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('progesterone', 'G03DA04', 8, '%', 64606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('progesterone', 'G03DA04', 50, 'mg / ml', 13300);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasone butyrate', 'D07AB01', 0.05, '%', 37001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 43175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 36954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 36953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 36952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 20127);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 20117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 13437);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 13438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 13439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 14381);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 14382);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 51612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 69609);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 69610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 69611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 74161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 74162);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 78510);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '% / w/w', 79513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 51610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%', 51611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednicarbate', 'D07AC18', 0.1, '%', 43464);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednicarbate', 'D07AC18', 0.1, '%', 49818);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('beclomethasone dipropionate', 'D07AC15', 0.025, '%', 28440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('beclomethasone dipropionate', 'R01AD01', 50, 'µg / spray', 62003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('beclomethasone dipropionate', 'R01AD01', 50, 'µg / spray', 62232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('beclomethasone dipropionate', 'R01AD01', 50, 'µg / act', 43481);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('beclomethasone dipropionate', 'R01AD01', 50, 'µg / act', 18874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('beclomethasone dipropionate', 'R03BA01', 50, 'µg / act', 65700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('beclomethasone dipropionate', 'R03BA01', 100, 'µg / act', 65701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyproterone acetate', 'G03HA01', 50, 'mg', 7394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyproterone acetate', 'G03HA01', 50, 'mg', 52361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyproterone acetate', 'G03HA01', 50, 'mg', 70015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyproterone acetate', 'G03HA01', 100, 'mg / ml', 11880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diflucortolone valerate', 'D07AC06', 0.1, '%', 5442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diflucortolone valerate', 'D07AC06', 0.1, '%', 5443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diflucortolone valerate', 'D07AC06', 0.1, '%', 5444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone valerate', 'D07AA02', 0.2, '%', 66824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone valerate', 'D07AA02', 0.2, '%', 66825);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cosyntropin', 'H01AA02', 0.25, 'mg / vial', 1954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cosyntropin (cosyntropin zinc hydroxide complex)', 'H01AA02', 1, 'mg / ml', 3725);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cortisone acetate', 'H02AB10', 25, 'mg', 1802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', 'D07AA02', 2, '%', 10393);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', 'A07EA02', 10, '% / w/w', 5575);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', 'D07AA02', 1, '%', 9275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone acetate', 'S01BA02', 25, 'mg / g', 13115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('megestrol acetate', 'L02AB01', 40, 'mg', 19730);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('megestrol acetate', 'L02AB01', 160, 'mg', 19731);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('megestrol acetate', 'L02AB01', 40, 'mg', 20029);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('megestrol acetate', 'L02AB01', 160, 'mg', 20026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('megestrol acetate', 'L02AB01', 40, 'mg / ml', 19230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('testosterone cypionate', 'G03BA03', 100, 'mg / ml', 13410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('testosterone cypionate', 'G03BA03', 100, 'mg / ml', 1398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('testosterone cypionate', 'G03BA03', 100, 'mg / ml', 70198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('testosterone propionate', 'G03BA03', 100, 'mg / ml', 13414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone acetate', 'G03DC02', 5, 'mg', 1401);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norethindrone', 'G03AC01', 0.35, 'mg', 1290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esterified estrogens', 'G03CA07', 0.3, 'mg', 3756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esterified estrogens', 'G03CA07', 0.625, 'mg', 1978);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estrone', 'G03CA07', 1, 'mg / g', 7645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norepinephrine (norepinephrine bitartrate)', 'C01CA03', 1, 'mg / ml', 11641);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norepinephrine (norepinephrine bitartrate)', 'C01CA03', 1, 'mg / ml', 65651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth tribromophenate', 'D09AX', 3, '%', 13539);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methoxsalen', 'D05BA02', 10, 'mg', 13573);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methoxsalen', 'D05BA02', 10, 'mg', 11972);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methoxsalen', 'D05AD02', 10, 'mg / ml', 13403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('monobenzone', 'D11AX13', 20, '%', 14008);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.55, '%', 71282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine acetate', 'A01AB03', 10, '%', 15801);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine acetate', 'V07AV', 2, '%', 1016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine acetate', 'V07AV', 0.01, '%', 73633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine acetate', 'D09AA12', 0.5, '%', 3111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene sodium', 'V07AV', 6.1, '%', 2494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene sodium', 'V07AV', 6.1, '%', 2495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorophene sodium', 'V07AV', 6.1, '%', 2493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.58, '%', 37672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.30, '%', 37673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.6, '%', 37625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '%', 37501);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '%', 37869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.25, '%', 19611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 13357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.55, '%', 11919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 6621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '%', 7341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D05AA', 0.3, '%', 1667);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 50946);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.375, '%', 59735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 60734);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 60738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 61685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.30, '%', 62780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 63657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 1, '%', 65853);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.19, '%', 65934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.10, '%', 65951);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.2, '%', 65956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 66674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 66676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.19, '%', 66138);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.1, '%', 65029);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 65095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.1, '%', 67303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.1, '%', 67304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.1, '%', 67305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.1, '%', 67306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.1, '%', 67307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 67995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 1, '%', 68120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.375, '%', 68204);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '%', 71337);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '%', 70825);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.50, '%', 69527);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '%', 70288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 70352);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 76373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 76374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.1, '%', 76689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.1, '%', 76690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '%', 75407);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.10, '%', 73055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.1, '%', 74262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 75504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 75505);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.1, '%', 73383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.4, '%', 73418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '%', 73440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 72682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 72683);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 73591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '%', 73652);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.46, '%', 74924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 73688);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 75039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '%', 72751);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 77277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 76939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.1, '%', 77860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '%', 77866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 77213);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 77216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.25, '%', 78342);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '%', 80104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '%', 80105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.1, '%', 82465);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.1, '%', 85169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.1, '% / w/w', 37844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.1, '% / w/w', 18812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.25, '% / w/w', 67289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '% / w/w', 68330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 1, '% / w/w', 68254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '% / w/w', 79709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '% / w/w', 79710);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '% / w/w', 79711);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 1, '% / w/w', 80794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '% / w/w', 80421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.2, '% / w/w', 80459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '% / w/w', 80461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.46, '% / w/w', 80877);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '% / w/w', 79431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '% / w/w', 82524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.2, '% / w/w', 83155);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.2, '% / w/w', 83339);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.2, '% / w/w', 83340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.2, '% / w/w', 83341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.2, '% / w/w', 84682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.2, '% / w/w', 84683);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.46, '% / w/w', 84702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.10, '% / w/v', 84043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.1, '% / w/v', 84206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.32, '%', 20166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.55, '%', 20042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 17953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 1, '%', 15566);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.2, '%', 15971);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '%', 10499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.745, '%', 10500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 11537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamabrom', 'C03BD', 50, 'mg', 66725);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 7122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '%', 6538);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.5, '%', 1668);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.2, '%', 50085);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.32, '%', 50961);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.25, '%', 61329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.2, '%', 61379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 62107);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 61762);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 1, '%', 63527);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 1, '%', 62713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 1.0, '%', 63917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.32, '%', 66041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triclosan', 'D08AE04', 0.3, '%', 64830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clofedanol hydrochloride', 'R05DB10', 25, 'mg / 5 ml', 13907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'D04AB01', 5, '%', 17236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'D04AB01', 0.5, '%', 12266);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'D04AB01', 5, '%', 211);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'D04AB01', 0.5, '%', 50081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'D04AB01', 2, '%', 50944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'D04AB01', 4, '%', 53831);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'D04AB01', 4, '%', 68513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'D04AB01', 5, '%', 70023);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'D04AB01', 5, '%', 70063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'D04AB01', 2, '%', 69914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'D04AB01', 5, '%', 76670);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'D04AB01', 2, '%', 74263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'N01BB02', 9.6, '%', 79170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'C05AD01', 5, '%', 80801);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'D04AB01', 2, '%', 84010);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'D04AB01', 9.6, '% / w/w', 46020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'D04AB01', 0.5, '% / w/w', 74102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine', 'D04AB01', 0.8, '% / w/w', 82012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine (lidocaine hydrochloride)', 'N01BB02', 10, 'mg / act', 50454);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine (lidocaine hydrochloride)', 'R02AD02', 100, 'mg / ml', 14240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betahistine hydrochloride', 'N07CA01', 16, 'mg', 67819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betahistine hydrochloride', 'N07CA01', 8, 'mg', 76586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betahistine hydrochloride', 'N07CA01', 24, 'mg', 76588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betahistine hydrochloride', 'N07CA01', 16, 'mg', 76587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betahistine hydrochloride', 'N07CA01', 24, 'mg', 72312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 2, 'mg', 3290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 10, 'mg', 3291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 5, 'mg', 3178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 10, 'mg', 3084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 2, 'mg', 3085);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 2, 'mg', 1718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 5, 'mg', 1719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 10, 'mg', 1720);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 5, 'mg', 2037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 5, 'mg', 2657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 2, 'mg', 71416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 5, 'mg', 71417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 10, 'mg', 71418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 2, 'mg', 71740);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 5, 'mg', 71741);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 10, 'mg', 71742);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 5, 'mg / ml', 18641);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 1, 'mg / ml', 13092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 5, 'mg / ml', 3721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 5, 'mg / ml', 61553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazepam', 'N05BA01', 5, 'mg / ml', 67132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propylthiouracil', 'H03BA02', 50, 'mg', 158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propylthiouracil', 'H03BA02', 100, 'mg', 159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thioguanine', 'L01BB03', 40, 'mg', 1812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allopurinol', 'M04AA01', 200, 'mg', 19183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allopurinol', 'M04AA01', 300, 'mg', 3843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allopurinol', 'M04AA01', 100, 'mg', 3194);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allopurinol', 'M04AA01', 200, 'mg', 4835);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allopurinol', 'M04AA01', 300, 'mg', 4302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allopurinol', 'M04AA01', 200, 'mg', 4303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allopurinol', 'M04AA01', 300, 'mg', 4304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allopurinol', 'M04AA01', 100, 'mg', 4305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allopurinol', 'M04AA01', 100, 'mg', 4276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allopurinol', 'M04AA01', 100, 'mg', 4724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allopurinol', 'M04AA01', 300, 'mg', 4725);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allopurinol', 'M04AA01', 200, 'mg', 4547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allopurinol', 'M04AA01', 300, 'mg', 1892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('proline', 'B05ZA', 59.5, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pentazocine (pentazocine hydrochloride)', 'N02AD01', 50, 'mg', 18230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pentazocine (pentazocine lactate)', 'N02AD01', 30, 'mg / ml', 65646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vinblastine sulfate', 'L01CA01', 1, 'mg / ml', 44270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('spironolactone', 'C03DA01', 25, 'mg', 5646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('spironolactone', 'C03DA01', 100, 'mg', 5647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('spironolactone', 'C03DA01', 25, 'mg', 1403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('spironolactone', 'C03DA01', 100, 'mg', 2145);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vasopressin', 'H01BA01', 20, 'unit / ml', 31359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vasopressin', 'H01BA01', 20, 'unit / ml', 8604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vasopressin', 'H01BA01', 20, 'unit / ml', 72248);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vasopressin (arginine vasopressin)', 'H01BA01', 20, 'unit / 1 ml', 70276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', 'G03CA03', 25, 'µg', 64959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol (estradiol hemihydrate)', 'G03CA03', 10, 'µg', 81084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', 'G03CA03', 0.5, 'mg', 43420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', 'G03CA03', 2.0, 'mg', 19405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', 'G03CA03', 1.0, 'mg', 19406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', 'G03CA03', 2, 'mg', 18640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', 'G03CA03', 2, 'mg', 8386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', 'G03CA03', 8, 'mg', 8175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol (estradiol hemihydrate)', 'G03CA03', 3.8, 'mg', 50849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol (estradiol hemihydrate)', 'G03CA03', 7.6, 'mg', 50850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', 'G03CA03', 0.585, 'mg', 67942);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', 'G03CA03', 0.780, 'mg', 67943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', 'G03CA03', 1.17, 'mg', 67944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', 'G03CA03', 1.56, 'mg', 67945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', 'G03CA03', 5, 'mg', 67654);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', 'G03CA03', 10, 'mg', 67656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol (estradiol hemihydrate)', 'G03CA03', 2, 'mg', 71749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol (estradiol hemihydrate)', 'G03CA03', 5.7, 'mg', 71750);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', 'G03CA03', 0.39, 'mg', 69776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol (estradiol hemihydrate)', 'G03CA03', 4, 'mg', 71196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol (estradiol hemihydrate)', 'G03CA03', 6, 'mg', 71197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol (estradiol hemihydrate)', 'G03CA03', 8, 'mg', 71198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol', 'G03CA03', 0.06, '%', 62136);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chorionic gonadotropin', 'G03GA01', 10000, 'unit / vial', 44257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chorionic gonadotropin', 'G03GA01', 10000, 'unit / vial', 71705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 6, 'mg', 66943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 12, 'mg', 66944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 24, 'mg', 66945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 10, 'mg / vial', 43174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 8.8, 'mg / vial', 75761);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 1, 'mg / ml', 8187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 5, 'mg / ml', 47897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 10, 'mg / 2 ml', 73387);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 5.0, 'mg / 1.5 ml', 81048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 10.0, 'mg / 1.5 ml', 81049);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 15, 'mg / 1.5 ml', 82055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 10, 'mg / 1.5 ml', 82056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 5, 'mg / 1.5 ml', 82057);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 5.83, 'mg / ml', 83536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 8, 'mg / ml', 83537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 8, 'mg / ml', 83538);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 3.3, 'mg / kit', 43151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 5, 'mg / kit', 62499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 6, 'mg / kit', 62500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatropin', 'H01AC01', 5, 'mg / kit', 61332);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxytocin', 'H01BB02', 10, 'unit / ml', 31361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxytocin', 'H01BB02', 10, 'unit / ml', 4293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gonadorelin acetate', 'H01CA01', 0.8, 'mg / vial', 16274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dehydrocholic acid', 'A05AA', 300, 'mg', 34260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', 'D11AX11', 3.5, '%', 75425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc oxide', 'D11AX11', 3.5, '%', 74229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calamine', 'D04AA32', 8, '%', 41558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calamine', 'D04AB07', 3.0, '%', 63619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calamine', 'D04AB07', 3.0, '%', 63620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calamine', 'D04AA32', 8, '%', 65100);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calamine', 'D04AA32', 8, 'g / 100 ml', 70891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alteplase', 'B01AD02', 1, 'mg / ml', 69976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alteplase', 'B01AD02', 50, 'mg / kit', 43443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alteplase', 'B01AD02', 100, 'mg / kit', 20105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin nph human dna origin', 'A10AC01', 100, 'unit / ml', 5326);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin semi synthetic human', 'A10AB01', 100, 'unit / ml', 5325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pollen', 'V01AA20', 100000, 'unit / ml', 1914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pollen', 'V01AA20', 40000, 'unit / ml', 37484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('kentucky bluegrass', 'V01AA02', 100000, 'unit / ml', 61900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('kentucky bluegrass', 'V01AA02', 10000, 'unit / ml', 61901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.025, '%', 42932);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.05, '%', 19617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 100, 'mg', 64097);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.01, '%', 11843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.025, '%', 11844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.1, '%', 11151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.05, '%', 11152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.025, '%', 11153);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.01, '%', 11154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.01, '%', 12753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.025, '%', 12754);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.05, '%', 12544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.1, '%', 8989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.025, '%', 5471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.01, '%', 6619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.05, '%', 6204);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.05, '%', 4220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.025, '%', 5278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.025, '%', 5168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.1, '%', 67856);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tretinoin', 'D10AD01', 0.04, '%', 75010);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium alkyl polyether sulfate', 'V07AV', 6, '%', 2493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butoxy polyoxypropylene polyoxyethylene gly.iodine', 'D08AG', 10.4, '%', 10873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butoxy polyoxypropylene polyoxyethylene gly.iodine', 'V07AV', 15.5, '%', 2954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 15.36, '%', 37840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.684, '%', 37819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.68, '%', 36709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 4.35, '%', 34234);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 9.22, '%', 33839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.906, '%', 28516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 9.22, '%', 27723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.95, '%', 27724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.9, '%', 27725);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.05, '%', 26014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.953, '%', 21969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.54, '%', 20265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 9.22, '%', 20266);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.88, '%', 20267);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.44, '%', 20268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.99, '%', 20223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.953, '%', 20091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.324, '%', 20068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.1475, '%', 18016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.35, '%', 18733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.35, '%', 18713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.953, '%', 18714);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.54, '%', 17768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 65845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 15.36, '%', 17771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.85, '%', 17772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.906, '%', 18934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 4.61, '%', 16774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 15.36, '%', 16721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.85, '%', 16722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 15.36, '%', 15586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.906, '%', 16875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.24, '%', 15973);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.27, '%', 15972);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.3, '%', 15954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.31, '%', 15947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 4.61, '%', 13683);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.31, '%', 13687);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 9.22, '%', 14412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 10.14, '%', 13249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 5.07, '%', 13233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.9, '%', 13211);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.953, '%', 14255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 4.61, '%', 12403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 9.22, '%', 12404);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.31, '%', 12405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.31, '%', 12406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.31, '%', 12407);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 4.61, '%', 12210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.684, '%', 11922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.125, '%', 9822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.875, '%', 8461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.875, '%', 8435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.05, '%', 9621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.125, '%', 9323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.26, '%', 7079);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 4.5, '%', 5849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylene blue', 'V03AB17', 10, 'mg / ml', 50032);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 4.5, '%', 6799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.0, '%', 6784);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.5, '%', 4830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 15.36, '%', 49585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 15.36, '%', 49586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 15.36, '%', 49587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.85, '%', 50583);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.75, '%', 49650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.684, '%', 50870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 15.36, '%', 49954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.35, '%', 61859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.906, '%', 60432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 15.36, '%', 61177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.99, '%', 61178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.31, '%', 61429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.35, '%', 60956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.68, '%', 61784);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.99, '%', 62416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.684, '%', 62417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 15.36, '%', 62418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.68, '%', 62419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.8, '%', 63207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 11.525, '%', 64646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.5, '%', 64299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.68, '%', 63042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.31, '%', 67119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.31, '%', 67134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.953, '%', 65191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.953, '%', 65192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 15.36, '%', 65240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.68, '%', 65839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 66379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 9.22, '%', 66562);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.99, '%', 66174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 11.53, '%', 66931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 66940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 15.36, '%', 65643);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.015, '%', 66995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 8.704, '%', 65142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 67048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 68309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 67512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 69105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 68144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 67651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 67652);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 67608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.76, '%', 67773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.9, '%', 68288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.01995, '%', 72148);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 72152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 72153);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 72154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 69931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.015, '%', 69957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 15.36, '%', 72200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.35, '%', 70000);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 4.5, '%', 70001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.015, '%', 70767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.58, '%', 71522);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.58, '%', 71523);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 8.704, '%', 72301);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.0945, '%', 70268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.4, '%', 70274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.99, '%', 71698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.815, '%', 71713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.99, '%', 70365);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 69735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.35, '%', 70471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.015, '%', 70506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.9, '%', 71209);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.14, '%', 70549);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 4.61, '%', 71318);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.407, '%', 76443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.048, '%', 76444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.048, '%', 76446);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.35, '%', 73896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 6.72, '%', 76498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.31, '%', 72793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 15.36, '%', 75205);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.815, '%', 75206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.47, '%', 75223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.44, '%', 75225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.45, '%', 75242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.31, '%', 75251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.0, '%', 76631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 76639);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 60, 'mg', 78810);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.018, '%', 76640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.99, '%', 76650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 72933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 6.72, '%', 72991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 10.5, '%', 75402);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.99, '%', 76765);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.015, '%', 76777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 10.14, '%', 73025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 73035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 73036);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 73037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 72340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.88, '%', 74326);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.026, '%', 75586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.1, '%', 75632);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.015, '%', 75633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 9.22, '%', 72427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 15.36, '%', 74491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.31, '%', 72498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 9.22, '%', 72499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 9.22, '%', 75959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.906, '%', 73296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 73298);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 30, '%', 73357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 4.1472, '%', 76012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.52, '%', 76050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.99, '%', 76078);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.825, '%', 73405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 9.22, '%', 75783);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.85, '%', 76119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.015, '%', 73470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.03, '%', 73633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.09, '%', 74943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 9.22, '%', 76264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.906, '%', 72770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.906, '%', 72771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.47, '%', 73858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 78114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 5.28, '%', 77180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.44, '%', 78400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 78415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 9.22, '%', 78487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.35, '%', 76873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.68, '%', 77548);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.01995, '%', 78044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 78127);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.013, '%', 78230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 78233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.45, '%', 78236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 78238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.534, '%', 77005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.016, '%', 77006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.85, '%', 77235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 77874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 77412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.54, '%', 76820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.125, '%', 78017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.5, '%', 79845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 79846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.953, '%', 78933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.35, '%', 79260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.990, '%', 78783);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.5, '%', 81857);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.5375, '%', 80095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.8, '%', 80737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.29, '%', 80738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 83038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.407, '%', 83039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.5, '%', 83042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.407, '%', 79106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.953, '%', 79881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.013, '%', 79882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.875, '%', 82554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 5.28, '%', 80406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.29, '%', 80754);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 5.28, '%', 79968);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 81651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 80642);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 80646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.5, '%', 79561);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 79562);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.2, '%', 80976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.0, '%', 80388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.875, '%', 79858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 81996);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.875, '%', 81997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.5, '%', 80887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.5, '%', 81165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.5, '%', 83041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.06, '%', 80216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.2, '%', 80532);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.018, '%', 82114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.54, '%', 83214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.2, '%', 83379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.63, '%', 83525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.013, '%', 83950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 84056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.5, '%', 84216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 84357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.125, '%', 84367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.62, '%', 84439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.75, '%', 84638);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.2, '%', 84650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.048, '%', 84735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 85405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.54, '% / w/w', 13294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 10.14, '% / w/w', 82604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.990, '% / w/w', 77007);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.015, '% / w/w', 77008);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.68, '% / w/w', 79847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 9.2, '% / w/w', 80521);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.01125, '% / w/w', 80866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.01995, '% / w/w', 79995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 300, 'mg', 66413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.628, '% / w/w', 79977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.628, '% / w/w', 80645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.01995, '% / w/w', 81994);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 10.14, '% / w/w', 80036);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.53, '% / w/w', 80037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.84, '% / w/w', 82532);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.84, '% / w/w', 82533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.84, '% / w/w', 84144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.84, '% / w/w', 84389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.628, '% / w/w', 85333);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.628, '% / w/w', 85423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.104, 'mg / ml', 61680);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzyl paraben', 'V04CL', 0.16, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pitcher plant', 'M02AX10', 100, '%', 1235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 0.6, 'mg', 1253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 0.3, 'mg', 1254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 22.4, 'mg', 49993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 44.8, 'mg', 49995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 67.2, 'mg', 49996);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 2, '%', 12220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 75, 'mg / srd', 15572);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 0.4, 'mg / act', 50758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 0.4, 'mg / act', 62447);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 0.4, 'mg / act', 67506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 54, 'mg / 20 sq cm', 19028);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 36, 'mg / 13.3 sq cm', 19029);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 160, 'mg / 40 sq cm', 14742);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 80, 'mg / 20 sq cm', 11225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 120, 'mg / 30 sq cm', 11226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 40, 'mg / 10 sq cm', 11227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 50, 'mg / 20 sq cm', 10116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 25, 'mg / 10 sq cm', 9858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 18, 'mg / 6.7 sq cm', 891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 40, 'mg / 100 ml', 18085);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 20, 'mg / 100 ml', 18086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 10, 'mg / 100 ml', 18087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 5, 'mg / ml', 16848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 1, 'mg / ml', 10705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitroglycerin', 'C01DA02', 5, 'mg / ml', 10706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dithranol', 'D05AC01', 0.4, '%', 8125);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dithranol', 'D05AC01', 2, '%', 5667);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dithranol', 'D05AC01', 1, '%', 5668);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dithranol', 'D05AC01', 0.1, '%', 4677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dithranol', 'D05AC01', 0.2, '%', 4678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ergonovine maleate', 'G02AB03', 0.25, 'mg / ml', 17401);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ergonovine maleate', 'G02AB03', 0.25, 'mg / ml', 4292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ergonovine maleate', 'G02AB03', 0.25, 'mg / ml', 78148);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trolamine salicylate', 'M02AC', 10, '%', 42699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trolamine salicylate', 'M02AC', 13.3, '%', 33537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trolamine salicylate', 'M02AC', 15, '%', 49001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trolamine salicylate', 'M02AC', 15, '%', 64100);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trolamine salicylate', 'M02AC', 20, '%', 68558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trolamine salicylate', 'M02AC', 10, '%', 70239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trolamine salicylate', 'M02AC', 12.5, '%', 76410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trolamine salicylate', 'M02AC', 15, '% / w/w', 63472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trolamine salicylate', 'M02AC', 10, '% / w/w', 80107);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trolamine salicylate', 'M02AC', 10, '% / w/w', 80615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trolamine salicylate', 'M02AC', 20, '% / w/w', 83559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trolamine salicylate', 'M02AC', 15, '%', 42373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trolamine salicylate', 'M02AC', 10, '%', 42374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trolamine salicylate', 'M02AC', 15, '%', 33476);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('crotamiton', 'P03AX', 10, '%', 7152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipramine hydrochloride', 'N06AA02', 75, 'mg', 9411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipramine hydrochloride', 'N06AA02', 75, 'mg', 10008);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipramine hydrochloride', 'N06AA02', 25, 'mg', 8560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipramine hydrochloride', 'N06AA02', 50, 'mg', 8561);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipramine hydrochloride', 'N06AA02', 10, 'mg', 8562);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipramine hydrochloride', 'N06AA02', 25, 'mg', 1877);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipramine hydrochloride', 'N06AA02', 50, 'mg', 1884);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipramine hydrochloride', 'N06AA02', 10, 'mg', 1885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipramine hydrochloride', 'N06AA02', 10, 'mg', 2444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipramine hydrochloride', 'N06AA02', 50, 'mg', 1030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipramine hydrochloride', 'N06AA02', 10, 'mg', 1031);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipramine hydrochloride', 'N06AA02', 25, 'mg', 1032);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipramine hydrochloride', 'N06AA02', 25, 'mg', 2211);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imipramine hydrochloride', 'N06AA02', 50, 'mg', 2212);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dibucaine', 'C05AD04', 1, '%', 7287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinine sulfate', 'P01BC01', 300, 'mg', 38054);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinine sulfate', 'P01BC01', 200, 'mg', 38055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinine sulfate', 'P01BC01', 300, 'mg', 38056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinine sulfate', 'P01BC01', 200, 'mg', 651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinine sulfate', 'P01BC01', 300, 'mg', 290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinine sulfate', 'P01BC01', 200, 'mg', 79680);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinine sulfate', 'P01BC01', 300, 'mg', 79681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dl-methionine', 'B05ZA', 85, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodine (nonyl phenoxypoly ethoxy ethanol-iodine complex)', 'V07AV', 1.75, '%', 15803);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodine (nonyl phenoxypoly ethoxy ethanol-iodine)', 'V07AV', 1.75, '%', 8159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodine (nonyl phenoxypoly ethoxy ethanol-iodine complex)', 'V07AV', 1.75, '%', 4000);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 400, 'mg', 66438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodine (nonylphenyl-omega-hydroxypoly oxyethylene - iodine complex)', 'V07AV', 1.75, '%', 50507);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodine (nonyl phenoxypoly ethoxy ethanol-iodine complex)', 'V07AV', 1.75, '%', 70184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodine', 'C05BB', 60, 'mg / ml', 14491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodine (ethiodized oil)', 'V08AD01', 380, 'mg / g', 2570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subgallate', 'A07BB', 200, 'mg', 3166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylene blue', 'V04CG05', 1, '%', 41559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylene blue', 'V04CG05', 1, '%', 68);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylene blue', 'V03AB17', 2, '%', 69);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylene blue', 'V03AB17', 10, 'mg / ml', 16999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylene blue', 'V03AB17', 10, 'mg / ml', 10064);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylene blue', 'V03AB17', 10, 'mg / ml', 78806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'S01XA20', 3, '%', 41919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'S01XA20', 3, '%', 41925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 58, '%', 20058);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 20, '%', 18687);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 35, '%', 16065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 0.8, '%', 13689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 58, '%', 13535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 3, '%', 11758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 1, '%', 48981);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 0.5, '%', 63257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 7, '%', 63315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 25, '%', 63904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 27.11, '%', 78600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 4.0, '%', 78598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 7, '%', 64864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 3, '%', 64865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 7, '%', 66791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 7.50, '%', 66941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 7, '%', 68494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 7, '%', 69065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 7, '%', 68698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 21.7, '%', 70105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 0.5, '%', 71130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'S01XA20', 3, '%', 69761);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 3.95, '%', 73893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 2, '%', 76483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 7, '%', 76716);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 7, '%', 75418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 58, '%', 73517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 22.00, '%', 76311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 58, '%', 73816);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 2, '%', 77192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 0.5, '%', 77657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 7, '%', 77279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 0.5, '%', 77085);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 0.5, '%', 77125);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 0.5, '%', 77127);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 0.5, '%', 76896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 7.99, '%', 77844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 58, '%', 78203);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 4.5, '%', 78271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 0.5, '%', 76812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 59, '%', 78892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 7.99, '%', 79843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 22, '%', 80386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 50, '%', 82791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 4.25, '%', 81862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 4.4, '%', 82224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 3.95, '%', 82590);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 3.95, '%', 82588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 1, '%', 80714);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 3.95, '%', 83358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 3.95, '%', 83359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 0.80, '%', 83744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 0.5, '%', 84615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 7, '%', 84646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 0.5, '%', 84977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 0.5, '% / w/w', 64866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 0.5, '% / w/w', 76533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 7, '% / w/w', 77278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 0.5, '% / w/w', 76912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 0.5, '% / w/w', 76913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 22.7, '% / w/w', 81863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 3.130, '% / w/w', 80441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 4.5, '% / w/w', 79564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 4.5, '% / w/w', 79857);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 4.5, '% / w/w', 80463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 23.0, '% / w/w', 83975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 8.3, '% / w/w', 84438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 50, '% / w/w', 84820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrogen peroxide', 'V07AV', 0.5, '% / w/w', 85205);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinamide', 'A11HA01', 100, 'mg / ml', 3921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('adenine', 'V07AC', 17.3, 'mg / 63 ml', 23039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiamine hydrochloride', 'A11DA01', 100, 'mg / ml', 35700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiamine hydrochloride', 'A11DA01', 100, 'mg / ml', 17000);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiamine hydrochloride', 'A11DA01', 100, 'mg / ml', 10063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiamine hydrochloride', 'A11DA01', 100, 'mg / ml', 3503);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiamine hydrochloride', 'A11DA01', 100, 'mg / ml', 65653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiamine hydrochloride', 'A11DA01', 100, 'mg / ml', 67443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isotretinoin', 'D10BA01', 10, 'mg', 5128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isotretinoin', 'D10BA01', 40, 'mg', 5129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isotretinoin', 'D10BA01', 10, 'mg', 74319);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isotretinoin', 'D10BA01', 40, 'mg', 74320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyridoxine hydrochloride', 'A11HA02', 100, 'mg / ml', 4267);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyridoxine hydrochloride', 'A11HA02', 100, 'mg / ml', 3501);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyridoxine hydrochloride', 'A11HA02', 100, 'mg / ml', 69230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 400, 'mg', 6161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylcholine chloride', 'S01EB09', 10, 'mg / ml', 31096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxocobalamin', 'V03AB33', 2.5, 'g / vial', 84573);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxocobalamin', 'B03BA03', 1, 'mg / ml', 5852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxocobalamin', 'B03BA03', 1, 'mg / ml', 3502);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin k1', 'B02BA01', 2, 'mg / ml', 9993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin k1', 'B02BA01', 10, 'mg / ml', 9994);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin k1', 'B02BA01', 2, 'mg / ml', 4270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin k1', 'B02BA01', 10, 'mg / ml', 4271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 600, 'mg', 47123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 400, 'mg', 47112);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 35329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 19585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 13625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 300, 'mg', 14089);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 400, 'mg', 14090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 600, 'mg', 14091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 13452);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 10294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 400, 'mg', 5432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 300, 'mg', 5433);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 600, 'mg', 5917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 6320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 300, 'mg', 6321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 400, 'mg', 6322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 600, 'mg', 6323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 600, 'mg', 6749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 49613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 65432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 400, 'mg', 68562);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 50, 'mg', 71586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 100, 'mg', 71587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 100, 'mg', 70575);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 76703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 74314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 400, 'mg', 72567);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 75835);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 75836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 77730);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 400, 'mg', 77840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 78292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 400, 'mg', 81864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 400, 'mg', 80337);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 400, 'mg', 80349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 80029);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 80030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 400, 'mg', 80031);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 400, 'mg', 79650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 100, 'mg', 81395);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 400, 'mg', 80286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 200, 'mg', 84240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 400, 'mg', 84241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 400, 'mg', 85291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 100, 'mg / 5 ml', 51742);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 40, 'mg / ml', 62054);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 100, 'mg / 5 ml', 66076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 40, 'mg / ml', 66270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 100, 'mg / 5 ml', 76585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 100, 'mg / 5 ml', 81396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 40, 'mg / ml', 81397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibuprofen', 'M01AE01', 100, 'mg / 5 ml', 83995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02', 2, 'mg', 18851);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02', 4, 'mg', 18852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02', 4, 'mg', 18067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02', 2, 'mg', 18068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 200, 'µg / blister', 66984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol', 'R03AC02', 100, 'µg / act', 9941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 100, 'µg / act', 69769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 100, 'µg / act', 81180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 100, 'µg / dose', 52048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 100, 'µg / dose', 65137);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 1, 'mg / ml', 43194);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02', 0.4, 'mg / ml', 43769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02', 1, 'mg / ml', 43104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 5, 'mg / ml', 43108);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 2.5, 'mg / 2.5 ml', 43100);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 5, 'mg / 2.5 ml', 43101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 0.5, 'mg / ml', 19761);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 2, 'mg / ml', 19762);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 1, 'mg / ml', 19763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 5, 'mg / ml', 19237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 2, 'mg / ml', 19058);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 5, 'mg / ml', 16521);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 5, 'mg / ml', 16452);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 1, 'mg / ml', 13668);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 1, 'mg / ml', 13550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 5, 'mg / ml', 10391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 1, 'mg / ml', 51215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 2, 'mg / ml', 51216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol', 'R03AC02', 2.5, 'mg / 2.5 ml', 50819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 100, 'mg', 78811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 2, 'mg / ml', 51054);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 5, 'mg / ml', 52472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 0.5, 'mg / ml', 60224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 1, 'mg / ml', 60225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 2, 'mg / ml', 60226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 0.5, 'mg / ml', 62834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 2, 'mg / ml', 62835);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03AC02', 0.5, 'mg / ml', 67769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02', 0.4, 'mg / ml', 74671);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'C02AC01', 0.2, 'mg', 14713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'C02AC01', 0.1, 'mg', 14715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'C02AC01', 0.1, 'mg', 10909);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'C02AC01', 0.2, 'mg', 10910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'C02AC01', 0.2, 'mg', 12692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'C02AC01', 0.1, 'mg', 12693);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'C02AC01', 0.2, 'mg', 11482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'C02AC01', 0.1, 'mg', 11483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'N02CX02', 0.025, 'mg', 4045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'C02AC01', 0.2, 'mg', 1943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'C02AC01', 0.1, 'mg', 1601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'C02AC01', 0.1, 'mg', 71867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'C02AC01', 0.2, 'mg', 71868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'C02AC01', 0.025, 'mg', 73100);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'C02AC01', 0.025, 'mg', 78947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'C02AC01', 0.025, 'mg', 84635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'C02AC01', 0.1, 'mg', 84636);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonidine hydrochloride', 'C02AC01', 0.2, 'mg', 84637);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupivacaine hydrochloride', 'N01BB01', 5, 'mg / ml', 16164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupivacaine hydrochloride', 'N01BB01', 2.5, 'mg / ml', 16161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupivacaine hydrochloride', 'N01BB01', 7.5, 'mg / ml', 65584);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupivacaine hydrochloride', 'N01BB01', 7.5, 'mg / ml', 65587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupivacaine hydrochloride', 'N01BB01', 2.5, 'mg / ml', 65588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupivacaine hydrochloride', 'N01BB01', 5.0, 'mg / ml', 65589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupivacaine hydrochloride', 'N01BB01', 5.0, 'mg / ml', 79145);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupivacaine hydrochloride', 'N01BB01', 2.5, 'mg / ml', 79144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorazepate dipotassium', 'N05BA05', 15, 'mg', 10899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorazepate dipotassium', 'N05BA05', 3.75, 'mg', 10902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorazepate dipotassium', 'N05BA05', 7.5, 'mg', 10903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorazepate dipotassium', 'N05BA05', 3.75, 'mg', 6096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorazepate dipotassium', 'N05BA05', 7.5, 'mg', 6097);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clorazepate dipotassium', 'N05BA05', 15, 'mg', 6098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pancuronium bromide', 'M03AC01', 1, 'mg / ml', 43714);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pancuronium bromide', 'M03AC01', 2, 'mg / ml', 19555);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pancuronium bromide', 'M03AC01', 1, 'mg / ml', 19556);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pancuronium bromide', 'M03AC01', 2, 'mg / ml', 18549);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thimerosal', 'V04CL', 0.0065, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium iodide', 'C05BB', 90, 'mg / ml', 14491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 650, 'g', 81095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'V07AB', 0.21, '%', 4913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 650, 'g / cartridge', 13018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 650, 'g / cartridge', 81113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 200, 'mg', 78812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 650, 'g / pck', 37283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 650, 'g / pck', 37559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 6, 'kg / pck', 76654);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 58.8, 'g / 1000 ml', 76040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 3.090, 'g / 1000 ml', 76308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 3.090, 'g / 1000 ml', 76310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 3.09, 'g / 1000 ml', 66962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05XA02', 42, 'mg / ml', 8350);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05XA02', 75, 'mg / ml', 3837);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05XA02', 84, 'mg / ml', 1905);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 650, 'g / 8 l', 8587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 81.3, 'g / l', 6775);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 81.25, 'g / l', 48615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 39.7, 'g / l', 67542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 3.29, 'g / l', 71993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 3.29, 'g / l', 71997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 3.29, 'g / l', 71998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 80.7, 'g / l', 73309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 28.35, 'g / l', 76226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 12.9, 'g / l', 78010);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium bicarbonate', 'B05ZA', 12.9, 'g / l', 78012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 20, 'mg', 42846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 50, 'mg', 42847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 100, 'mg', 42848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 15, 'mg', 18878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 200, 'mg', 18877);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 5, 'mg', 16102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 20, 'mg', 16480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 30, 'mg', 16481);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 30, 'mg', 14176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 100, 'mg', 14178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 200, 'mg', 14142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 10, 'mg', 14144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 25, 'mg', 14107);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 50, 'mg', 14108);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 10, 'mg', 14110);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 5, 'mg', 14111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 100, 'mg', 14541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 60, 'mg', 14542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 10, 'mg', 14543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 30, 'mg', 14502);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 60, 'mg', 14394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 15, 'mg', 14395);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 25, 'mg', 6753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 10, 'mg', 6754);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 5, 'mg', 6755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 50, 'mg', 6757);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 20, 'mg', 6129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 10, 'mg', 6132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 30, 'mg', 51392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 5, 'mg', 51391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 10, 'mg', 65841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 15, 'mg', 69308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 30, 'mg', 69309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 60, 'mg', 69310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 100, 'mg', 69311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 200, 'mg', 69312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 15, 'mg', 68780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 30, 'mg', 68781);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 60, 'mg', 68782);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 15, 'mg', 78808);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 30, 'mg', 78809);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 15, 'mg', 83602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 30, 'mg', 83608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 60, 'mg', 83610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 100, 'mg', 83611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 200, 'mg', 83613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 1, 'mg / ml', 31285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 2, 'mg / ml', 31286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 50, 'mg / ml', 31288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 1, 'mg / ml', 13077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 2, 'mg / ml', 13078);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 5, 'mg / ml', 13079);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 2, 'mg / ml', 12990);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 10, 'mg / ml', 12991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 15, 'mg / 1 ml', 12992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 0.5, 'mg / ml', 12968);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 1, 'mg / ml', 14020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 0.5, 'mg / ml', 13966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 50, 'mg / ml', 10485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 1, 'mg / ml', 12728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 25, 'mg / ml', 12701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 50, 'mg / ml', 12702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 10, 'mg / ml', 8917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 5, 'mg / ml', 7136);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 50, 'mg / ml', 7421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 1, 'mg / ml', 6871);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 20, 'mg / ml', 6131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 5, 'mg / ml', 6133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 1, 'mg / ml', 6134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 25, 'mg / ml', 6690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 10, 'mg / ml', 3043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 15, 'mg / ml', 3042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine sulfate', 'N02AA01', 2, 'mg / ml', 66221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meperidine hydrochloride', 'N02AB02', 50, 'mg', 18316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meperidine hydrochloride', 'N02AB02', 10, 'mg / ml', 36719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meperidine hydrochloride', 'N02AB02', 10, 'mg / ml', 6872);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meperidine hydrochloride', 'N02AB02', 10, 'mg / ml', 4294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meperidine hydrochloride', 'N02AB02', 25, 'mg / ml', 4234);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meperidine hydrochloride', 'N02AB02', 50, 'mg / ml', 4235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meperidine hydrochloride', 'N02AB02', 75, 'mg / ml', 4236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meperidine hydrochloride', 'N02AB02', 100, 'mg / ml', 4237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meperidine hydrochloride', 'N02AB02', 50, 'mg / ml', 65672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meperidine hydrochloride', 'N02AB02', 50, 'mg / ml', 65673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meperidine hydrochloride', 'N02AB02', 75, 'mg / ml', 65674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meperidine hydrochloride', 'N02AB02', 100, 'mg / ml', 65675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meperidine hydrochloride', 'N02AB02', 100, 'mg / ml', 65676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('camphor', 'D02AC', 1.7, '%', 76643);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('camphor', 'D02AC', 1.7, '%', 76644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('camphor', 'D04AB07', 0.5, '% / ml', 13570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('camphor', 'M02AC', 0.3, 'g / 100 g', 61438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', 'R05DA04', 30, 'mg', 16474);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', 'R05DA04', 15, 'mg', 16475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', 'R05DA04', 15, 'mg', 9439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', 'R05DA04', 15, 'mg', 6415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', 'R05DA04', 30, 'mg', 6416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', 'R05DA04', 15, 'mg', 67922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', 'R05DA04', 30, 'mg', 67923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', 'R05DA04', 0.2, '%', 2982);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', 'R05DA04', 5, 'mg / ml', 8616);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', 'R05DA04', 30, 'mg / ml', 4806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', 'R05DA04', 30, 'mg / ml', 4232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', 'R05DA04', 60, 'mg / ml', 4233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine phosphate', 'R05DA04', 143, 'mg / 30 ml', 943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate calcium', 'A06AA02', 240, 'mg', 10569);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate calcium', 'A06AA02', 240, 'mg', 10505);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate calcium', 'A06AA02', 240, 'mg', 12344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate calcium', 'A06AA02', 240, 'mg', 10316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate calcium', 'A06AA02', 240, 'mg', 6756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate calcium', 'A06AA02', 240, 'mg', 47964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate calcium', 'A06AA02', 240, 'mg', 69084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate calcium', 'A06AA02', 240, 'mg', 70938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate calcium', 'A06AA02', 240, 'mg', 76888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclopentamine hydrochloride', 'V07AV', 2.25, '%', 11296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clioquinol', 'V04CL', 0.08, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nylidrin hydrochloride', 'C04AA02', 6, 'mg', 11970);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nylidrin hydrochloride', 'C04AA02', 6, 'mg', 5367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetrimonium bromide', 'D08AJ02', 0.5, '%', 10565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetrimonium bromide', 'D08AJ02', 0.5, '%', 12864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hexetidine', 'A01AB12', 0.1, '%', 13344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycerine', 'V07AB', 2.6, '%', 43651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycerine', 'V07AB', 50, '%', 1912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycerine', 'S01XA20', 0.2, '%', 47379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycerine', 'S01XA20', 0.2, '%', 66850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycerine', 'S01XA20', 0.2, '%', 70567);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycerine', 'S01XA20', 0.25, '%', 77230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycerine', 'S01XA20', 0.3, '% / w/v', 80709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycerine', 'S01XA20', 0.2, '% / w/v', 83970);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycerine', 'V07AC', 57, 'g / 100 ml', 11330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycerine', 'S01XA20', 3, 'mg / ml', 66081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dibucaine hydrochloride', 'V04CL', 0.073, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methenamine mandelate', 'J01XX05', 500, 'mg', 4538);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin d3 (cholecalciferol)', 'A11CC05', 10000, 'unit', 73813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin d3', 'A11CC05', 50000, 'unit', 85666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin d2', 'A11CC01', 50000, 'unit', 60784);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin d2', 'A11CC01', 50000, 'unit', 78724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alfacalcidol', 'A11CC03', 0.25, 'µg', 7292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alfacalcidol', 'A11CC03', 1, 'µg', 7293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alfacalcidol', 'A11CC03', 2, 'µg / ml', 63869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alfacalcidol', 'A11CC03', 2, 'µg / ml', 66245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcitriol', 'A11CC04', 0.5, 'µg', 3429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcitriol', 'A11CC04', 0.25, 'µg', 3430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcitriol', 'A11CC04', 2, 'µg / ml', 11291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcitriol', 'A11CC04', 1, 'µg / ml', 11150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcitriol', 'A11CC04', 1, 'µg / ml', 12885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcitriol', 'A11CC04', 1, 'µg / ml', 69787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcitriol', 'D05AX03', 3, 'µg / g', 82422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium acetate', 'V03AE', 667, 'mg', 47284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 10, '%', 2488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('telmisartan', 'C09CA07', 80, 'mg', 64359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('telmisartan', 'C09CA07', 40, 'mg', 64358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zanamivir', 'J05AH01', 5, 'mg / blister', 64454);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lepirudin', 'B01AE02', 50, 'mg / vial', 64588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inosine pranobex', 'J05AX05', 500, 'mg', 64296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('orlistat', 'A08AB01', 120, 'mg', 63865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alitretinoin', 'D11AX19', 10, 'mg', 82321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alitretinoin', 'D11AX19', 30, 'mg', 82322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eptifibatide', 'B01AC16', 0.75, 'mg / ml', 63892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eptifibatide', 'B01AC16', 2, 'mg / ml', 63894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('abacavir (abacavir sulfate)', 'J05AF06', 300, 'mg', 63899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('abacavir (abacavir sulfate)', 'J05AF06', 20, 'mg / ml', 63900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eprosartan (eprosartan mesylate)', 'C09CA02', 400, 'mg', 63981);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eprosartan (eprosartan mesylate)', 'C09CA02', 600, 'mg', 67885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rizatriptan (rizatriptan benzoate)', 'N02CC04', 5, 'mg', 64089);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rizatriptan (rizatriptan benzoate)', 'N02CC04', 10, 'mg', 64090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rizatriptan (rizatriptan benzoate)', 'N02CC04', 5, 'mg', 64091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rizatriptan (rizatriptan benzoate)', 'N02CC04', 10, 'mg', 64092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triptorelin (triptorelin pamoate)', 'L02AE04', 3.75, 'mg / vial', 63507);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triptorelin (triptorelin pamoate)', 'L02AE04', 11.25, 'mg / vial', 67797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('efavirenz', 'J05AG03', 200, 'mg', 63376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('efavirenz', 'J05AG03', 50, 'mg', 63374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('efavirenz', 'J05AG03', 600, 'mg', 70176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('repaglinide', 'A10BX02', 0.5, 'mg', 63424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('repaglinide', 'A10BX02', 1.0, 'mg', 63425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('repaglinide', 'A10BX02', 2.0, 'mg', 63426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('repaglinide', 'A10BX02', 0.5, 'mg', 80688);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('repaglinide', 'A10BX02', 1, 'mg', 80689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('repaglinide', 'A10BX02', 2, 'mg', 80690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('repaglinide', 'A10BX02', 0.5, 'mg', 84011);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('repaglinide', 'A10BX02', 1.0, 'mg', 84012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('repaglinide', 'A10BX02', 2.0, 'mg', 84013);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('repaglinide', 'A10BX02', 0.5, 'mg', 84259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('repaglinide', 'A10BX02', 1, 'mg', 84260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('repaglinide', 'A10BX02', 2, 'mg', 84261);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('celecoxib', 'M01AH01', 100, 'mg', 63442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('celecoxib', 'M01AH01', 200, 'mg', 63443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 30, 'mg', 62602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 5, 'mg', 66266);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 35, 'mg', 71123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium (risedronate sodium monohydrate)', 'M05BA07', 5, 'mg', 78367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium (risedronate sodium monohydrate)', 'M05BA07', 30, 'mg', 78368);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium (risedronate sodium monohydrate)', 'M05BA07', 35, 'mg', 78369);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 75, 'mg', 78312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 150, 'mg', 80233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 35, 'mg', 82662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 35, 'mg', 79553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 35, 'mg', 78754);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 35, 'mg', 81259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 35, 'mg', 80533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 35, 'mg', 83286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 35, 'mg', 83739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 35, 'mg', 83888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 35, 'mg', 85557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tizanidine (tizanidine hydrochloride)', 'M03BX02', 4, 'mg', 62626);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tizanidine (tizanidine hydrochloride)', 'M03BX02', 4, 'mg', 74515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tizanidine (tizanidine hydrochloride)', 'M03BX02', 4, 'mg', 75758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cat (felis domesticus) pelt and cat dander', 'V01AA11', 10000, 'unit / ml', 62882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 2, 'mg', 13536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 10, 'mg', 13418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 2.5, 'mg', 13419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 4, 'mg', 13375);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 1, 'mg', 12818);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 5, 'mg', 12819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 3, 'mg', 63731);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 6, 'mg', 63732);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 1, 'mg', 66470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 2, 'mg', 66471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 2.5, 'mg', 66472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 3, 'mg', 66473);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 4, 'mg', 66474);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 5, 'mg', 66475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 6, 'mg', 66476);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 10, 'mg', 66477);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 7.5, 'mg', 66492);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 1, 'mg', 66762);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 2, 'mg', 66763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 2.5, 'mg', 66764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 4, 'mg', 66765);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 5, 'mg', 66766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 10, 'mg', 66767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 1, 'mg', 68431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 2, 'mg', 68432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 2.5, 'mg', 68433);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 4, 'mg', 68435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 5, 'mg', 68436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 10, 'mg', 68437);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 3, 'mg', 69718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 1, 'mg', 75076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 2, 'mg', 75077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 2.5, 'mg', 75078);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 3, 'mg', 75079);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 4, 'mg', 75080);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 5, 'mg', 75081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 3, 'mg', 77289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 6, 'mg', 77290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 7.5, 'mg', 77291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 1, 'mg', 82943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 2, 'mg', 82944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 2.5, 'mg', 82945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 3, 'mg', 82946);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 4, 'mg', 82947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 5, 'mg', 82948);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 6, 'mg', 82949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 7.5, 'mg', 82950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('warfarin sodium', 'B01AA03', 10, 'mg', 82951);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acenocoumarol', 'B01AA07', 1, 'mg', 1118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acenocoumarol', 'B01AA07', 4, 'mg', 1084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('scopolamine hydrobromide', 'A04AD01', 0.4, 'mg / ml', 4787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('scopolamine hydrobromide', 'A04AD01', 0.6, 'mg / ml', 4788);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('scopolamine hydrobromide', 'N05CM05', 0.4, 'mg / ml', 66635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('scopolamine hydrobromide', 'N05CM05', 0.6, 'mg / ml', 66636);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', 'C01CA24', 1, 'mg / ml', 16998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', 'C01CA24', 0.1, 'mg / ml', 8352);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', 'C01CA24', 1, 'mg / ml', 9164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', 'C01CA24', 0.5, 'mg / ml', 5970);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', 'C01CA24', 1, 'mg / ml', 3883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine hydrochloride)', 'C01CA24', 1, 'mg / ml', 940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine (epinephrine hydrochloride)', 'R01AA14', 1, 'mg / ml', 1508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', 'C01CA24', 0.3, 'mg / 0.3 ml', 71553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', 'C01CA24', 0.15, 'mg / 0.15 ml', 75360);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', 'C01CA24', 1, 'mg / ml', 81063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', 'C01CA24', 0.15, 'mg / 0.3 ml', 79244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine', 'C01CA24', 0.3, 'mg / 0.3 ml', 79245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ephedrine sulfate', 'R03CA02', 50, 'mg / ml', 11096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ephedrine sulfate', 'R03CA02', 50, 'mg / ml', 790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ephedrine sulfate', 'R03CA02', 50, 'mg / ml', 66800);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', 'R02AA06', 7.5, 'mg', 4665);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', 'D05AA', 2, '%', 48713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzocaine', 'V04CL', 0.364, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('formaldehyde', 'V07AV', 0.05, '%', 14494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('formaldehyde', 'V07AV', 0.2, '%', 13786);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('formaldehyde', 'V07AV', 37, '%', 1926);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('formaldehyde', 'V07AV', 0.23, '%', 52647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('formaldehyde', 'V07AV', 2.02, '%', 66752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('formaldehyde', 'V07AV', 2.28, '%', 69733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('formaldehyde', 'V07AV', 0.23, 'g / 100 g', 61292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lanolin', 'S01XA20', 3, '%', 28169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lanolin', 'S01XA20', 2, '%', 17759);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lanolin', 'S01XA20', 2, '%', 18099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lanolin', 'D02AC', 4, '%', 2256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lanolin', 'D02AC', 15.5, '% / w/w', 59943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lanolin', 'D02AC', 3, '%', 12947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenol', 'V07AV', 1.56, '%', 36396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenol', 'V07AV', 0.5, '%', 17211);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenol', 'N01BX03', 6, '%', 13999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenol', 'V07AB', 0.4, '%', 1911);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenol', 'V07AB', 0.4, '%', 1912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenol', 'D02AC', 0.44, '%', 76643);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenol', 'D02AC', 0.44, '%', 76644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenol', 'V07AV', 1.56, '% / w/w', 36398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin', 'S01AA17', 5, 'mg / g', 81202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenol', 'V07AB', 5, 'mg / ml', 4792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('papaverine hydrochloride', 'A03AD01', 65, 'mg / 2 ml', 160);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rosin', 'V04CL', 0.69, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 20, '%', 2490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diiodohydroxyquin', 'P01AA', 210, 'mg', 13104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diiodohydroxyquin', 'P01AA', 650, 'mg', 13112);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 0.166, '%', 41695);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 7.5, '%', 42099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 7.5, '%', 42042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 7.5, '%', 42043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 4.25, '%', 41889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 1, '%', 42609);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 2, '%', 42610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 4, '%', 17265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 0.5, '%', 15950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 0.5, '%', 13012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 0.55, '%', 13013);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 0.5, '%', 13014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 8, '%', 10142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 4.3, '%', 9334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 10, '%', 6435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 1, '%', 6436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 3, '%', 6437);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 10, '%', 6848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 2, '%', 6207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 0.33, '%', 5557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 10, '%', 4037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'M02AC', 1.0, '%', 3998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 2, '%', 3320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 0.04, '%', 2984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 20, '%', 2317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 5.0, '%', 1667);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 10, '%', 2197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 0.09, '%', 1495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 40.8, '%', 48713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 0.50, '%', 64224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 1.25, '%', 63668);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 0.33, '%', 64533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 0.66, '%', 71204);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 10.0, '%', 77120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 2.0, '%', 77934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 1, '%', 79280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 10, '% / w/v', 10674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 10, '% / w/v', 10141);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coal tar', 'D05AA', 10.0, '% / w/v', 77121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 4, '%', 37729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 37836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 37837);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 2.5, '%', 37835);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 34258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 20298);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 20299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 14500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 8, '%', 14396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 13311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 4, '%', 13244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 10, '%', 11862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 10498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 10, '%', 11657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 11658);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 3292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 10, '%', 3293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 10, '%', 4408);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 20, '%', 3198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 4131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 20, '%', 1339);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 1317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 10, '%', 1647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 1648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 59870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 2.5, '%', 62868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 2.50, '%', 62870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 65812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 2.5, '%', 72252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 2.5, '%', 72253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 70091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 71270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 3.7, '%', 75208);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 2.5, '%', 74146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 74147);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 75421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 3.0, '%', 74359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5.0, '%', 75687);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5.0, '%', 72553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 76851);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 77539);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 2.5, '%', 77590);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5.00, '%', 77752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5.0, '%', 77622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '%', 79019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 3.5, '%', 79193);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 2.5, '%', 79194);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 2.5, '% / w/w', 16458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '% / w/w', 4861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '% / w/w', 60085);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '% / w/w', 60086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 2.5, '% / w/w', 80076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5.0, '% / w/w', 79848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '% / w/w', 80729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '% / w/w', 80728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5.0, '% / w/w', 80530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 2.5, '% / w/w', 80610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 4, '% / w/w', 81233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 4, '% / w/w', 81234);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '% / w/w', 80893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '% / w/w', 82243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5.0, '% / w/w', 80822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 5, '% / w/w', 84307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoyl peroxide', 'D10AE01', 2.5, '% / w/w', 84309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('adenosine', 'C01EB10', 3, 'mg / ml', 43936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('adenosine', 'C01EB10', 3, 'mg / ml', 19437);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('adenosine', 'C01EB10', 3, 'mg / ml', 67346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('adenosine', 'C01EB10', 3, 'mg / ml', 75307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium phosphate (tribasic)', 'V07AV', 1.19, '%', 75535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 77858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 63077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 63078);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 70781);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 70782);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 70187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 70188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 72326);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 72327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 74277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 74278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 10, 'mg', 75597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 72370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 72371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 10, 'mg', 75855);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 72503);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 72504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 73317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 73318);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 73319);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V03AZ01', 100, '%', 3011);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 73320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 73411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 73412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 10, 'mg', 75903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 73647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 75, 'mg', 80150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 73649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20.0, 'mg', 73700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40.0, 'mg', 73701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 77113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 77114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 77859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 30, 'mg', 78149);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 77039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 77040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 79893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 79894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 10, 'mg', 78858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 78859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 78860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 79179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 79180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 10, 'mg', 79783);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 78996);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 78997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 10, 'mg', 81046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 83886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 83887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20, 'mg', 84052);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40, 'mg', 84053);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('modafinil', 'N06BA07', 100, 'mg', 63139);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sildenafil (sildenafil citrate)', 'G04BE03', 25, 'mg', 63248);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sildenafil (sildenafil citrate)', 'G04BE03', 50, 'mg', 63249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sildenafil (sildenafil citrate)', 'G04BE03', 100, 'mg', 63250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sildenafil (sildenafil citrate)', 'G04BE03', 20, 'mg', 76500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sildenafil (sildenafil citrate)', 'G04BE03', 20, 'mg', 80498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sildenafil (sildenafil citrate)', 'G04BE03', 0.8, 'mg / ml', 82711);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon alfacon-1', 'L03AB09', 0.03, 'mg / ml', 63319);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('capecitabine', 'L01BC06', 150, 'mg', 61873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('capecitabine', 'L01BC06', 500, 'mg', 61874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nelfinavir (nelfinavir mesylate)', 'J05AE04', 250, 'mg', 62045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nelfinavir (nelfinavir mesylate)', 'J05AE04', 625, 'mg', 73129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nelfinavir (nelfinavir mesylate)', 'J05AE04', 50, 'mg / g', 62046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zolmitriptan', 'N02CC03', 2.5, 'mg', 62089);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zolmitriptan', 'N02CC03', 2.5, 'mg', 66907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zolmitriptan', 'N02CC03', 2.5, 'mg', 81019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zolmitriptan', 'N02CC03', 2.5, 'mg', 82803);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zolmitriptan', 'N02CC03', 2.5, 'mg', 80970);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zolmitriptan', 'N02CC03', 2.5, 'mg', 79948);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zolmitriptan', 'N02CC03', 2.5, 'mg', 84796);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zolmitriptan', 'N02CC03', 2.5, 'mg', 84797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zolmitriptan', 'N02CC03', 2.5, 'mg', 85398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zolmitriptan', 'N02CC03', 2.5, 'mg / spray', 73377);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zolmitriptan', 'N02CC03', 5.0, 'mg / spray', 73378);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clopidogrel (clopidogrel bisulfate)', 'B01AC04', 75, 'mg', 62114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clopidogrel (clopidogrel bisulfate)', 'B01AC04', 300, 'mg', 81628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nevirapine', 'J05AG01', 200, 'mg', 62181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nevirapine', 'J05AG01', 200, 'mg', 80408);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penciclovir', 'D06BB06', 1, '%', 62288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brinzolamide', 'S01EC04', 1, '%', 62313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mercaptopurine', 'L01BB02', 50, 'mg', 960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('raloxifene hydrochloride', 'G03XC01', 60, 'mg', 62480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('raloxifene hydrochloride', 'G03XC01', 60, 'mg', 76475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('raloxifene hydrochloride', 'G03XC01', 60, 'mg', 79780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('delavirdine mesylate', 'J05AG02', 100, 'mg', 61760);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('candesartan cilexetil', 'C09CA06', 4, 'mg', 62546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('candesartan cilexetil', 'C09CA06', 8, 'mg', 62547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('candesartan cilexetil', 'C09CA06', 16, 'mg', 62548);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('candesartan cilexetil', 'C09CA06', 4, 'mg', 81228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('candesartan cilexetil', 'C09CA06', 8, 'mg', 81229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('candesartan cilexetil', 'C09CA06', 16, 'mg', 81230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('candesartan cilexetil', 'C09CA06', 32, 'mg', 79720);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('candesartan cilexetil', 'C09CA06', 4, 'mg', 85025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('candesartan cilexetil', 'C09CA06', 8, 'mg', 85026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('candesartan cilexetil', 'C09CA06', 16, 'mg', 85027);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 75, 'mg', 61288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 150, 'mg', 61289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 300, 'mg', 61290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 75, 'mg', 81399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 150, 'mg', 81400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 300, 'mg', 81401);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 75, 'mg', 80257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 150, 'mg', 80258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 300, 'mg', 80259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 75, 'mg', 80190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 150, 'mg', 80191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 300, 'mg', 80192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 75, 'mg', 81358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 150, 'mg', 81359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 300, 'mg', 81361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 150, 'mg', 80151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 300, 'mg', 80152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 75, 'mg', 85004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 150, 'mg', 85005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irbesartan', 'C09CA04', 300, 'mg', 85006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sevelamer hydrochloride', 'V03AE02', 800, 'mg', 68278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamsulosin hydrochloride', 'G04CA02', 0.4, 'mg', 78022);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamsulosin hydrochloride', 'G04CA02', 0.4, 'mg', 76705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamsulosin hydrochloride', 'G04CA02', 0.4, 'mg', 75550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamsulosin hydrochloride', 'G04CA02', 0.4, 'mg', 78387);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamsulosin hydrochloride', 'G04CA02', 0.4, 'mg', 77961);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamsulosin hydrochloride', 'G04CA02', 0.4, 'mg', 78045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamsulosin hydrochloride', 'G04CA02', 0.4, 'mg', 82577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamsulosin hydrochloride', 'G04CA02', 0.4, 'mg', 83768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('montelukast (montelukast sodium)', 'R03DC03', 5, 'mg', 61609);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('montelukast (montelukast sodium)', 'R03DC03', 10, 'mg', 61610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('montelukast (montelukast sodium)', 'R03DC03', 4, 'mg', 67521);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('montelukast (montelukast sodium)', 'R03DC03', 4, 'mg / pck', 72310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('emedastine (emedastine difumarate)', 'S01GX06', 0.05, '%', 60678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tirofiban (tirofiban hydrochloride)', 'B01AC17', 5, 'mg / 100 ml', 64293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ziprasidone (ziprasidone hydrochloride monohydrate)', 'N05AE04', 20, 'mg', 78389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ziprasidone (ziprasidone hydrochloride monohydrate)', 'N05AE04', 40, 'mg', 78392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ziprasidone (ziprasidone hydrochloride monohydrate)', 'N05AE04', 60, 'mg', 78393);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ziprasidone (ziprasidone hydrochloride monohydrate)', 'N05AE04', 80, 'mg', 78394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 320, 'mg', 84181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 7.5, 'mg', 66608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 15, 'mg', 66609);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 7.5, 'mg', 72198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 7.5, 'mg', 72961);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 15, 'mg', 72962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 7.5, 'mg', 72963);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 15, 'mg', 72964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 7.5, 'mg', 74120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 15, 'mg', 74121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 15, 'mg', 72351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 7.5, 'mg', 74353);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 15, 'mg', 74354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 7.5, 'mg', 72606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 15, 'mg', 72607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 7.5, 'mg', 73355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 15, 'mg', 73356);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 7.5, 'mg', 73483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 15, 'mg', 73484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 15, 'mg', 80979);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 7.5, 'mg', 80978);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 7.5, 'mg', 83836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meloxicam', 'M01AC06', 15, 'mg', 83837);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naratriptan (naratriptan hydrochloride)', 'N02CC02', 1, 'mg', 61179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naratriptan (naratriptan hydrochloride)', 'N02CC02', 2.5, 'mg', 61180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naratriptan (naratriptan hydrochloride)', 'N02CC02', 1, 'mg', 79985);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naratriptan (naratriptan hydrochloride)', 'N02CC02', 2.5, 'mg', 79986);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naratriptan (naratriptan hydrochloride)', 'N02CC02', 2.5, 'mg', 80778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupropion hydrochloride', 'N06AX12', 150, 'mg', 61860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupropion hydrochloride', 'N06AX12', 150, 'mg', 61184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupropion hydrochloride', 'N06AX12', 150, 'mg', 74546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupropion hydrochloride', 'N06AX12', 100, 'mg', 76058);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupropion hydrochloride', 'N06AX12', 150, 'mg', 76059);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupropion hydrochloride', 'N06AX12', 150, 'mg', 76060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupropion hydrochloride', 'N06AX12', 300, 'mg', 76061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupropion hydrochloride', 'N06AX12', 100, 'mg', 77116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupropion hydrochloride', 'N06AX12', 150, 'mg', 77117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupropion hydrochloride', 'N06AX12', 100, 'mg', 81077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupropion hydrochloride', 'N06AX12', 150, 'mg', 81075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupropion hydrochloride', 'N06AX12', 150, 'mg', 79896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bupropion hydrochloride', 'N06AX12', 100, 'mg', 81729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.25, 'mg', 60463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.0, 'mg', 60464);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.5, 'mg', 60465);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.5, 'mg', 65251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.25, 'mg', 75469);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.5, 'mg', 75470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.0, 'mg', 75471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.5, 'mg', 75472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.25, 'mg', 77541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.50, 'mg', 77542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.0, 'mg', 77543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.5, 'mg', 77544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.125, 'mg', 78262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.25, 'mg', 78267);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.5, 'mg', 78268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.0, 'mg', 78269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.5, 'mg', 78270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.25, 'mg', 77772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.5, 'mg', 77773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.0, 'mg', 77774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.5, 'mg', 77776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.25, 'mg', 80080);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.5, 'mg', 80081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.0, 'mg', 80082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.5, 'mg', 80083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.25, 'mg', 79472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.50, 'mg', 79473);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.0, 'mg', 79474);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.5, 'mg', 79475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.25, 'mg', 81116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.50, 'mg', 81117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.0, 'mg', 81118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.5, 'mg', 81119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.25, 'mg', 85244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.50, 'mg', 85245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.0, 'mg', 85247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.5, 'mg', 85248);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propyl alcohol', 'V07AV', 32, '%', 13988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propyl alcohol', 'V07AV', 15, '%', 13850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 70.5, '%', 36829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 70.5, '%', 36797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 18.5, '%', 36791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 53, '%', 26739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 50.16, '%', 25672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'B05BA03', 5, '%', 21687);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 2.5, '%', 15507);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 70, '%', 15498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 70, '%', 15499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 70, '%', 15500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 49.95, '%', 13706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 26, '%', 13988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 49.95, '%', 13830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 82.2, '%', 13786);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 70, '%', 12408);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 2.5, '%', 2406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 57.02, '%', 52647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 70.5, '%', 60446);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 18.5, '%', 60445);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 70, '%', 61475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 79, '%', 62709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 79, '%', 63709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 12.0, '%', 63862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 70.5, '%', 67988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 79, '%', 70836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 49.95, '%', 70166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 65, '%', 70268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'D08AJ51', 65.87, '%', 72815);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 79.0, '%', 75267);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 79.0, '%', 75587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 50.16, '%', 74949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 50.16, '%', 76854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 79, '%', 76811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 2.5, '%', 78729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 2.5, '%', 80171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 2.5, '%', 81653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 50.16, '%', 80691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 50.16, '%', 82117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 53.72, '%', 12254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 53.72, '%', 83945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 62.74, '%', 44478);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 58.0, '% / w/w', 76471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 70, '% / w/w', 50653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'D08AJ51', 70, '% / w/w', 80681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'D08AJ51', 70, '% / w/w', 79988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'D08AJ51', 20, '% / w/w', 79811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V07AV', 70, '% / w/w', 82418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'B05BA03', 5, 'ml / 100 ml', 10924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'V03AX', 0.995, 'ml / ml', 4442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'D08AJ51', 70, '% / ml', 80735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol anhydrous', 'D08AJ51', 70, '% / ml', 80764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('succinylcholine chloride', 'M03AB01', 20, 'mg / ml', 27606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('succinylcholine chloride', 'M03AB01', 100, 'mg / ml', 2526);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('succinylcholine chloride', 'M03AB01', 20, 'mg / ml', 227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('procaine hydrochloride', 'N01BA02', 2, '%', 65649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythrosine', 'V04C', 2, '%', 26307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentian violet', 'D01AE02', 1, '%', 44);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('colchicine', 'M04AC01', 1, 'mg', 6196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('colchicine', 'M04AC01', 0.6, 'mg', 5069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('colchicine', 'M04AC01', 0.6, 'mg', 1931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('colchicine', 'M04AC01', 1, 'mg', 1934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracaine hydrochloride', 'D04AB06', 2, '%', 60078);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracaine hydrochloride', 'S01HA03', 0.5, '%', 65647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracaine hydrochloride', 'S01HA03', 1, '% / w/v', 18749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracaine hydrochloride', 'S01HA03', 0.5, '% / w/v', 18751);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracaine hydrochloride', 'V04CL', 0.073, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracaine hydrochloride', 'N01BA03', 20, 'mg / 2 ml', 65648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('podophyllin', 'D06BB04', 250, 'mg / ml', 5764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triethylene glycol', 'V07AV', 4.66, '%', 25672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triethylene glycol', 'V07AV', 4.66, '%', 74949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triethylene glycol', 'V07AV', 4.66, '%', 76854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triethylene glycol', 'V07AV', 4.66, '%', 80691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triethylene glycol', 'V07AV', 4.66, '%', 82117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized cat pelt', 'V01AA11', 10000, 'unit / ml', 57341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aprotinin (bovine)', 'B02AB01', 10000, 'unit / ml', 42886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glatiramer acetate', 'L03AX13', 20, 'mg / 1 ml', 69719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('reteplase', 'B01AD07', 10.4, 'unit / vial', 52499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olopatadine (olopatadine hydrochloride)', 'S01GX09', 0.1, '%', 53275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olopatadine (olopatadine hydrochloride)', 'S01GX09', 0.2, '% / w/v', 84721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('urea', 'D04AB01', 5, '%', 69914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracycline hydrochloride', 'J01AA07', 250, 'mg', 14282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracycline hydrochloride', 'J01AA07', 250, 'mg', 11956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracycline hydrochloride', 'J01AA07', 250, 'mg', 5293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracycline hydrochloride', 'J01AA07', 250, 'mg', 735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetracycline hydrochloride', 'S01AA09', 10, 'mg / g', 10602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 18421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 14939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 14940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 9814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 10383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 10117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 10024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 7627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 6795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'A01AB22', 20, 'mg', 71343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 77482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 77490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 77494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 77480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 77481);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 77489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 83642);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100, 'mg', 83643);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline (doxycycline hyclate)', 'A01AB22', 44, 'mg / unit', 66197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxycycline hyclate', 'J01AA02', 100, 'mg', 10897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin (erythromycin stearate)', 'J01FA01', 250, 'mg', 14938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin', 'J01FA01', 500, 'mg', 11252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin', 'J01FA01', 333, 'mg', 11929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin', 'J01FA01', 333, 'mg', 10707);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin', 'J01FA01', 333, 'mg', 9162);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin', 'J01FA01', 250, 'mg', 9939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin', 'J01FA01', 250, 'mg', 5599);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin (erythromycin ethylsuccinate)', 'J01FA01', 600, 'mg', 6686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin', 'J01FA01', 250, 'mg', 6687);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin (erythromycin stearate)', 'J01FA01', 500, 'mg', 6688);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin (erythromycin ethylsuccinate)', 'J01FA01', 600, 'mg', 5296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin (erythromycin stearate)', 'J01FA01', 250, 'mg', 4465);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin (erythromycin lactobionate)', 'J01FA01', 1, 'g / vial', 12859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin (erythromycin lactobionate)', 'J01FA01', 1, 'g / vial', 9397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin (erythromycin lactobionate)', 'J01FA01', 500, 'mg / vial', 12858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin (erythromycin lactobionate)', 'J01FA01', 500, 'mg / vial', 9396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin (erythromycin ethylsuccinate)', 'J01FA01', 400, 'mg / 5 ml', 6324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin (erythromycin ethylsuccinate)', 'J01FA01', 200, 'mg / 5 ml', 5603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pilocarpine hydrochloride', 'S01EB01', 1, '%', 47468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin (erythromycin ethylsuccinate)', 'J01FA01', 400, 'mg / 5 ml', 3172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin (erythromycin ethylsuccinate)', 'J01FA01', 40, 'mg / ml', 3698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin (erythromycin estolate)', 'J01FA01', 250, 'mg / 5 ml', 1642);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin (erythromycin estolate)', 'J01FA01', 125, 'mg / 5 ml', 901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin', 'S01AA17', 5, 'mg / g', 31467);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin', 'S01AA17', 5, 'mg / g', 12875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erythromycin', 'S01AA17', 5, 'mg / g', 11423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paromomycin (paromomycin sulfate)', 'A07AA06', 250, 'mg', 16701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('framycetin sulfate', 'D09AA01', 1, '%', 18285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('framycetin sulfate', 'D09AA01', 1, '%', 16888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('framycetin sulfate', 'S01AA07', 5, 'mg / ml', 37386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('framycetin sulfate', 'S01AA07', 5, 'mg / g', 37387);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin sulfate', 'S01AA11', 5, 'mg / ml', 12265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'J01GB03', 4.5, 'mg', 44317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'S01AA11', 0.3, '%', 37211);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'D06AX07', 0.1, '%', 10751);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'D06AX07', 0.1, '%', 10752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'S01AA11', 0.3, '%', 703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'S01AA11', 0.3, '%', 16244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'S01AA11', 0.3, '%', 16983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'S01AA11', 0.3, '%', 16862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'J01GB03', 1.2, 'mg / ml', 18241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'J01GB03', 1, 'mg / ml', 18242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'J01GB03', 1.6, 'mg / ml', 18243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'J01GB03', 1.4, 'mg / ml', 12674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'J01GB03', 0.8, 'mg / ml', 12675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'S01AA11', 3, 'mg / ml', 9617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'S02AA14', 3, 'mg / ml', 4181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'S01AA11', 3, 'mg / ml', 4182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'S01AA11', 3, 'mg / ml', 47318);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'S02AA14', 3, 'mg / ml', 47319);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'S02AA14', 3, 'mg / ml', 50167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'J01GB03', 40, 'mg / ml', 66434);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'J01GB03', 10, 'mg / ml', 75394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'D06AX07', 1, 'mg / g', 11062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'D06AX07', 1, 'mg / g', 10995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gentamicin (gentamicin sulfate)', 'S01AA11', 3, 'mg / g', 50166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neomycin sulfate', 'V04CL', 0.19, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carbonate (anhydrous)', 'V07AV', 2, '%', 15899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carbonate (anhydrous)', 'V07AV', 1.5, '%', 15508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carbonate (anhydrous)', 'V07AV', 2, '%', 13767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carbonate (anhydrous)', 'V07AV', 3, '%', 3594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carbonate (anhydrous)', 'V07AV', 3, '%', 2545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carbonate (anhydrous)', 'V07AV', 2, '%', 2486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carbonate (anhydrous)', 'V07AV', 1.2, '%', 2487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carbonate (anhydrous)', 'V07AV', 3, '%', 2298);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carbonate (anhydrous)', 'V07AV', 3.5, '%', 2679);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pilocarpine nitrate', 'S01EB01', 2, '% / w/v', 18744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pilocarpine hydrochloride', 'N07AX01', 5, 'mg', 43182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pilocarpine hydrochloride', 'S01EB01', 1, '%', 16241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pilocarpine hydrochloride', 'S01EB01', 2, '%', 16217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pilocarpine hydrochloride', 'S01EB01', 4, '%', 16631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pilocarpine hydrochloride', 'S01EB01', 1, '%', 12257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pilocarpine hydrochloride', 'S01EB01', 2, '%', 12258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pilocarpine hydrochloride', 'S01EB01', 4, '%', 12259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pilocarpine hydrochloride', 'S01EB01', 4, '%', 6053);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pilocarpine hydrochloride', 'S01EB01', 4, '%', 47466);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pilocarpine hydrochloride', 'S01EB01', 2, '%', 47467);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pilocarpine hydrochloride', 'S01EB01', 6, '%', 48923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pilocarpine hydrochloride', 'S01EB01', 40, 'mg / ml', 2374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pilocarpine hydrochloride', 'S01EB01', 20, 'mg / ml', 2375);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pilocarpine hydrochloride', 'S01EB01', 10, 'mg / ml', 2376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thyroid', 'H03AA05', 60, 'mg', 773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thyroid', 'H03AA05', 125, 'mg', 774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoniazid', 'J04AC01', 300, 'mg', 19268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoniazid', 'J04AC01', 100, 'mg', 5718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoniazid', 'J04AC01', 300, 'mg', 5719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoniazid', 'J04AC01', 50, 'mg', 6752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoniazid', 'J04AC01', 100, 'mg', 2400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoniazid', 'J04AC01', 300, 'mg', 2401);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoniazid', 'J04AC01', 50, 'mg / 5 ml', 5720);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoniazid', 'J04AC01', 10, 'mg / ml', 2865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoniazid', 'J04AC01', 500, 'g / bottle', 2553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl myristate', 'D02AC', 10, '%', 2256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl myristate', 'P03AX', 50, '% / w/w', 76520);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroquine diphosphate', 'P01BA01', 250, 'mg', 682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 1.8, '%', 41955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 1.5, '%', 41956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 2, '%', 41957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 2, '%', 37415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 2, '%', 33818);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 2, '%', 32776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 2, '%', 16271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 2, '%', 16272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 2, '%', 12972);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 2, '%', 12973);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 4, '%', 13382);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 4, '%', 13899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 4, '%', 14324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 2, '%', 11207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 1.5, '%', 61543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 2.0, '%', 61544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 4, '%', 66771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 4, '%', 66772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 4, '%', 66848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 4, '%', 72192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 4.0, '%', 69834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 4.0, '%', 76383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 2, '%', 75425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 4.0, '%', 74229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 4, '%', 73220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 4, '%', 73222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 4, '%', 73488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 2, '%', 73651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 4.0, '% / w/w', 80960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 4.0, '% / w/w', 80453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 2, '%', 32777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 2, '%', 32778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroquinone', 'D11AX11', 4, 'g / 100 g', 15518);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotine', 'N07BA01', 30, 'mg / 7 sq cm', 15591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cinnamaldehyde', 'V04CL', 0.034, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon beta-1a', 'L03AB07', 22, 'µg / 0.5 ml', 60641);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon beta-1a', 'L03AB07', 44, 'µg / 0.5 ml', 60642);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon beta-1a', 'L03AB07', 8.8, 'µg / 0.2 ml', 76736);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon beta-1a', 'L03AB07', 22.0, 'µg / 0.5 ml', 76736);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon beta-1a', 'L03AB07', 30, 'µg / 0.5 ml', 75459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon beta-1a', 'L03AB07', 8.8, 'µg / 0.2 ml', 76312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon beta-1a', 'L03AB07', 132, 'µg / 1.5 ml', 80377);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon beta-1a', 'L03AB07', 66, 'µg / 1.5 ml', 80376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone (trazodone hydrochloride)', 'N06AX05', 68.25, 'mg', 60663);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone (trazodone hydrochloride)', 'N06AX05', 68.25, 'mg', 73464);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('anagrelide (anagrelide hydrochloride)', 'L01XX35', 0.5, 'mg', 60149);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 40, 'mg', 75588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('anagrelide (anagrelide hydrochloride monohydrate)', 'L01XX35', 0.5, 'mg', 76693);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('anagrelide (anagrelide hydrochloride monohydrate)', 'L01XX35', 0.5, 'mg', 74534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('anagrelide (anagrelide hydrochloride monohydrate)', 'L01XX35', 0.5, 'mg', 76047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('anagrelide (anagrelide hydrochloride)', 'L01XX35', 0.5, 'mg', 73797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brimonidine tartrate', 'S01EA05', 0.2, '%', 60166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brimonidine tartrate', 'S01EA05', 0.2, '%', 66888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brimonidine tartrate', 'S01EA05', 0.2, '%', 70445);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brimonidine tartrate', 'S01EA05', 0.2, '%', 74531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brimonidine tartrate', 'S01EA05', 0.15, '%', 72483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brimonidine tartrate', 'S01EA05', 0.15, '%', 78666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('brimonidine tartrate', 'S01EA05', 0.2, '%', 79097);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nadroparin calcium', 'B01AB06', 9500, 'unit / 1.0 ml', 60205);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nadroparin calcium', 'B01AB06', 19000, 'unit / ml', 63628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 25, 'mg', 60245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 100, 'mg', 60246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 200, 'mg', 60247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 300, 'mg', 68066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 25, 'mg', 78440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 100, 'mg', 78441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 200, 'mg', 78443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 300, 'mg', 78444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 25, 'mg', 78445);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 100, 'mg', 78446);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 200, 'mg', 78448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 300, 'mg', 78449);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 200, 'mg', 76981);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 150, 'mg', 76980);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 300, 'mg', 76982);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 25, 'mg', 78188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 100, 'mg', 78189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 200, 'mg', 78191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 300, 'mg', 78192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 25, 'mg', 76978);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 100, 'mg', 76979);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 50, 'mg', 78550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 200, 'mg', 78551);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 300, 'mg', 78552);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 400, 'mg', 78553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 25, 'mg', 81615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 100, 'mg', 81616);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 200, 'mg', 81618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 300, 'mg', 81619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 25, 'mg', 79725);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 100, 'mg', 79726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 200, 'mg', 79729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 300, 'mg', 79730);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 25, 'mg', 80341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 100, 'mg', 80342);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 200, 'mg', 80344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 300, 'mg', 80345);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 25, 'mg', 79348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 100, 'mg', 79349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 200, 'mg', 79351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 300, 'mg', 79352);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 25, 'mg', 79951);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 100, 'mg', 79952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 200, 'mg', 79953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 300, 'mg', 79954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 25, 'mg', 80220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 100, 'mg', 80221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 200, 'mg', 80223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 300, 'mg', 80224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 25, 'mg', 80161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 100, 'mg', 80162);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 200, 'mg', 80164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 300, 'mg', 80165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 25, 'mg', 79943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 100, 'mg', 79944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 200, 'mg', 79945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 300, 'mg', 79946);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 150, 'mg', 80692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 25, 'mg', 80287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 100, 'mg', 80288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 200, 'mg', 80289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 300, 'mg', 80290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 25, 'mg', 83838);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 100, 'mg', 83839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 200, 'mg', 83841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 300, 'mg', 83842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 50, 'mg', 84693);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatostatin (somatostatin acetate)', 'H01CB01', 250, 'µg / kit', 43833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('somatostatin (somatostatin acetate)', 'H01CB01', 3, 'mg / amp', 43834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 80, 'mg', 60097);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 160, 'mg', 60098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 80, 'mg', 68771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 160, 'mg', 68772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 320, 'mg', 77486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 40, 'mg', 82307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 80, 'mg', 82308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 160, 'mg', 82309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 320, 'mg', 82310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 40, 'mg', 84178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 80, 'mg', 84179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 160, 'mg', 84180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 40, 'mg', 84187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 80, 'mg', 84188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 160, 'mg', 84189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 320, 'mg', 84190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 40, 'mg', 84808);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 80, 'mg', 84812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 160, 'mg', 84813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 40, 'mg', 85256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 80, 'mg', 85257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 160, 'mg', 85258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valsartan', 'C09CA03', 320, 'mg', 85259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('myristamidopropyl dimethylamine', 'S01XA20', 0.0005, '%', 60122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('myristamidopropyl dimethylamine', 'S01XA20', 0.0005, '%', 78302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin', 'J01MA12', 250, 'mg', 60130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin', 'J01MA12', 500, 'mg', 60131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin', 'J01MA12', 750, 'mg', 71004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin', 'J01MA12', 250, 'mg', 72599);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin', 'J01MA12', 500, 'mg', 72600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 250, 'mg', 78395);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 500, 'mg', 78396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 750, 'mg', 78397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 250, 'mg', 77026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 500, 'mg', 77027);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 250, 'mg', 77023);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 500, 'mg', 77024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 750, 'mg', 77115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 250, 'mg', 79949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 500, 'mg', 79950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 250, 'mg', 80096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 500, 'mg', 80097);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 750, 'mg', 80098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 750, 'mg', 79115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 750, 'mg', 81129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levofloxacin', 'J01MA12', 5, 'mg / ml', 60128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zafirlukast', 'R03DC01', 20, 'mg', 59964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vancomycin (vancomycin hydrochloride)', 'A07AA09', 250, 'mg', 9593);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vancomycin (vancomycin hydrochloride)', 'A07AA09', 125, 'mg', 9594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01', 5, 'g / vial', 43933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01', 1, 'g / vial', 19705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01', 10, 'g / vial', 65472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01', 1.0, 'g / vial', 65486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01', 500, 'mg / vial', 19703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01', 500, 'mg / vial', 82835);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01', 500, 'mg / vial', 48884);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01', 1000, 'mg / vial', 48885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01', 500, 'mg / vial', 65485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01', 1000, 'mg / vial', 82836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 300, 'mg', 19455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 150, 'mg', 874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 150, 'mg', 65371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 300, 'mg', 65372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 150, 'mg', 66121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 300, 'mg', 66122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 150, 'mg', 69247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 300, 'mg', 69248);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 150, 'mg', 72878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 300, 'mg', 72879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 150, 'mg', 74355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 300, 'mg', 74356);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 150, 'mg', 77875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 300, 'mg', 77876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 150, 'mg', 78015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 300, 'mg', 78016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin phosphate)', 'D10AF01', 1, '%', 11260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin phosphate)', 'D10AF01', 1.0, '%', 66809);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin phosphate)', 'D10AF01', 1, '%', 66912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin phosphate)', 'D10AF01', 1, '%', 67589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin phosphate)', 'D10AF01', 1, '%', 75233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin phosphate)', 'J01FF01', 150, 'mg / ml', 18964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin 2-palmitate hydrochloride)', 'J01FF01', 75, 'mg / 5 ml', 1225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin phosphate)', 'J01FF01', 150, 'mg / ml', 1620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin phosphate)', 'J01FF01', 150, 'mg / ml', 49605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin phosphate)', 'J01FF01', 150, 'mg / ml', 49612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clindamycin (clindamycin phosphate)', 'G01AA10', 20, 'mg / g', 15942);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('streptozocin', 'L01AD04', 1, 'g / vial', 6166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rifampin', 'J04AB02', 300, 'mg', 19034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rifampin', 'J04AB02', 150, 'mg', 17105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rifampin', 'J04AB02', 300, 'mg', 2863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rifampin', 'J04AB02', 150, 'mg', 2866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin zinc', 'D06AX05', 500, 'unit / g', 83729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin', 'J01XX10', 50000, 'unit / vial', 69667);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin', 'J01XX10', 50000, 'unit / 10 ml', 431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin', 'D06AX05', 500, 'unit / g', 42145);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin', 'D06AX05', 500, 'unit / g', 20131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin', 'D06AX05', 500, 'unit / g', 17895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin (bacitracin zinc)', 'D06AX05', 500, 'unit / g', 16171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin', 'D06AX05', 500, 'unit / g', 8398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin', 'D06AX05', 500, 'unit / g', 5863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin', 'D06AX05', 500, 'unit / g', 78976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacitracin', 'D06AX05', 500, 'unit / g', 83697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fusidic acid', 'D06AX01', 2, '%', 5637);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fusidic acid', 'S01AA13', 10, 'mg / g', 67802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fusidic acid', 'S01AA13', 10, 'mg / g', 67803);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fusidate sodium', 'D06AX01', 2, '%', 5638);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nystatin', 'A07AA02', 500000, 'unit', 35797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nystatin', 'A07AA02', 100000, 'unit / ml', 35798);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nystatin', 'A07AA02', 100, 'unit / ml', 30739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nystatin', 'A07AA02', 100000, 'unit / ml', 10435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nystatin', 'A07AA02', 100000, 'unit / ml', 9973);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nystatin', 'G01AA01', 100000, 'unit / g', 35795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nystatin', 'D01AA01', 100000, 'unit / g', 35799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nystatin', 'D01AA01', 100000, 'unit / g', 35800);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nystatin', 'G01AA01', 25000, 'unit / g', 9277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nystatin', 'D01AA01', 100000, 'unit / g', 8977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nystatin', 'D01AA01', 100000, 'unit / g', 8978);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('colistin (colistimethate sodium)', 'J01XB01', 150, 'mg / vial', 5524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('colistin (colistimethate sodium)', 'J01XB01', 150, 'mg / vial', 68839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', 'D06AX05', 10000, 'unit / g', 42145);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', 'D06AX05', 10000, 'unit / g', 20131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', 'D06AX05', 10000, 'unit / g', 16171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', 'D06AX05', 10000, 'unit / g', 8398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polymyxin b (polymyxin b sulfate)', 'D06AX05', 10000, 'unit / g', 78976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gramicidin', 'D06AX05', 0.25, 'mg / g', 16171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalothin (cephalothin sodium)', 'J01DB03', 1, 'g / vial', 16984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dactinomycin', 'L01DA01', 0.5, 'mg / vial', 250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amphotericin b', 'J02AA01', 50, 'mg / vial', 933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amphotericin b', 'J02AA01', 50, 'mg / vial', 65288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amphotericin b', 'J02AA01', 100, 'mg / vial', 65412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amphotericin b', 'J02AA01', 50, 'mg / vial', 65413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amphotericin b', 'J02AA01', 5, 'mg / ml', 50926);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin v potassium', 'J01CE02', 500000, 'unit', 6421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin v potassium', 'J01CE02', 500000, 'unit', 3375);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin v potassium', 'J01CE02', 500000, 'unit', 295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin v potassium', 'J01CE02', 200000, 'unit / 5 ml', 6422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin v potassium', 'J01CE02', 500000, 'unit / 5 ml', 6423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin v potassium', 'J01CE02', 500000, 'unit / 5 ml', 2814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxychloroquine sulfate', 'P01BA02', 200, 'mg', 14735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxychloroquine sulfate', 'P01BA02', 200, 'mg', 70886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxychloroquine sulfate', 'P01BA02', 200, 'mg', 73748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxychloroquine sulfate', 'P01BA02', 200, 'mg', 79662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gold sodium thiomalate', 'M01CB01', 10, 'mg / ml', 13156);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gold sodium thiomalate', 'M01CB01', 50, 'mg / ml', 12845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gold sodium thiomalate', 'M01CB01', 25, 'mg / ml', 12846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gold sodium thiomalate', 'M01CB01', 10, 'mg / ml', 69514);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gold sodium thiomalate', 'M01CB01', 25, 'mg / ml', 69515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gold sodium thiomalate', 'M01CB01', 50, 'mg / ml', 69516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methadone hydrochloride', 'N07BC02', 1, 'mg', 71959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methadone hydrochloride', 'N07BC02', 5, 'mg', 71963);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methadone hydrochloride', 'N07BC02', 10, 'mg', 71964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methadone hydrochloride', 'N07BC02', 25, 'mg', 71965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methadone hydrochloride', 'N07BC02', 10, 'mg / ml', 65010);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methadone hydrochloride', 'N07BC02', 10, 'mg / ml', 68257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methadone hydrochloride', 'N07BC02', 1, 'mg / ml', 71958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dicyclomine hydrochloride', 'A03AA07', 20, 'mg', 17842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dicyclomine hydrochloride', 'A03AA07', 10, 'mg', 18227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dicyclomine hydrochloride', 'A03AA07', 20, 'mg', 4223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dicyclomine hydrochloride', 'A03AA07', 10, 'mg', 4710);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dicyclomine hydrochloride', 'A03AA07', 10, 'mg', 3556);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dicyclomine hydrochloride', 'A03AA07', 10, 'mg', 2623);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dicyclomine hydrochloride', 'A03AA07', 10, 'mg', 1857);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dicyclomine hydrochloride', 'A03AA07', 20, 'mg', 85095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dicyclomine hydrochloride', 'A03AA07', 10, 'mg / 5 ml', 17841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dicyclomine hydrochloride', 'A03AA07', 10, 'mg / ml', 3555);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', 'A07BB', 262, 'mg', 42736);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', 'A07BB', 262, 'mg', 69837);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', 'A07BB', 262, 'mg', 69838);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', 'A07BB', 262, 'mg', 79987);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', 'A07BB', 262, 'mg', 81124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', 'A07BB', 262, 'mg', 81194);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', 'A07BB', 17.6, 'mg / ml', 42395);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', 'A07BB', 17.6, 'mg / ml', 33448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', 'A07BB', 35.2, 'mg / ml', 47656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', 'A07BB', 35, 'mg / ml', 66286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', 'A07BB', 35, 'mg / ml', 71331);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', 'A07BB', 35, 'mg / ml', 74775);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', 'A07BB', 17.5, 'mg / ml', 78167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', 'A07BB', 35, 'mg / ml', 81398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth subsalicylate', 'A07BB', 17.5, 'mg / ml', 79869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methsuximide', 'N03AD03', 300, 'mg', 763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethylenediamine dihydrochloride', 'V04CL', 0.041, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorine peroxide', 'V07AV', 0.2, '%', 75693);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irinotecan hydrochloride', 'L01XX19', 20, 'mg / ml', 79791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('geraniol', 'V04CL', 0.07, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bismuth dipropylacetate', 'R07AX', 135, 'mg', 1090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 0.25, 'mg', 52041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 1, 'mg', 52043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 2, 'mg', 52044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 5, 'mg', 52047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 0.25, 'mg', 80234);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 1, 'mg', 80235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 2, 'mg', 80236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 5, 'mg', 80237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 0.25, 'mg', 79955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 1.0, 'mg', 79957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 2.0, 'mg', 79958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 5.0, 'mg', 79959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 0.25, 'mg', 81195);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 1.0, 'mg', 81197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 2.0, 'mg', 81198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 5.0, 'mg', 81199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 0.25, 'mg', 83760);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 1.0, 'mg', 83761);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 2.0, 'mg', 83762);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 5.0, 'mg', 83763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 0.25, 'mg', 83827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 1, 'mg', 83828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 2, 'mg', 83829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 5, 'mg', 83830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin g benzathine', 'J01CE08', 1200000, 'unit / 2 ml', 77729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('donepezil hydrochloride', 'N06DA02', 5, 'mg', 51491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('donepezil hydrochloride', 'N06DA02', 10, 'mg', 51492);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('donepezil hydrochloride', 'N06DA02', 5, 'mg', 75483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('donepezil hydrochloride', 'N06DA02', 10, 'mg', 75484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dinoprost (dinoprost tromethamine)', 'G02AD01', 5, 'mg / ml', 2224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('follitropin beta', 'G03GA06', 50, 'unit / 0.5 ml', 66152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('follitropin beta', 'G03GA06', 100, 'unit / 0.5 ml', 66154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('follitropin beta', 'G03GA06', 833, 'unit / ml', 67891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topotecan (topotecan hydrochloride)', 'L01XX17', 4, 'mg / vial', 50424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topotecan (topotecan hydrochloride)', 'L01XX17', 4, 'mg / vial', 81957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topotecan (topotecan hydrochloride)', 'L01XX17', 4, 'mg / vial', 82941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nafarelin (nafarelin acetate)', 'H01CA02', 2, 'mg / ml', 42902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trandolapril', 'C09AA10', 0.5, 'mg', 50773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trandolapril', 'C09AA10', 1, 'mg', 50775);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trandolapril', 'C09AA10', 2, 'mg', 50776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trandolapril', 'C09AA10', 4, 'mg', 62731);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dolasetron mesylate', 'A04AA04', 100, 'mg', 50690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('letrozole', 'L02BG04', 2.5, 'mg', 50695);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('letrozole', 'L02BG04', 2.5, 'mg', 79471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('letrozole', 'L02BG04', 2.5, 'mg', 80777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('letrozole', 'L02BG04', 2.5, 'mg', 82411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('letrozole', 'L02BG04', 2.5, 'mg', 83029);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('letrozole', 'L02BG04', 2.5, 'mg', 83335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('letrozole', 'L02BG04', 2.5, 'mg', 83427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cromolyn sodium', 'A07EB01', 100, 'mg', 4114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cromolyn sodium', 'S01GX01', 2, '%', 13857);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cromolyn sodium', 'R03BC01', 1, '%', 14758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cromolyn sodium', 'R01AC01', 2, '%', 50704);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cromolyn sodium', 'R03BC01', 1, '%', 50747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cromolyn sodium', 'R01AC01', 2, '% / w/v', 14565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cromolyn sodium', 'S01GX01', 2, '% / w/v', 49797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cromolyn sodium', 'R03BC01', 10, 'mg / ml', 51046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bleomycin (bleomycin sulfate)', 'L01DC01', 15, 'unit / vial', 43892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bleomycin (bleomycin sulfate)', 'L01DC01', 15, 'unit / vial', 75142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fexofenadine hydrochloride', 'R06AX26', 60, 'mg', 50779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin g (penicillin g sodium)', 'J01CE01', 10000000, 'unit / vial', 16991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fexofenadine hydrochloride', 'R06AX26', 120, 'mg', 66647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('follitropin alpha', 'G03GA05', 5.5, 'µg / vial', 72486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('follitropin alpha', 'G03GA05', 33, 'µg / vial', 72488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('follitropin alpha', 'G03GA05', 77, 'µg / vial', 72489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('follitropin alpha', 'G03GA05', 150, 'unit / vial', 50782);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('follitropin alpha', 'G03GA05', 1200, 'unit / vial', 68777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('follitropin alpha', 'G03GA05', 900, 'unit / 1.5 ml', 75576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('follitropin alpha', 'G03GA05', 450, 'unit / 0.75 ml', 75577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('follitropin alpha', 'G03GA05', 300, 'unit / 0.5 ml', 75578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('latanoprost', 'S01EE01', 50, 'µg / ml', 50823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbetocin', 'H01BB03', 100, 'µg / ml', 50960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irinotecan hydrochloride', 'L01XX19', 20, 'mg / ml', 50993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irinotecan hydrochloride', 'L01XX19', 20, 'mg / ml', 74343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irinotecan hydrochloride', 'L01XX19', 20, 'mg / ml', 79064);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('irinotecan hydrochloride (irinotecan hydrochloride trihydrate)', 'L01XX19', 20, 'mg / ml', 83053);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodide (sodium iodide)', 'A12CX', 100, 'µg / ml', 13600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclosporin', 'L04AD01', 25, 'mg', 17813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclosporin', 'L04AD01', 50, 'mg', 17814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclosporin', 'L04AD01', 100, 'mg', 17799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclosporin', 'L04AD01', 10, 'mg', 61016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclosporin', 'L04AD01', 100, 'mg', 66649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclosporin', 'L04AD01', 25, 'mg', 71308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclosporin', 'L04AD01', 50, 'mg', 71309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclosporin', 'S01XA18', 0.05, '% / w/v', 84087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclosporin', 'L04AD01', 100, 'mg / ml', 17801);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclosporin', 'L04AD01', 50, 'mg / ml', 5790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclosporin', 'L04AD01', 100, 'mg / ml', 68291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coagulation factor ix (recombinant)', 'B02BD04', 250, 'unit / vial', 77915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coagulation factor ix (recombinant)', 'B02BD04', 500, 'unit / vial', 77916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coagulation factor ix (recombinant)', 'B02BD04', 1000, 'unit / vial', 77917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coagulation factor ix (recombinant)', 'B02BD04', 2000, 'unit / vial', 77918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin g sodium', 'J01CE01', 1000000, 'unit / vial', 12394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin g sodium', 'J01CE01', 10000000, 'unit / vial', 12395);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin g sodium', 'J01CE01', 5000000, 'unit / vial', 12343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin g (penicillin g sodium)', 'J01CE01', 1000000, 'unit / vial', 37244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin g (penicillin g sodium)', 'J01CE01', 5000000, 'unit / vial', 37245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin g (penicillin g sodium)', 'J01CE01', 10000000, 'unit / vial', 37246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 500, 'mg', 75197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin g (penicillin g sodium)', 'J01CE01', 5000000, 'unit / vial', 16992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin g (penicillin g sodium)', 'J01CE01', 1000000, 'unit / vial', 16993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin g (penicillin g sodium)', 'J01CE01', 5000000, 'unit / vial', 78574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim', 'J01EA01', 100, 'mg', 66985);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimethoprim', 'J01EA01', 200, 'mg', 66986);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bleomycin sulfate', 'L01DC01', 15, 'unit / amp', 1589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 500, 'mg', 19065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 250, 'mg', 19066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 500, 'mg', 19042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 250, 'mg', 19043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 500, 'mg', 11962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 250, 'mg', 11963);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 500, 'mg', 9170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 250, 'mg', 9171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 250, 'mg', 9907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 500, 'mg', 9908);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 250, 'mg', 5181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 500, 'mg', 5182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 250, 'mg', 3945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 500, 'mg', 3946);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 250, 'mg', 2809);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 500, 'mg', 1434);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 125, 'mg / 5 ml', 19068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 250, 'mg / 5 ml', 19069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 125, 'mg / 5 ml', 19070);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 250, 'mg / 5 ml', 19072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 250, 'mg / 5 ml', 5072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 125, 'mg / 5 ml', 5073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 250, 'mg / 5 ml', 1212);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cephalexin', 'J01DB01', 125, 'mg / 5 ml', 1184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefotaxime sodium', 'J01DD01', 1, 'g / vial', 43411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefotaxime sodium', 'J01DD01', 2, 'g / vial', 43412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefotaxime sodium', 'J01DD01', 500, 'mg / vial', 43410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('idoxuridine', 'D06BB01', 0.1, '%', 60505);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rifabutin', 'J04AB04', 150, 'mg', 18081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atovaquone', 'P01AX06', 750, 'mg / 5 ml', 43212);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 500, 'mg', 17240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 250, 'mg', 12779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 500, 'mg', 68745);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 250, 'mg', 72112);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 500, 'mg', 72114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 250, 'mg', 71828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 500, 'mg', 71829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 250, 'mg', 75196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 250, 'mg', 73227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 500, 'mg', 73228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 250, 'mg', 76021);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 500, 'mg', 76022);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 250, 'mg', 80993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 500, 'mg', 80994);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 250, 'mg', 83195);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 500, 'mg', 83196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 500, 'mg', 83618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 250, 'mg', 84648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 500, 'mg', 84649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 125, 'mg / 5 ml', 18066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clarithromycin', 'J01FA09', 250, 'mg / 5 ml', 68628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aztreonam', 'J01DF01', 75, 'mg / vial', 81558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pivmecillinam (pivmecillinam hydrochloride)', 'J01CA08', 185, 'mg', 6471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized timothy grass pollen', 'V01AA02', 100000, 'unit / ml', 61918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized timothy grass pollen', 'V01AA02', 10000, 'unit / ml', 61919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized timothy grass pollen', 'V01AA02', 100000, 'unit / ml', 66453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized timothy grass pollen', 'V01AA02', 100000, 'unit / ml', 81085);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized timothy grass pollen', 'V01AA02', 25000, 'unit / ml', 81091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized timothy grass pollen', 'V01AA02', 20000, 'unit / ml', 81092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', 'M03BA03', 750, 'mg', 13624);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', 'M03BA03', 500, 'mg', 13297);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', 'M03BA03', 100, 'mg / ml', 19287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', 'M03BA03', 100, 'mg / ml', 9776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', 'M03BA03', 100, 'mg / ml', 8576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methocarbamol', 'M03BA03', 100, 'mg / ml', 71195);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', 'D04AB07', 1, '%', 9335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', 'D04AB07', 1, '%', 60289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', 'D04AB07', 1.0, '%', 63619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', 'D04AB07', 1.0, '%', 63620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', 'D04AB07', 1.0, '%', 70300);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', 'D04AB07', 1, '%', 75230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', 'D04AB07', 1, '%', 77276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', 'D04AB07', 1.0, '% / w/w', 80391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', 'D04AB07', 1, '% / w/w', 80397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', 'D04AB07', 1, '% / ml', 13570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pramoxine hydrochloride', 'D04AB07', 1, '% / ml', 80442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lindane', 'P03AB02', 1, '%', 8259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lindane', 'P03AB02', 1, '%', 8213);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lindane', 'P03AB02', 1, '%', 69989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lindane', 'P03AB02', 1, '%', 10506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethosuximide', 'N03AD01', 250, 'mg', 771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethosuximide', 'N03AD01', 250, 'mg / 5 ml', 731);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neostigmine bromide', 'N07AA01', 15, 'mg', 11691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyridostigmine bromide', 'N07AA02', 60, 'mg', 10567);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyridostigmine bromide', 'N07AA02', 180, 'mg', 11135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetazolamide', 'S01EC01', 250, 'mg', 4899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetazolamide', 'S01EC01', 250, 'mg', 1886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetazolamide (acetazolamide sodium)', 'S01EC01', 500, 'mg / vial', 84336);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 1.0, '% / w/w', 80419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diethylamine salicylate', 'M02AC', 100, 'mg / g', 13284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diethylamine salicylate', 'M02AC', 100, 'mg / g', 79617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histamine phosphate', 'V04CG03', 1, 'mg / ml', 16997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histamine phosphate', 'V04CL', 2.75, 'mg / ml', 5537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histamine phosphate', 'V04CL', 0.275, 'mg / ml', 5538);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclopentolate hydrochloride', 'S01FA04', 0.5, '% / w/v', 19307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclopentolate hydrochloride', 'S01FA04', 1, '% / w/v', 18742);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclopentolate hydrochloride', 'S01FA04', 1, '%', 16242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclopentolate hydrochloride', 'S01FA04', 0.5, '%', 16651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclopentolate hydrochloride', 'S01FA04', 1, '%', 12417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclopentolate hydrochloride', 'S01FA04', 1, '%', 5997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclopentolate hydrochloride', 'S01FA04', 0.5, '%', 5998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclopentolate hydrochloride', 'S01FA04', 1, '%', 1530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 200, 'mg', 14941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 200, 'mg', 9242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 200, 'mg', 8373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 400, 'mg', 8374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 100, 'mg', 6049);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 200, 'mg', 6463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 200, 'mg', 6819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 200, 'mg', 4582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 200, 'mg', 5107);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 200, 'mg', 3920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 200, 'mg', 777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 200, 'mg', 50883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 100, 'mg', 50885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 200, 'mg', 50886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 400, 'mg', 50887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 200, 'mg', 61270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 400, 'mg', 61271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 200, 'mg', 65552);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 400, 'mg', 65553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 100, 'mg', 68372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 200, 'mg', 68373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 200, 'mg', 74720);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 400, 'mg', 74721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 100, 'mg', 74722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 200, 'mg', 74723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 200, 'mg / srt', 61615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 400, 'mg / srt', 61616);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbamazepine', 'N03AF01', 100, 'mg / 5 ml', 19729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 7.6, '%', 34513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 0.046, '%', 26739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 0.03, '%', 25672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 2, '%', 19768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 1.7, '%', 17426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 1.75, '%', 16133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 0.045, '%', 13706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 1.75, '%', 14368);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 0.045, '%', 13830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 0.03, '%', 12288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 0.03, '%', 12254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 2, '%', 11343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 2, '%', 6212);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 0.05, '%', 3797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 1, '%', 4201);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 0.046, '%', 60627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 4.1, '%', 62881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 1.81, '%', 66340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 0.045, '%', 70166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 1.81, '%', 70589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 7.8, '%', 76472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 0.03, '%', 74949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 0.03, '%', 76854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 0.03, '%', 80691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 0.03, '%', 82117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-pentylphenol', 'V07AV', 0.03, '%', 83945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl benzyl ammonium saccharinate', 'V07AV', 0.1, '% / w/w', 76471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 2.5, 'mg', 37356);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 5, 'mg', 37357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 5, 'mg', 14094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 2.5, 'mg', 14095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 2.5, 'mg', 11780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 5, 'mg', 11781);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 5, 'mg', 11727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 2.5, 'mg', 11728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 2.5, 'mg', 11122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 5, 'mg', 11120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 2.5, 'mg', 12865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 5, 'mg', 11472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 2.5, 'mg', 11473);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 5, 'mg', 10834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 5, 'mg', 55852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 5, 'mg', 60020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 5, 'mg', 59930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 2.5, 'mg', 65770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 5, 'mg', 65771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 5, 'mg', 72325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 2.5, 'mg', 72324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 5, 'mg', 80203);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 2.5, 'mg', 83566);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glyburide', 'A10BB01', 5, 'mg', 83567);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leucovorin (leucovorin calcium)', 'V03AF03', 5, 'mg', 44146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leucovorin (leucovorin calcium)', 'V03AF03', 10, 'mg / ml', 44265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leucovorin (leucovorin calcium)', 'V03AF03', 10, 'mg / ml', 44266);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leucovorin (leucovorin calcium)', 'V03AF03', 10, 'mg / ml', 18209);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromine-phenol-benzethonium chloride complex', 'V07AV', 0.852, '% / w/w', 16228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromine-phenol-benzethonium chloride complex', 'V07AV', 0.852, '% / w/w', 5740);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromine-phenol-benzethonium chloride complex', 'V07AV', 0.852, '% / w/w', 83578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meperidine (meperidine hydrochloride)', 'N02AB02', 75, 'mg / ml', 8120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meperidine (meperidine hydrochloride)', 'N02AB02', 50, 'mg / ml', 8121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meperidine (meperidine hydrochloride)', 'N02AB02', 100, 'mg / ml', 8487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefepime (cefepime hydrochloride)', 'J01DE01', 2, 'g / vial', 20003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefepime (cefepime hydrochloride)', 'J01DE01', 1, 'g / vial', 20004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefepime (cefepime hydrochloride)', 'J01DE01', 2, 'g / vial', 80452);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imiglucerase', 'A16AB02', 200, 'unit / 20 ml', 49955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imiglucerase', 'A16AB02', 400, 'unit / 20 ml', 65414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 10, 'mg', 77377);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 20, 'mg', 77378);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 10, 'mg', 49973);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 20, 'mg', 49974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 40, 'mg', 49975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 80, 'mg', 66964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium propylene glycol solvate)', 'C10AA05', 10, 'mg', 78058);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium propylene glycol solvate)', 'C10AA05', 20, 'mg', 78059);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium propylene glycol solvate)', 'C10AA05', 40, 'mg', 78060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium propylene glycol solvate)', 'C10AA05', 80, 'mg', 78061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 40, 'mg', 77379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 80, 'mg', 77380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 10, 'mg', 79895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 20, 'mg', 79897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 40, 'mg', 79898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 80, 'mg', 79899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 10, 'mg', 79921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 20, 'mg', 79922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 40, 'mg', 79923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 80, 'mg', 79925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 10, 'mg', 79651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 20, 'mg', 79652);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 40, 'mg', 79653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 80, 'mg', 79654);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 10, 'mg', 78797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 20, 'mg', 78798);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 40, 'mg', 78799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 80, 'mg', 78801);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 10, 'mg', 81036);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 20, 'mg', 81037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 40, 'mg', 81038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 80, 'mg', 81039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium propylene glycol solvate)', 'C10AA05', 10, 'mg', 83185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium propylene glycol solvate)', 'C10AA05', 20, 'mg', 83192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium propylene glycol solvate)', 'C10AA05', 40, 'mg', 83193);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium propylene glycol solvate)', 'C10AA05', 80, 'mg', 83194);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 10, 'mg', 83397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 20, 'mg', 83398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 40, 'mg', 83399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 80, 'mg', 83400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 10, 'mg', 83405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 20, 'mg', 83406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 40, 'mg', 83407);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 80, 'mg', 83408);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 10, 'mg', 83551);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 20, 'mg', 83553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 40, 'mg', 83554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 80, 'mg', 83555);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 10, 'mg', 84083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 20, 'mg', 84084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 40, 'mg', 84085);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 1, 'mg', 50069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 2, 'mg', 50070);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 5, 'mg', 50071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 10, 'mg', 50072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 1, 'mg', 55839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 2, 'mg', 55840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 5, 'mg', 55841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 10, 'mg', 55842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 1, 'mg', 52538);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 2, 'mg', 52543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 5, 'mg', 52544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 10, 'mg', 52545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 1, 'mg', 60810);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 2, 'mg', 60811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 5, 'mg', 60812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 10, 'mg', 60813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 1, 'mg', 67437);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 2, 'mg', 67438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 5, 'mg', 67439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 10, 'mg', 67440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 1, 'mg', 67679);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 2, 'mg', 67680);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 5, 'mg', 67681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 10, 'mg', 67682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 1, 'mg', 70727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 2, 'mg', 70728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 5, 'mg', 70729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 10, 'mg', 70730);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 1, 'mg', 83568);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 2, 'mg', 83569);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 5, 'mg', 83570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 10, 'mg', 83571);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('saquinavir (saquinavir mesylate)', 'J05AE01', 200, 'mg', 19918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('saquinavir (saquinavir mesylate)', 'J05AE01', 500, 'mg', 76489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('apraclonidine (apraclonidine hydrochloride)', 'S01EA03', 0.5, '%', 18228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('apraclonidine (apraclonidine hydrochloride)', 'S01EA03', 1, '%', 12993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tazarotene', 'D05AX05', 0.05, '%', 50053);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tazarotene', 'D05AX05', 0.1, '%', 50054);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tazarotene', 'D05AX05', 0.05, '%', 67835);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tazarotene', 'D05AX05', 0.1, '%', 67836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('formoterol fumarate', 'R03AC13', 12, 'µg', 50160);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('granisetron (granisetron hydrochloride)', 'A04AA02', 1, 'mg', 19688);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('granisetron (granisetron hydrochloride)', 'A04AA02', 1, 'mg', 79450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('granisetron (granisetron hydrochloride)', 'A04AA02', 1, 'mg / ml', 19689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('granisetron (granisetron hydrochloride)', 'A04AA02', 1, 'mg / ml', 78998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('granisetron (granisetron hydrochloride)', 'A04AA02', 1, 'mg / ml', 80824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenelzine (phenelzine sulfate)', 'N06AF03', 15, 'mg', 4309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mefloquine (mefloquine hydrochloride)', 'P01BC02', 250, 'mg', 13721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 50, 'mg', 77198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mefloquine (mefloquine hydrochloride)', 'P01BC02', 250, 'mg', 68334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 37.5, 'mg', 60600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 75, 'mg', 60601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 150, 'mg', 60603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 37.5, 'mg', 76413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 75, 'mg', 76414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 150, 'mg', 76415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 37.5, 'mg', 75942);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 75, 'mg', 75943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 150, 'mg', 75944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 37.5, 'mg', 76054);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 75, 'mg', 76055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 150, 'mg', 76056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 37.5, 'mg', 78960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 75.0, 'mg', 78961);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 150.0, 'mg', 78962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 37.5, 'mg', 82485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 75, 'mg', 82486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 150, 'mg', 82487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 37.5, 'mg', 79596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 75.0, 'mg', 79597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 150.0, 'mg', 79598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 37.5, 'mg', 79345);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 75, 'mg', 79346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 150, 'mg', 79347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 37.5, 'mg', 79592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 75, 'mg', 79593);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 150, 'mg', 79594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 37.5, 'mg', 83988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 75, 'mg', 83989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 150, 'mg', 83990);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 10, 'mg', 43575);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 30, 'mg', 14006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 20, 'mg', 14007);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 10, 'mg', 64498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 20, 'mg', 64499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 30, 'mg', 64500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 10, 'mg', 72104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 20, 'mg', 72105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 30, 'mg', 72106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 10, 'mg', 72042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 20, 'mg', 72043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 30, 'mg', 72044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride acetone solvate)', 'N06AB05', 10, 'mg', 72911);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride acetone solvate)', 'N06AB05', 20, 'mg', 72912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride acetone solvate)', 'N06AB05', 30, 'mg', 72913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride acetone solvate)', 'N06AB05', 10, 'mg', 72914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride, isopropyl solvate)', 'N06AB05', 20, 'mg', 72915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride, isopropyl solvate)', 'N06AB05', 30, 'mg', 72916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride acetone solvate)', 'N06AB05', 10, 'mg', 72798);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride acetone solvate)', 'N06AB05', 20, 'mg', 72799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride acetone solvate)', 'N06AB05', 30, 'mg', 72800);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride acetone solvate)', 'N06AB05', 10, 'mg', 72801);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride acetone solvate)', 'N06AB05', 20, 'mg', 72802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride acetone solvate)', 'N06AB05', 30, 'mg', 72803);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 12.5, 'mg', 72855);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 25, 'mg', 72856);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride, isopropyl solvate)', 'N06AB05', 20, 'mg', 73992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride, isopropyl solvate)', 'N06AB05', 30, 'mg', 73993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 10, 'mg', 75480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 20, 'mg', 75481);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 30, 'mg', 75482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride, isopropyl solvate)', 'N06AB05', 10, 'mg', 72328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride, isopropyl solvate)', 'N06AB05', 20, 'mg', 72329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride, isopropyl solvate)', 'N06AB05', 30, 'mg', 72330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 10, 'mg', 73287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 20, 'mg', 73288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 30, 'mg', 73289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 10, 'mg', 74810);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 20, 'mg', 74811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 30, 'mg', 74812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride, isopropyl solvate)', 'N06AB05', 10, 'mg', 76846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride, isopropyl solvate)', 'N06AB05', 20, 'mg', 76847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride, isopropyl solvate)', 'N06AB05', 30, 'mg', 76848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 40, 'mg', 77913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 100, 'mg', 77199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride acetone solvate)', 'N06AB05', 10, 'mg', 78734);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride acetone solvate)', 'N06AB05', 20, 'mg', 78735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paroxetine (paroxetine hydrochloride acetone solvate)', 'N06AB05', 30, 'mg', 78736);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mitoxantrone (mitoxantrone hydrochloride)', 'L01DB07', 2, 'mg / ml', 68601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mitoxantrone (mitoxantrone hydrochloride)', 'L01DB07', 2, 'mg / ml', 75294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mitoxantrone (mitoxantrone hydrochloride)', 'L01DB07', 2, 'mg / ml', 77176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5, 'mg', 12938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10, 'mg', 12939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5, 'mg', 76581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10, 'mg', 76582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5, 'mg', 74489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10, 'mg', 74490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5.0, 'mg', 75765);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10.0, 'mg', 75766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5, 'mg', 73529);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10, 'mg', 73530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5.0, 'mg', 76997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10.0, 'mg', 76998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 2.5, 'mg', 78282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5, 'mg', 78283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10, 'mg', 78284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 2.5, 'mg', 78046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5.0, 'mg', 76963);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10.0, 'mg', 76964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 2.5, 'mg', 81210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5.0, 'mg', 81211);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10.0, 'mg', 81212);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 2.5, 'mg', 81213);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5.0, 'mg', 81214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10.0, 'mg', 81215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 2.5, 'mg', 81216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5.0, 'mg', 81217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10.0, 'mg', 81218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5.0, 'mg', 82829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10.0, 'mg', 82830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5, 'mg', 82664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10, 'mg', 82666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10, 'mg', 80727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5, 'mg', 80726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 2.5, 'mg', 81620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5, 'mg', 81699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10, 'mg', 81700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 2.5, 'mg', 82866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5, 'mg', 82867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10, 'mg', 82868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5, 'mg', 81681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10, 'mg', 81682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 2.5, 'mg', 81717);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5, 'mg', 81718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10, 'mg', 81719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 2.5, 'mg', 84231);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5, 'mg', 84232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10, 'mg', 84233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 2.5, 'mg', 84280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5, 'mg', 84281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10, 'mg', 84282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5, 'mg', 84766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10, 'mg', 84767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flupentixol (flupentixol dihydrochloride)', 'N05AF01', 0.5, 'mg', 18739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flupentixol (flupentixol dihydrochloride)', 'N05AF01', 3, 'mg', 18740);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vinorelbine (vinorelbine tartrate)', 'L01CA04', 10, 'mg / ml', 16101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vinorelbine (vinorelbine tartrate)', 'L01CA04', 10, 'mg / ml', 75143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vinorelbine (vinorelbine tartrate)', 'L01CA04', 10, 'mg / ml', 74301);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vinorelbine (vinorelbine tartrate)', 'L01CA04', 10, 'mg / ml', 75669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('procarbazine (procarbazine hydrochloride)', 'L01XB01', 50, 'mg', 938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indinavir (indinavir sulfate)', 'J05AE02', 200, 'mg', 43518);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indinavir (indinavir sulfate)', 'J05AE02', 400, 'mg', 43520);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salmeterol (salmeterol xinafoate)', 'R03AC12', 50, 'µg / dose', 36988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salmeterol (salmeterol xinafoate)', 'R03AC12', 50, 'µg / dose', 50436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 1, 'g / vial', 8074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 1, 'g / vial', 73509);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 2, 'g / vial', 73510);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 1, 'g / vial', 77304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 10, 'g / vial', 77306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 0.25, 'g / vial', 77762);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 1.0, 'g / vial', 77763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 2.0, 'g / vial', 77764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 10.0, 'g / vial', 77765);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 1.0, 'g / vial', 77822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 2.0, 'g / vial', 77823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 10.0, 'g / vial', 77825);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 10, 'g / vial', 77817);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 1, 'g / vial', 81098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 2, 'g / vial', 81099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 10, 'g / vial', 81100);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 250, 'mg / vial', 8037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 250, 'mg / vial', 73507);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 250, 'mg / vial', 77821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 250, 'mg / vial', 81096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('remifentanil (remifentanil hydrochloride)', 'N01AH06', 1, 'mg / vial', 49266);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('remifentanil (remifentanil hydrochloride)', 'N01AH06', 2, 'mg / vial', 49270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('remifentanil (remifentanil hydrochloride)', 'N01AH06', 5, 'mg / vial', 49272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 50, 'mg', 43076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 100, 'mg', 43077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 100, 'mg', 62836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 25, 'mg', 74163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 50, 'mg', 74164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 100, 'mg', 74165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 50, 'mg', 75377);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 100, 'mg', 75378);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 25, 'mg', 75430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 50, 'mg', 75431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 100, 'mg', 75432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 25, 'mg', 74311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 50, 'mg', 74312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 100, 'mg', 74313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 25, 'mg', 75608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 50, 'mg', 75609);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 100, 'mg', 75610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 25, 'mg', 75611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 50, 'mg', 75612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 100, 'mg', 75613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 50, 'mg', 75655);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 100, 'mg', 75656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 50, 'mg', 74843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 100, 'mg', 74844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 25, 'mg', 77197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 25, 'mg', 77227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 50, 'mg', 77228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 100, 'mg', 77229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 50, 'mg', 81009);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 100, 'mg', 81010);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan hemisulfate)', 'N02CC01', 5, 'mg / dose', 49288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan hemisulfate)', 'N02CC01', 20, 'mg / dose', 49290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 12, 'mg / ml', 43078);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 6, 'mg / 0.5 ml', 84675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flunarizine (flunarizine hydrochloride)', 'N07CA03', 5, 'mg', 48929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flunarizine (flunarizine hydrochloride)', 'N07CA03', 5, 'mg', 70217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenobarbital', 'N03AA02', 15, 'mg', 405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenobarbital', 'N03AA02', 30, 'mg', 406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenobarbital', 'N03AA02', 60, 'mg', 407);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenobarbital', 'N03AA02', 100, 'mg', 408);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenobarbital', 'N03AA02', 5, 'mg / ml', 6095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextroamphetamine sulfate', 'N06BA02', 5, 'mg', 15225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextroamphetamine sulfate', 'N06BA02', 15, 'mg', 15210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextroamphetamine sulfate', 'N06BA02', 10, 'mg', 15211);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('primidone', 'N03AA03', 250, 'mg', 2750);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('primidone', 'N03AA03', 125, 'mg', 2751);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propofol', 'N01AX10', 1, '%', 14476);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propofol', 'N01AX10', 10, 'mg / ml', 60178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propofol', 'N01AX10', 10, 'mg / ml', 66813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propofol', 'N01AX10', 10, 'mg / ml', 65144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propofol', 'N01AX10', 10, 'mg / ml', 68347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfamethoxazole', 'J01EC01', 500, 'mg', 2888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfisoxazole', 'J01EB05', 500, 'mg', 2591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 20, 'mg', 30780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 10, 'mg', 30781);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 10, 'mg', 10398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 20, 'mg', 10399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 20, 'mg', 6067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 10, 'mg', 800);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 20, 'mg', 801);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 10, 'mg', 49089);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 20, 'mg', 49090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 5, 'mg', 55866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 5, 'mg', 71609);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 5, 'mg', 71223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 18, 'mg', 72012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 36, 'mg', 72013);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 54, 'mg', 72014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 20, 'mg', 75209);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 15, 'mg', 76279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 20, 'mg', 76280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 10, 'mg', 76281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 30, 'mg', 76282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 40, 'mg', 76283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 50, 'mg', 76284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 60, 'mg', 76285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 80, 'mg', 76286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 5, 'mg', 75941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 10, 'mg', 73416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 20, 'mg', 73417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 27, 'mg', 73505);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 20, 'mg', 80575);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 5, 'mg', 81157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 10, 'mg', 81158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 20, 'mg', 81159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 18, 'mg', 80062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 27, 'mg', 80063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 36, 'mg', 80064);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylphenidate hydrochloride', 'N06BA04', 54, 'mg', 80065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium tetradecyl sulfate', 'C05BB04', 30, 'mg / ml', 8274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium tetradecyl sulfate', 'C05BB04', 10, 'mg / ml', 8275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indigo carmine', 'V04CH02', 0.8, '%', 18417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 10, 'mg', 20173);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 20, 'mg', 20174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 40, 'mg', 20175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 80, 'mg', 20176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 5, 'mg', 10433);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 20, 'mg', 3550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 10, 'mg', 3551);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 10, 'mg', 3996);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 5, 'mg', 51386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 10, 'mg', 63645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 20, 'mg', 63646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 5, 'mg', 74336);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 20, 'mg', 74839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 20, 'mg', 80544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 5, 'mg', 80542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 10, 'mg', 80543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 5, 'mg', 81130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 10, 'mg', 81131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 20, 'mg', 81132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 60, 'mg', 80870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 15, 'mg', 80868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxycodone hydrochloride', 'N02AA05', 30, 'mg', 80869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurazepam hydrochloride', 'N05CD01', 15, 'mg', 6751);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurazepam hydrochloride', 'N05CD01', 15, 'mg', 4239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurazepam hydrochloride', 'N05CD01', 30, 'mg', 4240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurazepam hydrochloride', 'N05CD01', 15, 'mg', 4728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurazepam hydrochloride', 'N05CD01', 30, 'mg', 4729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurazepam hydrochloride', 'N05CD01', 15, 'mg', 4697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurazepam hydrochloride', 'N05CD01', 15, 'mg', 5108);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurazepam hydrochloride', 'N05CD01', 30, 'mg', 5109);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurazepam hydrochloride', 'N05CD01', 15, 'mg', 4545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurazepam hydrochloride', 'N05CD01', 30, 'mg', 4546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurazepam hydrochloride', 'N05CD01', 30, 'mg', 1466);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurazepam hydrochloride', 'N05CD01', 15, 'mg', 72453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurazepam hydrochloride', 'N05CD01', 30, 'mg', 72454);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium polystyrene sulfonate', 'V03AE01', 100, '%', 17752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium polystyrene sulfonate', 'V03AE01', 100, '%', 8468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium polystyrene sulfonate', 'V03AE01', 250, 'mg / ml', 9611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium polystyrene sulfonate', 'V03AE01', 250, 'mg / ml', 9612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium polystyrene sulfonate', 'V03AE01', 94.3, 'mg / g', 8918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium polystyrene sulfonate', 'V03AE01', 94.3, 'mg / g', 74705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nonyl phenoxypoly ethoxy ethanol-iodine complex', 'V07AV', 8.74, '%', 16108);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethoxy polypropoxy polyethoxy ethanol - iodine complex', 'V07AV', 25, '%', 34205);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethoxy polypropoxy polyethoxy ethanol - iodine complex', 'V07AV', 9.1, '%', 16108);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethoxy polypropoxy polyethoxy ethanol - iodine complex', 'V07AV', 25, '%', 75118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyethylcellulose', 'S01FA01', 0.35, '%', 12215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('non pollen', 'V01AA20', 0, 'nil / nil', 4212);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('non pollen', 'V01AA20', 500, 'unit / ml', 37486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('non pollen', 'V01AA20', 100000, 'unit / ml', 1913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mepivacaine hydrochloride', 'N01BB03', 1, '%', 65669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mepivacaine hydrochloride', 'N01BB03', 1, '%', 65670);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mepivacaine hydrochloride', 'N01BB03', 30, 'mg / ml', 10038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mepivacaine hydrochloride', 'N01BB03', 30, 'mg / ml', 3804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mepivacaine hydrochloride', 'N01BB03', 30, 'mg / ml', 2743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mepivacaine hydrochloride', 'N01BB03', 20, 'mg / ml', 65671);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mepivacaine hydrochloride', 'N01BB03', 30, 'mg / ml', 75732);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mepivacaine hydrochloride', 'N01BB03', 30, 'mg / ml', 81649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phospholipid', 'R07AA30', 27, 'mg / ml', 69524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thymol', 'V07AV', 0.18, '%', 81942);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thymol (thyme oil)', 'V07AV', 0.23, '%', 66200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thymol', 'D04AB01', 0.36, '%', 74263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thymol (thyme oil)', 'V07AV', 0.092, '%', 78664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thymol (thyme oil)', 'V07AV', 0.23, '%', 78914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thymol (thyme oil)', 'V07AV', 0.23, '%', 82551);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thymol', 'V07AV', 18.02, '%', 79099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thymol (thyme oil)', 'V07AV', 0.05, '%', 84154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thymol', 'V07AV', 0.18, '%', 84667);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thymol', 'V07AV', 0.18, '%', 85436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thymol (thyme oil)', 'V07AV', 0.05, '% / w/w', 84146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thymol (thyme oil)', 'V07AV', 0.05, '% / w/w', 84148);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thymol', 'V07AV', 18.02, '% / w/v', 81943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thymol', 'V07AV', 18.02, '% / w/v', 84544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thymol (thyme oil)', 'V07AV', 0.23, '% / v/v', 82559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 100, 'mg', 8594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 100, 'mg', 3311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 50, 'mg', 4280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 25, 'mg', 4281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 50, 'mg', 1829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 25, 'mg', 1723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 25, 'mg', 2170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 50, 'mg', 812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 25, 'mg', 778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 25, 'mg', 71412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 50, 'mg', 71413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 25, 'mg', 71631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 50, 'mg', 71632);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 25, 'mg', 72463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 50, 'mg', 72464);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 12.5, 'mg', 75953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 25, 'mg', 73546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 50, 'mg', 73547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 12.5, 'mg', 81335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 25, 'mg', 84556);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochlorothiazide', 'C03AA03', 50, 'mg', 84557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cholestyramine resin', 'C10AC01', 4, 'g / dose', 18069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cholestyramine resin', 'C10AC01', 4, 'g / dose', 18070);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cholestyramine resin', 'C10AC01', 4, 'g / 9 g', 19757);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cholestyramine resin', 'C10AC01', 4, 'g / 5 g', 14332);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'N06AX02', 1, 'g', 7264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'N06AX02', 1, 'g', 48900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'N06AX02', 1, 'g', 60571);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'N06AX02', 1, 'g', 60252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'N06AX02', 1, 'g', 72893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'N06AX02', 500, 'mg', 15485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'N06AX02', 500, 'mg', 7263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'N06AX02', 500, 'mg', 63994);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'N06AX02', 500, 'mg', 64617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'N06AX02', 250, 'mg', 62795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'N06AX02', 750, 'mg', 62796);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'N06AX02', 500, 'mg', 63872);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'N06AX02', 500, 'mg', 63873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'N06AX02', 500, 'mg', 72892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'N06AX02', 500, 'mg', 72895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'N06AX02', 500, 'mg', 74780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'N06AX02', 500, 'mg', 74781);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tryptophan', 'B05ZA', 27, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('arginine', 'B05ZA', 107.1, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', 'R01BA03', 2.5, 'mg', 75727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', 'R01BA03', 10, 'mg', 73502);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', 'C05AX03', 0.25, '%', 36788);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', 'S01FB01', 2.5, '%', 3319);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', 'C05AX03', 0.25, '%', 49424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', 'C01CA06', 1, '%', 65650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', 'R01BA03', 0.125, '%', 75545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', 'S01FB01', 2.5, '% / w/v', 18860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', 'S01FB01', 10, '% / w/v', 18759);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', 'S01FB01', 2.5, '%', 16477);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', 'S01FB01', 2.5, '%', 6361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', 'S01GA05', 0.12, '%', 2716);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine hydrochloride', 'C01CA06', 10, 'mg / 1 ml', 61817);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', 'R06AB04', 12, 'mg', 41734);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', 'R06AB04', 4, 'mg', 41738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', 'R06AB04', 4, 'mg', 579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', 'R06AB04', 4, 'mg', 75101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', 'R06AB04', 4, 'mg', 76278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpheniramine maleate', 'R06AB04', 12, 'mg', 76278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlordiazepoxide hydrochloride', 'N05BA02', 5, 'mg', 4277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlordiazepoxide hydrochloride', 'N05BA02', 10, 'mg', 4278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlordiazepoxide hydrochloride', 'N05BA02', 25, 'mg', 4279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxymetazoline hydrochloride', 'R01AA05', 0.05, '%', 41903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxymetazoline hydrochloride', 'S01GA04', 0.025, '%', 42643);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxymetazoline hydrochloride', 'R01AA05', 0.05, '%', 33430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxymetazoline hydrochloride', 'R01AA05', 0.05, '%', 67620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxymetazoline hydrochloride', 'R01AA05', 0.05, '%', 70148);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxymetazoline hydrochloride', 'R01AA05', 0.05, '%', 69670);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxymetazoline hydrochloride', 'R01AA05', 0.05, '%', 69673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxymetazoline hydrochloride', 'R01AA05', 0.05, '%', 69676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxymetazoline hydrochloride', 'R01AA05', 0.05, '%', 73581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxymetazoline hydrochloride', 'R01AA05', 0.05, '%', 84725);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxymetazoline hydrochloride', 'R01AA05', 0.05, '% / w/v', 41970);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxymetazoline hydrochloride', 'R01AA05', 0.05, '% / w/v', 41954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxymetazoline hydrochloride', 'R01AA05', 0.05, '%', 42497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxymetazoline hydrochloride', 'S01GA04', 0.25, 'mg / ml', 67618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrofurantoin', 'J01XE01', 100, 'mg', 15173);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrofurantoin', 'J01XE01', 100, 'mg', 2093);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrofurantoin', 'J01XE01', 50, 'mg', 2094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrofurantoin', 'J01XE01', 50, 'mg', 50295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrofurantoin', 'J01XE01', 100, 'mg', 50297);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenytoin sodium', 'N03AB02', 100, 'mg', 1299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenytoin sodium', 'N03AB02', 30, 'mg', 1036);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenytoin sodium', 'N03AB02', 100, 'mg', 1037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenytoin sodium', 'N03AB02', 50, 'mg / ml', 13063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenytoin sodium', 'N03AB02', 50, 'mg / ml', 12697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenytoin sodium', 'N03AB02', 50, 'mg / ml', 9398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propylene glycol', 'R01AX10', 20, '%', 37257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propylene glycol', 'R01AX10', 5, '%', 8563);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propylene glycol', 'R01AX10', 20, '%', 4885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propylene glycol', 'R01AX10', 20, '%', 4886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propylene glycol', 'S01XA20', 0.3, '%', 73342);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propylene glycol', 'S01XA20', 1, '% / w/v', 80709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propylene glycol', 'D02AC', 4, '%', 2536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propylene glycol', 'R01AX30', 50, 'mg / ml', 11232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propylene glycol', 'S01XA20', 10, 'mg / ml', 66081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propylene glycol', 'R01AX30', 200, 'mg / g', 10299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylalanine', 'B05ZA', 57, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lithium carbonate', 'N05AN01', 300, 'mg', 19933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lithium carbonate', 'N05AN01', 600, 'mg', 19893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lithium carbonate', 'N05AN01', 150, 'mg', 19894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lithium carbonate', 'N05AN01', 150, 'mg', 13626);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lithium carbonate', 'N05AN01', 600, 'mg', 13429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lithium carbonate', 'N05AN01', 300, 'mg', 3192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lithium carbonate', 'N05AN01', 150, 'mg', 3414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lithium carbonate', 'N05AN01', 300, 'mg', 1327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lithium carbonate', 'N05AN01', 150, 'mg', 60306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lithium carbonate', 'N05AN01', 300, 'mg', 60307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lithium carbonate', 'N05AN01', 600, 'mg', 60308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lithium carbonate', 'N05AN01', 150, 'mg', 66667);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lithium carbonate', 'N05AN01', 300, 'mg', 66668);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lithium carbonate', 'N05AN01', 300, 'mg', 75210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lithium carbonate', 'N05AN01', 150, 'mg', 78979);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lithium carbonate', 'N05AN01', 300, 'mg', 78980);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 5, 'mg', 37582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 5, 'mg', 37161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 5, 'mg', 19925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 5, 'mg', 11680);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 10, 'mg', 12877);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 5, 'mg', 7456);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 5, 'mg', 4900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 10, 'mg', 4262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 10, 'mg', 1627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 5, 'mg', 1553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 5, 'mg', 1554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 10, 'mg', 1555);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 5, 'mg', 47962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 5, 'mg', 61546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 10, 'mg', 64686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 5, 'mg', 67779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 5, 'mg', 70170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 10, 'mg', 76622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 5, 'mg', 75889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 5, 'mg', 84063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 10, 'mg / sup', 9011);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisacodyl', 'A06AB02', 10, 'mg / sup', 47963);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethacrynic acid', 'C03CC01', 25, 'mg', 74372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethacrynic acid (sodium ethacrynate)', 'C03CC01', 50, 'mg / vial', 615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoproterenol hydrochloride', 'C01CA02', 0.2, 'mg / ml', 11642);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('silver sulfadiazine', 'D06BA01', 1, '%', 14024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('silver sulfadiazine', 'D06BA01', 1, '%', 2146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metolazone', 'C03BA08', 2.5, 'mg', 13126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfasalazine', 'A07EC01', 500, 'mg', 17416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfasalazine', 'A07EC01', 500, 'mg', 17417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfasalazine', 'A07EC01', 500, 'mg', 5864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfasalazine', 'A07EC01', 500, 'mg', 5728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfasalazine', 'A07EC01', 500, 'mg', 2908);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfacetamide sodium', 'S01AB04', 10, '%', 16623);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfacetamide sodium', 'S01AB04', 10, '%', 11868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfacetamide sodium', 'S01AB04', 10, '%', 6055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfacetamide sodium', 'S01AB04', 300, 'mg / ml', 11424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfacetamide sodium', 'S01AB04', 100, 'mg / ml', 371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dapsone', 'J04BA02', 100, 'mg', 16584);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrimeprazine (methotrimeprazine maleate)', 'N05AA02', 5, 'mg', 23257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrimeprazine (methotrimeprazine maleate)', 'N05AA02', 25, 'mg', 19668);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrimeprazine (methotrimeprazine maleate)', 'N05AA02', 5, 'mg', 52422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrimeprazine (methotrimeprazine maleate)', 'N05AA02', 25, 'mg', 52423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrimeprazine (methotrimeprazine maleate)', 'N05AA02', 50, 'mg', 52424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrimeprazine (methotrimeprazine maleate)', 'N05AA02', 2, 'mg', 61820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrimeprazine (methotrimeprazine maleate)', 'N05AA02', 5, 'mg', 61821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrimeprazine (methotrimeprazine maleate)', 'N05AA02', 25, 'mg', 61822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrimeprazine (methotrimeprazine maleate)', 'N05AA02', 50, 'mg', 61823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrimeprazine (methotrimeprazine hydrochloride)', 'N05AA02', 25, 'mg / ml', 13163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('procyclidine hydrochloride', 'N04AA04', 5, 'mg', 6392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('procyclidine hydrochloride', 'N04AA04', 2.5, 'mg', 6394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('procyclidine hydrochloride', 'N04AA04', 2.5, 'mg / 5 ml', 5725);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thalidomide', 'L04AX02', 50, 'mg', 84045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thalidomide', 'L04AX02', 100, 'mg', 84046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thalidomide', 'L04AX02', 200, 'mg', 84048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetrahydrozoline hydrochloride', 'S01GA02', 0.05, '%', 42015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetrahydrozoline hydrochloride', 'S01GA02', 0.5, 'mg / ml', 11133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetrahydrozoline hydrochloride', 'S01GA02', 0.5, 'mg / ml', 75893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('streptokinase', 'B01AD01', 250000, 'unit / vial', 17279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('streptokinase', 'B01AD01', 750000, 'unit / vial', 16299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('streptokinase', 'B01AD01', 1500000, 'unit / vial', 16422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroprocaine hydrochloride', 'N01BA04', 20, 'mg / ml', 5813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phentolamine mesylate', 'C04AB01', 10, 'mg / ml', 66819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phentolamine mesylate', 'C04AB01', 5, 'mg / ml', 67670);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dequalinium chloride', 'R02AA02', 0.25, 'mg', 28979);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dequalinium chloride', 'R02AA02', 0.5, '%', 19449);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allergenic extracts', 'V01AA20', 0, 'unit / ml', 66519);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epoxy resin', 'V04CL', 0.041, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-phenylenediamine', 'V04CL', 0.073, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfated oils', 'D10AX30', 6.3, '%', 1494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethylene glycol p-isooctylphenyl ether', 'V07AV', 3.5, '%', 2932);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium metasilicate', 'V07AV', 2.4, '%', 2196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium metasilicate', 'V07AV', 2.4, '%', 84220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium metasilicate', 'V07AV', 2.4, '%', 84223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clemastine (clemastine hydrogen fumarate)', 'R06AA04', 1, 'mg', 50687);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', 'J01CA12', 2, 'g / vial', 70832);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', 'J01CA12', 3, 'g / vial', 70833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', 'J01CA12', 4, 'g / vial', 70834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', 'J01CA12', 2, 'g / vial', 73314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', 'J01CA12', 3, 'g / vial', 73315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperacillin (piperacillin sodium)', 'J01CA12', 4, 'g / vial', 73316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buserelin (buserelin acetate)', 'L02AE01', 6.3, 'mg / imp', 43499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buserelin (buserelin acetate)', 'L02AE01', 9.45, 'mg / imp', 64338);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buserelin (buserelin acetate)', 'L02AE01', 1, 'mg / ml', 43416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buserelin (buserelin acetate)', 'L02AE01', 1, 'mg / ml', 43417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrantel (pyrantel pamoate)', 'P02CC01', 125, 'mg', 12926);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrantel (pyrantel pamoate)', 'P02CC01', 35, 'mg', 10128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrantel (pyrantel pamoate)', 'P02CC01', 125, 'mg', 62729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrantel (pyrantel pamoate)', 'P02CC01', 50, 'mg / ml', 18664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrantel (pyrantel pamoate)', 'P02CC01', 50, 'mg / ml', 12925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrantel (pyrantel pamoate)', 'P02CC01', 125, 'mg / g', 19275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefoxitin (cefoxitin sodium)', 'J01DC01', 1, 'g / vial', 19200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefoxitin (cefoxitin sodium)', 'J01DC01', 2, 'g / vial', 19201);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefoxitin (cefoxitin sodium)', 'J01DC01', 10, 'g / vial', 64362);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefoxitin (cefoxitin sodium)', 'J01DC01', 1, 'g / vial', 77707);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefoxitin (cefoxitin sodium)', 'J01DC01', 2, 'g / vial', 77708);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zuclopenthixol (zuclopenthixol hydrochloride)', 'N05AF05', 10, 'mg', 49241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zuclopenthixol (zuclopenthixol hydrochloride)', 'N05AF05', 25, 'mg', 49242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketotifen (ketotifen fumarate)', 'R06AX17', 1, 'mg', 10832);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketotifen (ketotifen fumarate)', 'R06AX17', 1, 'mg', 51056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketotifen (ketotifen fumarate)', 'R06AX17', 1, 'mg', 49992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketotifen (ketotifen fumarate)', 'R06AX17', 1, 'mg / 5 ml', 19550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketotifen (ketotifen fumarate)', 'R06AX17', 1, 'mg / 5 ml', 10860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketotifen (ketotifen fumarate)', 'R06AX17', 1, 'mg / 5 ml', 51055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketotifen (ketotifen fumarate)', 'S01GX08', 0.25, 'mg / ml', 66035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketotifen (ketotifen fumarate)', 'S01GX08', 0.25, 'mg / ml', 76476);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefazolin (cefazolin sodium)', 'J01DB04', 10, 'g / vial', 19534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefazolin (cefazolin sodium)', 'J01DB04', 1, 'g / vial', 19532);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefazolin (cefazolin sodium)', 'J01DB04', 1.0, 'g / vial', 60453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefazolin (cefazolin sodium)', 'J01DB04', 10, 'g / vial', 60455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefazolin (cefazolin sodium)', 'J01DB04', 20, 'g / vial', 60456);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefazolin (cefazolin sodium)', 'J01DB04', 1, 'g / vial', 78258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefazolin (cefazolin sodium)', 'J01DB04', 10, 'g / vial', 78259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefazolin (cefazolin sodium)', 'J01DB04', 1, 'g / vial', 79456);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefazolin (cefazolin sodium)', 'J01DB04', 10, 'g / vial', 79457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefazolin (cefazolin sodium)', 'J01DB04', 500, 'mg / vial', 19521);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefazolin (cefazolin sodium)', 'J01DB04', 500, 'mg / vial', 60452);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefazolin (cefazolin sodium)', 'J01DB04', 500, 'mg / vial', 79454);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine (desipramine hydrochloride)', 'N06AA01', 100, 'mg', 20021);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine (desipramine hydrochloride)', 'N06AA01', 75, 'mg', 20022);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine (desipramine hydrochloride)', 'N06AA01', 50, 'mg', 20023);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine (desipramine hydrochloride)', 'N06AA01', 10, 'mg', 20014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine (desipramine hydrochloride)', 'N06AA01', 25, 'mg', 20015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 100, 'mg', 34671);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 50, 'mg', 34672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 100, 'mg', 19204);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 50, 'mg', 19207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 100, 'mg', 16949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 50, 'mg', 16950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 100, 'mg', 15925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 50, 'mg', 15927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 50, 'mg', 13943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 100, 'mg', 13948);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 50, 'mg', 49998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 100, 'mg', 49999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 50, 'mg', 60635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 100, 'mg', 60636);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 100, 'mg', 63489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 50, 'mg', 62699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 100, 'mg', 62700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 50, 'mg', 63141);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 100, 'mg', 63142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 50, 'mg', 65754);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 100, 'mg', 65755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 50, 'mg', 77264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 100, 'mg', 77265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 50, 'mg', 77976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 100, 'mg', 77977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azathioprine', 'L04AX01', 50, 'mg', 66740);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 50, 'mg', 77949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 100, 'mg', 77950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minocycline (minocycline hydrochloride)', 'A01AB23', 1, 'mg / 4 mg', 76380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketamine (ketamine hydrochloride)', 'N01AX03', 10, 'mg / ml', 1214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketamine (ketamine hydrochloride)', 'N01AX03', 50, 'mg / ml', 1215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketamine (ketamine hydrochloride)', 'N01AX03', 10, 'mg / ml', 70995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketamine (ketamine hydrochloride)', 'N01AX03', 50, 'mg / ml', 70996);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal vaccine polyvalent', 'J07AL02', 25, 'µg / 0.5 ml', 50566);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betaxolol (betaxolol hydrochloride)', 'S01ED02', 0.5, '%', 59722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betaxolol (betaxolol hydrochloride)', 'S01ED02', 0.25, '%', 15625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 10, 'mg', 43367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 25, 'mg', 43368);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 10, 'mg', 43346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 25, 'mg', 43347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 10, 'mg', 44225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 25, 'mg', 44226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 10, 'mg', 49159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 25, 'mg', 49161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 10, 'mg', 47991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 25, 'mg', 47992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 10, 'mg', 15);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 25, 'mg', 16);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 10, 'mg', 51213);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 25, 'mg', 51214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 10, 'mg', 60699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 25, 'mg', 60700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinapril (quinapril hydrochloride)', 'C09AA06', 5, 'mg', 12331);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinapril (quinapril hydrochloride)', 'C09AA06', 10, 'mg', 12332);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinapril (quinapril hydrochloride)', 'C09AA06', 20, 'mg', 12333);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinapril (quinapril hydrochloride)', 'C09AA06', 40, 'mg', 12334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 100, 'mg', 42996);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perphenazine', 'N05AB03', 4, 'mg', 8215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 200, 'mg', 42997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 400, 'mg', 42998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 100, 'mg', 19939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 200, 'mg', 19940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 400, 'mg', 19941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 100, 'mg', 18843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 400, 'mg', 18844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 200, 'mg', 18845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 100, 'mg', 17826);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 200, 'mg', 17827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 400, 'mg', 17828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 100, 'mg', 12421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 200, 'mg', 12422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 400, 'mg', 12423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 100, 'mg', 61246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 200, 'mg', 61247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 400, 'mg', 61248);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 200, 'mg', 61076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 100, 'mg', 61075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 400, 'mg', 61077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 100, 'mg', 74284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 200, 'mg', 74285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 400, 'mg', 74286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 100, 'mg', 77170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 200, 'mg', 77171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 400, 'mg', 77172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.5, '%', 43718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.25, '%', 43719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.25, '%', 19252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.5, '%', 19242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.25, '%', 18777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.5, '%', 18778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.25, '%', 15253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.5, '%', 15254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.5, '%', 13095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.25, '%', 13177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.25, '%', 8958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.5, '%', 8959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.5, '%', 3186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.25, '%', 62206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.5, '%', 62207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.25, '%', 65975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.50, '%', 65976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.5, '%', 77623);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamoxifen (tamoxifen citrate)', 'L02BA01', 20, 'mg', 18639);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamoxifen (tamoxifen citrate)', 'L02BA01', 10, 'mg', 16663);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamoxifen (tamoxifen citrate)', 'L02BA01', 20, 'mg', 16664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamoxifen (tamoxifen citrate)', 'L02BA01', 10, 'mg', 10790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamoxifen (tamoxifen citrate)', 'L02BA01', 20, 'mg', 10791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamoxifen (tamoxifen citrate)', 'L02BA01', 20, 'mg', 10762);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamoxifen (tamoxifen citrate)', 'L02BA01', 10, 'mg', 10664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamoxifen (tamoxifen citrate)', 'L02BA01', 10, 'mg', 60793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamoxifen (tamoxifen citrate)', 'L02BA01', 20, 'mg', 60794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamoxifen (tamoxifen citrate)', 'L02BA01', 10, 'mg', 60935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tamoxifen (tamoxifen citrate)', 'L02BA01', 20, 'mg', 60936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('goserelin (goserelin acetate)', 'L02AE03', 3.6, 'mg', 16216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('goserelin (goserelin acetate)', 'L02AE03', 10.8, 'mg', 43433);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b2 (riboflavin 5''-phosphate sodium)', 'A11HA04', 50, 'mg / ml', 3498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alfentanil (alfentanil hydrochloride)', 'N01AH02', 500, 'µg / ml', 72517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropivacaine hydrochloride', 'N01BB09', 5, 'mg / ml', 47220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropivacaine hydrochloride', 'N01BB09', 10, 'mg / ml', 47225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropivacaine hydrochloride', 'N01BB09', 2, 'mg / ml', 47216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropivacaine hydrochloride', 'N01BB09', 10, 'mg / ml', 83320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ropivacaine hydrochloride', 'N01BB09', 5, 'mg / ml', 83319);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cisatracurium (cisatracurium besylate)', 'M03AC11', 2, 'mg / ml', 47231);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 40, 'mg', 47339);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 40, 'mg', 80417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 20, 'mg', 65469);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole magnesium)', 'A02BC02', 40, 'mg', 75263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium sesquihydrate)', 'A02BC02', 40, 'mg', 78496);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium sesquihydrate)', 'A02BC02', 20, 'mg', 77096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium sesquihydrate)', 'A02BC02', 40, 'mg', 77097);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 20, 'mg', 77826);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 40, 'mg', 77827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium sesquihydrate)', 'A02BC02', 20, 'mg', 79432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium sesquihydrate)', 'A02BC02', 40, 'mg', 79433);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium sesquihydrate)', 'A02BC02', 40, 'mg', 78576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 40, 'mg', 79586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 20, 'mg', 79354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 40, 'mg', 79355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 40, 'mg', 80197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium sesquihydrate)', 'A02BC02', 20, 'mg', 78642);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium sesquihydrate)', 'A02BC02', 40, 'mg', 78643);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 20, 'mg', 79040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 40, 'mg', 79041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 40, 'mg', 79555);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 20, 'mg', 79554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 40, 'mg / vial', 63087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium sesquihydrate)', 'A02BC02', 40, 'mg / vial', 77703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 40, 'mg / vial', 79242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 40, 'mg / vial', 83745);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 43092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 43093);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 19910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perphenazine', 'N05AB03', 16, 'mg', 8216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 19914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 11177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 11417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 10390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 10208);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 8482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 8483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 9890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 9891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 7426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 7427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 75, 'mg', 49044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 75, 'mg', 49561);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 75, 'mg', 61188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 75, 'mg', 62006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 67115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 67116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 65255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 65256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 66172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 66173);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 66900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 66901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 72108);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 72109);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 75, 'mg', 71801);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 69895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 69896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 72925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 72926);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 76295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 75, 'mg', 78405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 78429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 77158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 77159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 77884);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 78868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 78870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 82205);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 82207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 83824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 83825);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150, 'mg', 85222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300, 'mg', 85223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 25, 'mg / ml', 43094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 15, 'mg / ml', 43095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 15, 'mg / ml', 66779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 15, 'mg / ml', 76651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 25, 'mg / ml', 74194);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('raltitrexed (raltitrexed disodium)', 'L01BA03', 2, 'mg / vial', 47482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 125, 'mg', 15559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 250, 'mg', 14506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin)', 'J01CA04', 500, 'mg', 11853);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin)', 'J01CA04', 250, 'mg', 11854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin', 'J01CA04', 250, 'mg', 11949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin', 'J01CA04', 500, 'mg', 11950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin)', 'J01CA04', 500, 'mg', 6510);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin', 'J01CA04', 250, 'mg', 5822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin', 'J01CA04', 500, 'mg', 5823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 250, 'mg', 3264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 500, 'mg', 3263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 250, 'mg', 48975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 500, 'mg', 48976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 500, 'mg', 61563);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 250, 'mg', 61562);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 250, 'mg', 74824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 500, 'mg', 74827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 250, 'mg', 83797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 500, 'mg', 83798);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 250, 'mg', 83799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride)', 'A04AA01', 8, 'mg', 79178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 50, 'mg / ml', 16954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 25, 'mg / ml', 16955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin)', 'J01CA04', 250, 'mg / 5 ml', 11855);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin)', 'J01CA04', 125, 'mg / 5 ml', 11856);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin)', 'J01CA04', 125, 'mg / 5 ml', 11951);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin)', 'J01CA04', 250, 'mg / 5 ml', 11952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin)', 'J01CA04', 250, 'mg / 5 ml', 6511);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin', 'J01CA04', 125, 'mg / 5 ml', 5824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin', 'J01CA04', 250, 'mg / 5 ml', 5825);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 250, 'mg / 5 ml', 3344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 125, 'mg / 5 ml', 3345);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 125, 'mg / 5 ml', 48977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 250, 'mg / 5 ml', 48978);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin)', 'J01CA04', 125, 'mg / 5 ml', 50155);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin)', 'J01CA04', 250, 'mg / 5 ml', 50157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 125, 'mg / 5 ml', 74828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 250, 'mg / 5 ml', 74829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 125, 'mg / 5 ml', 83800);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 250, 'mg / 5 ml', 83801);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 125, 'mg / 5 ml', 83802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 250, 'mg / 5 ml', 83803);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylcysteine', 'R05CB01', 200, 'mg / ml', 28513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylcysteine', 'R05CB01', 200, 'mg / ml', 20133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylcysteine', 'R05CB01', 200, 'mg / ml', 66965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylcysteine', 'R05CB01', 200, 'mg / ml', 78573);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 4, 'mg', 43116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 8, 'mg', 43117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron', 'A04AA01', 4, 'mg', 62841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron', 'A04AA01', 8, 'mg', 62842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 4, 'mg', 76400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 8, 'mg', 76401);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 4, 'mg', 76411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 8, 'mg', 76412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 4, 'mg', 76418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 8, 'mg', 76419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 4, 'mg', 74341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 8, 'mg', 74342);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 4, 'mg', 75976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 8, 'mg', 75977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 4, 'mg', 74947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 8, 'mg', 74948);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 4, 'mg', 78168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 8, 'mg', 78169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 4, 'mg', 77362);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 8, 'mg', 77363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 4, 'mg', 78319);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 8, 'mg', 78320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride)', 'A04AA01', 4, 'mg', 79776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride)', 'A04AA01', 8, 'mg', 79777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 8, 'mg', 81057);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 4, 'mg', 82995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 8, 'mg', 82996);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride)', 'A04AA01', 4, 'mg', 79919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride)', 'A04AA01', 8, 'mg', 79920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride)', 'A04AA01', 4, 'mg', 79079);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride)', 'A04AA01', 8, 'mg', 79080);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride)', 'A04AA01', 4, 'mg', 79177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 4, 'mg', 83152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 8, 'mg', 83158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 2, 'mg / ml', 43137);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 4, 'mg / 5 ml', 47565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 2, 'mg / ml', 75098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 2, 'mg / ml', 75099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 2, 'mg / ml', 76501);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 2, 'mg / ml', 76502);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 2, 'mg / ml', 75730);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 2, 'mg / ml', 75731);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 2, 'mg / ml', 75987);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 2, 'mg / ml', 75988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 2.00, 'mg / ml', 78432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 4, 'mg / 5 ml', 77733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 2.00, 'mg / ml', 80811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prazosin (prazosin hydrochloride)', 'C02CA01', 1, 'mg', 10828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prazosin (prazosin hydrochloride)', 'C02CA01', 2, 'mg', 10829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prazosin (prazosin hydrochloride)', 'C02CA01', 5, 'mg', 10830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prazosin (prazosin hydrochloride)', 'C02CA01', 2, 'mg', 5359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prazosin (prazosin hydrochloride)', 'C02CA01', 5, 'mg', 5357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prazosin (prazosin hydrochloride)', 'C02CA01', 1, 'mg', 5358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valacyclovir (valacyclovir hydrochloride)', 'J05AB11', 1, 'g', 70742);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valacyclovir (valacyclovir hydrochloride)', 'J05AB11', 500, 'mg', 20218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valacyclovir (valacyclovir hydrochloride)', 'J05AB11', 500, 'mg', 78376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valacyclovir (valacyclovir hydrochloride)', 'J05AB11', 500, 'mg', 78118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valacyclovir (valacyclovir hydrochloride)', 'J05AB11', 500, 'mg', 79359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valacyclovir (valacyclovir hydrochloride)', 'J05AB11', 500, 'mg', 79360);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valacyclovir (valacyclovir hydrochloride)', 'J05AB11', 500, 'mg', 80195);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valacyclovir (valacyclovir hydrochloride)', 'J05AB11', 500, 'mg', 81743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valacyclovir (valacyclovir hydrochloride)', 'J05AB11', 500, 'mg', 80073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valacyclovir (valacyclovir hydrochloride)', 'J05AB11', 500, 'mg', 83683);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valacyclovir (valacyclovir hydrochloride)', 'J05AB11', 1000, 'mg', 83684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin lispro', 'A10AB04', 100, 'unit / ml', 47871);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin lispro', 'A10AB04', 100, 'unit / ml', 47872);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trifluoperazine (trifluoperazine hydrochloride)', 'N05AB06', 5, 'mg', 9420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trifluoperazine (trifluoperazine hydrochloride)', 'N05AB06', 2, 'mg', 9421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trifluoperazine (trifluoperazine hydrochloride)', 'N05AB06', 10, 'mg', 9350);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trifluoperazine (trifluoperazine hydrochloride)', 'N05AB06', 20, 'mg', 5732);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trifluoperazine (trifluoperazine hydrochloride)', 'N05AB06', 1, 'mg', 2308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trifluoperazine (trifluoperazine hydrochloride)', 'N05AB06', 10, 'mg', 2300);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trifluoperazine (trifluoperazine hydrochloride)', 'N05AB06', 5, 'mg', 2209);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trifluoperazine (trifluoperazine hydrochloride)', 'N05AB06', 2, 'mg', 2210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trifluoperazine (trifluoperazine hydrochloride)', 'N05AB06', 1, 'mg / ml', 9416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trifluoperazine (trifluoperazine hydrochloride)', 'N05AB06', 10, 'mg / ml', 8564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trifluoperazine hydrochloride', 'N05AB06', 2.36, 'mg', 1303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 75387);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trifluoperazine hydrochloride', 'N05AB06', 5.9, 'mg', 1304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trifluoperazine hydrochloride', 'N05AB06', 11.8, 'mg', 1305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thioproperazine (thioproperazine mesylate)', 'N05AB08', 10, 'mg', 12437);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perphenazine', 'N05AB03', 8, 'mg', 8219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perphenazine', 'N05AB03', 2, 'mg', 8214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perphenazine', 'N05AB03', 16, 'mg', 2365);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perphenazine', 'N05AB03', 8, 'mg', 2366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perphenazine', 'N05AB03', 4, 'mg', 2367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perphenazine', 'N05AB03', 2, 'mg', 2368);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perphenazine', 'N05AB03', 3.2, 'mg / ml', 8565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluphenazine decanoate', 'N05AB02', 25, 'mg / ml', 16523);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluphenazine decanoate', 'N05AB02', 100, 'mg / ml', 10488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluphenazine decanoate', 'N05AB02', 25, 'mg / ml', 63107);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluphenazine decanoate', 'N05AB02', 100, 'mg / ml', 65598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluphenazine decanoate', 'N05AB02', 100, 'mg / ml', 66341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluphenazine decanoate', 'N05AB02', 25, 'mg / ml', 68128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('promethazine hydrochloride', 'R06AD02', 25, 'mg', 5368);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('promethazine hydrochloride', 'R06AD02', 50, 'mg', 5369);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('promethazine hydrochloride', 'R06AD02', 10, 'mg / 5 ml', 5721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('promethazine (promethazine hydrochloride)', 'R06AD02', 25, 'mg / ml', 17003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('promethazine (promethazine hydrochloride)', 'R06AD02', 25, 'mg / ml', 5089);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimeprazine (trimeprazine tartrate)', 'R06AD01', 2.5, 'mg', 12419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimeprazine (trimeprazine tartrate)', 'R06AD01', 5, 'mg', 12651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabies immune globulin human', 'J06BB05', 150, 'unit / ml', 49960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabies immune globulin human', 'J06BB05', 150, 'unit / ml', 60651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetanus immune globulin (human)', 'J06BB02', 250, 'unit / dose', 49957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pimozide', 'N05AG02', 4, 'mg', 2059);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pimozide', 'N05AG02', 2, 'mg', 2058);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pimozide', 'N05AG02', 2, 'mg', 63316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pimozide', 'N05AG02', 4, 'mg', 63317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pimozide', 'N05AG02', 2, 'mg', 69484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pimozide', 'N05AG02', 4, 'mg', 69485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bretylium tosylate', 'C01BD02', 50, 'mg / ml', 19356);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indocyanine green', 'V04CX', 25, 'mg / vial', 18418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benztropine mesylate', 'N04AC01', 0.5, 'mg', 10713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benztropine mesylate', 'N04AC01', 1, 'mg', 8060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benztropine mesylate', 'N04AC01', 2, 'mg', 5724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benztropine mesylate', 'N04AC01', 2, 'mg', 3003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benztropine mesylate', 'N04AC01', 0.4, 'mg / ml', 37223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benztropine mesylate', 'N04AC01', 1, 'mg / ml', 62344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvacrol', 'V07AV', 2.37, '%', 79099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvacrol', 'V07AV', 0.02, '%', 81942);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvacrol', 'V07AV', 0.02, '%', 84667);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvacrol', 'V07AV', 0.02, '%', 85436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvacrol', 'V07AV', 2.37, '% / w/v', 81943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvacrol', 'V07AV', 2.37, '% / w/v', 84544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrazinamide', 'J04AK01', 500, 'mg', 6130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrazinamide', 'J04AK01', 500, 'mg', 1828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tranylcypromine (tranylcypromine sulfate)', 'N06AF04', 10, 'mg', 15231);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vincristine sulfate', 'L01CA02', 1, 'mg / ml', 44267);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vincristine sulfate', 'L01CA02', 1, 'mg / ml', 19756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrexate', 'L01BA01', 2.5, 'mg', 44263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 2.5, 'mg', 44161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrexate', 'L01BA01', 10, 'mg', 42842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 2.5, 'mg', 68788);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 25, 'mg / ml', 44264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 10, 'mg / ml', 44261);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 25, 'mg / ml', 44262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 25, 'mg / ml', 42844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 25, 'mg / ml', 19681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 7.5, 'mg / 0.75 ml', 80549);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 10, 'mg / ml', 80550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 15, 'mg / 1.5 ml', 80551);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 25, 'mg / 2.5 ml', 80552);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 20, 'mg / 2 ml', 79004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methazolamide', 'S01EC05', 50, 'mg', 69999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.1, '%', 41683);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.1, '%', 41684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.1, '%', 36767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.1, '%', 15478);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.1, '%', 11904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.1, '%', 11887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.1, '%', 51892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.05, '%', 62307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.1, '%', 65399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.1, '%', 70147);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.1, '%', 70149);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.1, '%', 73579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.1, '%', 73580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.1, '%', 78557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.1, '%', 81710);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.1, '% / w/v', 78558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bile salts', 'A09AA02', 65, 'mg', 3189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium ortho-phenylphenate', 'V07AV', 3.1, '%', 2493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium ortho-phenylphenate', 'V07AV', 3.1, '%', 2494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium ortho-phenylphenate', 'V07AV', 3.1, '%', 2495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('capsaicin', 'M02AC', 0.035, '% / w/w', 80107);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pine oil', 'V07AV', 1.87, '%', 3829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pine oil', 'V07AV', 15, '%', 69615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pine oil', 'V07AV', 15, '%', 71718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pine oil', 'V07AV', 2.50, '%', 70553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pine oil', 'V07AV', 8.7, '%', 76448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pine oil', 'V07AV', 8.7, '%', 80032);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('droperidol', 'N01AX01', 2.5, 'mg / ml', 18611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indomethacin', 'M01AB01', 100, 'mg', 13558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indomethacin', 'M01AB01', 50, 'mg', 11166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indomethacin', 'M01AB01', 25, 'mg', 11160);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indomethacin', 'M01AB01', 25, 'mg', 6558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indomethacin', 'M01AB01', 50, 'mg', 6559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indomethacin', 'M01AB01', 25, 'mg', 5918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indomethacin', 'M01AB01', 50, 'mg', 5919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indomethacin', 'M01AB01', 25, 'mg', 4129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indomethacin', 'M01AB01', 50, 'mg', 4130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indomethacin', 'M01AB01', 50, 'mg / sup', 51232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indomethacin', 'M01AB01', 100, 'mg / sup', 51233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indomethacin (sodium indomethacin)', 'C01EB03', 1, 'mg / vial', 6040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 40, 'mg', 19750);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 10, 'mg', 19751);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 80, 'mg', 20305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 60, 'mg', 17780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 80, 'mg', 16123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 120, 'mg', 16124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 160, 'mg', 16579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 120, 'mg', 14933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 80, 'mg', 14934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 40, 'mg', 14935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 20, 'mg', 14936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 10, 'mg', 14937);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 20, 'mg', 7349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 20, 'mg', 6685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 40, 'mg', 3810);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 80, 'mg', 3811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 10, 'mg', 3812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 10, 'mg', 4254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 40, 'mg', 4255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 80, 'mg', 4256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 10, 'mg', 5307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 40, 'mg', 5308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 80, 'mg', 5309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 120, 'mg', 5310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 120, 'mg', 4071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propranolol hydrochloride', 'C07AA05', 1, 'mg / ml', 43431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azathioprine', 'L04AX01', 50, 'mg', 1192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azathioprine', 'L04AX01', 50, 'mg', 50821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azathioprine', 'L04AX01', 50, 'mg', 60109);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azathioprine', 'L04AX01', 50, 'mg', 67279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azathioprine', 'L04AX01', 50, 'mg', 82849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azathioprine (azathioprine sodium)', 'L04AX01', 50, 'mg / vial', 68893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyurea', 'L01XX05', 500, 'mg', 3453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyurea', 'L01XX05', 500, 'mg', 66754);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyurea', 'L01XX05', 500, 'mg', 72247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyurea', 'L01XX05', 500, 'mg', 82857);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 43371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 18835);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 18416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 19231);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 18058);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 17104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 15115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 47421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 47422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 47631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 48078);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 49444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 48453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 62536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 62674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 66363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 66533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 66606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 66616);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 66617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 66769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 66814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 71020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 71021);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 71193);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 71194);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 75444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 75445);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 74296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 74297);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 77033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 77034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 1000, 'mg', 78575);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 80042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 80043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 500, 'mg', 83857);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metformin hydrochloride', 'A10BA02', 850, 'mg', 83858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochloric acid', 'V07AV', 36.5, '%', 18900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochloric acid', 'V07AV', 0.4, '%', 3456);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochloric acid', 'V07AV', 10.00, '%', 76446);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochloric acid', 'V07AV', 23.3, '%', 74298);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochloric acid', 'V07AV', 9.5, '%', 74536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochloric acid', 'V07AV', 10, '%', 75753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochloric acid', 'V07AV', 9.5, '%', 77549);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochloric acid', 'V07AV', 9.5, '%', 79867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochloric acid', 'V07AV', 9.5, '% / w/w', 78665);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrochloric acid', 'V07AV', 9.5, '% / w/v', 76110);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 240, 'mg', 20200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 240, 'mg', 20028);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 180, 'mg', 20017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 120, 'mg', 20018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 240, 'mg', 16754);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 180, 'mg', 16755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 120, 'mg', 16756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 180, 'mg', 15585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 120, 'mg', 11174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 80, 'mg', 11175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 120, 'mg', 11534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 80, 'mg', 10807);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 240, 'mg', 9264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 80, 'mg', 9731);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 120, 'mg', 9732);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 80, 'mg', 10034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 120, 'mg', 9940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 180, 'mg', 51052);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 240, 'mg', 51053);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 240, 'mg', 61148);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 80, 'mg', 61286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 120, 'mg', 61287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 240, 'mg', 61673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 240, 'mg', 63861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 120, 'mg', 71120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 180, 'mg', 71121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 240, 'mg', 71122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 240, 'mg', 72404);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 240, 'mg', 73465);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 120, 'mg', 80963);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 180, 'mg', 80964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 240, 'mg', 78885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 240, 'mg', 79822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 2.5, 'mg / ml', 18614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verapamil hydrochloride', 'C08DA01', 2.5, 'mg / ml', 17234);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiothixene', 'N05AF04', 10, 'mg', 783);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiothixene', 'N05AF04', 5, 'mg', 784);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiothixene', 'N05AF04', 2, 'mg', 785);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 5, 'mg', 43291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 5, 'mg', 43268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 5, 'mg', 18355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 5, 'mg', 18073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 5, 'mg', 49219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 5, 'mg', 50065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 2.5, 'mg', 64119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 5, 'mg', 64120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 5, 'mg', 65784);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 5, 'mg', 64895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 5, 'mg', 67903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 10, 'mg', 67904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 5, 'mg', 69943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 2.5, 'mg', 74619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 10, 'mg', 75905);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 15, 'mg', 75906);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 5, 'mg', 78474);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 5, 'mg', 83545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 1, 'mg / ml', 43358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 1, 'mg / ml', 50373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin chloride', 'G04BD04', 1, 'mg / ml', 74620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethylene oxide', 'V07AV', 10, '%', 37068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethylene oxide', 'V07AV', 10, '%', 27931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethylene oxide', 'V07AV', 8.6, '%', 27932);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethylene oxide', 'V07AV', 100, '%', 27366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethylene oxide', 'V07AV', 100, '%', 19413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethylene oxide', 'V07AV', 100, '%', 62746);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethylene oxide', 'V07AV', 10.4, '%', 65825);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethylene oxide', 'V07AV', 10, '%', 66070);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethylene oxide', 'V07AV', 8.5, '%', 74114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloral hydrate', 'N05CC01', 500, 'mg', 48143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloral hydrate', 'N05CC01', 100, 'mg / ml', 10976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloral hydrate', 'N05CC01', 100, 'mg / ml', 71882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium p-aminobenzoate', 'V03AX', 500, 'mg', 6245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium p-aminobenzoate', 'V03AX', 500, 'mg', 6246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium p-aminobenzoate', 'V03AX', 2, 'g / pck', 7024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mefenamic acid', 'M01AG01', 250, 'mg', 1598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mefenamic acid', 'M01AG01', 250, 'mg', 47492);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mefenamic acid', 'M01AG01', 250, 'mg', 47338);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mefenamic acid', 'M01AG01', 250, 'mg', 50515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mefenamic acid', 'M01AG01', 250, 'mg', 61185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piperazine', 'P02CB01', 100, 'mg / ml', 3228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neostigmine methylsulfate', 'N07AA01', 2.5, 'mg / ml', 11852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neostigmine methylsulfate', 'N07AA01', 1, 'mg / ml', 11131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neostigmine methylsulfate', 'N07AA01', 0.5, 'mg / ml', 11095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neostigmine methylsulfate', 'N07AA01', 0.5, 'mg / ml', 10876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neostigmine methylsulfate', 'N07AA01', 1, 'mg / ml', 10877);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neostigmine methylsulfate', 'N07AA01', 1, 'mg / ml', 49701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('neostigmine methylsulfate', 'N07AA01', 0.5, 'mg / ml', 49702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yellow fever vaccine', 'J07BL01', 109648, 'pfu / 0.5 ml', 2964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('botulinum antitoxin', 'J06AA04', 5000, 'unit / vial', 663);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('typhoid vaccine (salmonella typhi ty21a)', 'J07AP01', 10, 'b', 13630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('typhoid vaccine (salmonella typhi ty21a)', 'J07AP01', 10, 'b / pck', 50867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('varicella zoster immune globulin human', 'J06BB03', 125, 'unit / vial', 67247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium dichloroisocyanurate', 'V07AV', 2.5, 'g', 12398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium dichloroisocyanurate', 'V07AV', 5, 'g', 12399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium dichloroisocyanurate', 'V07AV', 500, 'mg', 12400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium dichloroisocyanurate', 'V07AV', 55, '%', 8505);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium dichloroisocyanurate', 'V07AV', 26.5, '%', 4791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium dichloroisocyanurate', 'V07AV', 25.8, '%', 4191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium dichloroisocyanurate', 'V07AV', 5, '%', 71548);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium dichloroisocyanurate', 'V07AV', 5, '%', 75119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium dichloroisocyanurate', 'V07AV', 7.0, '%', 76528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium dichloroisocyanurate', 'V07AV', 1.2, '%', 75485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized orchard grass pollen', 'V01AA02', 100000, 'unit / ml', 61905);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized orchard grass pollen', 'V01AA02', 10000, 'unit / ml', 61906);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized orchard grass pollen', 'V01AA02', 100000, 'unit / ml', 66463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized orchard grass pollen', 'V01AA02', 100000, 'unit / ml', 81086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized orchard grass pollen', 'V01AA02', 25000, 'unit / ml', 81091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized orchard grass pollen', 'V01AA02', 20000, 'unit / ml', 81092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sweet vernal grass', 'V01AA02', 10000, 'unit / ml', 61914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sweet vernal grass', 'V01AA02', 100000, 'unit / ml', 61913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sweet vernal grass', 'V01AA02', 100000, 'unit / ml', 66457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized june grass pollen', 'V01AA02', 100000, 'unit / ml', 81083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized june grass pollen', 'V01AA02', 25000, 'unit / ml', 81091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized june grass pollen', 'V01AA02', 20000, 'unit / ml', 81092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dyclonine hydrochloride', 'R02AD04', 1.2, 'mg', 47738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dyclonine hydrochloride', 'R02AD04', 3.0, 'mg', 75400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dyclonine hydrochloride', 'R02AD04', 3, 'mg', 76114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dyclonine hydrochloride', 'R02AD04', 0.1, '% / w/w', 62080);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxepin hydrochloride', 'N06AA12', 75, 'mg', 12671);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxepin hydrochloride', 'N06AA12', 100, 'mg', 12672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxepin hydrochloride', 'N06AA12', 150, 'mg', 12673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxepin hydrochloride', 'N06AA12', 25, 'mg', 12669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxepin hydrochloride', 'N06AA12', 50, 'mg', 12670);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxepin hydrochloride', 'D04AX', 5, '%', 17850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mechlorethamine hydrochloride', 'L01AA05', 10, 'mg / vial', 5644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('primaquine phosphate', 'P01BA03', 26.3, 'mg', 18330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyproheptadine hydrochloride', 'R06AX02', 4, 'mg', 40420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyproheptadine hydrochloride', 'R06AX02', 4, 'mg', 69767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyproheptadine hydrochloride', 'R06AX02', 4, 'mg', 81790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyproheptadine hydrochloride', 'R06AX02', 2, 'mg / 5 ml', 69768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycopyrrolate', 'A03AB02', 0.2, 'mg / ml', 14577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valine', 'B05ZA', 139.3, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('liothyronine', 'H03AA02', 25, 'µg', 15908);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('liothyronine', 'H03AA02', 5, 'µg', 15909);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'J01XD01', 500, 'mg', 12221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'J01XD01', 500, 'mg', 9910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'J01XD01', 250, 'mg', 5722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'P01AB01', 250, 'mg', 4902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'J01XD01', 250, 'mg', 3010);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'J01XD01', 250, 'mg', 1033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'J01XD01', 750, 'mg', 68374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'P01AB01', 500, 'mg', 72917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'D06BX01', 1, '%', 19257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'D06BX01', 0.75, '%', 17824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'G01AF01', 0.75, '%', 16852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'G01AF01', 10, '%', 12997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'J01XD01', 0.5, '%', 7425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'D06BX01', 1.0, '%', 66753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'D06BX01', 0.75, '%', 72542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'D06BX01', 1, '%', 78314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'D06BX01', 0.75, '%', 43445);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metronidazole', 'J01XD01', 5, 'mg / ml', 10871);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolnaftate', 'D01AE18', 1, '%', 41971);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolnaftate', 'D01AE18', 1, '%', 41933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolnaftate', 'D01AE18', 1, '%', 33528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolnaftate', 'D01AE18', 1, '%', 27993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolnaftate', 'D01AE18', 1, '%', 15558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolnaftate', 'D01AE18', 1, '%', 59733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolnaftate', 'D01AE18', 1, '%', 66930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolnaftate', 'D01AE18', 1, '%', 78123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolnaftate', 'D01AE18', 1, '%', 80479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolnaftate', 'D01AE18', 1, '% / w/w', 80475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolnaftate', 'D01AE18', 1, '%', 11879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolnaftate', 'D01AE18', 1, '%', 62521);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolnaftate', 'D01AE18', 10, 'mg / ml', 62971);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolnaftate', 'D01AE18', 10, 'mg / g', 41611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolnaftate', 'D01AE18', 10, 'mg / g', 41612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolnaftate', 'D01AE18', 10, 'mg / g', 41608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06', 75, 'mg', 15592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06', 25, 'mg', 14087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06', 12.5, 'mg', 14083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06', 100, 'mg', 14085);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06', 50, 'mg', 14086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06', 50, 'mg', 11767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06', 25, 'mg', 11768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06', 100, 'mg', 11769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06', 100, 'mg', 8106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06', 12.5, 'mg', 8065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06', 25, 'mg', 8066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06', 50, 'mg', 8067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline hydrochloride', 'N06AA10', 10, 'mg', 44232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nortriptyline hydrochloride', 'N06AA10', 25, 'mg', 44233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trihexyphenidyl hydrochloride', 'N04AA01', 5, 'mg', 8218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trihexyphenidyl hydrochloride', 'N04AA01', 2, 'mg', 8217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trihexyphenidyl hydrochloride', 'N04AA01', 2, 'mg', 4901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trihexyphenidyl hydrochloride', 'N04AA01', 5, 'mg', 4903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trihexyphenidyl hydrochloride', 'N04AA01', 0.4, 'mg / ml', 45323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alpha1-proteinase inhibitor (human)', 'B02AB02', 1000, 'mg / vial', 43004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis b immune globulin human', 'J06BB04', 217, 'unit / ml', 50001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis b immune globulin human', 'J06BB04', 312, 'unit / ml', 77637);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rho d immune globulin human', 'J06BB01', 5000, 'unit / vial', 78786);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rho d immune globulin human', 'J06BB01', 600, 'unit / vial', 78787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rho d immune globulin human', 'J06BB01', 1500, 'unit / vial', 78788);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rho d immune globulin human', 'J06BB01', 600, 'unit / kit', 43216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rho d immune globulin human', 'J06BB01', 1500, 'unit / kit', 43217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rho d immune globulin human', 'J06BB01', 5000, 'unit / kit', 49231);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('immune globulin (human)', 'J06BA01', 18, '%', 49688);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('immune globulin (human)', 'J06BA01', 18, '%', 49876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('immune globulin (human)', 'J06BA02', 10, '%', 76503);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('immune globulin (human)', 'J06BA02', 10, '%', 78988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('immune globulin (human)', 'J06BA02', 0.5, 'g / vial', 50792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('immune globulin (human)', 'J06BA02', 2.5, 'g / vial', 50793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('immune globulin (human)', 'J06BA02', 5, 'g / vial', 50794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('immune globulin (human)', 'J06BA02', 10, 'g / vial', 50795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('immune globulin (human)', 'J06BA02', 10, 'g / 100 ml', 72002);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('immune globulin (human)', 'J06BA02', 10, 'g / 100 ml', 76352);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('purified protein derivative of tuberculin', 'V04CF01', 5, 'tub / 0.1 ml', 2087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis b surface antigen (recombinant)', 'J07BC01', 20, 'µg / ml', 11742);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis b surface antigen (recombinant)', 'J07BC01', 10, 'µg / ml', 67606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis b surface antigen (recombinant)', 'J07BC01', 40, 'µg / ml', 70103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis b surface antigen (recombinant)', 'J07BC01', 10, 'µg / 0.5 ml', 78178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dermatophagoides pteronyssinus', 'V01AA07', 10000, 'unit / ml', 43207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dermatophagoides pteronyssinus', 'V01AA03', 10000, 'unit / ml', 37349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dermatophagoides pteronyssinus', 'V01AA03', 30000, 'unit / ml', 37350);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dermatophagoides pteronyssinus', 'V01AA03', 15000, 'unit / ml', 37353);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dermatophagoides pteronyssinus', 'V01AA03', 5000, 'unit / ml', 37354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dermatophagoides pteronyssinus', 'V01AA07', 10000, 'unit / ml', 50631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dermatophagoides pteronyssinus', 'V01AA03', 5000, 'unit / ml', 75630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin isophane human biosynthetic', 'A10AC01', 100, 'unit / ml', 14266);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin isophane human biosynthetic', 'A10AC01', 100, 'unit / ml', 14261);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin isophane human biosynthetic', 'A10AC01', 100, 'unit / ml', 12570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin injection human biosynthetic', 'A10AB01', 100, 'unit / ml', 14459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin injection human biosynthetic', 'A10AB01', 100, 'unit / ml', 14260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin injection human biosynthetic', 'A10AB01', 100, 'unit / ml', 12569);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('edetic acid', 'V07AV', 0.5, '%', 84220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('digoxin immune fab (ovine)', 'V03AB24', 38, 'mg / vial', 18784);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nickel sulfate', 'V04CL', 0.16, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paraldehyde', 'N05CC05', 100, '%', 31279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium nitroprusside', 'C02DD01', 25, 'mg / ml', 84678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorescein sodium', 'S01JA01', 1, 'mg', 34944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorescein sodium', 'S01JA01', 1, 'mg', 16977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorescein sodium', 'S01JA01', 1, 'mg', 6722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorescein sodium', 'S01JA01', 1, 'mg', 80283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorescein sodium', 'S01JA01', 2, '%', 18747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorescein sodium', 'V04CX', 25, '%', 16626);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorescein sodium', 'V04CX', 10, '%', 16627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorescein sodium', 'V04CX', 10, '%', 3781);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorescein sodium', 'S01JA01', 1, 'mg / strip', 19197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorescein sodium', 'V04CX', 100, 'mg / ml', 5951);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorescein sodium', 'V04CX', 250, 'mg / ml', 6359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('albumin', 'B05AA01', 50, 'mg / ml', 9740);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('albumin', 'B05AA01', 250, 'mg / ml', 9700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pregabalin', 'N03AX16', 25, 'mg', 75379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pregabalin', 'N03AX16', 50, 'mg', 75380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pregabalin', 'N03AX16', 75, 'mg', 75381);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pregabalin', 'N03AX16', 150, 'mg', 75383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pregabalin', 'N03AX16', 225, 'mg', 75385);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pregabalin', 'N03AX16', 300, 'mg', 75386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('copper (copper sulfate)', 'A12CX', 0.4, 'mg / ml', 13563);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nonylphenoxypoly(ethyleneoxy)ethanol-iodine complex', 'V07AV', 7.3, '% / w/w', 79866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diluent', 'H01AC01', 3.15, 'ml', 66943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diluent', 'H01AC01', 3.15, 'ml', 66944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diluent', 'H01AC01', 3.15, 'ml', 66945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcipotriol', 'D05AX02', 50, 'µg / ml', 19952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcipotriol', 'D05AX02', 50, 'µg / g', 18519);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcipotriol', 'D05AX02', 50, 'µg / g', 13340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamidronate disodium', 'M05BA03', 90, 'mg / vial', 19018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamidronate disodium', 'M05BA03', 30, 'mg / vial', 19020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamidronate disodium', 'M05BA03', 30, 'mg / vial', 70124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamidronate disodium', 'M05BA03', 90, 'mg / vial', 70125);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamidronate disodium', 'M05BA03', 6, 'mg / ml', 68534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamidronate disodium', 'M05BA03', 3, 'mg / ml', 68533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamidronate disodium', 'M05BA03', 9, 'mg / ml', 68535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamidronate disodium', 'M05BA03', 3, 'mg / ml', 70784);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamidronate disodium', 'M05BA03', 6, 'mg / ml', 70785);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamidronate disodium', 'M05BA03', 9, 'mg / ml', 70786);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamidronate disodium', 'M05BA03', 3.0, 'mg / ml', 73447);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamidronate disodium', 'M05BA03', 6.0, 'mg / ml', 73448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamidronate disodium', 'M05BA03', 9.0, 'mg / ml', 73449);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamidronate disodium', 'M05BA03', 3, 'mg / ml', 75046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamidronate disodium', 'M05BA03', 6, 'mg / ml', 75047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pamidronate disodium', 'M05BA03', 9, 'mg / ml', 75048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('itraconazole', 'J02AC02', 100, 'mg', 14518);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('itraconazole', 'J02AC02', 10, 'mg / ml', 50656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 1, '%', 45065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 4.8, '%', 41477);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'M02AX10', 0.5, '%', 42186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D05AA', 0.5, '%', 42099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'M02AX10', 0.5, '%', 42113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D05AA', 0.5, '%', 42042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D05AA', 0.5, '%', 42043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'M02AX10', 0.5, '%', 41939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 5, '%', 41864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 3, '%', 19577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.5, '%', 19976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.6, '%', 18208);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.5, '%', 13062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.5, '%', 11499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.6, '%', 12639);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.5, '%', 12137);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.5, '%', 9415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.6, '%', 7506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 1, '%', 51009);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.25, '%', 59731);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 2, '%', 62698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.52, '%', 61646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.5, '%', 61647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 1.0, '%', 61042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.3, '%', 67188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.3, '%', 65308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.50, '%', 65999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 1, '%', 66677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.6, '%', 67848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.5, '%', 67374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.6, '%', 68597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.3, '%', 69042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.5, '%', 70951);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.6, '%', 76461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 1.0, '%', 75365);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 1.49, '%', 75366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.5, '%', 76372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 1, '%', 75542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.3, '%', 75901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.5, '%', 73589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.3, '%', 73604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.3, '%', 75040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.3, '%', 77286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 3.0, '%', 77673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D05AA', 0.5, '%', 77120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 0.6, '% / w/w', 79962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D05AA', 0.5, '% / w/v', 77121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroxylenol', 'D08AE05', 8, 'mg / ml', 48988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('substituted phenols', 'V07AV', 6, '%', 70383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbolic oil', 'V07AV', 50, '%', 70383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iothalamate meglumine', 'V08AA04', 430, 'mg / ml', 3930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iothalamate meglumine', 'V08AA04', 300, 'mg / ml', 1201);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iothalamate meglumine', 'V08AA04', 172, 'mg / ml', 2949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iothalamate meglumine', 'V08AA04', 600, 'mg / ml', 899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bivalirudin', 'B01AE06', 250, 'mg / vial', 70715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('edetic acid', 'V07AV', 0.5, '%', 2196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('edetic acid', 'V07AV', 0.20, '%', 60445);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('edetic acid', 'V07AV', 0.20, '%', 60446);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('edetic acid', 'V07AV', 0.5, '%', 84223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nesiritide', 'C01DX19', 1.5, 'mg / vial', 78673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mesalazine', 'A07EC02', 1.2, 'g', 78289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mesalazine', 'A07EC02', 500, 'mg', 15218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mesalazine', 'A07EC02', 400, 'mg', 14552);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mesalazine', 'A07EC02', 1000, 'mg', 65824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mesalazine', 'A07EC02', 800, 'mg', 75261);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mesalazine', 'A07EC02', 400, 'mg', 83673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mesalazine', 'A07EC02', 500, 'mg / srt', 16855);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mesalazine', 'A07EC02', 400, 'mg / ect', 19524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mesalazine', 'A07EC02', 500, 'mg / ect', 18214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mesalazine', 'A07EC02', 1, 'g / sup', 18493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mesalazine', 'A07EC02', 500, 'mg / sup', 18212);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mesalazine', 'A07EC02', 4, 'g / 100 ml', 18494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mesalazine', 'A07EC02', 1, 'g / 100 ml', 18496);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mesalazine', 'A07EC02', 4, 'g / 60 g', 18509);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mesalazine', 'A07EC02', 2, 'g / 60 g', 18510);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nabumetone', 'M01AX01', 500, 'mg', 62067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nabumetone', 'M01AX01', 500, 'mg', 64458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nabumetone', 'M01AX01', 750, 'mg', 64459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nabumetone', 'M01AX01', 500, 'mg', 68548);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nabumetone', 'M01AX01', 500, 'mg', 82875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bezafibrate', 'C10AB02', 400, 'mg', 16968);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bezafibrate', 'C10AB02', 200, 'mg', 63870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril', 'C09AA08', 5, 'mg', 13834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril', 'C09AA08', 2.5, 'mg', 13835);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 1, 'mg', 75177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 2.5, 'mg', 75178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 5.0, 'mg', 75179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 1.0, 'mg', 76610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 2.5, 'mg', 76611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 5.0, 'mg', 76612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 1, 'mg', 77651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 2.5, 'mg', 77652);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 5, 'mg', 77653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 1, 'mg', 76935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 2.5, 'mg', 76936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 5.0, 'mg', 76937);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 2.5, 'mg', 77072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 5.0, 'mg', 77073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 1.0, 'mg', 79497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 2.5, 'mg', 79498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 5.0, 'mg', 79499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 1, 'mg', 83615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 2.5, 'mg', 83616);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 5, 'mg', 83617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ursodiol', 'A05AA02', 250, 'mg', 62432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ursodiol', 'A05AA02', 500, 'mg', 70011);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ursodiol', 'A05AA02', 250, 'mg', 76694);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ursodiol', 'A05AA02', 500, 'mg', 76695);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ursodiol', 'A05AA02', 250, 'mg', 76696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ursodiol', 'A05AA02', 500, 'mg', 76697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ursodiol', 'A05AA02', 250, 'mg', 75898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ursodiol', 'A05AA02', 500, 'mg', 75899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ofloxacin', 'J01MA01', 200, 'mg', 50873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ofloxacin', 'J01MA01', 300, 'mg', 50874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ofloxacin', 'J01MA01', 400, 'mg', 50875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ofloxacin', 'J01MA01', 200, 'mg', 67385);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ofloxacin', 'J01MA01', 300, 'mg', 67386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ofloxacin', 'J01MA01', 400, 'mg', 67387);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ofloxacin', 'S01AX11', 0.3, '%', 73745);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ofloxacin', 'S01AX11', 0.3, '%', 72744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ofloxacin', 'S01AX11', 0.3, '%', 18491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ticlopidine hydrochloride', 'B01AC05', 250, 'mg', 60138);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ticlopidine hydrochloride', 'B01AC05', 250, 'mg', 60898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ticlopidine hydrochloride', 'B01AC05', 250, 'mg', 61047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ticlopidine hydrochloride', 'B01AC05', 250, 'mg', 63226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ticlopidine hydrochloride', 'B01AC05', 250, 'mg', 67230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ticlopidine hydrochloride', 'B01AC05', 250, 'mg', 67505);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ticlopidine hydrochloride', 'B01AC05', 250, 'mg', 67746);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ticlopidine hydrochloride', 'B01AC05', 250, 'mg', 82853);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('podophyllotoxin', 'D06BB04', 0.5, '%', 12196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('podophyllotoxin', 'D06BB04', 5, 'mg / ml', 18274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didanosine', 'J05AF02', 125, 'mg', 68582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didanosine', 'J05AF02', 200, 'mg', 68583);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didanosine', 'J05AF02', 250, 'mg', 68584);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('didanosine', 'J05AF02', 400, 'mg', 68585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acarbose', 'A10BF01', 100, 'mg', 19655);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acarbose', 'A10BF01', 50, 'mg', 19648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('midodrine hydrochloride', 'C01CA17', 2.5, 'mg', 76425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('midodrine hydrochloride', 'C01CA17', 5.0, 'mg', 76426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 3.55, '%', 70589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levocabastine (levocabastine hydrochloride)', 'R01AC02', 0.5, 'mg / ml', 13796);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clodronate disodium (clodronate disodium tetrahydrate)', 'M05BA02', 400, 'mg', 13305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clodronate disodium', 'M05BA02', 400, 'mg', 69944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clodronate disodium (clodronate disodium tetrahydrate)', 'M05BA02', 60, 'mg / ml', 13304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atazanavir (atazanavir sulfate)', 'J05AE08', 150, 'mg', 72966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atazanavir (atazanavir sulfate)', 'J05AE08', 200, 'mg', 72967);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atazanavir (atazanavir sulfate)', 'J05AE08', 300, 'mg', 77952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('entecavir', 'J05AF10', 0.5, 'mg', 76788);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enfuvirtide', 'J05AX07', 108, 'mg / vial', 72003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bortezomib (bortezomib mannitol boronic ester)', 'L01XX32', 3.5, 'mg / vial', 74782);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tiotropium (tiotropium bromide monohydrate)', 'R03BB04', 18, 'µg', 70993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tyrosine', 'B05ZA', 30, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paclitaxel', 'L01CD01', 100, 'mg / vial', 76673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paclitaxel', 'L01CD01', 6, 'mg / ml', 14248);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paclitaxel (taxus canadensis)', 'L01CD01', 6, 'mg / ml', 68340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paclitaxel', 'L01CD01', 6, 'mg / ml', 73215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paclitaxel', 'L01CD01', 6, 'mg / ml', 78198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paclitaxel', 'L01CD01', 6, 'mg / ml', 80546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antithrombin iii (human)', 'B01AB02', 1000, 'unit / vial', 42930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antithrombin iii (human)', 'B01AB02', 1100, 'unit / vial', 61169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antithrombin iii (human)', 'B01AB02', 550, 'unit / vial', 61170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antithrombin iii (human)', 'B01AB02', 1650, 'unit / kit', 61171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 12.4, '%', 36549);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 7.7, '%', 34513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.199, '%', 26739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.1, '%', 25672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 5, '%', 19364);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 10, '%', 19768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 4.6, '%', 17426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.1, '%', 15242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 4, '%', 16133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.1, '%', 15498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.1, '%', 15499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.1, '%', 15500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.176, '%', 13706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 2, '%', 14368);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.176, '%', 13830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.28, '%', 12408);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 9, '%', 12396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.1, '%', 12288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.10, '%', 12254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 9, '%', 12247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 10, '%', 11343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 10, '%', 6212);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.10, '%', 3797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 3, '%', 4201);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.5, '%', 3093);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.28, '%', 50814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.199, '%', 60627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.28, '%', 61475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 3.4, '%', 60158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.1, '%', 61020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.10, '%', 62709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.10, '%', 63709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 12.1, '%', 62881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 3.55, '%', 66340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.28, '%', 69060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.25, '%', 72119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.10, '%', 70836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.176, '%', 70166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 1.47, '%', 70443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.25, '%', 70493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 1.11, '%', 76438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 7.9, '%', 76472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.1, '%', 75267);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.25, '%', 72344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.1, '%', 75587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.14, '%', 75848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.2, '%', 74887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.1, '%', 74949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.10, '%', 72700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.10, '%', 76854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.41, '%', 77124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.10, '%', 76811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.14, '%', 79967);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.1, '%', 80691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.10, '%', 82117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.10, '%', 83945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.28, '% / w/w', 50653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('o-phenylphenol', 'V07AV', 0.28, '% / w/w', 82418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('beractant', 'R07AA30', 25, 'mg / ml', 14318);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gadoteridol', 'V08CA04', 279.3, 'mg / ml', 43507);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 250, 'unit / vial', 67066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 500, 'unit / vial', 67067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 1000, 'unit / vial', 67068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 500, 'unit / vial', 73938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 250, 'unit / vial', 73937);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 1000, 'unit / vial', 73939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 250, 'unit / vial', 76968);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 500, 'unit / vial', 76969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 1000, 'unit / vial', 76970);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 1500, 'unit / vial', 76971);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 2000, 'unit / vial', 79422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 3000, 'unit / vial', 82824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 2000, 'unit / vial', 79865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 2000, 'unit / vial', 78756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 3000, 'unit / vial', 82280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', 'D11AX11', 3, '%', 66772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', 'D11AX11', 3, '%', 72192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', 'D10AF01', 2.0, '%', 66809);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('avobenzone', 'D06BX01', 2.0, '%', 66753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nonyl phenoxypoly ethoxy ethanol-iodine', 'V07AV', 1, '%', 11677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nonyl phenoxypoly ethoxy ethanol-iodine', 'V07AV', 3.5, '%', 3456);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nonyl phenoxypoly ethoxy ethanol-iodine', 'V07AV', 6, '%', 2305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nonyl phenoxypoly ethoxy ethanol-iodine', 'V07AV', 18.05, '%', 2199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nonyl phenoxypoly ethoxy ethanol-iodine', 'V07AV', 18.05, '%', 70180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phosphoric acid', 'V07AV', 30, '%', 18016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phosphoric acid', 'V07AV', 6.5, '%', 2954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phosphoric acid', 'V07AV', 21, '%', 2802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phosphoric acid', 'V07AV', 16, '%', 2199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phosphoric acid', 'V07AV', 17.4, '%', 71086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phosphoric acid', 'V07AV', 20.50, '%', 76049);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzyl di-hydroxyethyl-cocoalkyl-ammonium chl', 'V07AV', 0.05, '%', 13988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethylene glycol 3350', 'A06AD15', 100, '%', 81040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethylene glycol 3350', 'A06AD15', 100, '%', 81606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethylene glycol 3350', 'A06AD15', 100, '%', 83209);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethylene glycol 3350', 'A06AD15', 100, '%', 84310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethylene glycol 3350', 'A06AD15', 100, '% / w/w', 80366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethylene glycol 3350', 'A06AD15', 100, '% / w/w', 81376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethylene glycol 3350', 'A06AD15', 1, 'g / g', 80321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hexylresorcinol', 'R02AA12', 2.4, 'mg', 41796);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hexylresorcinol', 'R02AA12', 2.4, 'mg', 33590);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hexylresorcinol', 'R02AA12', 3.5, 'mg', 11320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hexylresorcinol', 'R02AA12', 3.5, 'mg', 11321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hexylresorcinol', 'R02AA12', 3.5, 'mg', 48138);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hexylresorcinol', 'R02AA12', 2.4, 'mg', 67829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hexylresorcinol', 'R02AA12', 2.4, 'mg', 74940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hexylresorcinol', 'R02AA12', 2.4, 'mg / loz', 19363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin e (dl-alpha tocopheryl acetate)', 'A11HA03', 100, 'unit / ml', 9325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin d (vitamin d3)', 'A11CC05', 10000, 'unit', 12345);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin a', 'A11CA01', 25000, 'unit', 502);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin a', 'A11CA01', 50000, 'unit', 503);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine hydrochloride', 'D01AE15', 1, '%', 14532);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine hydrochloride', 'D01AE15', 10, 'mg / g', 62135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextran 70', 'S01XA20', 0.1, '%', 37084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pentosan polysulfate sodium', 'C05BA04', 100, 'mg', 14161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 80, 'mg', 41821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 125, 'mg', 13362);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 125, 'mg', 11914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 80, 'mg', 1889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 180, 'mg', 61044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 180, 'mg', 62764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 166, 'mg', 65429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 125, 'mg', 69154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 180, 'mg', 69155);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 180, 'mg', 68167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 180, 'mg', 71367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 62.5, 'mg', 75572);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 180, 'mg', 78612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 125, 'mg', 81363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 40, 'mg / ml', 198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3.0, 'mg', 79827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 40, 'mg / ml', 69597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 20, 'mg / 0.3 ml', 75184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simethicone', 'A03AX13', 40, 'mg / ml', 72943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4, 'mg', 13922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2, 'mg', 13903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1, 'mg', 13904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3, 'mg', 13906);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 64121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.5, 'mg', 64122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.5, 'mg', 71971);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1, 'mg', 71973);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2, 'mg', 71974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 76402);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.5, 'mg', 76403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1.0, 'mg', 76404);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2.0, 'mg', 76405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3.0, 'mg', 76406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4.0, 'mg', 76407);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1.0, 'mg', 76539);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2.0, 'mg', 76540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3.0, 'mg', 76541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4.0, 'mg', 76542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 76658);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.5, 'mg', 76659);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1, 'mg', 76660);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3, 'mg', 76663);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2, 'mg', 76662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4, 'mg', 76664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3, 'mg', 75347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4, 'mg', 75348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 76778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1.0, 'mg', 76780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.50, 'mg', 76779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2.0, 'mg', 76781);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3.0, 'mg', 76782);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4.0, 'mg', 76783);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 76790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.50, 'mg', 76791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1.0, 'mg', 76792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2.0, 'mg', 76793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3.0, 'mg', 76794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4.0, 'mg', 76795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 74364);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.5, 'mg', 74365);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1.0, 'mg', 74366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2.0, 'mg', 74367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3.0, 'mg', 74368);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4.0, 'mg', 74369);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.5, 'mg', 74961);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1.0, 'mg', 74963);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2.0, 'mg', 74964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3.0, 'mg', 74965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4.0, 'mg', 74966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 73690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.5, 'mg', 73691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1.0, 'mg', 73692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2.0, 'mg', 73693);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3.0, 'mg', 73694);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4.0, 'mg', 73695);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 75026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.5, 'mg', 75027);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1.0, 'mg', 75028);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2.0, 'mg', 75029);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3.0, 'mg', 75030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4.0, 'mg', 75031);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 76833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 76916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.50, 'mg', 76917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1.0, 'mg', 76918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2.0, 'mg', 76919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3.0, 'mg', 76920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4.0, 'mg', 76921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.5, 'mg', 77713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1, 'mg', 77714);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2, 'mg', 77715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 76822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.5, 'mg', 76823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1.0, 'mg', 76824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2.0, 'mg', 76825);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3.0, 'mg', 76826);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4.0, 'mg', 76827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 78879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.5, 'mg', 78880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1.0, 'mg', 78881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2.0, 'mg', 78882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3.0, 'mg', 78883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4.0, 'mg', 78884);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 79823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.5, 'mg', 79824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1.0, 'mg', 79825);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2.0, 'mg', 79826);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4.0, 'mg', 79828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 81383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.5, 'mg', 81384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1.0, 'mg', 81385);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2.0, 'mg', 81386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3.0, 'mg', 81388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4.0, 'mg', 81389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 78897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.5, 'mg', 78898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 84200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.5, 'mg', 84201);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1.0, 'mg', 84202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2.0, 'mg', 84203);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3.0, 'mg', 84204);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4.0, 'mg', 84205);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 84454);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.50, 'mg', 84455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1.0, 'mg', 84456);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2.0, 'mg', 84457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3.0, 'mg', 84458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4.0, 'mg', 84459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.25, 'mg', 84478);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 0.50, 'mg', 84479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 1.0, 'mg', 84480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 2.0, 'mg', 84481);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 3.0, 'mg', 84482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 4.0, 'mg', 84483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 25, 'mg / vial', 74089);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 37.5, 'mg / vial', 74091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 50, 'mg / vial', 74093);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone', 'N05AX08', 12.5, 'mg / vial', 78377);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone (risperidone tartrate)', 'N05AX08', 1, 'mg / ml', 60243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone (risperidone tartrate)', 'N05AX08', 1, 'mg / ml', 76481);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('risperidone (risperidone tartrate)', 'N05AX08', 1, 'mg / ml', 76606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', 'D11AX11', 2, '%', 75425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', 'D11AX11', 2.0, '%', 74229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', 'D02BA02', 1.0, '% / w/w', 81378);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('titanium dioxide', 'D02BA02', 5.6, '% / w/w', 81033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D05AA', 1.0, '%', 41695);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 2, '%', 10999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D05AA', 1.0, '%', 5557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 2, '%', 4544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 77856);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D05AA', 1.0, '%', 64533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 0.2, '%', 66499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1.8, '%', 65136);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 0.5, '%', 68253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 70224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 0.2, '%', 71767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 69880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 72832);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 74079);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 75401);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1.0, '%', 74361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 0.25, '%', 76023);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 73544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 73545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 73611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 77705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 78334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 78335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 0.1, '%', 78526);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 78814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 0.1, '%', 78815);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 79455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 79582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 79020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1.0, '%', 78889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 83584);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 83582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 0.95, '% / w/w', 64845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '% / w/w', 75355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 2, '% / w/w', 72405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '% / w/w', 78321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1.0, '% / w/w', 80396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '% / w/w', 81015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '% / w/w', 80576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 2, '% / w/w', 80426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1.0, '% / w/w', 80329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 0.5, '% / w/w', 80831);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '% / w/w', 83579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 0.1, '% / w/w', 83585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '% / w/w', 83604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '% / w/w', 83605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '% / w/w', 83606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '% / w/w', 83733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '% / w/w', 83734);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '% / w/w', 83735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '% / w/w', 84283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '% / w/w', 84406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 2, '%', 37795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 14533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1, '%', 62742);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1.008, 'g / 100 g', 63067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 1.0, 'g / 100 g', 69792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione zinc', 'D11AX12', 2.5, 'mg / g', 61824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '%', 47178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'A01AB03', 0.12, '%', 43029);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'S01XA20', 0.003, '%', 42237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'V07AV', 0.75, '%', 36750);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'V07AV', 0.2, '%', 36829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'V07AV', 0.8, '%', 36792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'V07AV', 0.2, '%', 36797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'V07AV', 0.1, '%', 36791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 0.5, '%', 22030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'A01AB03', 0.12, '%', 20216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 0.05, '%', 17006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 4, '%', 13003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 0.05, '%', 14490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '%', 13327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 20, '%', 10767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '%', 10669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 0.05, '%', 10177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 4, '%', 1436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'V07AV', 0.10, '%', 60445);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'V07AV', 0.20, '%', 60446);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'A01AB03', 0.12, '%', 60786);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '%', 62430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'A01AB03', 0.12, '%', 63982);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'A01AB03', 0.12, '%', 64096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'V07AV', 0.12, '%', 63862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'A01AB03', 0.12, '%', 66040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'V07AV', 0.2, '%', 67988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '%', 69089);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 4, '%', 70226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AE02', 2, '%', 70264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '%', 71841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '%', 71177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '%', 69848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '%', 76467);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'S01XA20', 0.003, '%', 73892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '%', 75254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '%', 74413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '%', 78057);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 0.05, '%', 78106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '%', 78101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 4, '%', 78102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '%', 77786);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 4, '%', 77815);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'A01AB03', 0.12, '%', 80225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '% / w/w', 62989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '% / w/w', 79892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'V07AV', 0.01, '% / w/w', 50653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'V07AV', 0.01, '% / w/w', 82418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 20, '% / w/v', 16498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 0.05, '%', 27903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 4, '%', 28206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 4, '%', 19810);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '%', 11826);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 4, '%', 12713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 4, '%', 10668);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 20, '%', 9824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '%', 63965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 4, '%', 62715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 2, '%', 66260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 600, 'mg', 63199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 0.5, 'mg / ml', 19506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorhexidine gluconate', 'D08AC02', 40, 'mg / g', 14496);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gefitinib', 'L01XE02', 250, 'mg', 73040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('periciazine', 'N05AC01', 20, 'mg', 14767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('periciazine', 'N05AC01', 10, 'mg', 12425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('periciazine', 'N05AC01', 5, 'mg', 12653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('periciazine', 'N05AC01', 10, 'mg / ml', 13159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin detemir', 'A10AE05', 100, 'unit / ml', 75736);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('laronidase', 'A16AB05', 0.58, 'mg / ml', 73940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 250, 'mg', 71262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 500, 'mg', 71263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 750, 'mg', 71264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 250, 'mg', 75964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 500, 'mg', 75965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 750, 'mg', 75966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 250, 'mg', 78145);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 500, 'mg', 78146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 750, 'mg', 78147);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 250, 'mg', 77141);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 500, 'mg', 77142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 750, 'mg', 77143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 750, 'mg', 78274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 250, 'mg', 78272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 500, 'mg', 78273);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 250, 'mg', 78275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 500, 'mg', 78276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 750, 'mg', 78277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 500, 'mg', 79696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 750, 'mg', 79697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 250, 'mg', 83854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 500, 'mg', 83855);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levetiracetam', 'N03AX14', 750, 'mg', 83856);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 2, '%', 37137);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 2.1, '%', 37109);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 3.4, '%', 34111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 2.4, '%', 34112);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 2, '%', 26018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 0.15, '%', 17211);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 2, '%', 14692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 2, '%', 14177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 0.5, '%', 13891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 2, '%', 11833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 2, '%', 11834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 2.5, '%', 12768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 3.4, '%', 12770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 2.6, '%', 12767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 20, '%', 50234);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 10.725, '%', 63207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 2, '%', 67955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 2, '%', 71031);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 2.5, '%', 70486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 12.5, '%', 76498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 12.5, '%', 76631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 12.75, '%', 75223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 12.5, '%', 72991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 7.0, '%', 74558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 2.65, '%', 77951);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 24, '%', 78037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 7.5, '%', 80388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutaral', 'V07AV', 10, '% / w/v', 47571);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cisplatin', 'L01XA01', 1, 'mg / ml', 43840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rosuvastatin (rosuvastatin calcium)', 'C10AA07', 10, 'mg', 71404);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rosuvastatin (rosuvastatin calcium)', 'C10AA07', 20, 'mg', 71405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rosuvastatin (rosuvastatin calcium)', 'C10AA07', 40, 'mg', 71406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rosuvastatin (rosuvastatin calcium)', 'C10AA07', 5, 'mg', 75100);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ertapenem (ertapenem sodium)', 'J01DH03', 1, 'g / vial', 71683);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetuximab', 'L01XC06', 2, 'mg / ml', 75672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lutropin alfa', 'G03GA07', 75, 'unit / vial', 75446);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluticasone propionate', 'D07AC17', 0.05, '%', 43758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluticasone propionate', 'R03BA05', 50, 'µg / blister', 60564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluticasone propionate', 'R03BA05', 100, 'µg / blister', 60565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluticasone propionate', 'R03BA05', 250, 'µg / blister', 60566);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluticasone propionate', 'R03BA05', 500, 'µg / blister', 60567);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluticasone propionate', 'R01AD08', 50, 'µg / act', 43126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluticasone propionate', 'R01AD08', 50, 'µg / act', 78009);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluticasone propionate', 'R03BA05', 50, 'µg / act', 68258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluticasone propionate', 'R03BA05', 125, 'µg / act', 68259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluticasone propionate', 'R03BA05', 250, 'µg / act', 68260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluticasone propionate', 'R01AD08', 50, 'µg / act', 78143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c (sodium ascorbate)', 'A11GA01', 250, 'mg / ml', 9992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c', 'A11GA01', 500, 'mg / ml', 5851);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c', 'A11GA01', 500, 'mg / ml', 7309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin c (ascorbic acid)', 'A11GA01', 500, 'mg / ml', 69229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protease', 'A09AA02', 25000, 'unit', 36399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protease', 'A09AA02', 37500, 'unit', 36179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protease', 'A09AA02', 11000, 'unit', 35065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protease', 'A09AA02', 65000, 'unit', 27084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protease', 'A09AA02', 39000, 'unit', 27081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protease', 'A09AA02', 62500, 'unit', 13302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protease', 'A09AA02', 55000, 'unit', 9892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protease', 'A09AA02', 30000, 'unit', 3189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protease', 'A09AA02', 30000, 'unit', 3891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protease', 'A09AA02', 30000, 'unit', 1649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protease', 'A09AA02', 30000, 'unit', 48551);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protease', 'A09AA02', 104000, 'unit', 60913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protease', 'A09AA02', 18750, 'unit', 62457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protease', 'A09AA02', 75000, 'unit', 62458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protease', 'A09AA02', 60000, 'unit', 65603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lipase', 'A09AA02', 4500, 'unit', 36399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lipase', 'A09AA02', 10000, 'unit', 36179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lipase', 'A09AA02', 4000, 'unit', 35065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lipase', 'A09AA02', 20000, 'unit', 27084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lipase', 'A09AA02', 12000, 'unit', 27081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lipase', 'A09AA02', 25000, 'unit', 13302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lipase', 'A09AA02', 20000, 'unit', 9892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lipase', 'A09AA02', 8000, 'unit', 3189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lipase', 'A09AA02', 8000, 'unit', 3891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lipase', 'A09AA02', 8000, 'unit', 1649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lipase', 'A09AA02', 8000, 'unit', 48551);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lipase', 'A09AA02', 16640, 'unit', 60913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lipase', 'A09AA02', 5000, 'unit', 62457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lipase', 'A09AA02', 20000, 'unit', 62458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lipase', 'A09AA02', 16000, 'unit', 65603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dornase alfa', 'R05CB13', 1, 'mg / ml', 15483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vigabatrin', 'N03AG04', 500, 'mg', 15532);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vigabatrin', 'N03AG04', 500, 'mg / pck', 43682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 2.4, '%', 37952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 12, '%', 26016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 10.2, '%', 18662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 10.4, '%', 18901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 1.15, '%', 16020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 3.5, '%', 13342);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 12, '%', 9158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 10.8, '%', 8161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2a', 'L03AB11', 180, 'µg / ml', 72400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 12, '%', 2747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 10.8, '%', 47240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 0.5, '%', 62524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 10, '%', 67815);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 10, '%', 67818);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'D08AX07', 0.057, '%', 69617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 10.8, '%', 70367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 10.8, '%', 70368);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 1.84, '%', 70535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 2.4, '%', 70551);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'D08AX07', 0.114, '%', 69903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 10.8, '%', 75117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 1, '%', 72833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 7.20, '%', 76646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 2.0, '%', 75710);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 3, '%', 72574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 3, '%', 72575);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 10.3, '%', 76098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 1.45, '%', 73516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 5.25, '%', 78103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 2.4, '%', 78378);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 3, '%', 76976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 10.8, '%', 77075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 1.4, '%', 79879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 1.84, '%', 80494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 5.5, '%', 82758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 4, '%', 82760);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 0.6, '%', 80481);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 1.84, '%', 80497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 0.5, '%', 81958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 0.025, '%', 80038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 0.1, '%', 80039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 0.7, '%', 80040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 0.75, '%', 80041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 0.55, '%', 83458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 6, '%', 83676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 2.0, '%', 84125);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 2.0, '%', 84126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 0.5, '%', 84545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 0.5, '%', 84546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 0.1, '%', 84547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 0.05, '%', 84548);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 2.0, '% / w/w', 77566);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 6.15, '% / w/w', 81865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 2.73, '% / w/w', 81120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 1.4, '% / w/w', 81309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 800, 'mg', 63200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 0.7, '% / w/w', 81310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 0.75, '% / w/w', 81311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 0.1, '% / w/w', 81312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 0.025, '% / w/w', 81313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 2.4, '% / w/w', 84668);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'V07AV', 6, '% / w/v', 84317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hypochlorite', 'D08AX07', 5, 'g / l', 7083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcitonin (salmon synthetic)', 'H05BA01', 200, 'unit / spray', 71842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcitonin (salmon synthetic)', 'H05BA01', 200, 'unit / spray', 74713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcitonin (salmon synthetic)', 'H05BA01', 200, 'unit / act', 64365);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcitonin (salmon synthetic)', 'H05BA01', 100, 'unit / ml', 13975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcitonin (salmon synthetic)', 'H05BA01', 200, 'unit / ml', 12837);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcitonin (salmon synthetic)', 'H05BA01', 200, 'unit / ml', 70189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allergenic extracts pollens', 'V01AA20', 40000, 'unit / ml', 72046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allergenic extracts pollens', 'V01AA20', 40000, 'unit / ml', 72045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allergenic extracts pollens', 'V01AA20', 40000, 'unit / ml', 72047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allergenic extract non-pollen', 'V01AA20', 40000, 'unit / ml', 72048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allergenic extract non-pollen', 'V01AA20', 40000, 'unit / ml', 72049);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allergenic extract non-pollen', 'V01AA20', 40000, 'unit / ml', 72050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetrorelix (cetrorelix acetate)', 'H01CC02', 0.25, 'mg / vial', 72060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetrorelix (cetrorelix acetate)', 'H01CC02', 3, 'mg / vial', 72061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('adefovir dipivoxil', 'J05AF08', 10, 'mg', 72117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('everolimus', 'L04AA18', 5, 'mg', 82511);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('everolimus', 'L04AA18', 10, 'mg', 82512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone valerate', 'D07AC01', 0.1, '%', 9929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone valerate', 'D07AC01', 0.05, '%', 4521);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone valerate', 'D07AC01', 0.1, '%', 4522);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone valerate', 'D07AC01', 0.1, '%', 9268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone valerate', 'D07AC01', 1.22, 'mg / g', 9269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betamethasone valerate', 'D07AC01', 1, 'mg / g', 8973);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2a', 'L03AB11', 180, 'µg / 0.5 ml', 72399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('almotriptan (almotriptan malate)', 'N02CC05', 6.25, 'mg', 72455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('almotriptan (almotriptan malate)', 'N02CC05', 12.5, 'mg', 72456);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rasburicase', 'V03AF07', 1.5, 'mg / vial', 72766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('febuxostat', 'M04AA03', 80, 'mg', 84250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fulvestrant', 'L02BA03', 50, 'mg / ml', 72981);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leucine', 'B05ZA', 102, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('streptomycin (streptomycin sulfate)', 'J01GA01', 1, 'g / vial', 67590);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nelarabine', 'L01BB07', 5, 'mg / ml', 78527);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buffer solution', 'L01AA03', 10, 'ml / vial', 18786);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 400, 'mg', 16210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 100, 'mg', 15944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 300, 'mg', 15945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 100, 'mg', 67356);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 300, 'mg', 67357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 400, 'mg', 67358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 100, 'mg', 68490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 300, 'mg', 68491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 400, 'mg', 68492);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 100, 'mg', 67676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 300, 'mg', 67677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 400, 'mg', 67678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 100, 'mg', 68271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 300, 'mg', 68273);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 400, 'mg', 68274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 800, 'mg', 71589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 100, 'mg', 70477);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 300, 'mg', 70478);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 400, 'mg', 70479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 600, 'mg', 72809);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 600, 'mg', 74111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 800, 'mg', 74112);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 100, 'mg', 74137);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 300, 'mg', 74138);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 400, 'mg', 74139);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 800, 'mg', 74325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 600, 'mg', 74324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 600, 'mg', 74506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 800, 'mg', 74507);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 100, 'mg', 72596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 300, 'mg', 72597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 400, 'mg', 72598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 100, 'mg', 74631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 300, 'mg', 74632);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 400, 'mg', 74633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 600, 'mg', 74634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 800, 'mg', 74635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 100, 'mg', 73612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 300, 'mg', 73613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 400, 'mg', 73614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 100, 'mg', 77130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 300, 'mg', 77131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 400, 'mg', 77132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 600, 'mg', 77133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 800, 'mg', 77134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 600, 'mg', 77872);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 800, 'mg', 77873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 100, 'mg', 79608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 300, 'mg', 79609);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 400, 'mg', 79610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 600, 'mg', 79611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 800, 'mg', 79612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 100, 'mg', 79005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 300, 'mg', 79006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 400, 'mg', 79007);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 100, 'mg', 80454);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 300, 'mg', 80455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 400, 'mg', 80456);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 100, 'mg', 80660);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 300, 'mg', 80661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 400, 'mg', 80662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 100, 'mg', 83846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 300, 'mg', 83847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gabapentin', 'N03AX12', 400, 'mg', 83848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gadodiamide', 'V08CA03', 287, 'mg / ml', 44188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin', 'J01FA10', 250, 'mg', 43063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin', 'J01FA10', 600, 'mg', 50450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin isopropanolate monohydrate)', 'J01FA10', 250, 'mg', 71669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 250, 'mg', 76396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 250, 'mg', 76408);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 600, 'mg', 76409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 250, 'mg', 76416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 250, 'mg', 75127);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate)', 'J01FA10', 250, 'mg', 74052);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 250, 'mg', 75325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate)', 'J01FA10', 600, 'mg', 74132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 250, 'mg', 74701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 600, 'mg', 74702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 250, 'mg', 76092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate)', 'J01FA10', 250, 'mg', 76094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate)', 'J01FA10', 600, 'mg', 76095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin', 'J01FA10', 250, 'mg', 75998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 250, 'mg', 79623);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate)', 'J01FA10', 250, 'mg', 81664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate)', 'J01FA10', 600, 'mg', 81666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin', 'J01FA10', 500, 'mg / vial', 63455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin hydrogen citrate)', 'J01FA10', 500, 'mg / vial', 78290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin', 'J01FA10', 100, 'mg / 5 ml', 43386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin', 'J01FA10', 200, 'mg / 5 ml', 43387);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 100, 'mg / 5 ml', 75984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 200, 'mg / 5 ml', 75985);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 100, 'mg / 5 ml', 76803);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 200, 'mg / 5 ml', 76805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate)', 'J01FA10', 200, 'mg / 5 ml', 81805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate)', 'J01FA10', 100, 'mg / 5 ml', 81804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 100, 'mg / 5 ml', 80071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 200, 'mg / 5 ml', 80072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azithromycin (azithromycin dihydrate)', 'J01FA10', 2, 'g / bottle', 83998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'A03AX13', 160, 'mg', 7455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'D02AA', 3, '%', 11430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'D02AA', 1, '%', 11936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'D02AA', 5, '%', 60861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'D02AA', 5, '%', 60901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'D02AA', 3, '%', 69988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'D02AA', 1, '%', 74220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'D02AA', 5.0, '%', 77695);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'D02AA', 1.5, '%', 77697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'D02AA', 1.0, '%', 77698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'D02AA', 3.2, '%', 77895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'D02AA', 3.2, '%', 77896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'D02AA', 2, '% / w/w', 67909);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'D02AA', 6, '% / w/w', 73513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'D02AA', 1.5, '% / w/w', 77696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'D02AA', 5.0, '% / w/w', 78703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'D02AA', 1, '% / w/w', 79649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethicone', 'D04AB07', 5, '% / w/w', 80397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('agalsidase beta', 'A16AB04', 5, 'mg / vial', 73340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('agalsidase beta', 'A16AB04', 35, 'mg / vial', 73341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('agalsidase alfa', 'A16AB03', 1, 'mg / ml', 73392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eptacog alfa (activated)', 'B02BD08', 1.2, 'mg / vial', 63131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('memantine hydrochloride', 'N06DX01', 10, 'mg', 83442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eptacog alfa (activated)', 'B02BD08', 2.4, 'mg / vial', 63132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eptacog alfa (activated)', 'B02BD08', 4.8, 'mg / vial', 63133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eptacog alfa (activated)', 'B02BD08', 1, 'mg / vial', 83251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eptacog alfa (activated)', 'B02BD08', 2, 'mg / vial', 83252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eptacog alfa (activated)', 'B02BD08', 5, 'mg / vial', 83253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ambrisentan', 'C02KX02', 5, 'mg', 79274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ambrisentan', 'C02KX02', 10, 'mg', 79275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vardenafil (vardenafil hydrochloride)', 'G04BE09', 5, 'mg', 73526);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vardenafil (vardenafil hydrochloride)', 'G04BE09', 10, 'mg', 73527);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vardenafil (vardenafil hydrochloride)', 'G04BE09', 20, 'mg', 73528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miglustat', 'A16AX06', 100, 'mg', 73533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinagolide (quinagolide hydrochloride)', 'G02CB04', 0.025, 'mg', 43389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinagolide (quinagolide hydrochloride)', 'G02CB04', 0.05, 'mg', 43390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinagolide (quinagolide hydrochloride)', 'G02CB04', 0.075, 'mg', 43391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinagolide (quinagolide hydrochloride)', 'G02CB04', 0.15, 'mg', 43392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hyprolose', 'S01XA20', 5, 'mg', 73543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pemetrexed (pemetrexed disodium)', 'L01BA04', 500, 'mg / vial', 73841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pemetrexed (pemetrexed disodium)', 'L01BA04', 100, 'mg / vial', 79204);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('teriparatide', 'H05AA02', 250, 'µg / ml', 73983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybutynin', 'G04BD04', 36, 'mg', 73990);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium perborate monohydrate', 'V07AV', 29, '%', 74000);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eletriptan (eletriptan hydrobromide)', 'N02CC06', 20, 'mg', 74152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eletriptan (eletriptan hydrobromide)', 'N02CC06', 40, 'mg', 74153);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('voriconazole', 'J02AC03', 50, 'mg', 74170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('voriconazole', 'J02AC03', 200, 'mg', 74171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('voriconazole', 'J02AC03', 200, 'mg / vial', 74172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('voriconazole', 'J02AC03', 3, 'g / bottle', 76561);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('frovatriptan (frovatriptan succinate)', 'N02CC07', 2.5, 'mg', 74230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cinacalcet (cinacalcet hydrochloride)', 'H05BX01', 30, 'mg', 74235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cinacalcet (cinacalcet hydrochloride)', 'H05BX01', 60, 'mg', 74236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cinacalcet (cinacalcet hydrochloride)', 'H05BX01', 90, 'mg', 74237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 40, 'mg', 19642);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 10, 'mg', 19643);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 70, 'mg', 69356);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 10, 'mg', 71618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 5, 'mg', 73095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 10, 'mg', 73096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 70, 'mg', 73098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen (naproxen sodium)', 'M01AE02', 375, 'mg', 66249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium trihydrate)', 'M05BA04', 40, 'mg', 74334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium trihydrate)', 'M05BA04', 70, 'mg', 74335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium trihydrate)', 'M05BA04', 10, 'mg', 75552);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium trihydrate)', 'M05BA04', 70, 'mg', 75626);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 5, 'mg', 72588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 70, 'mg', 75867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 70, 'mg', 74709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 70, 'mg', 76091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium trihydrate)', 'M05BA04', 70, 'mg', 77179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 70, 'mg', 76840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 70, 'mg', 76841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 5, 'mg', 77346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 10, 'mg', 77347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 70, 'mg', 77349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 70, 'mg', 76957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 70, 'mg', 78733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 70, 'mg', 78840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 70, 'mg', 78508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium trihydrate)', 'M05BA04', 70, 'mg', 83819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alendronic acid (alendronate sodium trihydrate)', 'M05BA04', 70, 'mg / 75 ml', 72982);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('adalimumab', 'L04AB04', 40, 'mg / 0.8 ml', 74379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('omalizumab', 'R03DX05', 150, 'mg / vial', 74602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('memantine hydrochloride', 'N06DX01', 10, 'mg', 74607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('memantine hydrochloride', 'N06DX01', 10, 'mg', 80955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('memantine hydrochloride', 'N06DX01', 10, 'mg', 80632);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('memantine hydrochloride', 'N06DX01', 10, 'mg', 80653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('memantine hydrochloride', 'N06DX01', 10, 'mg', 83026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('memantine hydrochloride', 'N06DX01', 10, 'mg', 83428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('memantine hydrochloride', 'N06DX01', 10, 'mg', 85130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cytomegalovirus immune globulin (human)', 'J06BB09', 50, 'mg / ml', 51418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02', 250, 'mg', 13990);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02', 250, 'mg', 63385);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02', 250, 'mg', 64398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02', 250, 'mg', 63887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02', 250, 'mg', 66543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02', 250, 'mg', 66246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02', 250, 'mg', 73989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02', 250, 'mg', 73216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02', 250, 'mg', 74755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02', 250, 'mg', 74833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02', 250, 'mg', 78466);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02', 250, 'mg', 78330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02', 250, 'mg', 77963);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02', 250, 'mg', 80558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02', 250, 'mg', 83835);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02', 250, 'mg', 84217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvastatin (fluvastatin sodium)', 'C10AA04', 20, 'mg', 15820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvastatin (fluvastatin sodium)', 'C10AA04', 40, 'mg', 15821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvastatin (fluvastatin sodium)', 'C10AA04', 80, 'mg', 73534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fludarabine phosphate', 'L01BB05', 10, 'mg', 70384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fludarabine phosphate', 'L01BB05', 50, 'mg / vial', 77921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fludarabine phosphate', 'L01BB05', 25, 'mg / ml', 76943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fludarabine phosphate', 'L01BB05', 25, 'mg / ml', 83698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('midazolam', 'N05CD08', 1, 'mg / ml', 63823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('midazolam', 'N05CD08', 5, 'mg / ml', 63824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('midazolam (midazolam hydrochloride)', 'N05CD08', 1, 'mg / ml', 67147);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('midazolam (midazolam hydrochloride)', 'N05CD08', 5, 'mg / ml', 67148);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('midazolam', 'N05CD08', 1, 'mg / ml', 66736);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('midazolam', 'N05CD08', 5, 'mg / ml', 66737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('midazolam (midazolam hydrochloride)', 'N05CD08', 1, 'mg / ml', 67876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('midazolam (midazolam hydrochloride)', 'N05CD08', 5, 'mg / ml', 67877);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dorzolamide (dorzolamide hydrochloride)', 'S01EC03', 2, '%', 75449);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen (naproxen sodium)', 'M01AE02', 500, 'mg', 66250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 375, 'mg', 67341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dorzolamide (dorzolamide hydrochloride)', 'S01EC03', 20, 'mg / ml', 20083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dorzolamide (dorzolamide hydrochloride)', 'S01EC03', 20, 'mg / ml', 80181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromocriptine (bromocriptine mesylate)', 'G02CB01', 5, 'mg', 49403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromocriptine (bromocriptine mesylate)', 'G02CB01', 2.5, 'mg', 51080);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromocriptine (bromocriptine mesylate)', 'G02CB01', 2.5, 'mg', 62064);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromocriptine (bromocriptine mesylate)', 'G02CB01', 5, 'mg', 62065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromocriptine (bromocriptine mesylate)', 'G02CB01', 2.5, 'mg', 61585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromocriptine (bromocriptine mesylate)', 'G02CB01', 5, 'mg', 61586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromocriptine (bromocriptine mesylate)', 'G02CB01', 5, 'mg', 60242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triethanolamine stearate', 'D02AC', 4, '%', 2536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naloxone hydrochloride', 'V03AB15', 1, 'mg / ml', 18024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naloxone hydrochloride', 'V03AB15', 0.4, 'mg / ml', 18025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylase', 'A09AA02', 30000, 'unit', 1649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clomipramine hydrochloride', 'N06AA04', 25, 'mg', 19533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clomipramine hydrochloride', 'N06AA04', 50, 'mg', 18530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clomipramine hydrochloride', 'N06AA04', 10, 'mg', 14535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clomipramine hydrochloride', 'N06AA04', 50, 'mg', 14536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clomipramine hydrochloride', 'N06AA04', 25, 'mg', 14537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clomipramine hydrochloride', 'N06AA04', 50, 'mg', 4382);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clomipramine hydrochloride', 'N06AA04', 10, 'mg', 2164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clomipramine hydrochloride', 'N06AA04', 25, 'mg', 2039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clomipramine hydrochloride', 'N06AA04', 10, 'mg', 48987);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clomipramine hydrochloride', 'N06AA04', 25, 'mg', 51042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clomipramine hydrochloride', 'N06AA04', 50, 'mg', 51044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clomipramine hydrochloride', 'N06AA04', 10, 'mg', 68806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clomipramine hydrochloride', 'N06AA04', 25, 'mg', 68807);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clomipramine hydrochloride', 'N06AA04', 50, 'mg', 68808);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('deferoxamine mesylate', 'V03AC01', 2, 'g / vial', 13390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('deferoxamine mesylate', 'V03AC01', 2, 'g / vial', 67360);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('deferoxamine mesylate', 'V03AC01', 2, 'g / vial', 71256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('deferoxamine mesylate', 'V03AC01', 500, 'mg / vial', 13546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('deferoxamine mesylate', 'V03AC01', 500, 'mg / vial', 65727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('deferoxamine mesylate', 'V03AC01', 500, 'mg / vial', 65257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carmustine', 'L01AD01', 7.7, 'mg', 62433);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carmustine', 'L01AD01', 100, 'mg / vial', 2153);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('threonine', 'B05ZA', 64.6, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lactulose', 'A06AD11', 667, 'mg / ml', 38260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lactulose', 'A06AD11', 667, 'mg / ml', 12699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lactulose', 'A06AD11', 667, 'mg / ml', 66642);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lactulose', 'A06AD11', 667, 'mg / ml', 71628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lactulose', 'A06AD11', 667, 'mg / ml', 78124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lactulose', 'A06AD11', 667, 'mg / ml', 81724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dantrolene sodium', 'M03CA01', 25, 'mg', 14019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dantrolene sodium', 'M03CA01', 100, 'mg', 14018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dantrolene sodium', 'M03CA01', 20, 'mg / vial', 14017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lauryl ether sulfate', 'V07AV', 6, '%', 2495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 750, 'mg', 44216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 250, 'mg', 11184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 375, 'mg', 11185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 500, 'mg', 11186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 125, 'mg', 11187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 375, 'mg', 6524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 375, 'mg', 5860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 500, 'mg', 6266);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 375, 'mg', 5508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 500, 'mg', 5222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 500, 'mg', 5183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 250, 'mg', 5175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 250, 'mg', 5036);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 250, 'mg', 4980);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 125, 'mg', 4981);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 250, 'mg', 64377);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 375, 'mg', 64378);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 500, 'mg', 64379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 250, 'mg', 67215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 375, 'mg', 67216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 500, 'mg', 67217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 250, 'mg', 67340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 250, 'mg', 70894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 375, 'mg', 70895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 500, 'mg', 70896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 500, 'mg', 78006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 375, 'mg', 78005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 375, 'mg', 79656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 500, 'mg', 79657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 250, 'mg', 83596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 375, 'mg', 83597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 500, 'mg', 83598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 250, 'mg', 83599);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 375, 'mg', 83600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 500, 'mg', 83601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 750, 'mg / srt', 19314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 750, 'mg / srt', 50634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 250, 'mg / ect', 19448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 500, 'mg / ect', 19315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 375, 'mg / ect', 19316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 500, 'mg / ect', 64618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 500, 'mg / sup', 14566);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen', 'M01AE02', 25, 'mg / ml', 19661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis a vaccine, inactivated', 'J07BC02', 1440, 'unit / ml', 20256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis a vaccine, inactivated', 'J07BC02', 500, 'unit / 0.5 ml', 63411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis a vaccine, inactivated', 'J07BC02', 50, 'unit / ml', 47865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis a vaccine, inactivated', 'J07BC02', 720, 'unit / 0.5 ml', 50339);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis a vaccine, inactivated', 'J07BC02', 160, 'unit / 0.5 ml', 61149);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hepatitis a vaccine, inactivated', 'J07BC02', 80, 'unit / 0.5 ml', 67674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rocuronium bromide', 'M03AC09', 10, 'mg / ml', 17797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rocuronium bromide', 'M03AC09', 10, 'mg / ml', 80390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rocuronium bromide', 'M03AC09', 10, 'mg / ml', 80363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil light', 'D02AC', 100, '%', 36404);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil light', 'D02AC', 100, '%', 49031);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epoetin alfa', 'B03XA01', 10000, 'unit / ml', 18517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epoetin alfa', 'B03XA01', 2000, 'unit / ml', 18538);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epoetin alfa', 'B03XA01', 4000, 'unit / ml', 18529);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epoetin alfa', 'B03XA01', 1000, 'unit / 0.5 ml', 50949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epoetin alfa', 'B03XA01', 2000, 'unit / 0.5 ml', 50950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epoetin alfa', 'B03XA01', 3000, 'unit / 0.3 ml', 50951);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epoetin alfa', 'B03XA01', 4000, 'unit / 0.4 ml', 50952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epoetin alfa', 'B03XA01', 10000, 'unit / ml', 50953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epoetin alfa', 'B03XA01', 40000, 'unit / ml', 64311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epoetin alfa', 'B03XA01', 20000, 'unit / 0.5 ml', 67133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epoetin alfa', 'B03XA01', 5000, 'unit / 0.5 ml', 67308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epoetin alfa', 'B03XA01', 6000, 'unit / 0.6 ml', 67309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epoetin alfa', 'B03XA01', 8000, 'unit / 0.8 ml', 67311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epoetin alfa', 'B03XA01', 30000, 'unit / 0.75 ml', 77409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('urofollitropin', 'G03GA04', 75, 'unit / vial', 75353);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iron (iron dextran complex)', 'B03AC01', 50, 'mg / ml', 43298);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iron (iron dextran complex)', 'B03AC06', 50, 'mg / ml', 43006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iron (sodium ferric gluconate complex in sucrose injection)', 'B03AC07', 12.5, 'mg / ml', 67236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iron (iron sucrose)', 'B03AC02', 20, 'mg / ml', 67648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylase', 'A09AA02', 20000, 'unit', 36399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylase', 'A09AA02', 33200, 'unit', 36179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylase', 'A09AA02', 11000, 'unit', 35065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylase', 'A09AA02', 65000, 'unit', 27084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylase', 'A09AA02', 39000, 'unit', 27081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylase', 'A09AA02', 74000, 'unit', 13302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylase', 'A09AA02', 55000, 'unit', 9892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylase', 'A09AA02', 30000, 'unit', 3189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylase', 'A09AA02', 30000, 'unit', 3891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylase', 'A09AA02', 30000, 'unit', 48551);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylase', 'A09AA02', 140000, 'unit', 60913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylase', 'A09AA02', 16600, 'unit', 62457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylase', 'A09AA02', 66400, 'unit', 62458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amylase', 'A09AA02', 60000, 'unit', 65603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized cat hair acetone precipitated', 'V01AA11', 10000, 'unit / ml', 43218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized cat pelt acetone precipitated', 'V01AA11', 10000, 'unit / ml', 43219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'R02AD04', 6, 'mg', 76114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'M02AX10', 4, '%', 42186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'D05AA', 1.5, '%', 42099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'M02AX10', 1.25, '%', 42113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'D05AA', 1.5, '%', 42042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'D05AA', 1.5, '%', 42043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'M02AX10', 4, '%', 41939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'D05AA', 0.5, '%', 15950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'D11AX12', 0.3, '%', 10999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'D04AB07', 0.5, '%', 9335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'M02AC', 2.0, '%', 3998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'D02AA', 0.15, '%', 60861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'D02AA', 0.50, '%', 60901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'D04AB07', 1, '%', 60289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'D04AB01', 0.97, '%', 74263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'D04AB01', 1, '%', 74327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'D05AA', 1.5, '%', 77120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'M02AC', 1.25, '% / w/w', 80107);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'D04AB07', 0.5, '% / w/w', 80397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'D05AA', 1, '% / w/v', 10674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'D05AA', 1.5, '% / w/v', 77121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'R05CA03', 15, 'mg / 5 ml', 75089);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'R05CA03', 10, 'mg / 5 ml', 77454);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'R05CA03', 15, 'mg / 5 ml', 80636);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'R05CA03', 10, 'mg / 5 ml', 83190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menthol', 'D04AB07', 0.5, '% / ml', 13570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg', 42569);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 37097);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 37099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 33272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 32410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg', 31506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg', 26144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 22143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 22086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 19418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 19419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 20255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 19084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 120, 'mg', 15202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 15204);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 650, 'mg', 15205);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg', 15706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 14130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 14131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 14084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 14475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg', 14449);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg', 14450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 14383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 13865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg', 14206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg', 11794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 11140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 11141);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 12154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 12565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 8387);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 9627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 9628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 10205);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 8597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 5476);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 5345);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 7363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 7364);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 7352);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 5584);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 5570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 5571);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 4883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 4884);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 4733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 4734);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 5255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 5184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 5254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 5035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 2727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 2728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 2064);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 2065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg', 47718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 48231);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 120, 'mg', 49357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg', 49359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 49360);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 48431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg', 50212);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg', 50292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 60748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 60749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 650, 'mg', 62325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg', 60900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg', 61697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 64652);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg', 64806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 64807);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160.00, 'mg', 64993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg', 69009);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 68664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 68299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 650, 'mg', 70191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg', 70222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 74040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 75452);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 650, 'mg', 75800);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg', 74921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg', 74922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325.0, 'mg', 73774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500.0, 'mg', 73775);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 650.0, 'mg', 77210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 77128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg', 77806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 77807);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 650, 'mg', 76904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 650.0, 'mg', 81882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 650, 'mg', 78657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 79863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 79679);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 80540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 500, 'mg', 82884);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg', 83316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 120, 'mg / sup', 19271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg / sup', 19272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg / sup', 14591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 325, 'mg / sup', 14592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 120, 'mg / sup', 14593);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 650, 'mg / sup', 14594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 650, 'mg / sup', 49361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg / 5 ml', 42388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg / 1 ml', 42341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 32, 'mg / ml', 42135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg / ml', 42136);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg / 5 ml', 42066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg / 5 ml', 41867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg / ml', 41869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg / 5 ml', 33482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg / ml', 33483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg / ml', 21989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg / ml', 18015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg / 5 ml', 16988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg / ml', 11795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg / 5 ml', 11796);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 32, 'mg / ml', 10450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 16, 'mg / ml', 10451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg / 5 ml', 12412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg / ml', 11063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg / 5 ml', 12159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg / ml', 6112);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg / ml', 50056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg / 5 ml', 60014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg / ml', 60714);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg / 5 ml', 64653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg / 5 ml', 64394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg / ml', 74919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg / 5 ml', 74920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg / 5 ml', 74923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg / ml', 78697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg / 5 ml', 81650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 650, 'mg / 15 ml', 79762);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 80, 'mg / ml', 79547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetaminophen', 'N02BE01', 160, 'mg / 5 ml', 79548);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azelaic acid', 'D10AX03', 15, '%', 75617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aldesleukin', 'L03AC01', 22000000, 'unit / vial', 18314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('danaparoid sodium', 'B01AB09', 750, 'unit / 0.6 ml', 18868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacillus calmette-guerin (bcg) substrain connaught', 'L03AX03', 81, 'mg / vial', 20020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacillus calmette-guerin (bcg) substrain connaught', 'J07AN01', 0.1, 'mg / 0.1 ml', 673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('adapalene', 'D10AD03', 0.1, '%', 20107);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('adapalene', 'D10AD03', 0.1, '%', 50959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('adapalene', 'D10AD03', 0.3, '%', 75946);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenytoin', 'N03AB02', 50, 'mg', 1086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenytoin', 'N03AB02', 125, 'mg / 5 ml', 613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenytoin', 'N03AB02', 30, 'mg / 5 ml', 769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenytoin', 'N03AB02', 125, 'mg / 5 ml', 73583);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxylamine succinate', 'R06AA09', 25, 'mg', 12744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethyl sulfoxide', 'G04BX13', 500, 'mg / g', 3769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethyl sulfoxide', 'G04BX13', 500, 'mg / g', 67117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hyoscine butylbromide', 'A04AD01', 10, 'mg', 2481);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hyoscine butylbromide', 'A04AD01', 20, 'mg / ml', 2483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hyoscine butylbromide', 'A03BB01', 20, 'mg / ml', 48226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('juniper tar', 'D05AA', 0.166, '%', 41695);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('juniper tar', 'D05AA', 0.33, '%', 5557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('juniper tar', 'D05AA', 0.09, '%', 2984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('juniper tar', 'D05AA', 0.16, '%', 1495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('juniper tar', 'D05AA', 0.33, '%', 64533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium hydroxide', 'V07AV', 2, '%', 13850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dronabinol', 'A04AD10', 2.5, 'mg', 17209);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dronabinol', 'A04AD10', 5, 'mg', 17207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoin', 'D08AX', 10, '%', 27350);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzoin', 'D08AX', 25, '%', 34874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinic acid', 'C04AC01', 500, 'mg', 11254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinic acid', 'C10AD02', 500, 'mg', 74771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinic acid', 'C10AD02', 750, 'mg', 74772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinic acid', 'C10AD02', 1000, 'mg', 74773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinic acid', 'C10AD02', 500, 'mg', 79485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinic acid', 'C10AD02', 750, 'mg', 79486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinic acid', 'C10AD02', 1000, 'mg', 79488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinic acid', 'C04AC01', 100, 'mg / ml', 3499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nicotinic acid', 'C04AC01', 800, 'mg / 1.25 ml', 3965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quaternium-15', 'V04CL', 0.081, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('serine', 'B05ZA', 51, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miconazole nitrate', 'G01AF04', 400, 'mg', 19677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miconazole nitrate', 'G01AF04', 400, 'mg', 16612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miconazole nitrate', 'G01AF04', 1200, 'mg', 63071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miconazole nitrate', 'D01AC02', 2, '%', 17832);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miconazole nitrate', 'G01AF04', 2, '%', 16608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miconazole nitrate', 'D01AC02', 2, '%', 16609);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miconazole nitrate', 'G01AF04', 2, '%', 16610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miconazole nitrate', 'G01AF04', 2, '%', 16611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miconazole nitrate', 'D01AC02', 2, '%', 49064);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miconazole nitrate', 'G01AF04', 2, '%', 50390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miconazole nitrate', 'G01AF04', 4, '%', 67948);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miconazole nitrate', 'G01AF04', 2, '%', 69637);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miconazole nitrate', 'G01AF04', 400, 'mg / sup', 16610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miconazole nitrate', 'G01AF04', 100, 'mg / sup', 16611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miconazole nitrate', 'G01AF04', 2, '%', 50876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miconazole nitrate', 'G01AF04', 1200, 'mg / pck', 63070);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('miconazole nitrate', 'G01AF04', 2, '% / pck', 63070);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'G01AF02', 200, 'mg', 19479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'G01AF02', 500, 'mg', 19480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'G01AF02', 10, '%', 44016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'G01AF02', 1, '%', 19483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'G01AF02', 2, '%', 19484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'G01AF02', 1, '%', 49563);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'G01AF02', 10, '%', 49563);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'D01AC01', 1, '%', 62905);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'G01AF02', 1, '%', 74951);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'G01AF02', 1, '%', 74952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'D01AC01', 1, '%', 79727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'J02AC01', 1, '%', 79728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'G01AF02', 200, 'mg / vtab', 74951);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'G01AF02', 500, 'mg / vtab', 74952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'G01AF02', 2, '%', 47180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'D01AC01', 1, '%', 47181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'D01AC01', 1, '%', 19487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'D01AC01', 1, '%', 11893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'G01AF02', 1, '%', 9926);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clotrimazole', 'G01AF02', 2, '%', 9927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoprofen', 'M01AE03', 50, 'mg', 19340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoprofen', 'M01AE03', 50, 'mg', 19507);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoprofen', 'M01AE03', 200, 'mg', 19115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoprofen', 'M01AE03', 50, 'mg', 16039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoprofen', 'M01AE03', 100, 'mg', 14025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoprofen', 'M01AE03', 100, 'mg', 10134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoprofen', 'M01AE03', 50, 'mg', 10135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoprofen', 'M01AE03', 50, 'mg', 10136);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoprofen', 'M01AE03', 100, 'mg', 60312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoprofen', 'M01AE03', 100, 'mg / ect', 19338);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoprofen', 'M01AE03', 50, 'mg / ect', 19339);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoprofen', 'M01AE03', 50, 'mg / ect', 16042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoprofen', 'M01AE03', 100, 'mg / ect', 16038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('air', 'V03AN05', 99.7, '%', 13895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('air', 'V03AN05', 85, '%', 13896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('air', 'V03AN05', 50, '%', 13897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('air', 'V03AN05', 70, '%', 13892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('air', 'V03AN05', 100, '%', 5684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrous oxide', 'N01AX13', 99, '%', 19262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrous oxide', 'N01AX13', 99, '%', 13887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrous oxide', 'N01AX13', 100, '%', 5685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99.9, '%', 45814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 100, '%', 37030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99.5, '%', 27306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN05', 23.5, '%', 19291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 19299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 20047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 100, '%', 20349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 100, '%', 18663);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 15005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 13886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99.0, '%', 6826);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 100, '%', 5682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99.5, '%', 5545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99.99, '%', 50235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 61847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 61206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 62190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 64194);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 64346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 100, '%', 64373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 66253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 66280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 66284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 66939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 72159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 73046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99.0, '%', 73094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 72531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 77527);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 79765);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxygen', 'V03AN01', 99, '%', 80944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('helium', 'V03AN03', 99, '%', 19294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('helium', 'V03AN03', 99, '%', 13883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('helium', 'V03AN03', 100, '%', 5688);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon dioxide', 'V03AN02', 99, '%', 19263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon dioxide', 'V03AN05', 15, '%', 13896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon dioxide', 'V03AN05', 50, '%', 13897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon dioxide', 'V03AN02', 99, '%', 13884);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon dioxide', 'V03AN05', 30, '%', 13892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon dioxide', 'V03AN02', 100, '%', 5687);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terbutaline sulfate', 'R03AC03', 0.5, 'mg / act', 10665);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', 'D11AX11', 8, '%', 72192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', 'D11AX11', 2, '%', 69834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', 'D11AX11', 2.0, '% / w/w', 80960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octocrylene', 'D11AX11', 4.0, '% / w/w', 80453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('danazol', 'G03XA01', 50, 'mg', 15897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('danazol', 'G03XA01', 100, 'mg', 15163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('danazol', 'G03XA01', 200, 'mg', 14747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dodecyl dimethyl benzyl ammonium chloride', 'V07AV', 1.2, '%', 60895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol maleate', 'C07AA06', 5, 'mg', 13021);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol maleate', 'C07AA06', 20, 'mg', 14928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol maleate', 'C07AA06', 10, 'mg', 14929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol maleate', 'C07AA06', 5, 'mg', 14930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol maleate', 'C07AA06', 20, 'mg', 12879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol maleate', 'C07AA06', 10, 'mg', 12880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol maleate', 'C07AA06', 5, 'mg', 8589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol maleate', 'C07AA06', 10, 'mg', 8590);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol maleate', 'C07AA06', 20, 'mg', 8591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol maleate', 'S01ED01', 0.25, '%', 17212);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('timolol maleate', 'S01ED01', 0.5, '%', 17214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxorubicin hydrochloride', 'L01DB01', 10, 'mg / vial', 42943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxorubicin hydrochloride', 'L01DB01', 50, 'mg / vial', 42944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxorubicin hydrochloride', 'L01DB01', 150, 'mg / vial', 42945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxorubicin hydrochloride', 'L01DB01', 2, 'mg / ml', 18674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxorubicin hydrochloride', 'L01DB01', 2, 'mg / ml', 48640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxorubicin hydrochloride', 'L01DB01', 2, 'mg / ml', 61804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxorubicin hydrochloride', 'L01DB01', 2, 'mg / ml', 69014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 0.5, 'mg', 17817);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 1, 'mg', 16118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 2, 'mg', 16586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 2, 'mg', 16587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 1, 'mg', 16588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 0.5, 'mg', 16589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 1, 'mg', 11191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 2, 'mg', 11192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 0.5, 'mg', 11195);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 1, 'mg', 9423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 2, 'mg', 9424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 0.5, 'mg', 9349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 0.5, 'mg', 6656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 1, 'mg', 6657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 2, 'mg', 6658);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 0.5, 'mg', 6295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 1, 'mg', 6296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 2, 'mg', 6297);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 0.5, 'mg', 7314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 1, 'mg', 6135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 2, 'mg', 6136);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 0.5, 'mg', 69897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 1, 'mg', 69898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 2, 'mg', 69899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 0.5, 'mg', 78350);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 1, 'mg', 78351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 2, 'mg', 78352);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 0.5, 'mg', 83628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 1.0, 'mg', 83629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 2.0, 'mg', 83630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lorazepam', 'N05BA06', 4, 'mg / ml', 67176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromocriptine mesylate', 'G02CB01', 2.5, 'mg', 16195);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dacarbazine', 'L01AX04', 600, 'mg / vial', 65081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('maprotiline hydrochloride', 'N06AA21', 75, 'mg', 18485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('maprotiline hydrochloride', 'N06AA21', 50, 'mg', 18486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('maprotiline hydrochloride', 'N06AA21', 25, 'mg', 18489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lomustine', 'L01AD02', 100, 'mg', 2529);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lomustine', 'L01AD02', 40, 'mg', 2530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lomustine', 'L01AD02', 10, 'mg', 2531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tris hydroxymethyl nitromethane', 'V07AV', 19.2, '%', 66752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tris hydroxymethyl nitromethane', 'V07AV', 19.56, '%', 69733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('theophylline', 'R03DA04', 400, 'mg', 16103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('theophylline', 'R03DA04', 600, 'mg', 16482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('theophylline', 'R03DA04', 200, 'mg', 14032);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('theophylline', 'R03DA04', 100, 'mg', 14033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('theophylline', 'R03DA04', 300, 'mg', 14031);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('theophylline', 'R03DA04', 100, 'mg', 48617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('theophylline', 'R03DA04', 200, 'mg', 48618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('theophylline', 'R03DA04', 300, 'mg', 48619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('theophylline', 'R03DA04', 400, 'mg', 84507);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('theophylline', 'R03DA04', 600, 'mg', 84508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('theophylline', 'R03DA04', 80, 'mg / 15 ml', 13450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('theophylline', 'R03DA04', 80, 'mg / 15 ml', 6170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('theophylline', 'R03DA04', 80, 'mg / 15 ml', 3455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('theophylline', 'R03DA04', 80, 'mg / 15 ml', 5078);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perindopril erbumine', 'C09AA04', 4, 'mg', 16879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perindopril erbumine', 'C09AA04', 2, 'mg', 16880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perindopril erbumine', 'C09AA04', 8, 'mg', 70814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perindopril erbumine', 'C09AA04', 8, 'mg', 77467);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levocarnitine', 'A16AA01', 330, 'mg', 18931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levocarnitine', 'A16AA01', 100, 'mg / ml', 19094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levocarnitine', 'A16AA01', 200, 'mg / ml', 18903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyethylene glycol 400', 'S01XA20', 0.4, '%', 73342);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 100, 'mg', 17201);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 25, 'mg', 17203);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 150, 'mg', 17160);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 5, 'mg', 63629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 25, 'mg', 67259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 100, 'mg', 67260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 25, 'mg', 69223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 100, 'mg', 69224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 150, 'mg', 69225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 2, 'mg', 67741);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 25, 'mg', 71124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 100, 'mg', 71125);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 150, 'mg', 71126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 150, 'mg', 71190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 25, 'mg', 75095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 100, 'mg', 75096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 150, 'mg', 75097);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 25, 'mg', 72568);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 100, 'mg', 72569);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 150, 'mg', 72570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 25, 'mg', 82850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 100, 'mg', 82851);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 150, 'mg', 82852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 150, 'mg', 78831);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 25, 'mg', 78826);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamotrigine', 'N03AX09', 100, 'mg', 78830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil', 'J01DC10', 500, 'mg', 19228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil', 'J01DC10', 250, 'mg', 19229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil (cefprozil monohydrate)', 'J01DC10', 500, 'mg', 77837);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil (cefprozil monohydrate)', 'J01DC10', 250, 'mg', 77836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil (cefprozil monohydrate)', 'J01DC10', 250, 'mg', 77887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil (cefprozil monohydrate)', 'J01DC10', 500, 'mg', 77888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil (cefprozil monohydrate)', 'J01DC10', 500, 'mg', 80966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil', 'J01DC10', 250, 'mg', 78751);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil', 'J01DC10', 500, 'mg', 78752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil (cefprozil monohydrate)', 'J01DC10', 250, 'mg', 80284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil (cefprozil monohydrate)', 'J01DC10', 500, 'mg', 80285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil', 'J01DC10', 250, 'mg / 5 ml', 19226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil', 'J01DC10', 125, 'mg / 5 ml', 19227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil (cefprozil monohydrate)', 'J01DC10', 250, 'mg / 5 ml', 77893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil', 'J01DC10', 125, 'mg / 5 ml', 77932);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil', 'J01DC10', 250, 'mg / 5 ml', 77933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil (cefprozil monohydrate)', 'J01DC10', 125, 'mg / 5 ml', 78873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil (cefprozil monohydrate)', 'J01DC10', 250, 'mg / 5 ml', 78874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefprozil (cefprozil monohydrate)', 'J01DC10', 125, 'mg / 5 ml', 81489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zuclopenthixol decanoate', 'N05AF05', 200, 'mg / ml', 49245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zuclopenthixol acetate', 'N05AF05', 50, 'mg / ml', 49244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 46352);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.15, '%', 44478);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1, '%', 45490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 41219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 41220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 41221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D05AA', 0.2, '%', 41889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.1, '%', 37743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.52, '%', 37819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 37812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.09, '%', 34234);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.89, '%', 34215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 34190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.15, '%', 34197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.14, '%', 33839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 2.5, '%', 30372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.25, '%', 29437);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 29438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 29436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.68, '%', 28516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.4, '%', 28306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.14, '%', 27723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.34, '%', 27724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.68, '%', 27725);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.8, '%', 26014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.1, '%', 25675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.34, '%', 21969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 21701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.5, '%', 19411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.36, '%', 20265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.14, '%', 20266);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.92, '%', 20267);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.96, '%', 20268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.25, '%', 19346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.2, '%', 20223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.34, '%', 20091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.72, '%', 20068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 20341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 19504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D04AB01', 0.13, '%', 19488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 18892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 18514);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.06, '%', 18016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.15, '%', 17969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 18815);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 18799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 18782);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 18770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 18771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3, '%', 18733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.09, '%', 18329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.6, '%', 18304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3, '%', 18713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.34, '%', 18714);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.69, '%', 17768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.25, '%', 19113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.68, '%', 18934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.5, '%', 18626);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.2, '%', 18900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 17242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 17243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 17241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3, '%', 15899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 15873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.5, '%', 16773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.07, '%', 16774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.14, '%', 15830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 16719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 16720);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.125, '%', 16238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 16183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.09, '%', 16184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.25, '%', 15690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 15557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 15507);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.43, '%', 15508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.68, '%', 16875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.64, '%', 15973);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.72, '%', 15972);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.2, '%', 15954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.54, '%', 15947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 14705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.115, '%', 13705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.07, '%', 13683);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.54, '%', 13687);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.115, '%', 13656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.3, '%', 68184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 14632);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 14617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 13553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.25, '%', 13394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 13373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.25, '%', 13352);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.14, '%', 14412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.25, '%', 13891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 13341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 13868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 14321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.76, '%', 13249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.38, '%', 13233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.34, '%', 14255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 9.4, '%', 13788);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3, '%', 13767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 14211);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 14213);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexrazoxane', 'V03AF02', 250, 'mg / vial', 18480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.5, '%', 14215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.5, '%', 11314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 11296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 10490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 10491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 10471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 10425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.25, '%', 10429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.07, '%', 12403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.14, '%', 12404);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.54, '%', 12405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.54, '%', 12406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.54, '%', 12407);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.2, '%', 12408);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.6, '%', 11066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.125, '%', 12289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.125, '%', 12255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.07, '%', 12210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.25, '%', 11453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 12556);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 11431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.52, '%', 11922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 10686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.00, '%', 9822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 8461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 8435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2, '%', 9221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 9223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.08, '%', 9224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.28, '%', 8354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.80, '%', 9621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 8606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 10010);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.5, '%', 8044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 8045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 8046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3, '%', 9323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 8478);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 7139);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 20, '%', 5377);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.8, '%', 7079);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 7071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 7041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 6535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4, '%', 6523);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.680, '%', 67608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.5, '%', 7632);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 7022);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 6469);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.5, '%', 6466);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 6464);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 6465);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.8, '%', 6450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 7457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.35, '%', 5699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 6268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.5, '%', 6263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.5, '%', 6203);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.29, '%', 7322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 7320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 14.8, '%', 5578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 9, '%', 5579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 6666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.5, '%', 6667);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.89, '%', 5544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.3, '%', 3836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.44, '%', 4938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexrazoxane', 'V03AF02', 500, 'mg / vial', 18481);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 3824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.6, '%', 3826);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 3828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 4889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.12, '%', 3766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 7.5, '%', 3732);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 14.8, '%', 4218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.35, '%', 4200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 5289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.75, '%', 4199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 4190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 3619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.85, '%', 3594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 3592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.5, '%', 5240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 3470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.6, '%', 3471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.9, '%', 5132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1, '%', 5120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 4612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 5088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 3924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 4494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 7.4, '%', 3884);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 3307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.1, '%', 1984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.25, '%', 2589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.75, '%', 2545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 2486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3, '%', 2487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 2430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.625, '%', 3039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1, '%', 3040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 9, '%', 3026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.55, '%', 3015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.2, '%', 2404);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 2406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 2389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.89, '%', 2901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.8, '%', 2305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 2298);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.12, '%', 2932);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3, '%', 2265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 2868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 2196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 13, '%', 869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.8, '%', 2679);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 48111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 49187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 11.5, '%', 234);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 49430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 50059);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 50061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'S01XA20', 0.01, '%', 50153);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'S01XA20', 0.01, '%', 50154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.84, '%', 50646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 50866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.520, '%', 50870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.25, '%', 51889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 9, '%', 51894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.5, '%', 53825);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D04AB01', 0.13, '%', 53831);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3, '%', 61859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.68, '%', 60432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.2, '%', 61178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.44, '%', 62048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 61358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.54, '%', 61429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.2, '%', 61475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 60867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.00, '%', 60956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 61030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 62389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 62391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.20, '%', 62416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.520, '%', 62417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 63262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 17.06, '%', 63207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 7.675, '%', 64646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.25, '%', 64703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.20, '%', 62709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 62730);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.20, '%', 63709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.6, '%', 64299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 64461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.6, '%', 67114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.54, '%', 67119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.154, '%', 67128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.54, '%', 67134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.28, '%', 65206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 65736);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 65738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.340, '%', 65191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.340, '%', 65192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 67182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.106, '%', 65270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.170, '%', 65845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 65846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.170, '%', 66379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.125, '%', 66387);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.14, '%', 66562);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 7.95, '%', 64770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 7.95, '%', 64771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.86, '%', 65998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 66666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.1, '%', 66672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.29, '%', 66752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 64939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 66126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.20, '%', 66174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 7.68, '%', 66931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.106, '%', 65628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.17, '%', 66940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D04AB01', 0.13, '%', 65636);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D04AB01', 0.13, '%', 65637);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 65645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.034, '%', 66995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.190, '%', 65142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.339, '%', 67048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 68306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.170, '%', 68309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.25, '%', 68862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.7, '%', 69419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.05, '%', 68930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.25, '%', 68931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.28, '%', 68933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 67324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 67373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.125, '%', 67389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 67406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 67435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 67464);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.20, '%', 69060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.34, '%', 67512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.339, '%', 69105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 67586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 67597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.170, '%', 68144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.154, '%', 67640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.170, '%', 67651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.680, '%', 67652);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 67609);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.14, '%', 67773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2, '%', 68288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.33, '%', 72119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.0532, '%', 72148);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.339, '%', 72152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.680, '%', 72153);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.170, '%', 72154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.170, '%', 69931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 69936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.034, '%', 69957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1, '%', 69970);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.13, '%', 71395);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.13, '%', 71396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.13, '%', 71397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.0, '%', 70000);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 2.5, '%', 70044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.186, '%', 70059);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.5, '%', 70067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.05, '%', 70765);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.04, '%', 70767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.27, '%', 71522);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.27, '%', 71523);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 72292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 72294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 72295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.190, '%', 72301);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 70135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 70137);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 70143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 70144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.1, '%', 70804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.1, '%', 70805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.20, '%', 70836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 71528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 71597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 71598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.115, '%', 70165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.05, '%', 70197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.05, '%', 70199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.2520, '%', 70268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 11.2, '%', 70274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.2, '%', 71698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.173, '%', 71713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.12, '%', 69659);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.20, '%', 70365);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 69698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 69699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.09, '%', 69733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.680, '%', 69735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.145, '%', 70392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1, '%', 70410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.11, '%', 70433);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10.0, '%', 70442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.14, '%', 70460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.08, '%', 70469);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.02, '%', 70469);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3, '%', 70471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.01, '%', 70475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.33, '%', 70493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.034, '%', 70506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2, '%', 71209);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.12, '%', 69840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.08, '%', 70546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.02, '%', 70546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.5, '%', 71966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.64, '%', 71992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.6, '%', 71987);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D04AB01', 0.13, '%', 69914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.6, '%', 70599);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.1, '%', 70601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.13, '%', 70605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.07, '%', 71318);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.35, '%', 76438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.085, '%', 76443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.032, '%', 76444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.032, '%', 76446);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.4, '%', 76452);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.8, '%', 76453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.1, '%', 72889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.0, '%', 73896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.024, '%', 75171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.8, '%', 76457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 9, '%', 76458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.5, '%', 76459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.14, '%', 76460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.0240, '%', 76479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 76537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 72773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.54, '%', 72793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ51', 0.10, '%', 72815);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 72822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 72823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.11, '%', 72834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 72860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.173, '%', 75206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.24, '%', 75223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.96, '%', 75225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.74, '%', 75223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 75231);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.0, '%', 75242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.3, '%', 75243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.54, '%', 75251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 76592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.0, '%', 76631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.170, '%', 76639);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.04, '%', 76640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.20, '%', 76650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.5, '%', 72930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 72931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 72932);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.680, '%', 72933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.25, '%', 74028);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.15, '%', 74065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.15, '%', 74069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.2, '%', 75267);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.384, '%', 75290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.3, '%', 74145);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.14, '%', 75402);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.20, '%', 76765);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.034, '%', 76777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.76, '%', 73025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.680, '%', 73035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.339, '%', 73036);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.170, '%', 73037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.170, '%', 72340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.9, '%', 72341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.9, '%', 72342);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.33, '%', 72344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.4, '%', 74298);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.5, '%', 74316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 74317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.92, '%', 74326);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 74338);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 74344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 75554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.5, '%', 75555);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.2, '%', 75587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.04, '%', 75633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.085, '%', 75693);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.085, '%', 75693);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tacrolimus', 'L04AD02', 0.5, 'mg', 78179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.14, '%', 72427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 72428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.5, '%', 72443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.15, '%', 74517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 75729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.15, '%', 75784);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 72572);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 26.0, '%', 74558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.20, '%', 75848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 72493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.5, '%', 72494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.05, '%', 72496);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 72497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.54, '%', 72498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.14, '%', 72499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.15, '%', 75948);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.14, '%', 75959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.05, '%', 72614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.11, '%', 72615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.68, '%', 73296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 73297);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.17, '%', 73298);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 20, '%', 73357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.175, '%', 73358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 74691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.09, '%', 74753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 9.2160, '%', 76012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.48, '%', 76050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.20, '%', 76078);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.12, '%', 73373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.12, '%', 73374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.12, '%', 73375);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.12, '%', 73376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.200, '%', 73405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 74808);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.14, '%', 75783);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 10, '%', 76109);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.04, '%', 73470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.9, '%', 73518);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 73631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.125, '%', 73675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.1, '%', 73676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.20, '%', 74943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.14, '%', 76264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.11, '%', 76314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.11, '%', 76315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.3, '%', 72696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.10, '%', 73707);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 73723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.1, '%', 73722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 73726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.28, '%', 72742);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.680, '%', 72770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.680, '%', 72771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 73838);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.25, '%', 73858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.339, '%', 78114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 77369);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 77370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.339, '%', 78415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 78416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.1, '%', 78430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.14, '%', 78487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.5, '%', 77307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 77126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.0, '%', 77080);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.00, '%', 76873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.13, '%', 77627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 77546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 77547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.0532, '%', 78044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.680, '%', 78127);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 77801);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 77802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.15, '%', 77810);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.13, '%', 77811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.15, '%', 77814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 77829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.2, '%', 77844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.154, '%', 77845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 77869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 77870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 77871);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.00, '%', 77382);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 78183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 78184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.034, '%', 78230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.170, '%', 78233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.0, '%', 78236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.339, '%', 78238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 77175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.632, '%', 77005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.035, '%', 77006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 78260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.4, '%', 78279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.20, '%', 76811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.38, '%', 77300);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 77591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.37, '%', 77649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.339, '%', 77874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 78326);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.339, '%', 77412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 76819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.69, '%', 76820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.1375, '%', 77965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.1375, '%', 77966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.00, '%', 78017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 81582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.2, '%', 79843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.170, '%', 79846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.6, '%', 82831);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 82279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.1, '%', 78511);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 78729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.6, '%', 78730);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.34, '%', 78933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.00, '%', 79260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.3, '%', 78569);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 82833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 79876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.20, '%', 78783);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.115, '%', 80991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 81854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.1000, '%', 80095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4, '%', 80737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.64, '%', 80738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 83037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.170, '%', 83038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.085, '%', 83039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.85, '%', 78563);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 79842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 79844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 80719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.085, '%', 79106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.37, '%', 78918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.3, '%', 78919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.34, '%', 79881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.034, '%', 79882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 80171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.3, '%', 80496);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 82556);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.248, '%', 82554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.5, '%', 80303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.14, '%', 80305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.154, '%', 80458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.64, '%', 80754);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.12, '%', 79837);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.20, '%', 79967);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 79860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.025, '%', 81121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.680, '%', 81651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 81653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.680, '%', 80642);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.170, '%', 80646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.170, '%', 79562);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 81844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.59, '%', 81845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.145, '%', 80495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.63, '%', 80972);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.10, '%', 80374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.0, '%', 80388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.14, '%', 82428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.248, '%', 79858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 81305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 81992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.5, '%', 81995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.170, '%', 81996);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.248, '%', 81997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.154, '%', 80336);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.16, '%', 80216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.14, '%', 82417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%', 80541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 80464);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 80630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 82544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 79832);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.13, '%', 80379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.04, '%', 82114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.05, '%', 82115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.1, '%', 82120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.14, '%', 83084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.69, '%', 83214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.14, '%', 83511);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.34, '%', 83525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.14, '%', 83623);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.14, '%', 83682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.125, '%', 83946);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.034, '%', 83950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.154, '%', 83957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.05, '%', 83962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D04AB01', 0.13, '%', 84010);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.170, '%', 84056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 84220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%', 84223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 8.680, '%', 84357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%', 84358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 7.95, '%', 84366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 3.000, '%', 84367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.14, '%', 84373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.26, '%', 84404);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 20.32, '%', 84439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.6, '%', 84440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.154, '%', 84554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5, '%', 84566);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.032, '%', 84735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 84768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%', 85170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.339, '%', 85405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.69, '% / w/w', 13294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '% / w/w', 14193);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.76, '% / w/w', 82604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.20, '% / w/w', 50653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.15, '% / w/w', 75580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.20, '% / w/w', 77007);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.034, '% / w/w', 77008);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '% / w/w', 81274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.05, '% / w/w', 81277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.15, '% / w/w', 81564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.3, '% / w/w', 82781);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '% / w/w', 82414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.5, '% / w/w', 82413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.1, '% / w/w', 80749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '% / w/w', 80990);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ51', 0.15, '% / w/w', 80681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '% / w/w', 80403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.125, '% / w/w', 80420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 7.6, '% / w/w', 80521);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.2, '% / w/w', 80521);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.1, '% / w/w', 81286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.1, '% / w/w', 79941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.05320, '% / w/w', 79995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ51', 0.15, '% / w/w', 79988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '% / w/w', 79976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.339, '% / w/w', 79977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.1, '% / w/w', 80116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.339, '% / w/w', 80645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '% / w/w', 79901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.13, '% / w/w', 80857);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ51', 0.11, '% / w/w', 79811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '% / w/w', 81013);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '% / w/w', 81014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.13, '% / w/w', 80476);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '% / w/w', 81303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.05320, '% / w/w', 81994);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.15, '% / w/w', 79566);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.15, '% / w/w', 83051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.145, '% / w/w', 82416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.20, '% / w/w', 82418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 6.76, '% / w/w', 80036);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.69, '% / w/w', 80037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '% / w/w', 80465);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '% / w/w', 82548);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.1, '% / w/w', 80569);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.15, '% / w/w', 83237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.1, '% / w/w', 83493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.15, '% / w/w', 83633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.1, '% / w/w', 83718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.13, '% / w/w', 83994);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.2, '% / w/w', 84145);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.072, '% / w/w', 84419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.072, '% / w/w', 84422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 1.32, '% / w/w', 84441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.115, '% / w/w', 84999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.339, '% / w/w', 85333);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.339, '% / w/w', 85423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 4.5, '% / w/w', 85444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.154, '% / w/v', 80304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.154, '% / w/v', 83956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.133, '% / w/v', 84128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ51', 0.05, '%', 18082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.13, '%', 9483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.4, '%', 5046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.1, '%', 2171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.1, '%', 61938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.13, '%', 62787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ51', 4, 'mg / ml', 44888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'V07AV', 0.347, 'mg / ml', 61680);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ51', 0.15, '% / ml', 80735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ51', 0.15, '% / ml', 80764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D04AB07', 0.13, '% / ml', 80442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.13, 'mg / 100 mg', 62461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzalkonium chloride', 'D08AJ01', 0.13, 'mg / 100 mg', 64460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bacillus calmette-guerin (bcg) strain tice', 'L03AX03', 800000000, 'unit / vial', 19802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 36346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 36347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 650, 'mg', 19434);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 500, 'mg', 19790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 19489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 19474);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 500, 'mg', 19475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 19477);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 18349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 18909);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 14683);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 14369);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 650, 'mg', 14370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 500, 'mg', 14311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 14312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 650, 'mg', 11798);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 76928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 500, 'mg', 11025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 150, 'mg', 10711);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 650, 'mg', 10712);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 10200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 7362);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 4896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 650, 'mg', 4897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 3158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 4272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 3369);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 650, 'mg', 2410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 1171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 975, 'mg', 2966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 2811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 650, 'mg', 468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 61971);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 81, 'mg', 61080);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'B01AC06', 81, 'mg', 65982);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'B01AC06', 81, 'mg', 66968);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 81, 'mg', 67838);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 69500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 81, 'mg', 67917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 81, 'mg', 68992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 81, 'mg', 67738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 81, 'mg', 67739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 81, 'mg', 67740);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 68301);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 500, 'mg', 70004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 71561);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 71600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'B01AC06', 162, 'mg', 71800);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 500, 'mg', 69836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 76584);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 75453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 73562);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 75019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 650, 'mg', 75021);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 73778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 500, 'mg', 73779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 78087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 81, 'mg', 77528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 81, 'mg', 76924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 76925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 81, 'mg', 76929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 78136);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 77808);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 77088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 77009);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 650, 'mg', 77010);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 76948);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 80715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 80717);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 79706);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 80, 'mg', 79707);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 80238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 500, 'mg', 80239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 81, 'mg', 78992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg', 83769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 650, 'mg', 83770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 81, 'mg', 84814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'V07AV', 31, '%', 74000);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg / gum', 48139);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 325, 'mg / gum', 48140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetylsalicylic acid', 'N02BA01', 500, 'mg / pck', 77472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 125, 'mg', 43513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 250, 'mg', 43514);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 500, 'mg', 18768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 125, 'mg', 76420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 250, 'mg', 76421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 500, 'mg', 76422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 125, 'mg', 76367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 250, 'mg', 76368);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 500, 'mg', 76369);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 250, 'mg', 77741);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 500, 'mg', 77742);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 125, 'mg', 77739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 125, 'mg', 79124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 250, 'mg', 79125);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 500, 'mg', 79126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 125, 'mg', 81030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 250, 'mg', 81031);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famciclovir', 'J05AB09', 500, 'mg', 81032);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docetaxel', 'L01CD02', 20, 'mg / 0.5 ml', 18989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docetaxel', 'L01CD02', 80, 'mg / 2 ml', 18990);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docetaxel', 'L01CD02', 10.0, 'mg / ml', 84699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tacrolimus', 'L04AD02', 5, 'mg', 44210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tacrolimus', 'L04AD02', 1, 'mg', 44211);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tacrolimus', 'L04AD02', 0.5, 'mg', 67015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tacrolimus', 'L04AD02', 1, 'mg', 78180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tacrolimus', 'L04AD02', 5, 'mg', 78181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tacrolimus', 'L04AD02', 3, 'mg', 81736);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tacrolimus', 'D11AH01', 0.1, '%', 68109);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tacrolimus', 'D11AH01', 0.03, '%', 68110);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tacrolimus', 'L04AD02', 5, 'mg / ml', 44212);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sevoflurane', 'N01AB08', 99.97, '%', 19497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sevoflurane', 'N01AB08', 99.97, '%', 75141);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sevoflurane', 'N01AB08', 99.97, '%', 79344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyaminopropyl biguanide', 'S01XA20', 0.0005, '%', 42237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyaminopropyl biguanide', 'S01XA20', 0.00005, '%', 41994);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyaminopropyl biguanide', 'S01XA20', 0.0001, '%', 49610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyaminopropyl biguanide', 'S01XA20', 0.0005, '%', 73892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyaminopropyl biguanide', 'S01XA20', 0.0001, '%', 80971);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyaminopropyl biguanide', 'S01XA20', 0.0001, '% / w/v', 80854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon beta-1b', 'L03AB08', 0.3, 'mg / vial', 19241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon beta-1b', 'L03AB08', 0.3, 'mg / vial', 82345);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lansoprazole', 'A02BC03', 15, 'mg', 18515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lansoprazole', 'A02BC03', 30, 'mg', 18516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lansoprazole', 'A02BC03', 15, 'mg', 76617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lansoprazole', 'A02BC03', 30, 'mg', 76618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lansoprazole', 'A02BC03', 15, 'mg', 73429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lansoprazole', 'A02BC03', 30, 'mg', 73430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lansoprazole', 'A02BC03', 15, 'mg', 77919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lansoprazole', 'A02BC03', 30, 'mg', 77920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lansoprazole', 'A02BC03', 15, 'mg', 83904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lansoprazole', 'A02BC03', 30, 'mg', 83905);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lansoprazole', 'A02BC03', 15, 'mg', 84278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lansoprazole', 'A02BC03', 30, 'mg', 84279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lansoprazole', 'A02BC03', 30, 'mg', 85113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 36824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 85056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 34825);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 31477);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 12.5, 'mg', 27547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 27528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 24750);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 19820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 19951);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 17794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 17781);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 16067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 13447);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 13277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 13782);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 14223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 11762);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 12725);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 12743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 10874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 10875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 5363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 3266);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 3775);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 4253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 5187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 2552);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 1694);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 47391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 49235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 49476);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 48412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 48413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 48414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 62481);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 62482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 61145);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 61146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 62594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 60487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 62073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 63024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 64879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 64880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 69432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 68166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 12.5, 'mg', 73932);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 73933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 74279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 74280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 73828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 77809);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 78953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 78954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 12.5, 'mg', 81456);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 79190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 80667);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 80881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 79786);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 79541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25, 'mg', 83395);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg', 84371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 4.25, 'g / 100 ml', 10865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'D04AA32', 1, '%', 41558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'D04AA32', 2, '%', 14257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'D04AA32', 1, '%', 65100);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'D04AA32', 2, '%', 71812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'D04AA32', 2.0, '%', 76655);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'D04AA32', 2.0, '% / w/v', 76653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'D04AA32', 1, 'g / 100 ml', 70891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg / ml', 37198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 12.5, 'mg / 5 ml', 34247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 6.25, 'mg / 5 ml', 34604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 12.5, 'mg / 5 ml', 31478);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 12.5, 'mg / 5 ml', 19023);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 6.25, 'mg / 5 ml', 15880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 12.5, 'mg / 5 ml', 15516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg / ml', 15917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 2.5, 'mg / ml', 10486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 12.5, 'mg / 5 ml', 11772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg / ml', 11223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 12.5, 'mg / 5 ml', 11650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50, 'mg / ml', 5430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 6.25, 'mg / 5 ml', 64773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 6.25, 'mg / 5 ml', 71163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 6.25, 'mg / 5 ml', 71272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 12.5, 'mg / 5 ml', 78380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 12.5, 'mg / 5 ml', 80619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mycophenolate mofetil', 'L04AA06', 250, 'mg', 19525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mycophenolate mofetil', 'L04AA06', 500, 'mg', 60818);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mycophenolate mofetil (mycophenolate mofetil hydrochloride)', 'L04AA06', 500, 'mg / vial', 63885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mycophenolate mofetil', 'L04AA06', 200, 'mg / ml', 65823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamivudine', 'J05AF05', 150, 'mg', 19614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamivudine', 'J05AF05', 100, 'mg', 62649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamivudine', 'J05AF05', 300, 'mg', 72120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamivudine', 'J05AF05', 10, 'mg / ml', 19615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lamivudine', 'J05AF05', 5, 'mg / ml', 62650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phosphate-buffered saline (diluent)', 'L03AX03', 3, 'ml / vial', 20020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 83012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ganciclovir (ganciclovir sodium)', 'J05AB06', 500, 'mg / vial', 19553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('losartan potassium', 'C09CA01', 100, 'mg', 44255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('losartan potassium', 'C09CA01', 25, 'mg', 19167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('losartan potassium', 'C09CA01', 50, 'mg', 19168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bermuda grass', 'V01AA02', 10000, 'unit / ml', 66452);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('p-tert-butylphenol formaldehyde resin', 'V04CL', 0.041, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'S01XA20', 85, '%', 31093);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'S01XA20', 94, '%', 28169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'S01XA20', 55, '%', 17759);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'S01XA20', 55, '%', 18099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'S01XA20', 80, '%', 16777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AC', 100, '%', 13538);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AA', 6, '%', 11430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AA', 30, '%', 11936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AC', 100, '%', 10314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AC', 67, '%', 7127);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AC', 100, '%', 2259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AC', 50, '%', 60869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AC', 45.3, '%', 76643);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AC', 45.3, '%', 76644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AC', 55, '%', 72397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AC', 53.4, '% / w/w', 59943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AC', 98.79, '% / w/w', 81094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AC', 60.3, '% / w/w', 84162);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AC', 100, '%', 41756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AC', 100, '%', 9587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AC', 10.00, '%', 64111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AC', 95.96, '%', 63100);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('petrolatum', 'D02AC', 1000, 'g / kg', 62542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol denatured', 'V07AV', 71, '%', 15242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alcohol denatured', 'V07AV', 71.0, '%', 61020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosamprenavir (fosamprenavir calcium)', 'J05AE07', 700, 'mg', 74692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosamprenavir (fosamprenavir calcium)', 'J05AE07', 50, 'mg / ml', 74693);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylparaben', 'V04CL', 0.16, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethyl paraben', 'V04CL', 0.16, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium sulfate', 'B05XA05', 500, 'mg / ml', 19701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium sulfate', 'B05XA05', 500, 'mg / ml', 5614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium sulfate', 'B05XA05', 500, 'mg / ml', 3922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium sulfate', 'B05XA05', 200, 'mg / ml', 3088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium sulfate', 'B05XA05', 500, 'mg / ml', 2334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiamazole', 'H03BB02', 5, 'mg', 9);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiamazole', 'H03BB02', 5, 'mg', 74416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiamazole', 'H03BB02', 10, 'mg', 78139);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('disodium dodecyl diphenyloxide disulfonate', 'V07AV', 1.342, '%', 3629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.456, '%', 37819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 2.604, '%', 28516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.3, '%', 27724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 2.6, '%', 27725);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.05, '%', 26014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.302, '%', 21969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.66, '%', 20223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.302, '%', 20091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.216, '%', 20068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.1475, '%', 18016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.9, '%', 18733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.9, '%', 18713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.302, '%', 18714);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 2.604, '%', 18934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 2.604, '%', 16875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.24, '%', 15973);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.27, '%', 15972);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 2.3, '%', 15954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.302, '%', 14255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.9, '%', 13211);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.456, '%', 11922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.125, '%', 9822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.875, '%', 8461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.875, '%', 8435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.05, '%', 9621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.125, '%', 9323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.84, '%', 7079);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 2.0, '%', 6784);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.456, '%', 50870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.9, '%', 61859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 2.604, '%', 60432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.66, '%', 61178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 8.8, '%', 60895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.90, '%', 60956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.66, '%', 62416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.456, '%', 62417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 2.0, '%', 64299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.302, '%', 65191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.302, '%', 65192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 65845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 66379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.66, '%', 66174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 66940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.01, '%', 66995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 67048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 68309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 67512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 69105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 68144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 67651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 67652);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 67608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.84, '%', 67773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.6, '%', 68288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.01995, '%', 72148);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 72152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 72153);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 72154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 69931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.01, '%', 69957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.90, '%', 70000);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.015, '%', 70767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.06, '%', 71522);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.06, '%', 71523);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.0945, '%', 70268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.66, '%', 71698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.815, '%', 71713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.66, '%', 70365);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 69735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.90, '%', 70471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.010, '%', 70506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.6, '%', 71209);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.407, '%', 76443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.90, '%', 73896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.815, '%', 75206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.3, '%', 75242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 3.0, '%', 76631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 76639);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.012, '%', 76640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.66, '%', 76650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 72933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.66, '%', 76765);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.010, '%', 76777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 73035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 73036);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 73037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 72340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.026, '%', 75586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.012, '%', 75633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 2.604, '%', 73296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 73298);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 2.7648, '%', 76012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.66, '%', 76078);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.825, '%', 73405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.015, '%', 73470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.06, '%', 74943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 2.604, '%', 72770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 2.604, '%', 72771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.37, '%', 73858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 78114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.96, '%', 78400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 78415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.90, '%', 76873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.01995, '%', 78044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 78127);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.013, '%', 78230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 78233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.3, '%', 78236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 78238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.690, '%', 77005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.01, '%', 77006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 77874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 77412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.125, '%', 78017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 79846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.302, '%', 78933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.90, '%', 79260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.660, '%', 78783);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.5375, '%', 80095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.2, '%', 80737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.19, '%', 80738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 83038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.407, '%', 83039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.407, '%', 79106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.302, '%', 79881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.013, '%', 79882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.19, '%', 80754);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 81651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 80642);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 80646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 79562);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.2, '%', 80976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 3.0, '%', 80388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 81996);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.06, '%', 80216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.2, '%', 80532);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.012, '%', 82114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.2, '%', 83379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.63, '%', 83525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.013, '%', 83950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 84056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 84357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.125, '%', 84367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 7.62, '%', 84439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.2, '%', 84650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.628, '%', 85405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.660, '% / w/w', 77007);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.010, '% / w/w', 77008);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.01125, '% / w/w', 80866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.01995, '% / w/w', 79995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.628, '% / w/w', 79977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.628, '% / w/w', 80645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.01995, '% / w/w', 81994);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.628, '% / w/w', 85333);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 1.628, '% / w/w', 85423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dioctyl dimethyl ammonium chloride', 'V07AV', 0.156, 'mg / ml', 61680);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.14, '%', 37819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.51, '%', 28516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 27724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.51, '%', 27725);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.1, '%', 26014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 21969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.65, '%', 20223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 20091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.54, '%', 20068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.295, '%', 18016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.25, '%', 18733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.25, '%', 18713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 18714);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.51, '%', 18934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.51, '%', 16875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.48, '%', 15973);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.54, '%', 15972);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 4.6, '%', 15954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 14255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.8, '%', 13211);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.14, '%', 11922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.25, '%', 9822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.75, '%', 8461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.75, '%', 8435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.10, '%', 9621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.25, '%', 9323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.1, '%', 7079);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 5, '%', 6784);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.140, '%', 50870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.25, '%', 61859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.51, '%', 60432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.65, '%', 61178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.25, '%', 60956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.65, '%', 62416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.140, '%', 62417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 4.9, '%', 64299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 65191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 65192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 65845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 66379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.65, '%', 66174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 66940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.025, '%', 66995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 67048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 68309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.254, '%', 67512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 69105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 68144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 67651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.510, '%', 67652);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.510, '%', 67608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 4.6, '%', 67773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.5, '%', 68288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.0399, '%', 72148);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 72152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.510, '%', 72153);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 72154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 69931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.025, '%', 69957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.25, '%', 70000);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.03, '%', 70767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.64, '%', 71522);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.64, '%', 71523);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.1890, '%', 70268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.65, '%', 71698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.63, '%', 71713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.65, '%', 70365);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.510, '%', 69735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.25, '%', 70471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.025, '%', 70506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.5, '%', 71209);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 76443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.25, '%', 73896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.63, '%', 75206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.75, '%', 75242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.0, '%', 76631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 76639);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.03, '%', 76640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.65, '%', 76650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.510, '%', 72933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.65, '%', 76765);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.025, '%', 76777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.510, '%', 73035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 73036);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 73037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 72340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.054, '%', 75586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.03, '%', 75633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.51, '%', 73296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 73298);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.9120, '%', 76012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.65, '%', 76078);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.650, '%', 73405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.03, '%', 73470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.15, '%', 74943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.510, '%', 72770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.510, '%', 72771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.93, '%', 73858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 78114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.40, '%', 78400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 78415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.25, '%', 76873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 2, 'mg', 50229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.0399, '%', 78044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.510, '%', 78127);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.026, '%', 78230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 78233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.75, '%', 78236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 78238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 4.224, '%', 77005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.005, '%', 77006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 77874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 77412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.25, '%', 78017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 79846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 78933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.25, '%', 79260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.650, '%', 78783);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.0750, '%', 80095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3, '%', 80737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.48, '%', 80738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 83038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 83039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.814, '%', 79106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 79881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.026, '%', 79882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.48, '%', 80754);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.510, '%', 81651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.510, '%', 80642);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 80646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 79562);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.4, '%', 80976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.0, '%', 80388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 81996);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.12, '%', 80216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.4, '%', 80532);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.03, '%', 82114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.4, '%', 83379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.25, '%', 83525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.026, '%', 83950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.627, '%', 84056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 6.510, '%', 84357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.250, '%', 84367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 15.24, '%', 84439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 2.4, '%', 84650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 300, 'mg', 5196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '%', 85405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 1.650, '% / w/w', 77007);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.025, '% / w/w', 77008);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.0225, '% / w/w', 80866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.03990, '% / w/w', 79995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '% / w/w', 79977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '% / w/w', 80645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.03990, '% / w/w', 81994);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '% / w/w', 85333);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 3.255, '% / w/w', 85423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octyl decyl dimethyl ammonium chloride', 'V07AV', 0.260, 'mg / ml', 61680);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ribavirin', 'J05AB04', 6, 'g / vial', 34574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 43383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 43969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 1, 'mg', 43970);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 2, 'mg', 43971);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 43888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 19628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 18849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 2, 'mg', 18850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 2, 'mg', 18366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.25, 'mg', 19221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 19063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 2, 'mg', 19048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 17142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 2, 'mg', 17145);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 1, 'mg', 14587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 14588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 2, 'mg', 14589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 2568);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 2, 'mg', 2569);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 49164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 2.0, 'mg', 49167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 1.0, 'mg', 49166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 50228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 53892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 1, 'mg', 54229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 2, 'mg', 54230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 60241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 2, 'mg', 62476);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 62475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 2, 'mg', 65752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 65751);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 75602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 1.0, 'mg', 75603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 2.0, 'mg', 75604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 79715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 1, 'mg', 79716);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 2, 'mg', 79718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 1, 'mg', 83010);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 2, 'mg', 83011);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 1, 'mg', 78865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 2, 'mg', 78866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg', 83110);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prazosin hydrochloride', 'C02CA01', 1, 'mg', 12451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prazosin hydrochloride', 'C02CA01', 2, 'mg', 12452);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prazosin hydrochloride', 'C02CA01', 5, 'mg', 12453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prazosin hydrochloride', 'C02CA01', 1, 'mg', 12694);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prazosin hydrochloride', 'C02CA01', 2, 'mg', 12695);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prazosin hydrochloride', 'C02CA01', 5, 'mg', 12696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mitomycin', 'L01DC03', 5, 'mg / vial', 49399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mitomycin', 'L01DC03', 20, 'mg / vial', 49400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mitomycin', 'L01DC03', 20, 'mg / vial', 49991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mitomycin', 'L01DC03', 5, 'mg / vial', 61099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protirelin', 'V04CJ02', 200, 'µg / ml', 37362);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peracetic acid', 'V07AV', 4, '%', 18687);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peracetic acid', 'V07AV', 0.06, '%', 13689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peracetic acid', 'V07AV', 35, '%', 12252);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peracetic acid', 'V07AV', 0.08, '%', 48981);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peracetic acid', 'V07AV', 5, '%', 63904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peracetic acid', 'V07AV', 2.0, '%', 78600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peracetic acid', 'V07AV', 5.1, '%', 70105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peracetic acid', 'V07AV', 4.50, '%', 76311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peracetic acid', 'V07AV', 5, '%', 80386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peracetic acid', 'V07AV', 0.23, '%', 82224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peracetic acid', 'V07AV', 0.08, '%', 80714);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peracetic acid', 'V07AV', 0.06, '%', 83744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peracetic acid', 'V07AV', 5.1, '% / w/w', 81863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peracetic acid', 'V07AV', 0.050, '% / w/w', 80441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peracetic acid', 'V07AV', 5.3, '% / w/w', 83975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peracetic acid', 'V07AV', 6.8, '% / w/w', 84438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ortho-phthalaldehyde', 'V07AV', 0.55, '%', 63214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ortho-phthalaldehyde', 'V07AV', 5.75, '%', 76392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('collagenase', 'D03BA02', 250, 'unit / g', 16678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate', 'H01BA02', 0.1, 'mg', 19436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate', 'H01BA02', 0.2, 'mg', 19441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate', 'H01BA02', 0.1, 'mg', 70677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate', 'H01BA02', 0.1, 'mg', 74293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate', 'H01BA02', 0.2, 'mg', 74294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate', 'H01BA02', 0.1, 'mg', 77313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate', 'H01BA02', 0.2, 'mg', 77314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate', 'H01BA02', 0.1, 'mg', 76960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate', 'H01BA02', 0.2, 'mg', 76961);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate', 'H01BA02', 10, 'µg / spray', 66190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate', 'H01BA02', 10, 'µg / act', 9861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate', 'H01BA02', 150, 'µg / act', 61220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate', 'H01BA02', 15, 'µg / ml', 18289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate', 'H01BA02', 4, 'µg / ml', 13867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate', 'H01BA02', 0.1, 'mg / ml', 14413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 300, 'mg', 43457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 400, 'mg', 43458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 600, 'mg', 43459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 800, 'mg', 43460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 600, 'mg', 11958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 400, 'mg', 11959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 300, 'mg', 11960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 200, 'mg', 11961);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 800, 'mg', 8588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 400, 'mg', 5434);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 600, 'mg', 5435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 400, 'mg', 5361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 600, 'mg', 5362);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 600, 'mg', 6265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 800, 'mg', 7312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 200, 'mg', 5195);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 300, 'mg', 5152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 200, 'mg', 47892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 300, 'mg', 47893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 400, 'mg', 47894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 600, 'mg', 47895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 800, 'mg', 47896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 300, 'mg', 50597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 400, 'mg', 50598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine', 'A02BA01', 600, 'mg', 50600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cimetidine (cimetidine hydrochloride)', 'A02BA01', 300, 'mg / 5 ml', 66952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 20187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 20188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 20310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 20311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 17831);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 17833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 11188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 11189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 8602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 8603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 9887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 9886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 6611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 6612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 6512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 6513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 5818);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 5819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 6311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 200, 'mg', 5091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 2738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 2739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 50067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 50068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 50428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 50429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 72183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 72185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 25, 'mg', 70136);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 25, 'mg', 73226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 25, 'mg', 73713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 73847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 25, 'mg', 73846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 73848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 77067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 200, 'mg', 77068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 25, 'mg', 78208);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 25, 'mg', 78738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 25, 'mg', 80085);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 80086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 80087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 78871);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 200, 'mg', 78872);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 25, 'mg', 80066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 80067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 80068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 83560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 83561);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 83667);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 200, 'mg', 83668);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 83938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 83939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 25, 'mg', 84194);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 50, 'mg', 84195);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 100, 'mg', 84196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 1, 'mg / 1 ml', 7357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 1, 'mg / ml', 7325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoprolol tartrate', 'C07AB02', 1, 'mg / 1 ml', 75326);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diflunisal', 'N02BA11', 500, 'mg', 15823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diflunisal', 'N02BA11', 250, 'mg', 15826);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diflunisal', 'N02BA11', 250, 'mg', 14751);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diflunisal', 'N02BA11', 500, 'mg', 14752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diflunisal', 'N02BA11', 500, 'mg', 14553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diflunisal', 'N02BA11', 250, 'mg', 14554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid', 'N03AG01', 500, 'mg', 43234);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid', 'N03AG01', 250, 'mg', 43211);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid', 'N03AG01', 250, 'mg', 19664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid', 'N03AG01', 250, 'mg', 18804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid', 'N03AG01', 250, 'mg', 18998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 125, 'mg', 5676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 250, 'mg', 5677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 500, 'mg', 5678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid', 'N03AG01', 250, 'mg', 3112);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid', 'N03AG01', 500, 'mg', 47553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid', 'N03AG01', 500, 'mg', 50820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid', 'N03AG01', 250, 'mg', 50311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid', 'N03AG01', 500, 'mg', 50312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid', 'N03AG01', 250, 'mg', 50031);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid', 'N03AG01', 250, 'mg', 61189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid', 'N03AG01', 250, 'mg', 61972);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid', 'N03AG01', 250, 'mg', 61432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 125, 'mg', 63179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 125, 'mg', 63182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 250, 'mg', 63183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 500, 'mg', 63184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid', 'N03AG01', 250, 'mg', 63196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 125, 'mg', 63881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 250, 'mg', 63882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 500, 'mg', 63883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 125, 'mg', 68099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 250, 'mg', 68100);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 500, 'mg', 68101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 125, 'mg', 69859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 250, 'mg', 69860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 500, 'mg', 69861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid', 'N03AG01', 250, 'mg', 74609);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid', 'N03AG01', 500, 'mg', 74610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 125, 'mg', 75063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 250, 'mg', 75064);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 500, 'mg', 75065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 125, 'mg', 77946);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 250, 'mg', 77947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 500, 'mg', 77948);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 250, 'mg / ect', 63180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 500, 'mg / ect', 63181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 125, 'mg / ect', 62993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 250, 'mg / ect', 62994);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 500, 'mg / ect', 62995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (sodium valproate)', 'N03AG01', 50, 'mg / ml', 43944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (sodium valproate)', 'N03AG01', 50, 'mg / ml', 3156);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (sodium valproate)', 'N03AG01', 250, 'mg / 5 ml', 60096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (sodium valproate)', 'N03AG01', 250, 'mg / 5 ml', 62254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (sodium valproate)', 'N03AG01', 250, 'mg / 5 ml', 61603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valproic acid (sodium valproate)', 'N03AG01', 50, 'mg / ml', 61782);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triazolam', 'N05CD05', 0.125, 'mg', 9574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('triazolam', 'N05CD05', 0.25, 'mg', 9575);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('colestipol hydrochloride', 'C10AC02', 1, 'g', 18627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('colestipol hydrochloride', 'C10AC02', 5, 'g / pck', 18552);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('colestipol hydrochloride', 'C10AC02', 5, 'g / pck', 7199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulindac', 'M01AB02', 150, 'mg', 16293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulindac', 'M01AB02', 200, 'mg', 16294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulindac', 'M01AB02', 150, 'mg', 9238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulindac', 'M01AB02', 200, 'mg', 9239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulindac', 'M01AB02', 150, 'mg', 8592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulindac', 'M01AB02', 200, 'mg', 8593);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', 'D11AX11', 3.3, '%', 16272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', 'D11AX11', 3.3, '%', 61544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', 'D11AX11', 8, '%', 69834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('padimate o', 'D11AX11', 8.0, '% / w/w', 80453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flunisolide', 'R01AD04', 25, 'µg / act', 19650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flunisolide', 'R01AD04', 0.25, 'mg / ml', 62753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mycophenolic acid (mycophenolate sodium)', 'L04AA06', 180, 'mg', 75000);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mycophenolic acid (mycophenolate sodium)', 'L04AA06', 360, 'mg', 75001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('patent blue sodium', 'V04CX', 50, 'mg / 2 ml', 3486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('charcoal activated', 'A07BA01', 260, 'mg', 22917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('charcoal activated', 'A07BA01', 225, 'mg', 59931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('charcoal activated', 'A07BA01', 170, 'mg', 80809);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('charcoal activated', 'A07BA01', 260, 'mg', 79065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('charcoal activated', 'A07BA01', 100, '%', 67893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('charcoal activated', 'A07BA01', 50, 'g / 225 ml', 6317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('charcoal activated', 'A07BA01', 50, 'g / 250 ml', 7267);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('charcoal activated', 'A07BA01', 200, 'mg / ml', 29506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('charcoal activated', 'A07BA01', 200, 'mg / ml', 29507);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('charcoal activated', 'A07BA01', 200, 'mg / ml', 17399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('charcoal activated', 'A07BA01', 222, 'mg / ml', 16533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('charcoal activated', 'A07BA01', 200, 'mg / ml', 6393);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('charcoal activated', 'A07BA01', 1, 'g / 1 g', 62983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('coagulation factor ix (human)', 'B02BD04', 720, 'unit / 5 ml', 43011);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 250, 'mg', 44074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 500, 'mg', 44075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 750, 'mg', 44076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 7.5, 'mg', 76241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 250, 'mg', 44057);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 500, 'mg', 44058);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 750, 'mg', 44059);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 250, 'mg', 47426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 500, 'mg', 47427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 750, 'mg', 47428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride, ciprofloxacin)', 'J01MA02', 500, 'mg', 72225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 250, 'mg', 71582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 500, 'mg', 71583);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 750, 'mg', 71584);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 250, 'mg', 71025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 500, 'mg', 71026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 750, 'mg', 71027);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 250, 'mg', 69747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 500, 'mg', 69748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 750, 'mg', 69749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 250, 'mg', 72788);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 500, 'mg', 72789);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 750, 'mg', 72790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 250, 'mg', 75238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 500, 'mg', 75239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 250, 'mg', 73124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 500, 'mg', 73125);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 750, 'mg', 73126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 250, 'mg', 73618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 500, 'mg', 73619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 750, 'mg', 73620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 250, 'mg', 73622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 500, 'mg', 73623);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 750, 'mg', 73624);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 250, 'mg', 73626);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 500, 'mg', 73627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 750, 'mg', 73628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride, ciprofloxacin)', 'J01MA02', 1000, 'mg', 73669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 250, 'mg', 80332);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 500, 'mg', 80333);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 250, 'mg', 78902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 500, 'mg', 78903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 750, 'mg', 78904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 250, 'mg', 80295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 500, 'mg', 80296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 750, 'mg', 80297);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 250, 'mg', 83851);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 500, 'mg', 83852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'J01MA02', 750, 'mg', 83853);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'S01AX13', 0.3, '%', 12953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'S01AX13', 0.3, '%', 73887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'S01AX13', 0.3, '%', 74854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin (ciprofloxacin lactate)', 'J01MA02', 0.2, '%', 78663);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin', 'J01MA02', 10, 'g / 100 ml', 60849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin', 'J01MA02', 2.0, 'mg / ml', 75287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin', 'J01MA02', 10, 'mg / ml', 74200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin', 'J01MA02', 2, 'mg / ml', 78723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin', 'J01MA02', 2, 'mg / ml', 78981);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin', 'J01MA02', 2, 'mg / ml', 79003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ritonavir', 'J05AE03', 100, 'mg', 65120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ritonavir', 'J05AE03', 100, 'mg', 84270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ritonavir', 'J05AE03', 80, 'mg / ml', 43516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desflurane', 'N01AB07', 1, 'ml / ml', 43455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 2.5, 'mg', 43530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5, 'mg', 43531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 7.5, 'mg', 43532);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10, 'mg', 43533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15, 'mg', 62290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 20, 'mg', 62291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5, 'mg', 66953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10, 'mg', 66954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15, 'mg', 66955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 20, 'mg', 66956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 2.5, 'mg', 76745);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5.0, 'mg', 76746);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 7.5, 'mg', 76747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10.0, 'mg', 76748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15.0, 'mg', 76749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10, 'mg', 76242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15, 'mg', 76243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 2.5, 'mg', 76239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5, 'mg', 76240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 2.5, 'mg', 82351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5, 'mg', 82352);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 7.5, 'mg', 82353);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10, 'mg', 82354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15, 'mg', 82355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 20, 'mg', 82356);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 20.0, 'mg', 81866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 2.5, 'mg', 79749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5, 'mg', 79750);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 7.5, 'mg', 79751);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10, 'mg', 79752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15, 'mg', 79753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 2.5, 'mg', 81102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5, 'mg', 81103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 7.5, 'mg', 81104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10, 'mg', 81105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15, 'mg', 81106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 20, 'mg', 81107);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 2.5, 'mg', 79599);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5.0, 'mg', 79600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 7.5, 'mg', 79601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10.0, 'mg', 79602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15.0, 'mg', 79603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5, 'mg', 80674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10, 'mg', 80675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15, 'mg', 80676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 20, 'mg', 80677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 2.5, 'mg', 78844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5, 'mg', 78848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 7.5, 'mg', 78849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10, 'mg', 78850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15, 'mg', 78851);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5, 'mg', 78852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10, 'mg', 78853);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15, 'mg', 78854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 2.5, 'mg', 79308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5, 'mg', 79309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 7.5, 'mg', 79310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10, 'mg', 79311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15, 'mg', 79312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5, 'mg', 79313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10, 'mg', 79314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15, 'mg', 79315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5, 'mg', 81288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10, 'mg', 81289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15, 'mg', 81290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 20, 'mg', 81291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5, 'mg', 81318);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10, 'mg', 81319);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15, 'mg', 81320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 20, 'mg', 81321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 2.5, 'mg', 82273);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5, 'mg', 82274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 7.5, 'mg', 82275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10, 'mg', 82276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15, 'mg', 82277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5, 'mg', 82431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10, 'mg', 82432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15, 'mg', 82433);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 5, 'mg', 82535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 10, 'mg', 82540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 15, 'mg', 82541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine', 'N05AH03', 20, 'mg', 84470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olanzapine (olanzapine tartrate)', 'N05AH03', 10, 'mg / vial', 71336);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('anastrozole', 'L02BG03', 1, 'mg', 43395);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', 'D11AX11', 4, '%', 41955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', 'D11AX11', 4, '%', 41956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', 'D11AX11', 4, '%', 41957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', 'D11AX11', 2.5, '%', 16272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', 'D11AX11', 2.5, '%', 61544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', 'D11AX11', 4, '%', 72192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', 'D11AX11', 3, '%', 69834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', 'D11AX11', 5.5, '%', 76383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', 'D11AX11', 3, '%', 75425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', 'D11AX11', 3.0, '%', 74229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', 'D11AX11', 5.5, '%', 73488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', 'D11AX11', 4.0, '% / w/w', 80960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', 'D11AX11', 4.0, '% / w/w', 80453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxybenzone', 'D11AX11', 4, 'g / 100 g', 15518);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meropenem', 'J01DH02', 1, 'g / vial', 43254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('meropenem', 'J01DH02', 500, 'mg / vial', 43253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 5, '%', 21687);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 50, '%', 17398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'V07AB', 0.092, '%', 4913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 81241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 40, '%', 22423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 222.7, 'g / pck', 18319);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'V07AC', 2, 'g / 63 ml', 23039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 40, 'g / 100 ml', 18823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 50, 'g / 100 ml', 18824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 33.3, 'g / 100 ml', 18825);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 13.3, 'g / 100 ml', 18826);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 20, 'g / 100 ml', 18827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 70, 'g / 100 ml', 18686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'C01DA02', 5, 'g / 100 ml', 18085);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'C01DA02', 5, 'g / 100 ml', 18086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'C01DA02', 5, 'g / 100 ml', 18087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 5, 'g / 100 ml', 10511);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 5, 'g / 100 ml', 10924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 1.5, 'g / 100 ml', 10863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 2.5, 'g / 100 ml', 10864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'V07AC', 2.45, 'g / 100 ml', 11376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'V07AC', 1.47, 'g / 100 ml', 11354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 4.25, 'g / 100 ml', 10143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 1.5, 'g / 100 ml', 10144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 2.5, 'g / 100 ml', 10009);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 10, 'g / 100 ml', 59976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 700, 'mg / ml', 21689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 200, 'mg / ml', 15538);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 500, 'mg / ml', 15539);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 50, 'mg / ml', 13714);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 100, 'mg / ml', 14251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'C01BB01', 50, 'mg / ml', 10518);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'C01BB01', 50, 'mg / ml', 10519);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'C01BB01', 50, 'mg / ml', 10520);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 500, 'mg / 100 ml', 10512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 250, 'mg / ml', 6260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 400, 'mg / ml', 3819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 200, 'mg / ml', 3747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'C01BB01', 50, 'mg / ml', 5339);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'C01BB01', 50, 'mg / ml', 5340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 700, 'mg / ml', 3585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 500, 'mg / ml', 1746);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 100, 'mg / ml', 1748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05BA03', 50, 'mg / ml', 2902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 89.99, 'g / l', 36836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 112.53, 'g / l', 36814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 90, 'g / l', 34881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 45, 'g / l', 34878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 45, 'g / l', 34879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 90, 'g / l', 19744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 89.99, 'g / l', 19735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 90, 'g / l', 20121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 67.5, 'g / l', 20115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 45, 'g / l', 20116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 67.5, 'g / l', 20118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 45, 'g / l', 20119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 45, 'g / l', 20111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 45, 'g / l', 20114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 90, 'g / l', 19739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 90, 'g / l', 20076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 45, 'g / l', 20044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 45, 'g / l', 20046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 67.5, 'g / l', 20040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 90, 'g / l', 20041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leflunomide', 'L04AA13', 10, 'mg', 76953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 90, 'g / l', 18268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 45, 'g / l', 18206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 90, 'g / l', 18202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 45, 'g / l', 18199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 45, 'g / l', 18200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 45, 'g / l', 18167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 45, 'g / l', 10820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 67.5, 'g / l', 9854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 45.0, 'g / l', 9852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 45, 'g / l', 9848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 67.5, 'g / l', 9845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 89.99, 'g / l', 9131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 89.99, 'g / l', 9130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 89.99, 'g / l', 9129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 67.54, 'g / l', 10114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 67.54, 'g / l', 10115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 67.54, 'g / l', 8585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 67.5, 'g / l', 8586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 90, 'g / l', 62960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 90, 'g / l', 62965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 90.0, 'g / l', 66299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 37.5, 'g / l', 71993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 62.6, 'g / l', 71997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 105.5, 'g / l', 71998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 74.25, 'g / l', 73901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 99.0, 'g / l', 73902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 99.0, 'g / l', 73903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 99.0, 'g / l', 73904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 99.0, 'g / l', 73905);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 99.0, 'g / l', 73915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.5, 'g / l', 73916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.5, 'g / l', 73917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.5, 'g / l', 73919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.5, 'g / l', 73921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.5, 'g / l', 73922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.5, 'g / l', 73923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.5, 'g / l', 73924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 99.0, 'g / l', 73925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 99.0, 'g / l', 73927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 74.25, 'g / l', 73929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.5, 'g / l', 75411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.5, 'g / l', 75804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.5, 'g / l', 75805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.5, 'g / l', 75811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.5, 'g / l', 75812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 99, 'g / l', 73193);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 99.0, 'g / l', 74785);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.5, 'g / l', 74787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 99.0, 'g / l', 74790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 74.25, 'g / l', 74791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 74.25, 'g / l', 74792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 74.25, 'g / l', 74793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81573);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 74.28, 'g / l', 81236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 98.99, 'g / l', 81238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 74.28, 'g / l', 81577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 74.28, 'g / l', 81579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 74.28, 'g / l', 81580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 74.28, 'g / l', 81224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 98.99, 'g / l', 81225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 98.99, 'g / l', 81280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 98.99, 'g / l', 81593);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 98.99, 'g / l', 81594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 98.99, 'g / l', 81240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 74.28, 'g / l', 81241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.49, 'g / l', 81275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.05, 'g / l', 80217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 98.99, 'g / l', 80218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.5, 'g / l', 85140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.5, 'g / l', 85141);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose', 'B05ZA', 49.5, 'g / l', 85142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'A12BA01', 1.5, 'g', 9588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'A12BA01', 600, 'mg', 5975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'A12BA01', 600, 'mg', 4739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'A12BA01', 600, 'mg', 889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'S01XA20', 0.075, '%', 15177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'V07AB', 0.075, '%', 7474);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'V07AB', 0.075, '%', 6366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'V07AB', 0.038, '%', 4913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 0.157, 'g / 1000 ml', 76308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 0.314, 'g / 1000 ml', 76310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05XA01', 20, 'meq / 10 ml', 3394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'A12BA01', 100, 'mg / ml', 15227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'V07AC', 30, 'mg / 100 ml', 11330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05XA01', 149, 'mg / ml', 2527);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05XA01', 14.9, 'mg / ml', 65337);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05XA01', 29.8, 'mg / ml', 65339);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05XA01', 7.46, 'mg / ml', 65336);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.06, 'g / l', 36836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 8.39, 'g / l', 36814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.7, 'g / l', 34878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 34881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 5.02, 'g / l', 19744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.7, 'g / l', 20121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.7, 'g / l', 20116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.7, 'g / l', 20118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.7, 'g / l', 20119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 20111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 20114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 5.02, 'g / l', 20115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.06, 'g / l', 19739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 19735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10, 'g / l', 20044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 20045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 20046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.7, 'g / l', 20040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10, 'g / l', 20041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.7, 'g / l', 18268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 18206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 18202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 5.02, 'g / l', 18199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 5.02, 'g / l', 18200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 251.6, 'g / l', 13833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.05, 'g / l', 10820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 9854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.1, 'g / l', 9852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.06, 'g / l', 9131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 9129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 9130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 10115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.06, 'g / l', 8586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 8585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 0.298, 'g / l', 49559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 0.149, 'g / l', 49560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 62960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.1, 'g / l', 62964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.1, 'g / l', 62965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 13.42, 'g / l', 66299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.1, 'g / l', 73902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 5.02, 'g / l', 73903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 73904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 5.02, 'g / l', 73905);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 73915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 73916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 73917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 73919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.1, 'g / l', 73921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.1, 'g / l', 73922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 73923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 73924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 73925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 73927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 5.02, 'g / l', 73929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 13.47, 'g / l', 75411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.70, 'g / l', 75811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.70, 'g / l', 75812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.1, 'g / l', 73193);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 74785);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 74787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.1, 'g / l', 74790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.1, 'g / l', 74791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 74792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 74793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 0.398, 'g / l', 78012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.36, 'g / l', 81573);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 5.03, 'g / l', 81574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.36, 'g / l', 81578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 81236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 5.03, 'g / l', 81237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 81238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 81262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.06, 'g / l', 81265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 81270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.355, 'g / l', 81271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 8.39, 'g / l', 81272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.06, 'g / l', 81577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 81579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 81580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 81227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.06, 'g / l', 81225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 81280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.06, 'g / l', 81282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 81592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 81593);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 81594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.06, 'g / l', 81595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.36, 'g / l', 81596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 81598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 5.03, 'g / l', 81600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 81601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.36, 'g / l', 81602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.36, 'g / l', 81279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 81281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 81283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.06, 'g / l', 81284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.06, 'g / l', 81240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 81241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 81275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 80217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 80218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 8.39, 'g / l', 81222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g / l', 85140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g / l', 85141);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium chloride', 'B05ZA', 10.1, 'g / l', 85142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'V07AB', 73.5, 'mg', 50130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'A07EA06', 115, 'ml', 16264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'R01AX10', 10, '%', 18738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'R01AX10', 0.45, '%', 18743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'R01AX30', 0.9, '%', 17778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'S01XA20', 0.64, '%', 15177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'R01AX10', 3, '%', 16829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'R01AX10', 0.9, '%', 16830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05CB01', 0.9, '%', 13286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 0.9, '%', 12185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'V07AB', 0.64, '%', 7474);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'V07AB', 0.64, '%', 6366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'V07AB', 0.714, '%', 4913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'V07AB', 0.9, '%', 1911);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'V07AB', 0.9, '%', 1912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 0.9, '%', 83557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 0.9, '% / w/v', 79733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 5, 'g / 100 ml', 15492);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 3, 'g / 100 ml', 11039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 5, 'g / 100 ml', 11040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05CB01', 12, 'g / 100 ml', 12168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05CB01', 1.6, 'g / 100 ml', 12169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 5.38, 'g / 1000 ml', 70916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 5.38, 'g / 1000 ml', 70916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 5.38, 'g / 1000 ml', 70916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 5.38, 'g / 1000 ml', 70917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 5.38, 'g / 1000 ml', 70917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 5.38, 'g / 1000 ml', 70917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 6.449, 'g / 1000 ml', 76040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 6.450, 'g / 1000 ml', 76308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 6.450, 'g / 1000 ml', 76310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 6.45, 'g / 1000 ml', 66962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 234, 'mg / ml', 18937);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 9, 'mg / ml', 18136);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 4.5, 'mg / ml', 14579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 567, 'mg / 100 ml', 10512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'R01AX30', 9, 'mg / ml', 11232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 450, 'mg / 100 ml', 10442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'J01GB03', 9, 'mg / ml', 12674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'J01GB03', 9, 'mg / ml', 12675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 538, 'mg / 100 ml', 10863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 538, 'mg / 100 ml', 10864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 538, 'mg / 100 ml', 10865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05CB01', 900, 'mg / 100 ml', 9825);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'V07AB', 9, 'mg / ml', 8276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 567, 'mg / 100 ml', 10143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 567, 'mg / 100 ml', 10144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 567, 'mg / 100 ml', 10009);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 900, 'mg / 100 ml', 10040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'V04CX', 4.4, 'mg / ml', 5984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'V07AB', 9, 'mg / ml', 78963);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'V07AB', 9, 'mg / ml', 4792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 9, 'mg / ml', 4092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 234, 'mg / ml', 3395);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 9, 'mg / ml', 3396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 146, 'mg / ml', 1848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05CB01', 9, 'mg / ml', 1239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 50, 'mg / ml', 1735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 4.5, 'mg / ml', 1736);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 234, 'mg / ml', 3009);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05XA03', 9, 'mg / ml', 817);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05CB01', 9, 'mg / ml', 228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05CB01', 9, 'mg / ml', 115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 538, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'V07AB', 9, 'mg / ml', 76534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 262.98, 'g / l', 36836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 81240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 262.98, 'g / l', 36814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 34878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 34879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 34881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 275, 'g / l', 19744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 20121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 20116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 20118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 20119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 20111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 20114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 20115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 275, 'g / l', 19739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 268.24, 'g / l', 19735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 20076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 20044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 20045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 20046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 20040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 20041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 18268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 18206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 18202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 18199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 18200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 18167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 10820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 9854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 9852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 9848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 9845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 268.24, 'g / l', 9131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 268.24, 'g / l', 9129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 268.24, 'g / l', 9130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 10115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 10114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 8586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 8585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 5.844, 'g / l', 49558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 5.844, 'g / l', 49559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 5.961, 'g / l', 49560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 268, 'g / l', 62960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 62964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 268, 'g / l', 62965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 66299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 82.84, 'g / l', 67542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 8.43, 'g / l', 71993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 8.43, 'g / l', 71997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 8.43, 'g / l', 71998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 275.0, 'g / l', 73901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 268.0, 'g / l', 73902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 275.0, 'g / l', 73903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 275.0, 'g / l', 73904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 275.0, 'g / l', 73905);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 73915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 73916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 73917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 73919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 73921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 73922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 73923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 73924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 268.0, 'g / l', 73925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 268.0, 'g / l', 73927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 275.0, 'g / l', 73929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 75411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 289.3, 'g / l', 75804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 75805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 289.3, 'g / l', 75811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 75812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 275, 'g / l', 73193);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 74785);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 74787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 74790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 74791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 74792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 74793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 90.73, 'g / l', 76226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 7.66, 'g / l', 78010);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 7.66, 'g / l', 78012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81573);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 81236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 81238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 289.3, 'g / l', 81270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 262.99, 'g / l', 81271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 81579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 81580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 81225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 289.3, 'g / l', 81226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 81280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81593);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 289.3, 'g / l', 81598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 276.1, 'g / l', 81600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 81240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 81275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263.0, 'g / l', 80217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 80218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 273.5, 'g / l', 81222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 85140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 85141);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'B05ZA', 263, 'g / l', 85142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'H01CB01', 9, 'mg / kit', 43833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'H01AC01', 5, 'ml / kit', 43151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chloride', 'R01AX30', 9, 'mg / g', 10299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('abciximab', 'B01AC13', 2, 'mg / ml', 43196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('stavudine', 'J05AF04', 15, 'mg', 20322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('stavudine', 'J05AF04', 40, 'mg', 20323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('stavudine', 'J05AF04', 30, 'mg', 20324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('stavudine', 'J05AF04', 20, 'mg', 20325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('daunorubicin (daunorubicin hydrochloride)', 'L01DB02', 20, 'mg / vial', 13226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('daunorubicin (daunorubicin hydrochloride)', 'L01DB02', 20, 'mg / vial', 50738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfur', 'D05AA', 2.0, '%', 13014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfur', 'D05AA', 2, '%', 3320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leflunomide', 'L04AA13', 20, 'mg', 74174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gadobutrol', 'V08CA09', 604.72, 'mg / ml', 64684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temozolomide', 'L01AX03', 5, 'mg', 64696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temozolomide', 'L01AX03', 20, 'mg', 64697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temozolomide', 'L01AX03', 100, 'mg', 64698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temozolomide', 'L01AX03', 250, 'mg', 64699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temozolomide', 'L01AX03', 140, 'mg', 79831);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temozolomide', 'L01AX03', 100, 'mg / vial', 80666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rosiglitazone (rosiglitazone maleate)', 'A10BG02', 2, 'mg', 64716);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rosiglitazone (rosiglitazone maleate)', 'A10BG02', 4, 'mg', 64717);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rosiglitazone (rosiglitazone maleate)', 'A10BG02', 8, 'mg', 64718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propylparaben', 'V04CL', 0.16, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 17.20, '%', 37547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 15, '%', 19302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 17.20, '%', 20013);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 8, '%', 15830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 1.18, '%', 16133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 5.54, '%', 3829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 53.41, '%', 3797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 21.0, '%', 67128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 14.85, '%', 66387);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 17.20, '%', 65889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 15.3, '%', 65545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 70, '%', 67366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 70, '%', 67367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 14.85, '%', 67389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 21.0, '%', 67640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 17.20, '%', 70138);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 8, '%', 70460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'D08AC02', 4, '%', 71177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 8.00, '%', 76460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 20.0, '%', 75711);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 20.0, '%', 75722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 14.85, '%', 73675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 70, '%', 76263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 70.0, '%', 77442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 45.60, '%', 77124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 21.0, '%', 77845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 8, '%', 80305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 21.0, '%', 80458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 21.00, '%', 80336);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 21.0, '%', 83957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 21.0, '%', 84554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 5.0, '% / w/w', 16228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 5.0, '% / w/w', 5740);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 5.0, '% / w/w', 83578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 21.0, '% / w/v', 80304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isopropyl alcohol', 'V07AV', 21.0, '% / w/v', 83956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butylparaben', 'V04CL', 0.16, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'A06AA01', 100, '%', 41536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'S01XA20', 15, '%', 31093);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'S01XA20', 3, '%', 28169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'A06AA01', 78, '%', 20312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'S01XA20', 42.5, '%', 17759);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'S01XA20', 42.5, '%', 18099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'S01XA20', 20, '%', 16777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'S01XA20', 42.5, '%', 9820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'A06AA01', 78, '%', 5792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'D02AC', 80, '%', 2256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'A06AA01', 100, '%', 721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'D02AC', 100, '%', 57);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'A06AA01', 100, '%', 41698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'D02AC', 63.4, '%', 16438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'D02AC', 91.7, '%', 12947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'D02AC', 100, '%', 14042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'A06AA01', 100, '%', 11629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'D02AC', 12, '%', 2536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mineral oil', 'D02AC', 7.00, '%', 64111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrogen', 'V03AN05', 76.5, '%', 19291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrogen', 'V03AN04', 99, '%', 19292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrogen', 'V03AN04', 99, '%', 13882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrogen', 'V03AN04', 100, '%', 5683);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrogen', 'V03AN04', 99.0, '%', 5221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrogen', 'V03AN04', 99.5, '%', 72506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrogen', 'V03AN04', 100, '%', 78261);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'V07AV', 9, '%', 80386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'V07AV', 4.9, '%', 82224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 36836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 5.4, 'g / l', 36814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 34881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 34878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 34879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 19744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 8.11, 'g / l', 19735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 20121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 20115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 20116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 20118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 20119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 20111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 20114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 19739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 20076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 20044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 20045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 20046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 20040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 20041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 18268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 18206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 18202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 8.11, 'g / l', 18199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 5.41, 'g / l', 18200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 18167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 10820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 9854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 9852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 9848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 9845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 8.11, 'g / l', 9131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 8.11, 'g / l', 9129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 8.11, 'g / l', 9130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 10114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 10115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 8585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 8586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 8.11, 'g / l', 62960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 62964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 8.11, 'g / l', 62965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 66299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 73901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 73902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 8.11, 'g / l', 73903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 73904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 73905);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 73915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 73916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 73917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 73919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 73921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 73922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 73923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 73924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 73925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 73927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 73929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 75411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 75804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 75805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 8.11, 'g / l', 75811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 75812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 8.11, 'g / l', 73193);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 74785);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 74787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 74790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 74791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 74792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 74793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81573);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 81236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 81237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 81238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 8.1, 'g / l', 81270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 81271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 81577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 81579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 81580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 81224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 81225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 81280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81593);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 8.1, 'g / l', 81598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 8.1, 'g / l', 81600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.8, 'g / l', 81275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 80217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 10.81, 'g / l', 80218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acetic acid', 'B05ZA', 8.1, 'g / l', 81222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium citrate', 'S01XA20', 0.17, '%', 15177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium citrate', 'V07AC', 1.66, 'g / 63 ml', 23039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium citrate', 'V07AC', 4, 'g / 100 ml', 10497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium citrate', 'V07AC', 2.2, 'g / 100 ml', 11376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium citrate', 'V07AC', 1.32, 'g / 100 ml', 11354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyl salicylate', 'M02AC', 2.0, '%', 3998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hydroxide', 'V07AB', 0, 'mg', 50130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hydroxide', 'V07AV', 0.34, '%', 81278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium hydroxide', 'V07AV', 0.34, '%', 82116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium citrate', 'A12BA02', 540, 'mg', 46885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium citrate', 'A12BA02', 1080, 'mg', 83921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('povidone', 'S01XA20', 0.6, '%', 37543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('povidone', 'S01XA20', 0.6, '%', 47557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('povidone', 'S01XA20', 6, 'mg / ml', 71788);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', 'V07AB', 94, 'mg', 50130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', 'B05CX03', 1.5, '%', 15540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxcarbazepine', 'N03AF02', 150, 'mg', 76987);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', 'B05CX03', 1.5, 'g / 100 ml', 9828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', 'B05CX03', 15, 'mg / ml', 3865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glycine', 'B05ZA', 51, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium phosphate dibasic', 'V07AB', 0.042, '%', 4913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leflunomide', 'L04AA13', 10, 'mg', 74665);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium phosphate dibasic', 'V07AC', 124.2, 'mg / 100 ml', 11330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium phosphate dibasic', 'V04CX', 7.58, 'mg / ml', 5984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium phosphate monobasic', 'V07AC', 140, 'mg / 63 ml', 23039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium phosphate monobasic', 'V07AC', 51.7, 'mg / 100 ml', 11330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium phosphate monobasic', 'V04CX', 1.81, 'mg / ml', 5984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium ascorbate', 'A11GA01', 250, 'mg / ml', 4133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyvinyl alcohol', 'S01XA20', 1.4, '%', 37542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyvinyl alcohol', 'S01XA20', 1.4, '%', 37543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyvinyl alcohol', 'S01XA20', 1, '%', 19791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyvinyl alcohol', 'S01XA20', 1.4, '%', 18791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyvinyl alcohol', 'S01XA20', 1.4, '%', 16655);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyvinyl alcohol', 'S01XA20', 1.4, '%', 5121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyvinyl alcohol', 'S01XA20', 1.4, '%', 47493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyvinyl alcohol', 'S01XA20', 1.4, '%', 47557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyvinyl alcohol', 'S01XA20', 5, 'mg / ml', 71788);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histidine', 'B05ZA', 71.4, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tranexamic acid', 'B02AA02', 500, 'mg', 18072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tranexamic acid', 'B02AA02', 100, 'mg / ml', 18371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tranexamic acid', 'B02AA02', 100, 'mg / ml', 70531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobazam', 'N05BA09', 10, 'mg', 43305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobazam', 'N05BA09', 10, 'mg', 61740);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobazam', 'N05BA09', 10, 'mg', 68447);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobazam', 'N05BA09', 10, 'mg', 68625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobazam', 'N05BA09', 10, 'mg', 71472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clobazam', 'N05BA09', 10, 'mg', 72805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etoposide', 'L01CB01', 50, 'mg', 5963);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etoposide', 'L01CB01', 20, 'mg / ml', 16507);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etoposide', 'L01CB01', 20, 'mg / ml', 64788);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chromium (chromic chloride)', 'A12CX', 4, 'µg / ml', 13523);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 100, 'mg', 20306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 50, 'mg', 20307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 50, 'mg', 19936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 100, 'mg', 19937);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 150, 'mg', 19938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 50, 'mg', 18853);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 100, 'mg', 18854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 150, 'mg', 18855);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 150, 'mg', 18189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 100, 'mg', 18190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 50, 'mg', 18191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 50, 'mg', 18046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 100, 'mg', 18045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 150, 'mg', 18040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 100, 'mg', 13780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 50, 'mg', 4241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 50, 'mg', 49041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 100, 'mg', 49042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 150, 'mg', 49043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 50, 'mg', 51060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 100, 'mg', 51061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 150, 'mg', 51062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 50, 'mg', 60234);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 100, 'mg', 60235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 50, 'mg', 76298);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 100, 'mg', 76299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 150, 'mg', 76300);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 50, 'mg', 81051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 100, 'mg', 81052);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 50, 'mg', 83411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 100, 'mg', 83412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 150, 'mg', 83413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 150, 'mg', 84690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trazodone hydrochloride', 'N06AX05', 300, 'mg', 84691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketotifen fumarate', 'R06AX17', 1, 'mg / 5 ml', 43304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketotifen fumarate', 'R06AX17', 1, 'mg / 5 ml', 43232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 0.025, '%', 43176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R01AX03', 0.03, '%', 70218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R01AX03', 0.06, '%', 70219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R01AX03', 42, 'µg / act', 19651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R01AX03', 21, 'µg / act', 19245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 20, 'µg / act', 71950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 0.025, '%', 50824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 125, 'µg / ml', 43798);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 250, 'µg / ml', 19798);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 250, 'µg / ml', 16947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 250, 'µg / ml', 50551);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 250, 'µg / ml', 50552);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 250, 'µg / ml', 51217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 125, 'µg / ml', 50442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 250, 'µg / ml', 50443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 250, 'µg / ml', 60449);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 250, 'µg / ml', 60450);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 125, 'µg / ml', 60227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 125, 'µg / ml', 67766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 0.25, 'mg / ml', 20153);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 0.25, 'mg / ml', 62586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R01AX03', 0.3, 'mg / ml', 64077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ipratropium bromide', 'R03BB01', 0.30, 'mg / ml', 63098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glutathione disulfide', 'V07AB', 0.0184, '%', 4913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 1.25, 'mg', 43448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 2.5, 'mg', 43381);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 2.5, 'mg', 43374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 1.25, 'mg', 19089);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 2.5, 'mg', 19009);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 2.5, 'mg', 18065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 1.25, 'mg', 63413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 2.5, 'mg', 63417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 2.5, 'mg', 4857);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 2.5, 'mg', 50491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 1.25, 'mg', 63577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 1.25, 'mg', 63891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 2.5, 'mg', 63893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 1.25, 'mg', 63090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 2.5, 'mg', 63091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 2.5, 'mg', 65803);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 1.25, 'mg', 69270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 1.25, 'mg', 71487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 1.25, 'mg', 79803);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('indapamide', 'C03BA11', 2.5, 'mg', 79804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nifedipine', 'C08CA05', 10, 'mg', 43071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nifedipine', 'C08CA05', 20, 'mg', 42967);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nifedipine', 'C08CA05', 10, 'mg', 19557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nifedipine', 'C08CA05', 20, 'mg', 19232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nifedipine', 'C08CA05', 60, 'mg', 19098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nifedipine', 'C08CA05', 30, 'mg', 19099);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nifedipine', 'C08CA05', 10, 'mg', 11183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leflunomide', 'L04AA13', 20, 'mg', 74666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nifedipine', 'C08CA05', 10, 'mg', 8376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nifedipine', 'C08CA05', 5, 'mg', 9938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nifedipine', 'C08CA05', 5, 'mg', 59718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nifedipine', 'C08CA05', 10, 'mg', 59719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nifedipine', 'C08CA05', 20, 'mg', 60957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nifedipine', 'C08CA05', 60, 'mg', 80655);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nifedipine', 'C08CA05', 30, 'mg', 83448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mexiletine hydrochloride', 'C01BB02', 100, 'mg', 49155);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mexiletine hydrochloride', 'C01BB02', 200, 'mg', 49157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 300, 'mg', 42867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 600, 'mg', 19191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 600, 'mg', 17230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 300, 'mg', 15824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 600, 'mg', 15825);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 300, 'mg', 13840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 600, 'mg', 13841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 600, 'mg', 9259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 300, 'mg', 5759);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 600, 'mg', 48859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 600, 'mg', 49439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 600, 'mg', 49689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 300, 'mg', 63454);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 600, 'mg', 65804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 300, 'mg', 65265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 300, 'mg', 65364);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 300, 'mg', 74001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemfibrozil', 'C10AB04', 600, 'mg', 74002);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nimodipine', 'C08CA06', 30, 'mg', 81127);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclopirox olamine', 'D01AE14', 1, '%', 43307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclopirox olamine', 'D01AE14', 1.5, '%', 71470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclopirox olamine', 'D01AE14', 10, 'mg / g', 43306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tiaprofenic acid', 'M01AE11', 200, 'mg', 19720);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tiaprofenic acid', 'M01AE11', 300, 'mg', 19722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tiaprofenic acid', 'M01AE11', 300, 'mg', 18761);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tiaprofenic acid', 'M01AE11', 200, 'mg', 18762);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tiaprofenic acid', 'M01AE11', 200, 'mg', 17118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tiaprofenic acid', 'M01AE11', 300, 'mg', 17119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tiaprofenic acid', 'M01AE11', 200, 'mg', 50097);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tiaprofenic acid', 'M01AE11', 300, 'mg', 50098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tiaprofenic acid', 'M01AE11', 300, 'mg', 50342);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('teniposide', 'L01CB02', 10, 'mg / ml', 5995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 60, 'mg', 43330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 90, 'mg', 43331);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 120, 'mg', 43332);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 240, 'mg', 17253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 180, 'mg', 17254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 120, 'mg', 17125);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 300, 'mg', 17102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 30, 'mg', 11161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 60, 'mg', 11162);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 30, 'mg', 9172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 60, 'mg', 9173);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 30, 'mg', 10394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 60, 'mg', 10395);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 60, 'mg', 9902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 30, 'mg', 9903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 300, 'mg', 47431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 120, 'mg', 48067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 180, 'mg', 48071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 240, 'mg', 48076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 300, 'mg', 48077);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 120, 'mg', 50278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 180, 'mg', 50279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 240, 'mg', 50280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 120, 'mg', 50796);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 180, 'mg', 50798);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 240, 'mg', 50799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 120, 'mg', 50333);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 180, 'mg', 50334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 240, 'mg', 50335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 300, 'mg', 50338);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 120, 'mg', 50458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 180, 'mg', 50459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 240, 'mg', 50460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 300, 'mg', 50461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 360, 'mg', 50462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 120, 'mg', 67243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 180, 'mg', 67244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 240, 'mg', 67245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 300, 'mg', 67246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 120, 'mg', 66289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 180, 'mg', 66290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 240, 'mg', 66291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 300, 'mg', 66292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 120, 'mg', 70038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 180, 'mg', 70039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 240, 'mg', 70040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 300, 'mg', 70041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 360, 'mg', 70042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 120, 'mg', 74195);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 180, 'mg', 74196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 240, 'mg', 74197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 300, 'mg', 74198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 360, 'mg', 74199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 120, 'mg', 75715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 180, 'mg', 75716);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 240, 'mg', 75717);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 300, 'mg', 75718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 360, 'mg', 75719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 120, 'mg', 77643);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 180, 'mg', 77644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 240, 'mg', 77645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 300, 'mg', 77646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 360, 'mg', 77647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 120, 'mg', 81070);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 180, 'mg', 81071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 240, 'mg', 81072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 300, 'mg', 81073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 360, 'mg', 81074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 120, 'mg', 84095);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 180, 'mg', 84096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 240, 'mg', 84097);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 300, 'mg', 84098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 5, 'mg / ml', 49026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 5, 'mg / ml', 64862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diltiazem hydrochloride', 'C08DB01', 5, 'mg / ml', 68717);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pentoxifylline', 'C04AD03', 400, 'mg', 43321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pentoxifylline', 'C04AD03', 400, 'mg', 48622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pentoxifylline', 'C04AD03', 400, 'mg', 49240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amsacrine', 'L01XX01', 50, 'mg / ml', 5262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('misoprostol', 'A02BB01', 100, 'µg', 64343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('misoprostol', 'A02BB01', 200, 'µg', 64344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('misoprostol', 'A02BB01', 100, 'µg', 67965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('misoprostol', 'A02BB01', 200, 'µg', 67966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('misoprostol', 'A02BB01', 0.1, 'mg', 68082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('misoprostol', 'A02BB01', 0.2, 'mg', 68083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxaprozin', 'M01AE12', 600, 'mg', 43573);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxaprozin', 'M01AE12', 600, 'mg', 67591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flecainide acetate', 'C01BC04', 100, 'mg', 13514);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flecainide acetate', 'C01BC04', 50, 'mg', 13513);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flecainide acetate', 'C01BC04', 50, 'mg', 76117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flecainide acetate', 'C01BC04', 100, 'mg', 76118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propafenone hydrochloride', 'C01BC03', 150, 'mg', 8464);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propafenone hydrochloride', 'C01BC03', 300, 'mg', 8465);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propafenone hydrochloride', 'C01BC03', 150, 'mg', 67227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propafenone hydrochloride', 'C01BC03', 300, 'mg', 67228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propafenone hydrochloride', 'C01BC03', 150, 'mg', 69411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propafenone hydrochloride', 'C01BC03', 300, 'mg', 69412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propafenone hydrochloride', 'C01BC03', 150, 'mg', 67659);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propafenone hydrochloride', 'C01BC03', 300, 'mg', 67660);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propafenone hydrochloride', 'C01BC03', 150, 'mg', 67721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propafenone hydrochloride', 'C01BC03', 300, 'mg', 67722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propafenone hydrochloride', 'C01BC03', 150, 'mg', 77991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propafenone hydrochloride', 'C01BC03', 300, 'mg', 77992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propafenone hydrochloride', 'C01BC03', 150, 'mg', 82854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('propafenone hydrochloride', 'C01BC03', 300, 'mg', 82855);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oseltamivir (oseltamivir phosphate)', 'J05AH02', 75, 'mg', 65111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oseltamivir (oseltamivir phosphate)', 'J05AH02', 30, 'mg', 79011);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oseltamivir (oseltamivir phosphate)', 'J05AH02', 45, 'mg', 79012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oseltamivir (oseltamivir phosphate)', 'J05AH02', 12, 'mg / ml', 69640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('daclizumab', 'L04AC01', 5, 'mg / ml', 65112);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium citrate dihydrate', 'V07AB', 0.17, '%', 6366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leflunomide', 'L04AA13', 10, 'mg', 65558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leflunomide', 'L04AA13', 20, 'mg', 65559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leflunomide', 'L04AA13', 100, 'mg', 65560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leflunomide', 'L04AA13', 10, 'mg', 74173);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leflunomide', 'L04AA13', 20, 'mg', 76954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leflunomide', 'L04AA13', 10, 'mg', 77371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leflunomide', 'L04AA13', 20, 'mg', 77372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leflunomide', 'L04AA13', 10, 'mg', 79493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leflunomide', 'L04AA13', 20, 'mg', 79494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leflunomide', 'L04AA13', 10, 'mg', 80469);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leflunomide', 'L04AA13', 20, 'mg', 80470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leflunomide', 'L04AA13', 10, 'mg', 83692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leflunomide', 'L04AA13', 20, 'mg', 83693);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rituximab', 'L01XC02', 10, 'mg / ml', 65597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxcarbazepine', 'N03AF02', 150, 'mg', 65740);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxcarbazepine', 'N03AF02', 300, 'mg', 65741);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxcarbazepine', 'N03AF02', 600, 'mg', 65742);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxcarbazepine', 'N03AF02', 300, 'mg', 76988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxcarbazepine', 'N03AF02', 600, 'mg', 76989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxcarbazepine', 'N03AF02', 60, 'mg / ml', 68661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 1.5, 'mg', 65791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 3, 'mg', 65792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 4.5, 'mg', 65793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 6, 'mg', 65794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 1.5, 'mg', 79154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 3, 'mg', 79155);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 4.5, 'mg', 79156);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 6, 'mg', 79157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 1.5, 'mg', 81846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 3, 'mg', 81847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 4.5, 'mg', 81848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 6, 'mg', 81849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 1.5, 'mg', 79159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 3.0, 'mg', 79160);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 4.5, 'mg', 79161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 6.0, 'mg', 79162);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 1.5, 'mg', 81001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 3, 'mg', 81002);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 4.5, 'mg', 81003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 6, 'mg', 81004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 1.5, 'mg', 79687);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 3, 'mg', 79688);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 4.5, 'mg', 79689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 6, 'mg', 79690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 1.5, 'mg', 82234);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 3, 'mg', 82235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 4.5, 'mg', 82236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 6, 'mg', 82237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine', 'N06DA03', 9, 'mg / 5 sq cm', 78816);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine', 'N06DA03', 18, 'mg / 10 sq cm', 78817);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 2, 'mg / ml', 69257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('verteporfin', 'S01LA01', 15, 'mg / vial', 66078);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ibutilide fumarate', 'C01BD05', 0.1, 'mg / ml', 66196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cabergoline', 'G02CB03', 0.5, 'mg', 66198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cabergoline', 'G02CB03', 0.5, 'mg', 78674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 15, 'mg', 66344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30, 'mg', 66345);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45, 'mg', 66346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 15, 'mg', 76044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30, 'mg', 76045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45, 'mg', 76046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 15, 'mg', 78323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30, 'mg', 78324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45, 'mg', 78325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 15, 'mg', 78357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30, 'mg', 78358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45, 'mg', 78359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 15, 'mg', 81184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30, 'mg', 81185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45, 'mg', 81186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 15, 'mg', 79757);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30, 'mg', 79758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45, 'mg', 79759);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 15, 'mg', 78676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30, 'mg', 78677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45, 'mg', 78678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 15, 'mg', 79332);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30, 'mg', 79333);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45, 'mg', 79334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 15, 'mg', 79335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30, 'mg', 79336);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45, 'mg', 79341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 15, 'mg', 78824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30, 'mg', 78825);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45, 'mg', 78827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 15, 'mg', 78845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30, 'mg', 78846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white petrolatum', 'D02AC', 100, '%', 79066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45, 'mg', 78847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 15, 'mg', 78875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30, 'mg', 78876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45, 'mg', 78877);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30, 'mg', 78819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 15, 'mg', 78818);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45, 'mg', 78820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30, 'mg', 82518);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45, 'mg', 82519);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 15, 'mg', 80616);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30, 'mg', 80617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45, 'mg', 80618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 15, 'mg', 83078);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30, 'mg', 83079);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45, 'mg', 83080);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30, 'mg', 85042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45, 'mg', 85043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('kentucky blue/june', 'V01AA02', 100000, 'unit / ml', 66455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('exemestane', 'L02BG06', 25, 'mg', 66502);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allergen extract - alum precipitated', 'V01AA02', 10000, 'unit / ml', 66518);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allergen extract - alum precipitated', 'V01AA02', 1000, 'unit / ml', 66520);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allergen extract - alum precipitated', 'V01AA02', 100, 'unit / ml', 66521);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allergen extract - diagnostic', 'V04CL', 0, 'unit / ml', 66522);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zoledronic acid', 'M05BA08', 5, 'mg / 100 ml', 75458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zoledronic acid', 'M05BA08', 4, 'mg / 5 ml', 72636);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('riluzole', 'N07XX02', 50, 'mg', 66576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('basiliximab', 'L04AC02', 20, 'mg / vial', 66643);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone phosphate (dexamethasone sodium phosphate)', 'H02AB02', 10, 'mg / ml', 36481);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone phosphate (dexamethasone sodium phosphate)', 'H02AB02', 4, 'mg / ml', 36480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone phosphate (dexamethasone sodium phosphate)', 'H02AB02', 4, 'mg / ml', 13255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone phosphate (dexamethasone sodium phosphate)', 'H02AB02', 10, 'mg / ml', 11011);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone phosphate (dexamethasone sodium phosphate)', 'H02AB02', 4, 'mg / ml', 9613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone phosphate (dexamethasone sodium phosphate)', 'S03BA01', 1, 'mg / ml', 9616);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone phosphate (dexamethasone sodium phosphate)', 'H02AB02', 4, 'mg / ml', 6593);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexamethasone phosphate (dexamethasone sodium phosphate)', 'H02AB02', 10, 'mg / ml', 74553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etanercept', 'L04AB01', 50, 'mg / ml', 76019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etanercept', 'L04AB01', 25, 'mg / kit', 66735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buprenorphine', 'N02AE01', 5, 'µg / hour', 82671);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buprenorphine', 'N02AE01', 20, 'µg / hour', 82676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buprenorphine', 'N02AE01', 10, 'µg / hour', 82675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moxifloxacin (moxifloxacin hydrochloride)', 'J01MA14', 400, 'mg', 66804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moxifloxacin (moxifloxacin hydrochloride)', 'S01AX22', 0.5, '%', 73714);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moxifloxacin (moxifloxacin hydrochloride)', 'J01MA14', 400, 'mg / 250 ml', 70586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2b', 'L03AB10', 74, 'µg / vial', 66805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2b', 'L03AB10', 118.4, 'µg / vial', 66806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2b', 'L03AB10', 177.6, 'µg / vial', 66807);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peginterferon alfa-2b', 'L03AB10', 222, 'µg / vial', 66808);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fomepizole', 'V03AB34', 1, 'g / ml', 66820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gadoversetamide', 'V08CA06', 330.9, 'mg / ml', 66826);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('perflutren', 'V08DA04', 150, 'µl / ml', 67049);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gatifloxacin', 'S01AX21', 0.3, '%', 74247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pizotifen (pizotifen malate)', 'N02CX01', 1, 'mg', 4222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pizotifen (pizotifen malate)', 'N02CX01', 0.50, 'mg', 48362);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sirolimus', 'L04AA10', 1.0, 'mg', 71350);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sirolimus', 'L04AA10', 1.0, 'mg / ml', 67127);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pimecrolimus', 'D11AH02', 1, '%', 71480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ammonium hydroxide', 'M02AC', 0.1, '%', 3998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', 'S01XA20', 0.39, '%', 15177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', 'B05XA08', 328, 'mg / ml', 35083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', 'B05XA08', 328, 'mg / ml', 31360);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 2, 'mg', 13686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', 'B05ZA', 1.11, 'g / l', 85140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', 'B05ZA', 1.11, 'g / l', 85141);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate', 'B05ZA', 1.11, 'g / l', 85142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('disodium edetate', 'S01XA20', 0.025, '%', 42295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('disodium edetate', 'S01XA20', 0.05, '%', 42237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('disodium edetate', 'S01XA20', 0.10, '%', 41994);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('disodium edetate', 'S01XA20', 0.10, '%', 49610);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('disodium edetate', 'S01XA20', 0.05, '%', 60122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('disodium edetate', 'S01XA20', 0.10, '%', 80971);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('disodium edetate', 'S01XA20', 0.10, '% / w/v', 80854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetylpyridinium chloride', 'R02AA06', 1.4, 'mg', 42462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetylpyridinium chloride', 'R02AA06', 1.5, 'mg', 4665);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetylpyridinium chloride', 'R02AA06', 1.5, 'mg', 4666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetylpyridinium chloride', 'R02AA06', 0.05, '%', 5812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetylpyridinium chloride', 'R02AA06', 0.05, '%', 67489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetylpyridinium chloride', 'R02AA06', 0.07, '% / w/w', 75427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetylpyridinium chloride', 'R02AA06', 0.07, '% / w/w', 79990);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetylpyridinium chloride', 'R02AA06', 0.5, 'mg / ml', 42479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'V07AV', 0.1, '%', 37743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'V07AV', 0.28, '%', 37547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'V07AV', 0.28, '%', 20013);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'V07AV', 0.28, '%', 65889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'V07AV', 0.25, '%', 65545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'V07AV', 0.28, '%', 70138);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'D08AJ08', 0.2, '%', 76393);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'D08AJ08', 0.2, '%', 76652);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'D08AJ08', 0.2, '%', 75279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'D04AB01', 0.28, '%', 74263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'D08AJ08', 0.2, '%', 74299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'V07AV', 0.35, '%', 75711);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'V07AV', 0.35, '%', 75722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'D08AJ08', 0.2, '%', 73352);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'D08AJ08', 0.2, '%', 73590);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'V07AV', 0.1, '%', 73676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'D08AJ08', 0.20, '%', 79250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'D08AJ08', 0.1, '% / w/w', 47404);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'D08AJ08', 0.1, '% / w/w', 70020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'D08AJ08', 0.3, '% / w/w', 78942);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'D08AJ08', 0.13, '% / w/w', 82271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'D08AJ08', 0.2, '% / w/w', 83325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'D08AJ08', 0.2, '% / w/w', 83401);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzethonium chloride', 'D08AJ08', 0.13, '% / w/w', 84430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('macrogol', 'R01AX10', 15, '%', 37257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('macrogol', 'R01AX10', 15, '%', 8563);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('macrogol', 'R01AX10', 15, '%', 4885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('macrogol', 'R01AX10', 15, '%', 4886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('macrogol', 'R01AX30', 160, 'mg / ml', 11232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('macrogol', 'R01AX30', 152, 'mg / g', 10299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pegaptanib', 'S01LA03', 0.3, 'mg / 90 µl', 75262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butorphanol tartrate', 'N02AF01', 10, 'mg / ml', 66247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butorphanol tartrate', 'N02AF01', 10, 'mg / ml', 68484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclobenzaprine hydrochloride', 'M03BX08', 10, 'mg', 43292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclobenzaprine hydrochloride', 'M03BX08', 10, 'mg', 19827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclobenzaprine hydrochloride', 'M03BX08', 10, 'mg', 18806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclobenzaprine hydrochloride', 'M03BX08', 10, 'mg', 18760);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclobenzaprine hydrochloride', 'M03BX08', 10, 'mg', 15912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclobenzaprine hydrochloride', 'M03BX08', 10, 'mg', 50662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclobenzaprine hydrochloride', 'M03BX08', 10, 'mg', 59925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclobenzaprine hydrochloride', 'M03BX08', 10, 'mg', 62061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclobenzaprine hydrochloride', 'M03BX08', 10, 'mg', 65753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclobenzaprine hydrochloride', 'M03BX08', 10, 'mg', 73419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclobenzaprine hydrochloride', 'M03BX08', 10, 'mg', 77249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclobenzaprine hydrochloride', 'M03BX08', 10, 'mg', 81060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclobenzaprine hydrochloride', 'M03BX08', 10, 'mg', 83419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 10, 'mg', 15696);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 5, 'mg', 15687);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 10, 'mg', 11180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 15, 'mg', 11181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 5, 'mg', 11182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 5, 'mg', 10949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 10, 'mg', 10950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 15, 'mg', 10951);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 5, 'mg', 9167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 10, 'mg', 9168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 15, 'mg', 9169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 5, 'mg', 9899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 10, 'mg', 9900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 15, 'mg', 9901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 5, 'mg', 3089);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 15, 'mg', 3090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 10, 'mg', 3091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 5, 'mg', 50877);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 10, 'mg', 50879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 15, 'mg', 50882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 5, 'mg', 51024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 10, 'mg', 61430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 15, 'mg', 61431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 5, 'mg', 74715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 10, 'mg', 74716);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pindolol', 'C07AA03', 15, 'mg', 74717);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('praziquantel', 'P02BA01', 600, 'mg', 50175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nadolol', 'C07AA12', 80, 'mg', 16965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nadolol', 'C07AA12', 40, 'mg', 16966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nadolol', 'C07AA12', 80, 'mg', 9176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nadolol', 'C07AA12', 160, 'mg', 9177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nadolol', 'C07AA12', 40, 'mg', 9178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nadolol', 'C07AA12', 40, 'mg', 9906);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nadolol', 'C07AA12', 80, 'mg', 9897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nadolol', 'C07AA12', 160, 'mg', 9898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mitotane', 'L01XX23', 500, 'mg', 3348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estramustine phosphate sodium', 'L01XX11', 140, 'mg', 19428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 10, 'mg', 20308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 20, 'mg', 20309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 20, 'mg', 18752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 10, 'mg', 18753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 10, 'mg', 17246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 20, 'mg', 17247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 20, 'mg', 16532);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 10, 'mg', 16534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 10, 'mg', 15547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 20, 'mg', 15548);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 10, 'mg', 16890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 20, 'mg', 16891);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 20, 'mg', 6244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 10, 'mg', 3182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 10, 'mg', 48389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 20, 'mg', 48390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 10, 'mg', 59927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 20, 'mg', 59928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 10, 'mg', 60258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 20, 'mg', 60259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 10, 'mg', 65828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 20, 'mg', 65829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 10, 'mg', 77246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 20, 'mg', 77247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 0.5, 'mg / ml', 17954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 2, 'mg / ml', 17276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('baclofen', 'M03BX01', 0.05, 'mg / ml', 17277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sincalide', 'V04CC03', 5, 'µg / vial', 37574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzydamine hydrochloride', 'A01AD02', 0.15, '%', 13579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzydamine hydrochloride', 'A01AD02', 0.15, '%', 62497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzydamine hydrochloride', 'A01AD02', 1.5, 'mg / ml', 48059);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzydamine hydrochloride', 'A01AD02', 1.5, 'mg / ml', 48124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzydamine hydrochloride', 'A01AD02', 1.5, 'mg / ml', 63013);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benzydamine hydrochloride', 'A01AD02', 1.5, 'mg / ml', 79606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 80, 'mg', 19817);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 80, 'mg', 19662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 160, 'mg', 19663);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 80, 'mg', 20002);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 160, 'mg', 18779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 160, 'mg', 18350);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 80, 'mg', 48060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 160, 'mg', 48061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 80, 'mg', 50489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 160, 'mg', 50490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 80, 'mg', 49903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 160, 'mg', 49907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 240, 'mg', 49910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 80, 'mg', 62062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 160, 'mg', 62063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 80, 'mg', 62204);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 160, 'mg', 62205);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 80, 'mg', 61729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 160, 'mg', 61730);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 80, 'mg', 65834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 160, 'mg', 65835);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 80, 'mg', 74307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 160, 'mg', 74308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 80, 'mg', 75600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 160, 'mg', 75601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 80, 'mg', 75769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 80, 'mg', 81061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 160, 'mg', 81062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 80, 'mg', 80201);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sotalol hydrochloride', 'C07AA07', 160, 'mg', 80202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nabilone', 'A04AD11', 1, 'mg', 4941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nabilone', 'A04AD11', 0.5, 'mg', 74143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nabilone', 'A04AD11', 0.25, 'mg', 79778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 0.25, 'mg', 17972);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 0.5, 'mg', 17973);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 1, 'mg', 13685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 0.25, 'mg', 11803);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 0.5, 'mg', 11804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 0.25, 'mg', 12175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 0.5, 'mg', 12180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 0.25, 'mg', 10904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 0.25, 'mg', 11484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 0.5, 'mg', 11485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 0.5, 'mg', 10905);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 0.25, 'mg', 4471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 0.5, 'mg', 4472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 1, 'mg', 48166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 2, 'mg', 48167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 1, 'mg', 67530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 2, 'mg', 67531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 1, 'mg', 73070);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 0.25, 'mg', 83451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprazolam', 'N05BA12', 0.50, 'mg', 83452);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromazepam', 'N05BA08', 3, 'mg', 43282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromazepam', 'N05BA08', 6, 'mg', 43283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromazepam', 'N05BA08', 1.5, 'mg', 20147);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromazepam', 'N05BA08', 1.5, 'mg', 18846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromazepam', 'N05BA08', 3, 'mg', 18847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromazepam', 'N05BA08', 6, 'mg', 18848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromazepam', 'N05BA08', 6, 'mg', 19047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromazepam', 'N05BA08', 3, 'mg', 19056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromazepam', 'N05BA08', 1.5, 'mg', 19057);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromazepam', 'N05BA08', 3, 'mg', 4157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromazepam', 'N05BA08', 6, 'mg', 4158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromazepam', 'N05BA08', 3, 'mg', 49693);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bromazepam', 'N05BA08', 6, 'mg', 49694);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nalbuphine hydrochloride', 'N02AF02', 20, 'mg / ml', 13963);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nalbuphine hydrochloride', 'N02AF02', 10, 'mg / ml', 13803);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('floctafenine', 'N02BG04', 400, 'mg', 68669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('floctafenine', 'N02BG04', 200, 'mg', 68668);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minoxidil', 'C02DC01', 10, 'mg', 4010);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minoxidil', 'C02DC01', 2.5, 'mg', 4011);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minoxidil', 'D11AX01', 2, '%', 66088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minoxidil', 'D11AX01', 20, 'mg / ml', 43482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minoxidil', 'D11AX01', 20, 'mg / ml', 12757);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minoxidil', 'D11AX01', 20, 'mg / ml', 7084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('minoxidil', 'D11AX01', 20, 'mg / ml', 84173);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 75, 'mg', 43472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 100, 'mg', 43473);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 75, 'mg', 43393);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 100, 'mg', 43394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 50, 'mg', 20263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 100, 'mg', 19678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 75, 'mg', 18239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 100, 'mg', 14717);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 50, 'mg', 11193);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 25, 'mg', 11194);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 50, 'mg', 10772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 25, 'mg', 10036);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 50, 'mg', 10037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 75, 'mg', 9943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 25, 'mg', 9888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 50, 'mg', 9889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 50, 'mg', 6461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 100, 'mg', 6462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 100, 'mg', 6379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 50, 'mg', 4043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 50, 'mg', 50843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 25, 'mg', 50842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 75, 'mg', 50844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 100, 'mg', 50845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 50, 'mg', 50847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 100, 'mg', 50848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 25, 'mg', 51037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 50, 'mg', 51039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 75, 'mg', 51040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 75, 'mg', 74726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 50, 'mg', 74727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 100, 'mg', 74728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 100, 'mg', 74729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 25, 'mg', 74730);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 50, 'mg', 74731);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 25, 'mg', 78791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 50, 'mg', 78792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 50, 'mg', 83766);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 75, 'mg', 83767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M02AA15', 1.5, '% / w/w', 71508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'S01BC03', 0.1, '% / w/v', 11969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 75, 'mg / srt', 19125);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac sodium', 'M01AB05', 100, 'mg / srt', 16471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoflurane', 'N01AB06', 100, '%', 20160);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoflurane', 'N01AB06', 99.9, '%', 14158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoflurane', 'N01AB06', 99.9, '%', 51381);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoflurane', 'N01AB06', 99.9, '%', 64934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sucralfate', 'A02BX02', 1, 'g', 19192);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sucralfate', 'A02BX02', 1, 'g', 17250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sucralfate', 'A02BX02', 1, 'g', 16656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sucralfate', 'A02BX02', 1, 'g', 16899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sucralfate', 'A02BX02', 1, 'g', 14504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sucralfate', 'A02BX02', 1000, 'mg', 63412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sucralfate', 'A02BX02', 1000, 'mg', 61602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sucralfate', 'A02BX02', 1, 'g / 5 ml', 17852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('honey bee venom protein', 'V01AA07', 550, 'µg / vial', 43270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('honey bee venom protein', 'V01AA07', 120, 'µg / vial', 37436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('wasp venom protein', 'V01AA07', 550, 'µg / vial', 43272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('wasp venom protein', 'V01AA07', 120, 'µg / vial', 37438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white faced hornet venom protein', 'V01AA07', 550, 'µg / vial', 43302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white faced hornet venom protein', 'V01AA07', 550, 'µg / vial', 43273);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white faced hornet venom protein', 'V01AA07', 120, 'µg / vial', 37445);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white faced hornet venom protein', 'V01AA07', 120, 'µg / vial', 37440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white faced hornet venom protein', 'V01AA07', 120, 'µg / vial', 14599);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white faced hornet venom protein', 'V01AA07', 1300, 'µg / vial', 50135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white faced hornet venom protein', 'V01AA07', 1.1, 'mg / vial', 14101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yellow jacket venom protein', 'V01AA07', 550, 'µg / vial', 43302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yellow jacket venom protein', 'V01AA07', 550, 'µg / vial', 43274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yellow jacket venom protein', 'V01AA07', 120, 'µg / vial', 37444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yellow jacket venom protein', 'V01AA07', 120, 'µg / vial', 37445);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yellow jacket venom protein', 'V01AA07', 120, 'µg / vial', 14599);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yellow jacket venom protein', 'V01AA07', 1300, 'µg / vial', 50135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yellow jacket venom protein', 'V01AA07', 1.1, 'mg / vial', 14101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yellow hornet venom protein', 'V01AA07', 550, 'µg / vial', 43302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yellow hornet venom protein', 'V01AA07', 550, 'µg / vial', 43271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yellow hornet venom protein', 'V01AA07', 120, 'µg / vial', 37445);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yellow hornet venom protein', 'V01AA07', 120, 'µg / vial', 37442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yellow hornet venom protein', 'V01AA07', 120, 'µg / vial', 14599);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yellow hornet venom protein', 'V01AA07', 1300, 'µg / vial', 50135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yellow hornet venom protein', 'V01AA07', 1.1, 'mg / vial', 14101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen sodium', 'M01AE02', 550, 'mg', 44029);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen sodium', 'M01AE02', 275, 'mg', 19446);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen sodium', 'M01AE02', 550, 'mg', 19313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen sodium', 'M01AE02', 275, 'mg', 17199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen sodium', 'M01AE02', 550, 'mg', 14048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen sodium', 'M01AE02', 550, 'mg', 13848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen sodium', 'M01AE02', 275, 'mg', 9241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen sodium', 'M01AE02', 275, 'mg', 10035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen sodium', 'M01AE02', 275, 'mg', 64418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen sodium', 'M01AE02', 550, 'mg', 64419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen sodium', 'M01AE02', 220, 'mg', 78704);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen sodium', 'M01AE02', 275, 'mg', 83619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen sodium', 'M01AE02', 550, 'mg', 83620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naproxen sodium', 'M01AE02', 220, 'mg', 84744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 19691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 19692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 17905);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 17906);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 18188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 18161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 11142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 11143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 11964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 11965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 9174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 9175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 9905);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 9904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 47357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 47358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 51110);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 51112);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 60939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 60940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 61718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 61719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 65768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 65769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 25, 'mg', 71424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 25, 'mg', 70768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 25, 'mg', 75207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 75337);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 75338);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 74074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 74075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 25, 'mg', 76301);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 25, 'mg', 78896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 25, 'mg', 81205);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 25, 'mg', 83656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 83657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 83658);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 25, 'mg', 85239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 85240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 85241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 25, 'mg', 85283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 85284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 85285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 25, 'mg', 85363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 50, 'mg', 85364);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atenolol', 'C07AB03', 100, 'mg', 85365);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homosalate', 'D11AX11', 5.0, '% / w/w', 80960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrithione disulfide', 'D05AA', 1.0, '%', 15950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 50, 'mg', 18869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 100, 'mg', 18870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 25, 'mg', 18871);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 12.5, 'mg', 18872);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 6.25, 'mg', 13401);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 25, 'mg', 11763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 50, 'mg', 11764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 100, 'mg', 11765);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 12.5, 'mg', 11760);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 100, 'mg', 12176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 50, 'mg', 12177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 25, 'mg', 12178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 12.5, 'mg', 12179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 25, 'mg', 10907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 50, 'mg', 10908);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 100, 'mg', 10900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 25, 'mg', 11490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 12.5, 'mg', 10906);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 25, 'mg', 4619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 12.5, 'mg', 48901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 25, 'mg', 48902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 50, 'mg', 48903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 100, 'mg', 48904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 25, 'mg', 61978);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 12.5, 'mg', 61977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 50, 'mg', 61979);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 100, 'mg', 61980);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 12.5, 'mg', 61982);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 25, 'mg', 61983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 50, 'mg', 61984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 100, 'mg', 61985);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 12.5, 'mg', 66611);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 25, 'mg', 66612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 50, 'mg', 66613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('captopril', 'C09AA01', 100, 'mg', 66614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drotrecogin alfa (activated)', 'B01AD10', 5, 'mg / vial', 71369);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('drotrecogin alfa (activated)', 'B01AD10', 20, 'mg / vial', 71370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('infliximab', 'L04AB02', 100, 'mg / vial', 67959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bimatoprost', 'S01EE03', 0.03, '%', 69977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bimatoprost', 'S01EE03', 0.01, '% / w/v', 81041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bimatoprost', 'S01EE03', 0.03, '% / w/v', 83612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('linezolid', 'J01XX08', 600, 'mg', 67614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 81601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('linezolid', 'J01XX08', 2, 'mg / ml', 67615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('linezolid', 'J01XX08', 3, 'g / bottle', 67616);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('anti-thymocyte globulin (rabbit)', 'L04AA04', 25, 'mg / vial', 71005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white petrolatum', 'D02AC', 100, '%', 41367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white petrolatum', 'S01XA20', 57.3, '%', 9820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white petrolatum', 'D02AC', 30, '%', 73888);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white petrolatum', 'D02AC', 100, '%', 75311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white petrolatum', 'D02AC', 100, '%', 80620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white petrolatum', 'D02AC', 99.9, '%', 80621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white petrolatum', 'D02AC', 99.96, '% / w/w', 41564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('white petrolatum', 'D02AC', 71.5, '% / w/w', 76338);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('entacapone', 'N04BX02', 200, 'mg', 67698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 10, 'mg', 79974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 10, 'mg', 67734);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 20, 'mg', 67735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 20, 'mg', 78200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 10, 'mg', 78199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 10, 'mg', 78338);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 20, 'mg', 78339);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 10, 'mg', 80074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 20, 'mg', 80075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 10, 'mg', 80602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 20, 'mg', 80603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 20, 'mg', 79975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 10, 'mg', 79643);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 20, 'mg', 79644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 10, 'mg', 81584);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 20, 'mg', 81585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 10, 'mg', 84166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabeprazole sodium', 'A02BC04', 20, 'mg', 84167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('corynebacterium diphtheriae crm-197 protein', 'J07AL02', 20, 'µg / 0.5 ml', 68040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('corynebacterium diphtheriae crm-197 protein', 'J07AL02', 34, 'µg / 0.5 ml', 82074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('argatroban', 'B01AE03', 100, 'mg / ml', 67776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eflornithine hydrochloride', 'D11AX16', 13.9, '% / w/w', 67778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rose bengal', 'S01JA02', 10, 'mg / ml', 9819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polycarbophil (calcium polycarbophil)', 'A06AC08', 500, 'mg', 69987);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polycarbophil (calcium polycarbophil)', 'A06AC08', 500, 'mg', 71429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('resorcinol', 'D05AA', 1.0, '%', 13013);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 40, 'mg', 83632);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'S01XA20', 0.03, '%', 15177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'V07AB', 0.03, '%', 7474);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'V07AB', 0.03, '%', 6366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'V07AB', 0.02, '%', 4913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.033, 'g / 1000 ml', 66962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 0.054, 'g / 1000 ml', 70916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 0.054, 'g / 1000 ml', 70917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 0.108, 'g / 1000 ml', 76040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.033, 'g / 1000 ml', 76308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.033, 'g / 1000 ml', 76310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 81595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g / l', 81602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 15.2, 'mg / 100 ml', 10512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 5.08, 'mg / 100 ml', 10865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 5.08, 'mg / 100 ml', 10863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 5.08, 'mg / 100 ml', 10864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 15.2, 'mg / 100 ml', 10143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 15.2, 'mg / 100 ml', 10144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 15.2, 'mg / 100 ml', 10009);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 5.1, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 36836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g / l', 36814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 34881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 34878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 34879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 19744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 20121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g / l', 20115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 20116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 20118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 20119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 20111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 20.5, 'g / 4.5 l', 20112);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 20114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 19739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g / l', 19735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 20076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 20044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 20045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 20046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g / l', 20040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 20041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 18268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 18206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 18202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 18199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 18200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 18167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 10820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 9854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 9852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 9848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 9845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g / l', 9131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g / l', 9129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g / l', 9130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 10114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 10115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 8585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 8586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 0.152, 'g / l', 49558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 0.152, 'g / l', 49559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 0.152, 'g / l', 49560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g / l', 62960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 62964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g / l', 62965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 66299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.06, 'g / l', 67542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 0.14, 'g / l', 71993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 0.14, 'g / l', 71997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 0.14, 'g / l', 71998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g / l', 73901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g / l', 73902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 73903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g / l', 73904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 73905);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 73915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 73916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 73917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g / l', 73919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 73921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 73922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g / l', 73923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 73924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g / l', 73925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g / l', 73927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g / l', 73929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 75411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.12, 'g / l', 75804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 75805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.12, 'g / l', 75811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.12, 'g / l', 75812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 73193);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 74785);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 74787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g / l', 74790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 74791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 74792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 74793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.06, 'g / l', 76226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 0.136, 'g / l', 78010);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 0.136, 'g / l', 78012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 81573);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 81574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 81576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 81578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g / l', 81236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g / l', 81237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 81238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 6.86, 'g / l', 81262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 6.86, 'g / l', 81265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g / l', 81270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 6.861, 'g / l', 81271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g / l', 81272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g / l', 81577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g / l', 81579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g / l', 81580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g / l', 81227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 81224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 81225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g / l', 81226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 81280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 81282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 81592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 81593);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 81594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 81596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g / l', 81598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g / l', 81600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g / l', 81279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 81281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g / l', 81283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 6.86, 'g / l', 81284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 6.86, 'g / l', 81239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 81240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g / l', 81241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g / l', 81242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 6.86, 'g / l', 81275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 6.86, 'g / l', 80217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g / l', 80218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g / l', 81222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 85140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 85141);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g / l', 85142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc acetate', 'D04AB07', 0.1, '%', 70300);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc acetate', 'D04AA32', 0.1, '%', 76655);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc acetate', 'D04AB07', 0.1, '% / w/w', 80391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc acetate', 'D04AA32', 0.1, '% / w/v', 76653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tromethamine', 'B05XX02', 36, 'mg / ml', 1731);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'S01XA20', 0.048, '%', 15177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'V07AB', 0.048, '%', 7474);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'V07AB', 0.048, '%', 6366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'V07AB', 0.0154, '%', 4913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 14.9, 'g / pck', 18321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.45, 'g / pck', 18310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 5.145, 'g / 1000 ml', 66962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 0.271, 'g / 1000 ml', 70916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 0.209, 'g / 1000 ml', 70917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 5.145, 'g / 1000 ml', 76308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 5.145, 'g / 1000 ml', 76310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 23.9, 'mg / 100 ml', 10512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 18.3, 'mg / 100 ml', 10865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 18.3, 'mg / 100 ml', 10863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 18.3, 'mg / 100 ml', 10864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05XA07', 100, 'mg / ml', 10770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 23.9, 'mg / 100 ml', 10143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 23.9, 'mg / 100 ml', 10144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 23.9, 'mg / 100 ml', 10009);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05XA07', 100, 'mg / ml', 4230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 18.4, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 36836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 2.5, 'g / l', 36814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 34881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.49, 'g / l', 34878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 2.49, 'g / l', 34879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 19744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 20121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 20116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 4.99, 'g / l', 20118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 20119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 20111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 20114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 20115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 19739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 19735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.48, 'g / l', 20076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 20044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 20045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 4.99, 'g / l', 20046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 20040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.48, 'g / l', 20041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.49, 'g / l', 18268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.49, 'g / l', 18206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.49, 'g / l', 18202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.49, 'g / l', 18199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 18200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.49, 'g / l', 18167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.49, 'g / l', 10820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 4.99, 'g / l', 9854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 9852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 4.99, 'g / l', 9845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.74, 'g / l', 9131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.74, 'g / l', 9129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.74, 'g / l', 9130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 10115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 10114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carboxymethyl cellulose', 'S01XA20', 0.5, '%', 78932);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.49, 'g / l', 8585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.49, 'g / l', 8586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 0.257, 'g / l', 49558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 0.257, 'g / l', 49559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 0.257, 'g / l', 49560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 62960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.49, 'g / l', 62964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 62965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 66299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 0.507, 'g / l', 71993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 0.507, 'g / l', 71997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 0.507, 'g / l', 71998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 73901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.74, 'g / l', 73902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 73903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 5.00, 'g / l', 73904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.49, 'g / l', 73905);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.47, 'g / l', 73915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 73916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 5.0, 'g / l', 73917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 73919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 73921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.47, 'g / l', 73922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.47, 'g / l', 73923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.47, 'g / l', 73924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.74, 'g / l', 73925);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.74, 'g / l', 73927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 73929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 75411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 75804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.49, 'g / l', 75805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 75811);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.49, 'g / l', 75812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 73193);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.47, 'g / l', 74785);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 74787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.47, 'g / l', 74790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 74791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 74792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 5.00, 'g / l', 74793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 0.343, 'g / l', 78010);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 0.343, 'g / l', 78012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.44, 'g / l', 81573);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 9.92, 'g / l', 81576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 9.92, 'g / l', 81578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 9.92, 'g / l', 81237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 9.92, 'g / l', 81270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.268, 'g / l', 81271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81579);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.62, 'g / l', 81580);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 9.92, 'g / l', 81227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 9.92, 'g / l', 81592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 9.92, 'g / l', 81593);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 9.92, 'g / l', 81594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 9.92, 'g / l', 81595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.61, 'g / l', 81602);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 7.44, 'g / l', 81281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.61, 'g / l', 81283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 9.92, 'g / l', 81284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 9.92, 'g / l', 81239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 9.92, 'g / l', 81240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.62, 'g / l', 81241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 3.31, 'g / l', 81242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 9.92, 'g / l', 81275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 10.25, 'g / l', 80217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 11.58, 'g / l', 80218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g / l', 81222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 85140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 85141);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g / l', 85142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', 'V07AV', 27.7, '%', 76536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', 'V07AV', 4.875, '%', 71086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', 'V07AV', 4.0, '%', 78664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', 'V07AV', 2.5, '%', 80092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', 'V07AV', 5.33, '%', 76049);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', 'V07AV', 6, '%', 83163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', 'V07AV', 4.846, '% / w/w', 82082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', 'V07AV', 59.9, '% / w/w', 78823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', 'V07AC', 189, 'mg / 63 ml', 23039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', 'V07AC', 730, 'mg / 100 ml', 11376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', 'V07AC', 440, 'mg / 100 ml', 11354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', 'B05ZA', 6.91, 'g / l', 85140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', 'B05ZA', 6.91, 'g / l', 85141);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('citric acid', 'B05ZA', 6.91, 'g / l', 85142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('edetate sodium', 'V07AV', 1.6, '%', 25675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('edetate sodium', 'V07AV', 0.38, '%', 15899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('edetate sodium', 'V07AV', 2.28, '%', 16133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('edetate sodium', 'V07AV', 0.5, '%', 15508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('edetate sodium', 'V07AV', 0.38, '%', 13767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('edetate sodium', 'V07AV', 1, '%', 3594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('edetate sodium', 'V07AV', 2.3, '%', 2486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('edetate sodium', 'V07AV', 1.4, '%', 2487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('edetate sodium', 'V07AV', 1.5, '%', 2679);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('edetate sodium', 'V07AV', 1.6, '%', 78430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('edetate sodium', 'V07AV', 1.6, '%', 82120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium tripolyphosphate', 'V07AV', 5, '%', 2305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium thiosulfate', 'V03AB06', 25, '%', 31283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate monobasic', 'B05XA06', 224, 'mg / ml', 19442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate monobasic', 'B05XA06', 224, 'mg / ml', 10509);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate monobasic', 'B05XA06', 176, 'mg / ml', 8119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate monobasic', 'B05XA06', 224, 'mg / ml', 69934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carboxymethyl cellulose', 'S01XA20', 1, '%', 11138);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carboxymethyl cellulose', 'S01XA20', 0.5, '%', 50289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carboxymethyl cellulose', 'S01XA20', 0.25, '%', 65756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carboxymethyl cellulose', 'S01XA20', 0.25, '%', 73225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carboxymethyl cellulose', 'S01XA20', 1.0, '%', 77230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carboxymethyl cellulose', 'S01XA20', 0.25, '%', 77181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carboxymethyl cellulose', 'S01XA20', 0.5, '% / w/v', 79819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carboxymethyl cellulose', 'S01XA20', 1.0, '% / w/v', 79819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carboxymethyl cellulose', 'S01XA20', 5, 'mg / ml', 27183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium carboxymethyl cellulose', 'S01XA20', 10, 'mg / ml', 68637);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mupirocin', 'D06AX09', 2, '%', 15207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mupirocin (mupirocin calcium dihydrate)', 'D06AX09', 2, '%', 63239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mupirocin', 'D06AX09', 2, '%', 76560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('domperidone (domperidone maleate)', 'A03FA03', 10, 'mg', 44066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('domperidone (domperidone maleate)', 'A03FA03', 10, 'mg', 13180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('domperidone (domperidone maleate)', 'A03FA03', 10, 'mg', 50801);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('domperidone (domperidone maleate)', 'A03FA03', 10, 'mg', 59887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('domperidone (domperidone maleate)', 'A03FA03', 10, 'mg', 60147);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('domperidone (domperidone maleate)', 'A03FA03', 10, 'mg', 61717);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('domperidone (domperidone maleate)', 'A03FA03', 10, 'mg', 61748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('domperidone (domperidone maleate)', 'A03FA03', 10, 'mg', 76423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('domperidone (domperidone maleate)', 'A03FA03', 10, 'mg', 75346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('domperidone (domperidone maleate)', 'A03FA03', 10, 'mg', 43813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('domperidone (domperidone maleate)', 'A03FA03', 10, 'mg', 83565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flutamide', 'L02BB01', 250, 'mg', 6035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flutamide', 'L02BB01', 250, 'mg', 48621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flutamide', 'L02BB01', 250, 'mg', 48636);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flutamide', 'L02BB01', 250, 'mg', 50149);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flutamide', 'L02BB01', 250, 'mg', 62498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flutamide', 'L02BB01', 250, 'mg', 61987);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levobunolol hydrochloride', 'S01ED03', 0.25, '%', 19584);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levobunolol hydrochloride', 'S01ED03', 0.5, '%', 19592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levobunolol hydrochloride', 'S01ED03', 0.25, '%', 20355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levobunolol hydrochloride', 'S01ED03', 0.5, '%', 20356);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levobunolol hydrochloride', 'S01ED03', 0.25, '%', 11894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levobunolol hydrochloride', 'S01ED03', 0.5, '%', 65228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levobunolol hydrochloride', 'S01ED03', 0.25, '%', 65229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levobunolol hydrochloride', 'S01ED03', 0.5, '%', 65379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levobunolol hydrochloride', 'S01ED03', 0.25, '%', 65378);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levobunolol hydrochloride', 'S01ED03', 0.5, '%', 61367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levobunolol hydrochloride', 'S01ED03', 5, 'mg / ml', 6230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoconazole', 'J02AB02', 200, 'mg', 43830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoconazole', 'J02AB02', 200, 'mg', 50343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoconazole', 'J02AB02', 200, 'mg', 60554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoconazole', 'D01AC08', 2, '%', 44259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketoconazole', 'D01AC08', 2, '%', 69762);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril maleate', 'C09AA02', 20, 'mg', 14388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril maleate', 'C09AA02', 10, 'mg', 14387);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril maleate', 'C09AA02', 2.5, 'mg', 14385);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril maleate', 'C09AA02', 5, 'mg', 14386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril maleate', 'C09AA02', 2.5, 'mg', 79698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril maleate', 'C09AA02', 5, 'mg', 79699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril maleate', 'C09AA02', 10, 'mg', 79700);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril maleate', 'C09AA02', 20, 'mg', 79701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon alfa-2b', 'L03AB05', 10000000, 'unit / vial', 43361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon alfa-2b', 'L03AB05', 18, 'miu / vial', 51025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon alfa-2b', 'L03AB05', 6000000, 'unit / ml', 62105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon alfa-2b', 'L03AB05', 10000000, 'unit / ml', 62106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon alfa-2b', 'L03AB05', 15000000, 'unit / ml', 64280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon alfa-2b', 'L03AB05', 25000000, 'unit / ml', 64281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('interferon alfa-2b', 'L03AB05', 50000000, 'unit / ml', 64282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carboplatin', 'L01XA02', 10, 'mg / ml', 43846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carboplatin', 'L01XA02', 10, 'mg / ml', 17830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leuprolide acetate', 'L02AE02', 3.75, 'mg / vial', 13443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leuprolide acetate', 'L02AE02', 7.5, 'mg / vial', 10318);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leuprolide acetate', 'L02AE02', 22.5, 'mg / vial', 48922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leuprolide acetate', 'L02AE02', 30, 'mg / vial', 63320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leuprolide acetate', 'L02AE02', 11.25, 'mg / vial', 63321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leuprolide acetate', 'L02AE02', 58.2, 'mg / syr', 75428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leuprolide acetate', 'L02AE02', 10.2, 'mg / syr', 72576);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leuprolide acetate', 'L02AE02', 28.2, 'mg / syr', 72577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leuprolide acetate', 'L02AE02', 35.8, 'mg / syr', 73384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 20, 'mg', 83631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('leuprolide acetate', 'L02AE02', 5, 'mg / ml', 7367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('d&c red no. 28', 'V04CX', 5, 'mg', 18692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cladribine', 'L01BB04', 1, 'mg / ml', 13846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cladribine', 'L01BB04', 1, 'mg / ml', 80536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ifosfamide', 'L01AA06', 3, 'g / vial', 64988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ifosfamide', 'L01AA06', 1, 'g / vial', 64989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ifosfamide', 'L01AA06', 1, 'g / vial', 70748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 30, 'mg', 67852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 15, 'mg', 72897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 30, 'mg', 72898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 45, 'mg', 72899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 15, 'mg', 76547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 30, 'mg', 76548);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 45, 'mg', 76549);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 15, 'mg', 76737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 15, 'mg', 76739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 15, 'mg', 74133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 30, 'mg', 74134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 45, 'mg', 74135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 30, 'mg', 73130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 30, 'mg', 75631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 30, 'mg', 74461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 30, 'mg', 75981);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 15, 'mg', 73540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 30, 'mg', 73541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 30, 'mg', 73715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 30, 'mg', 73716);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 30, 'mg', 75075);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 15, 'mg', 75940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 15, 'mg', 77206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 30, 'mg', 77207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 45, 'mg', 77208);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 15, 'mg', 79829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 30, 'mg', 79830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 15, 'mg', 81058);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 30, 'mg', 81059);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 15, 'mg', 78516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 30, 'mg', 78517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mirtazapine', 'N06AX11', 45, 'mg', 78518);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desloratadine', 'R06AX27', 5, 'mg', 67861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desloratadine', 'R06AX27', 5, 'mg', 78346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desloratadine', 'R06AX27', 5, 'mg', 82406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desloratadine', 'R06AX27', 0.5, 'mg / ml', 71435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tick-borne encephalitis vaccine (inactivated)', 'J07BA01', 2.4, 'µg / 0.5 ml', 75009);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aminolevulinic acid hydrochloride', 'L01XD04', 20, '%', 67875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tenofovir disoproxil fumarate', 'J05AF07', 300, 'mg', 71368);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fondaparinux sodium', 'B01AX05', 2.5, 'mg / 0.5 ml', 69618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fondaparinux sodium', 'B01AX05', 12.5, 'mg / ml', 74328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salmonella typhi vi capsular polysaccharide vaccine', 'J07AP03', 25, 'µg / 0.5 ml', 20287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('salmonella typhi vi capsular polysaccharide vaccine', 'J07AP03', 25, 'µg / 0.5 ml', 66534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gadobenate dimeglumine', 'V08CA08', 529, 'mg / ml', 72643);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pine tar', 'D05AA', 0.166, '%', 41695);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pine tar', 'D05AA', 0.33, '%', 5557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pine tar', 'D05AA', 0.09, '%', 2984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pine tar', 'D05AA', 0.16, '%', 1495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pine tar', 'D05AA', 0.33, '%', 64533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pegfilgrastim', 'L03AA13', 10, 'mg / ml', 73463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('galantamine (galantamine hydrobromide)', 'N06DA04', 8, 'mg', 75213);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('galantamine (galantamine hydrobromide)', 'N06DA04', 16, 'mg', 75214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('galantamine (galantamine hydrobromide)', 'N06DA04', 24, 'mg', 75215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('galantamine (galantamine hydrobromide)', 'N06DA04', 8, 'mg', 80244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('galantamine (galantamine hydrobromide)', 'N06DA04', 16, 'mg', 80245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('galantamine (galantamine hydrobromide)', 'N06DA04', 24, 'mg', 80246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('galantamine (galantamine hydrobromide)', 'N06DA04', 8, 'mg', 82505);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('galantamine (galantamine hydrobromide)', 'N06DA04', 16, 'mg', 82506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('galantamine (galantamine hydrobromide)', 'N06DA04', 24, 'mg', 82507);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caspofungin (caspofungin acetate)', 'J02AX04', 50, 'mg / vial', 68232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('caspofungin (caspofungin acetate)', 'J02AX04', 70, 'mg / vial', 68233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin aspart', 'A10AB05', 100, 'unit / ml', 68321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin aspart', 'A10AB05', 100, 'unit / ml', 69441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sufentanil (sufentanil citrate)', 'N01AH03', 50, 'µg / ml', 68108);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tadalafil', 'G04BE08', 10, 'mg', 72410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tadalafil', 'G04BE08', 20, 'mg', 72411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tadalafil', 'G04BE08', 2.5, 'mg', 78223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tadalafil', 'G04BE08', 5.0, 'mg', 78224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tadalafil', 'C02KX', 20, 'mg', 82395);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esomeprazole (esomeprazole magnesium trihydrate)', 'A02BC05', 20, 'mg', 68498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esomeprazole (esomeprazole magnesium trihydrate)', 'A02BC05', 40, 'mg', 68499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esomeprazole (esomeprazole magnesium)', 'A02BC05', 40, 'mg', 82473);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esomeprazole (esomeprazole magnesium trihydrate)', 'A02BC05', 10, 'mg / pck', 78581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium peroxymonosulfate', 'V07AV', 23, '%', 61485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium peroxymonosulfate', 'V07AV', 23, '%', 71548);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium peroxymonosulfate', 'V07AV', 21.4, '%', 73885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium peroxymonosulfate', 'V07AV', 23, '%', 75119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium peroxymonosulfate', 'V07AV', 21.4, '% / w/w', 30727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium peroxymonosulfate', 'V07AV', 34.4, '% / w/w', 72199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium peroxymonosulfate', 'V07AV', 21.4, '% / w/w', 76203);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclopirox', 'D01AE14', 8, '% / w/w', 78435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclopirox', 'D01AE14', 80, 'mg / g', 73535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('choriogonadotropin alpha', 'G03GA08', 250, 'µg / 0.5 ml', 74742);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hypromellose', 'S01XA20', 0.3, '%', 37084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hypromellose', 'S01XA20', 0.3, '%', 13167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hypromellose', 'S01XA20', 0.5, '%', 11709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hypromellose', 'S01XA20', 0.3, '%', 10032);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hypromellose', 'S01XA20', 0.3, '%', 2682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hypromellose', 'S01XA20', 0.5, '%', 793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hypromellose', 'S01XA20', 1, '%', 794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hypromellose', 'S01XA20', 0.2, '%', 47379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hypromellose', 'S01XA20', 0.3, '%', 66817);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hypromellose', 'S01XA20', 0.2, '%', 66850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hypromellose', 'S01XA20', 0.3, '%', 70567);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hypromellose', 'S01XA20', 0.3, '%', 77181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hypromellose', 'S01XA20', 0.2, '% / w/v', 83970);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hypromellose', 'S01XA20', 10, 'mg / ml', 11898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hypromellose', 'S01XA20', 3, 'mg / g', 50599);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 80, 'mg', 76495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 100, 'mg', 76496);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 10, 'mg', 74816);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 18, 'mg', 74817);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 25, 'mg', 74820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 40, 'mg', 74822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 60, 'mg', 74823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 10, 'mg', 80353);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 18, 'mg', 80354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 25, 'mg', 80355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 40, 'mg', 80356);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 60, 'mg', 80357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 80, 'mg', 80358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 100, 'mg', 80359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('escitalopram (escitalopram oxalate)', 'N06AB10', 10, 'mg', 74862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('escitalopram (escitalopram oxalate)', 'N06AB10', 20, 'mg', 74864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('allantoin', 'D04AB07', 1.5, '%', 75230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylchloroisothiazolinone', 'V04CL', 0.0032, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabies vaccine inactivated (purified chick embryo cell culture)', 'J07BG01', 2.5, 'unit / dose', 75308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 10, 'mg', 42879);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 20, 'mg', 19913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 40, 'mg', 19915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 40, 'mg', 15563);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 20, 'mg', 15564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 20, 'mg', 13654);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 40, 'mg', 13655);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 40, 'mg', 13583);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 20, 'mg', 13572);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 20, 'mg', 7087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 40, 'mg', 7088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 10, 'mg', 50715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 10, 'mg', 50389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 10, 'mg', 50911);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 10, 'mg', 50426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 20, 'mg', 60466);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 40, 'mg', 60467);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 10, 'mg', 60544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 10, 'mg', 63963);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 20, 'mg', 75884);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 10, 'mg / ml', 68883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 10, 'mg / ml', 68997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 10, 'mg / ml', 72016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('famotidine', 'A02BA03', 10, 'mg / ml', 72026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lithium (lithium citrate)', 'N05AN01', 8, 'mmo / 5 ml', 16938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 200, 'mg', 15489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 200, 'mg', 63322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 200, 'mg', 63581);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 200, 'mg', 64175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 200, 'mg', 66199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 200, 'mg', 67777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 200, 'mg', 71459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 200, 'mg', 70344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 200, 'mg', 70495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 200, 'mg', 69894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 100, 'mg', 77754);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 200, 'mg', 78625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 200, 'mg', 79532);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 200, 'mg', 84924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 50, 'mg / ml', 66036);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 50, 'mg / ml', 69271);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 50, 'mg / ml', 69797);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiodarone hydrochloride', 'C01BD01', 50, 'mg / ml', 71180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bumetanide', 'C03CA02', 1, 'mg', 14334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bumetanide', 'C03CA02', 5, 'mg', 14322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyhexanide', 'S01XA20', 0.0001, '%', 42295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyhexanide', 'S01XA20', 0.0001, '%', 71357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyhexanide', 'S01XA20', 0.0001, '%', 71150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyhexanide', 'S01XA20', 0.0001, '%', 75193);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyhexanide', 'S01XA20', 0.0001, '%', 75250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyhexanide', 'S01XA20', 0.0001, '%', 72573);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyhexanide', 'S01XA20', 0.0001, '%', 77650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nedocromil sodium', 'S01GX04', 2, '%', 65043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mesna', 'V03AF01', 100, 'mg / ml', 65047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mesna', 'V03AF01', 100, 'mg / ml', 68929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imatinib (imatinib mesylate)', 'L01XE01', 100, 'mg', 73824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imatinib (imatinib mesylate)', 'L01XE01', 400, 'mg', 73825);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tenecteplase', 'B01AD11', 50, 'mg / vial', 68816);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('travoprost', 'S01EE04', 0.004, '% / w/v', 80351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erlotinib (erlotinib hydrochloride)', 'L01XE03', 25, 'mg', 75441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erlotinib (erlotinib hydrochloride)', 'L01XE03', 100, 'mg', 75442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('erlotinib (erlotinib hydrochloride)', 'L01XE03', 150, 'mg', 75443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alemtuzumab', 'L01XC04', 30, 'mg / ml', 77636);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 42328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 29540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 200, 'mg', 26561);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 16492);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 14487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 250, 'mg', 13945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 11028);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 200, 'mg', 10975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 10986);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 9782);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 8974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 6258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 7365);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 52463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 63130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 69083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 69227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 70070);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 70167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 71630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 76671);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 78347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 78912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 81142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 200, 'mg', 82068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 250, 'mg', 82069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 84243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 100, 'mg', 84277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 10, 'mg / ml', 28453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 4, 'mg / ml', 28280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 20, 'mg / 5 ml', 26438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 4, 'mg / ml', 18776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 20, 'mg / 5 ml', 13039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 10, 'mg / ml', 14590);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 50, 'mg / ml', 10575);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 20, 'mg / 5 ml', 11520);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 10, 'mg / ml', 11521);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 10, 'mg / ml', 10878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 4, 'mg / ml', 9812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 20, 'mg / 5 ml', 8116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 4, 'mg / ml', 7366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 10, 'mg / ml', 47965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 20, 'mg / 5 ml', 61679);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 20, 'mg / 5 ml', 71056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 50, 'mg / ml', 76885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 4, 'mg / ml', 76886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docusate sodium', 'A06AA02', 10, 'mg / ml', 81816);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('peruvian balsam', 'V04CL', 0.65, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octanoic acid', 'V07AV', 3.05, '%', 76049);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octanoic acid', 'V07AV', 0.099, '% / w/w', 80441);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('immunoglobulin g (human)', 'J06BA01', 160, 'mg / ml', 76814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lactic acid', 'V07AV', 3.2, '%', 80959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lactic acid', 'B05ZA', 0.284, 'g / 1000 ml', 76040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lactic acid', 'B05ZA', 5.4, 'g / 1000 ml', 66962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-menthol', 'R02AA12', 4.0, 'mg', 74940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('l-menthol', 'M02AC', 1.00, 'g / 100 g', 61438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sorafenib (sorafenib tosylate)', 'L01XE05', 200, 'mg', 76977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('abatacept', 'L04AA24', 250, 'mg / vial', 76776);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pancreatin', 'A09AA02', 325, 'mg', 18096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pancreatin', 'A09AA02', 50, 'mg', 50394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bosentan (bosentan monohydrate)', 'C02KX01', 62.5, 'mg', 68979);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bosentan (bosentan monohydrate)', 'C02KX01', 125, 'mg', 68980);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('darbepoetin alfa', 'B03XA02', 25, 'µg / ml', 70520);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('darbepoetin alfa', 'B03XA02', 40, 'µg / ml', 70521);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('darbepoetin alfa', 'B03XA02', 100, 'µg / ml', 70523);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('darbepoetin alfa', 'B03XA02', 200, 'µg / ml', 70524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('darbepoetin alfa', 'B03XA02', 500, 'µg / ml', 70526);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alefacept', 'L04AA15', 15, 'mg / 0.5 ml', 74433);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('natalizumab', 'L04AA23', 300, 'mg / 15 ml', 77184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dutasteride', 'G04CB02', 0.5, 'mg', 72107);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethylbenzyl ammonium chloride', 'V07AV', 3.17, '%', 77180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethylbenzyl ammonium chloride', 'V07AV', 3.17, '%', 80406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimethylbenzyl ammonium chloride', 'V07AV', 3.17, '%', 79968);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('treprostinil (treprostinil sodium)', 'B01AC21', 1, 'mg / ml', 70735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('treprostinil (treprostinil sodium)', 'B01AC21', 2.5, 'mg / ml', 70736);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('treprostinil (treprostinil sodium)', 'B01AC21', 5, 'mg / ml', 70737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('treprostinil (treprostinil sodium)', 'B01AC21', 10, 'mg / ml', 70738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 1, 'mg', 69295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 2, 'mg', 69296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 4, 'mg', 69297);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 1, 'mg', 75494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 2, 'mg', 75495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 4, 'mg', 75497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 1, 'mg', 75861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 2, 'mg', 75862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 4, 'mg', 75863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 1, 'mg', 75923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 2, 'mg', 75924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 4, 'mg', 75926);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 1, 'mg', 75969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 2, 'mg', 75970);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 4, 'mg', 75972);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 1, 'mg', 78068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 2, 'mg', 78069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 4, 'mg', 78070);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 1, 'mg', 77011);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glimepiride', 'A10BB12', 2, 'mg', 77012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('anakinra', 'L04AC03', 150, 'mg / ml', 70033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etidronate disodium', 'M05BA01', 200, 'mg', 69359);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etidronate disodium', 'M05BA01', 200, 'mg', 73050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', 'B05XA06', 236, 'mg / ml', 19442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', 'B05XA06', 236, 'mg / ml', 10509);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium phosphate dibasic', 'B05XA06', 236, 'mg / ml', 69934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('arginine hydrochloride', 'V04CD', 250, 'mg / ml', 3378);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pollen and non pollen', 'V01AA20', 20000, 'unit / ml', 6237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('albumin (human)', 'B05AA01', 5, '%', 43384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('albumin (human)', 'B05AA01', 25, '%', 43385);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('albumin (human)', 'V07AB', 0.03, '%', 43388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('albumin (human)', 'B05AA01', 5, '%', 207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('albumin (human)', 'B05AA01', 25, '%', 208);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('albumin (human)', 'B05AA01', 5, '%', 76013);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('albumin (human)', 'B05AA01', 25, '%', 76014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('albumin (human)', 'V07AB', 0.03, '%', 76932);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('albumin (human)', 'B05AA01', 50, 'mg / ml', 42926);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('albumin (human)', 'B05AA01', 250, 'mg / ml', 42927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('albumin (human)', 'V07AB', 0.3, 'mg / ml', 8276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polysorbate 80', 'S01XA20', 0.8, '%', 16654);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protamine sulfate', 'V03AB14', 10, 'mg / ml', 19443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protamine sulfate', 'V03AB14', 10, 'mg / ml', 51049);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('protamine sulfate', 'V03AB14', 10, 'mg / ml', 64191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trisodium edetate', 'V07AV', 0.4, '%', 3026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 20, 'mg', 43279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 40, 'mg', 43280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 40, 'mg', 11100);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 20, 'mg', 9253);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 20, 'mg', 50750);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 20, 'mg', 66997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 40, 'mg', 66999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 20, 'mg', 69938);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 40, 'mg', 69939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 40, 'mg', 70725);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 20, 'mg', 70726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 20, 'mg', 71473);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 40, 'mg', 71474);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 20, 'mg', 70139);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 40, 'mg', 70140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 20, 'mg', 71221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 40, 'mg', 71222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 20, 'mg', 71291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 40, 'mg', 71292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 20, 'mg', 72927);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 40, 'mg', 72928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 20, 'mg', 75335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 40, 'mg', 75336);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 20, 'mg', 75781);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 40, 'mg', 75782);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 20, 'mg', 79820);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 40, 'mg', 79821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 20, 'mg', 83844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lovastatin', 'C10AA02', 40, 'mg', 83845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('selegiline hydrochloride', 'N04BD01', 5, 'mg', 16175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('selegiline hydrochloride', 'N04BD01', 5, 'mg', 50319);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('selegiline hydrochloride', 'N04BD01', 5, 'mg', 49813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('selegiline hydrochloride', 'N04BD01', 5, 'mg', 49977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('selegiline hydrochloride', 'N04BD01', 5, 'mg', 61495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('selegiline hydrochloride', 'N04BD01', 5, 'mg', 61721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('selegiline hydrochloride', 'N04BD01', 5, 'mg', 61747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isosorbide-5-mononitrate', 'C01DA14', 60, 'mg', 16804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isosorbide-5-mononitrate', 'C01DA14', 60, 'mg', 75834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isosorbide-5-mononitrate', 'C01DA14', 60, 'mg', 78661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isosorbide-5-mononitrate', 'C01DA14', 60, 'mg', 79692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loratadine', 'R06AX13', 10, 'mg', 10533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loratadine', 'R06AX13', 10, 'mg', 61088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loratadine', 'R06AX13', 10, 'mg', 67821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loratadine', 'R06AX13', 10, 'mg', 76583);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loratadine', 'R06AX13', 1, 'mg / ml', 13970);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loratadine', 'R06AX13', 1, 'mg / ml', 65175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nizatidine', 'A02BA04', 150, 'mg', 43277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nizatidine', 'A02BA04', 300, 'mg', 43278);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nizatidine', 'A02BA04', 150, 'mg', 44227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nizatidine', 'A02BA04', 300, 'mg', 44228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nizatidine', 'A02BA04', 150, 'mg', 42870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nizatidine', 'A02BA04', 150, 'mg', 8915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nizatidine', 'A02BA04', 300, 'mg', 8916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nizatidine', 'A02BA04', 150, 'mg', 61587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nizatidine', 'A02BA04', 300, 'mg', 61588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nizatidine', 'A02BA04', 150, 'mg', 64020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nizatidine', 'A02BA04', 300, 'mg', 64021);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('butoconazole nitrate', 'G01AF15', 2, '%', 72767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('felodipine', 'C08CA02', 10, 'mg', 43324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('felodipine', 'C08CA02', 2.5, 'mg', 43322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('felodipine', 'C08CA02', 5, 'mg', 43323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('felodipine', 'C08CA02', 2.5, 'mg', 15574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('felodipine', 'C08CA02', 5, 'mg', 12458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('felodipine', 'C08CA02', 10, 'mg', 12459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('felodipine', 'C08CA02', 5, 'mg', 76593);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('felodipine', 'C08CA02', 10, 'mg', 76594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('omeprazole', 'A02BC01', 10, 'mg', 43827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('omeprazole (omeprazole magnesium)', 'A02BC01', 20, 'mg', 19716);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('omeprazole', 'A02BC01', 20, 'mg', 9823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('omeprazole (omeprazole magnesium)', 'A02BC01', 10, 'mg', 50000);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('omeprazole', 'A02BC01', 20, 'mg', 69062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('omeprazole (omeprazole magnesium)', 'A02BC01', 10, 'mg', 74628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('omeprazole (omeprazole magnesium)', 'A02BC01', 20, 'mg', 74629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('omeprazole', 'A02BC01', 10, 'mg', 78175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('omeprazole', 'A02BC01', 20, 'mg', 78176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('omeprazole', 'A02BC01', 20, 'mg', 82550);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('omeprazole', 'A02BC01', 10, 'mg', 81517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('omeprazole', 'A02BC01', 20, 'mg', 81518);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('omeprazole', 'A02BC01', 20, 'mg', 80626);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('omeprazole (omeprazole magnesium)', 'A02BC01', 10, 'mg', 79590);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('omeprazole (omeprazole magnesium)', 'A02BC01', 20, 'mg', 79591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('omeprazole', 'A02BC01', 20, 'mg', 83404);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 5, 'mg', 43221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 10, 'mg', 43222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 20, 'mg', 43223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 40, 'mg', 43224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 10, 'mg', 17215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 20, 'mg', 17123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 5, 'mg', 17126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 5, 'mg', 11101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 10, 'mg', 11102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 20, 'mg', 11103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 10, 'mg', 74204);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 5, 'mg', 74203);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 20, 'mg', 74205);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 5, 'mg', 75690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 10, 'mg', 75691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 20, 'mg', 75692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 5, 'mg', 76037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 10, 'mg', 76038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 20, 'mg', 76039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 5, 'mg', 77059);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 10, 'mg', 77060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 20, 'mg', 77061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 5, 'mg', 77062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 10, 'mg', 77063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 20, 'mg', 77064);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 5, 'mg', 77458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 10, 'mg', 77459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 20, 'mg', 77460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 5, 'mg', 77958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 10, 'mg', 77959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 20, 'mg', 77960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 5, 'mg', 77756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 10, 'mg', 77757);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 20, 'mg', 77758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 5, 'mg', 77994);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 10, 'mg', 77995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 20, 'mg', 77996);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 5, 'mg', 77997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 10, 'mg', 77998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 20, 'mg', 77999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 5, 'mg', 78522);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 10, 'mg', 78523);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 20, 'mg', 78524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 5, 'mg', 79658);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 10, 'mg', 79659);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 20, 'mg', 79660);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 10, 'mg', 78633);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 5, 'mg', 78631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 20, 'mg', 78634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 5, 'mg', 80292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 10, 'mg', 80293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 20, 'mg', 80294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 5, 'mg', 80698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 10, 'mg', 80699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril', 'C09AA03', 20, 'mg', 80702);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 5, 'mg', 84661);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 10, 'mg', 84662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 20, 'mg', 84663);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acitretin', 'D05BB02', 25, 'mg', 16167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acitretin', 'D05BB02', 10, 'mg', 16168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pentastarch', 'B05AA07', 10, 'g / 100 ml', 13582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 50, 'mg', 43250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 100, 'mg', 43251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 100, 'mg', 11751);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 50, 'mg', 11752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 50, 'mg', 50637);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 100, 'mg', 50638);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 50, 'mg', 50499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 100, 'mg', 50500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 50, 'mg', 60040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 100, 'mg', 60041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 50, 'mg', 63456);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 100, 'mg', 63457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 50, 'mg', 64266);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 100, 'mg', 64267);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 50, 'mg', 64977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 100, 'mg', 64978);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 50, 'mg', 71289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 100, 'mg', 71290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 50, 'mg', 74072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 100, 'mg', 74073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 50, 'mg', 74800);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 100, 'mg', 74801);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 50, 'mg', 78867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluvoxamine maleate', 'N06AB08', 100, 'mg', 78869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benazepril hydrochloride', 'C09AA07', 5, 'mg', 14273);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benazepril hydrochloride', 'C09AA07', 10, 'mg', 14274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benazepril hydrochloride', 'C09AA07', 20, 'mg', 14276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benazepril hydrochloride', 'C09AA07', 20, 'mg', 75937);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benazepril hydrochloride', 'C09AA07', 5, 'mg', 77563);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('benazepril hydrochloride', 'C09AA07', 10, 'mg', 77564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('milrinone (milrinone lactate)', 'C01CE02', 1, 'mg / ml', 68801);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('milrinone (milrinone lactate)', 'C01CE02', 1.0, 'mg / ml', 68844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('milrinone (milrinone lactate)', 'C01CE02', 1.0, 'mg / ml', 68609);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('milrinone (milrinone lactate)', 'C01CE02', 1.0, 'mg / ml', 73466);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoprolol fumarate', 'C07AB07', 5, 'mg', 78793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoprolol fumarate', 'C07AB07', 5, 'mg', 71685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoprolol fumarate', 'C07AB07', 10, 'mg', 71686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoprolol fumarate', 'C07AB07', 5, 'mg', 75288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoprolol fumarate', 'C07AB07', 10, 'mg', 75289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoprolol fumarate', 'C07AB07', 5, 'mg', 74136);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoprolol fumarate', 'C07AB07', 10, 'mg', 74140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoprolol fumarate', 'C07AB07', 10, 'mg', 78794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoprolol fumarate', 'C07AB07', 5, 'mg', 79399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoprolol fumarate', 'C07AB07', 10, 'mg', 79400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoprolol fumarate', 'C07AB07', 5, 'mg', 79267);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoprolol fumarate', 'C07AB07', 10, 'mg', 79268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoprolol fumarate', 'C07AB07', 5, 'mg', 80695);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bisoprolol fumarate', 'C07AB07', 10, 'mg', 80697);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tenoxicam', 'M01AC02', 20, 'mg', 49920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flumazenil', 'V03AB25', 0.1, 'mg / ml', 11944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flumazenil', 'V03AB25', 0.1, 'mg / ml', 75176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flumazenil', 'V03AB25', 0.1, 'mg / ml', 73439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenhydramine citrate', 'R06AA02', 38, 'mg', 77477);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketorolac tromethamine', 'M01AB15', 10, 'mg', 43510);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketorolac tromethamine', 'M01AB15', 10, 'mg', 19348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketorolac tromethamine', 'M01AB15', 10, 'mg', 48899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketorolac tromethamine', 'M01AB15', 10, 'mg', 61273);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketorolac tromethamine', 'S01BC05', 0.5, '%', 13121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketorolac tromethamine', 'S01BC05', 0.5, '%', 69937);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketorolac tromethamine', 'S01BC05', 0.5, '%', 71709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketorolac tromethamine', 'S01BC05', 0.4, '%', 73086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketorolac tromethamine', 'M01AB15', 10, 'mg / ml', 44090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketorolac tromethamine', 'M01AB15', 30, 'mg / ml', 63447);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketorolac tromethamine', 'M01AB15', 30, 'mg / ml', 67933);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ketorolac tromethamine', 'M01AB15', 30, 'mg / ml', 68945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zidovudine', 'J05AF01', 100, 'mg', 13022);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zidovudine', 'J05AF01', 100, 'mg', 11300);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zidovudine', 'J05AF01', 100, 'mg', 12839);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zidovudine', 'J05AF01', 50, 'mg / 5 ml', 11942);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zidovudine', 'J05AF01', 10, 'mg / ml', 11342);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 3.125, 'mg', 70034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 6.25, 'mg', 70035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 12.5, 'mg', 70036);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 25, 'mg', 70037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 3.125, 'mg', 70711);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 6.25, 'mg', 70712);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 12.5, 'mg', 70713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 25, 'mg', 70714);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 3.125, 'mg', 72243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 6.25, 'mg', 72244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 12.5, 'mg', 72245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 25, 'mg', 72246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 12.5, 'mg', 75344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 6.25, 'mg', 75343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 3.125, 'mg', 75342);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 25, 'mg', 75345);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 3.125, 'mg', 73116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 6.25, 'mg', 73117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 12.5, 'mg', 73118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 25, 'mg', 73119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 3.125, 'mg', 73120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 6.25, 'mg', 73121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 12.5, 'mg', 73122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 25, 'mg', 73123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 3.125, 'mg', 73718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 6.25, 'mg', 73719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 12.5, 'mg', 73720);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 25, 'mg', 73721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 3.125, 'mg', 83013);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 6.25, 'mg', 83014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 12.5, 'mg', 83015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 3.125, 'mg', 80995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 6.25, 'mg', 80996);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 12.5, 'mg', 80997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 25.0, 'mg', 80998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 3.125, 'mg', 82370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 6.25, 'mg', 82371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 12.5, 'mg', 82374);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 25, 'mg', 82375);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 3.125, 'mg', 83290);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 6.25, 'mg', 83292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 12.5, 'mg', 83294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 25, 'mg', 83296);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 3.125, 'mg', 84979);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 6.25, 'mg', 84980);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 12.5, 'mg', 84981);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 25, 'mg', 84982);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 3.125, 'mg', 85386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 6.25, 'mg', 85387);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 12.5, 'mg', 85388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carvedilol', 'C07AG02', 25, 'mg', 85389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('formoterol fumarate dihydrate', 'R03AC13', 12, 'µg / dose', 60542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('formoterol fumarate dihydrate', 'R03AC13', 6, 'µg / dose', 60543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nateglinide', 'A10BX03', 60, 'mg', 69490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nateglinide', 'A10BX03', 120, 'mg', 69491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tipranavir', 'J05AE09', 250, 'mg', 75881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('surfactant-associated proteins sp-b and sp-c', 'R07AA30', 500, 'µg / ml', 69524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alfuzosin hydrochloride', 'G04CA01', 10, 'mg', 69657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alfuzosin hydrochloride', 'G04CA01', 10, 'mg', 78993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alfuzosin hydrochloride', 'G04CA01', 10, 'mg', 79984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alfuzosin hydrochloride', 'G04CA01', 10, 'mg', 80137);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 1.25, 'mg', 15889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 0.625, 'mg', 15782);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 0.3, 'mg', 15486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 2.5, 'mg', 10883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 1.25, 'mg', 10884);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 0.9, 'mg', 10885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 0.625, 'mg', 10886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 0.3, 'mg', 10887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 0.625, 'mg', 5311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 1.25, 'mg', 5312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 0.625, 'mg', 1657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 1.25, 'mg', 1658);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 0.3, 'mg', 50169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 0.9, 'mg', 50170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 0.3, 'mg', 63126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 0.9, 'mg', 63127);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 25, 'mg / vial', 16736);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('conjugated estrogens', 'G03CA57', 0.625, 'mg / g', 15704);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ganirelix (ganirelix acetate)', 'H01CC01', 250, 'µg / 0.5 ml', 69741);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('modified ragweed tyrosine adsorbate', 'V01AA02', 210, 'unit / ml', 3409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('modified ragweed tyrosine adsorbate', 'V01AA02', 500, 'unit / ml', 3409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('modified ragweed tyrosine adsorbate', 'V01AA02', 1400, 'unit / ml', 3409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('modified ragweed tyrosine adsorbate', 'V01AA02', 4300, 'unit / ml', 3409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('docosanol', 'D06BB11', 10, '%', 69777);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin glargine', 'A10AE04', 100, 'unit / ml', 69790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin glargine', 'A10AE04', 100, 'unit / ml', 73683);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin glargine', 'A10AE04', 100, 'unit / ml', 77967);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chlorite', 'V07AV', 20.8, '%', 76528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium chlorite', 'V07AV', 30.5, '% / w/w', 78823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 50, 'ml', 50130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'J07BK01', 0.5, 'ml', 64641);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 1, 'ml', 76176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 100, '%', 31491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 100, '%', 19812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'G04BE01', 99.1, '%', 20353);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 99.1, '%', 20354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 100, '%', 17402);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 100, '%', 13509);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 100, '%', 9831);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 100, '%', 3822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 100, '%', 3383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 100, '%', 1734);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 100, '%', 117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 100, '%', 68381);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 100, '%', 229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 100, '%', 75493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 100, '%', 78457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'L03AB05', 1, 'ml / vial', 43361);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'G03GA01', 10, 'ml / vial', 44257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'H01AC01', 10, 'ml / vial', 43174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'L03AB05', 1, 'ml / vial', 51025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'H02AB04', 10, 'ml / vial', 52240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'H02AB04', 20, 'ml / vial', 52242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'B01AB02', 20, 'ml / vial', 61169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'B01AB02', 10, 'ml / vial', 61170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 10, 'ml / vial', 83498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 100, '%', 15867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'V07AB', 100, '%', 13287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'B01AD02', 50, 'ml / kit', 43443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'B01AD02', 100, 'ml / kit', 20105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'H01AC01', 1, 'ml / kit', 62499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'H01AC01', 1, 'ml / kit', 62500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'B01AB02', 30, 'ml / kit', 61171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'H01AC01', 10, 'ml / kit', 61332);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('water', 'L04AB01', 1, 'ml / kit', 66735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('wool alcohols', 'V04CL', 0.81, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tramadol hydrochloride', 'N02AX02', 100, 'mg', 78172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tramadol hydrochloride', 'N02AX02', 200, 'mg', 78173);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tramadol hydrochloride', 'N02AX02', 300, 'mg', 78174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tramadol hydrochloride', 'N02AX02', 100, 'mg', 78458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tramadol hydrochloride', 'N02AX02', 200, 'mg', 78459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tramadol hydrochloride', 'N02AX02', 300, 'mg', 78460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tramadol hydrochloride', 'N02AX02', 150, 'mg', 77188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tramadol hydrochloride', 'N02AX02', 200, 'mg', 77189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tramadol hydrochloride', 'N02AX02', 300, 'mg', 77190);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tramadol hydrochloride', 'N02AX02', 400, 'mg', 77191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tramadol hydrochloride', 'N02AX02', 50, 'mg', 83476);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tramadol hydrochloride', 'N02AX02', 75, 'mg', 84529);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tramadol hydrochloride', 'N02AX02', 100, 'mg', 84531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium dodecylbenzenesulfonate', 'V07AV', 2.028, '%', 3629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium dodecylbenzenesulfonate', 'V07AV', 2.75, '%', 2802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.5, '%', 65189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 2.23, '%', 67293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 2.23, '%', 65332);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 2, '%', 64877);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D11AX11', 7.5, '%', 66772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.5, '%', 69963);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 1.0, '%', 72269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 5, '%', 70113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 6, '%', 70114);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 4, '%', 71614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 3.5, '%', 70981);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 3.5, '%', 70997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 4.996, '%', 70539);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7, '%', 72890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.5, '%', 72783);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D11AX11', 7.5, '%', 76383);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D11AX11', 7.5, '%', 75425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D11AX11', 7.5, '%', 74229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.5, '%', 74408);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.5, '%', 75864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 5, '%', 73389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 5, '%', 73391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D11AX11', 7.5, '%', 73488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 5, '%', 75061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.0, '%', 76974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.5, '%', 77552);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.5, '%', 77295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.50, '%', 76914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 3.0, '%', 76915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 5.0, '%', 78680);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 2.0, '%', 79387);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 5.0, '%', 79225);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D10AF01', 7.5, '%', 66809);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.5, '%', 84268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D06BX01', 7.5, '%', 66753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 2, '% / w/w', 82349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.5, '% / w/w', 81410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D11AX11', 7.5, '% / w/w', 80960);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 3.5, '% / w/w', 80720);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 4, '% / w/w', 82802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 3.5, '% / w/w', 78652);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 2.5, '% / w/w', 81378);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 2.5, '% / w/w', 81352);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.5, '% / w/w', 80878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 6.5, '% / w/w', 81145);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.5, '% / w/w', 80319);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 3, '% / w/w', 81984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.5, '% / w/w', 81033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.0, '% / w/w', 82128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 2.0, '% / w/w', 79705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 3, '% / w/w', 83081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.5, '% / w/w', 83120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.5, '% / w/w', 83121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.0, '% / w/w', 83146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.5, '% / w/w', 83317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.5, '% / w/w', 84040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7, '% / w/w', 84151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 4, '% / w/w', 84378);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 2, '% / w/w', 84398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 7.5, '% / w/w', 84761);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 6, '%', 50055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 3, '%', 64341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octinoxate', 'D02BA02', 4, 'g / 100 g', 74459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium oxybate', 'N07XX04', 500, 'mg / ml', 75367);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clozapine', 'N05AH02', 100, 'mg', 11421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clozapine', 'N05AH02', 25, 'mg', 11422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clozapine', 'N05AH02', 25, 'mg', 71485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clozapine', 'N05AH02', 100, 'mg', 71486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clozapine', 'N05AH02', 25, 'mg', 72354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clozapine', 'N05AH02', 100, 'mg', 72355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clozapine', 'N05AH02', 50, 'mg', 79038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clozapine', 'N05AH02', 200, 'mg', 79039);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terconazole', 'G01AG02', 80, 'mg', 17222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terconazole', 'G01AG02', 0.8, '%', 17222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terconazole', 'G01AG02', 0.4, '%', 71914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terconazole', 'G01AG02', 4, 'mg / g', 11460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg', 43478);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg', 43233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 5.0, 'mg', 43171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg', 19922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg', 12426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg', 62024);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg', 64177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg', 64414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 3.75, 'mg', 66207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg', 66208);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 5, 'mg', 67334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 5, 'mg', 69081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 5, 'mg', 70717);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 5, 'mg', 70480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 5, 'mg', 75330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg', 75331);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 5, 'mg', 74282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg', 74283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 5, 'mg', 75747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg', 75748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg', 73639);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 5, 'mg', 73638);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg', 76363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 5, 'mg', 76362);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg', 76809);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 5, 'mg', 77941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg', 77942);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 5, 'mg', 78196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 5, 'mg', 82952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 5, 'mg', 79861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg', 79862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 5, 'mg', 80693);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg', 80694);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 43329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 11029);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 11030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 68318);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 68319);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 68320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 67424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 67425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 67426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 67763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 67764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 67765);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 72163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 72165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 72166);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 71157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 71158);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 71159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 71918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 71919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 71920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 71241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 71242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 71243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 74231);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 74232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 74233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 75562);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 75563);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 75564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 72518);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 72519);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 72520);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 73456);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 73457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 73458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 73459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 73460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 73461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 77000);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 77001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 77002);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 78713);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 78714);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 78715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 80298);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 80299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 80300);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 81669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 81670);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 81671);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 10, 'mg', 84168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 20, 'mg', 84169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pravastatin sodium', 'C10AA03', 40, 'mg', 84170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 150, 'mg', 17789);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 50, 'mg', 10952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 100, 'mg', 10953);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 50, 'mg', 60693);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 100, 'mg', 60694);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 50, 'mg', 60273);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 100, 'mg', 60274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 150, 'mg', 65565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 50, 'mg', 69316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 100, 'mg', 69317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 150, 'mg', 67573);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 150, 'mg', 70808);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 50, 'mg', 70245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 100, 'mg', 70246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 50, 'mg', 69743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 100, 'mg', 69744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 150, 'mg', 69798);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 150, 'mg', 74071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 50, 'mg', 76691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 100, 'mg', 76692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 100, 'mg', 75698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 50, 'mg', 73413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 100, 'mg', 73414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 150, 'mg', 76799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 150, 'mg', 77940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 100, 'mg', 79630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 150, 'mg', 79631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 50, 'mg', 78725);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 100, 'mg', 78726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 150, 'mg', 78727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 150, 'mg', 79724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 150, 'mg', 80890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 150, 'mg', 83738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 50, 'mg / 5 ml', 18010);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 2, 'mg / ml', 10954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 2, 'mg / ml', 72232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 2, 'mg / ml', 72035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 2, 'mg / ml', 72794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 2, 'mg / ml', 74685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluconazole', 'J02AC01', 150, 'mg / cap', 79728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac potassium', 'M01AB05', 50, 'mg', 13805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac potassium', 'M01AB05', 50, 'mg', 62824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac potassium', 'M01AB05', 50, 'mg', 63235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac potassium', 'M01AB05', 50, 'mg', 67343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac potassium', 'M01AB05', 50, 'mg', 74714);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac potassium', 'M01AB05', 50, 'mg', 79703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac potassium', 'M01AB05', 50, 'mg', 83694);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyethyl starch 130/0.4', 'B05AA07', 6, '%', 84242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', 'V07AC', 1.6, 'g / 100 ml', 11330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', 'B05ZA', 4.72, 'g / 1000 ml', 70916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', 'B05ZA', 4.72, 'g / 1000 ml', 70917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', 'B05ZA', 392, 'mg / 100 ml', 10512);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', 'B05ZA', 448, 'mg / 100 ml', 10863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', 'B05ZA', 448, 'mg / 100 ml', 10864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', 'B05ZA', 448, 'mg / 100 ml', 10865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', 'B05ZA', 392, 'mg / 100 ml', 10143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', 'B05ZA', 392, 'mg / 100 ml', 10144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', 'B05ZA', 392, 'mg / 100 ml', 10009);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', 'B05ZA', 448, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', 'B05ZA', 4.483, 'g / l', 49558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', 'B05ZA', 4.483, 'g / l', 49559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', 'B05ZA', 4.483, 'g / l', 49560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', 'B05ZA', 2.63, 'g / l', 71993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', 'B05ZA', 2.63, 'g / l', 71997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium lactate', 'B05ZA', 2.63, 'g / l', 71998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium acetate', 'B05XA17', 392, 'mg / ml', 19078);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium acetate', 'B05XA17', 392, 'mg / ml', 9429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ezetimibe', 'C10AX09', 10, 'mg', 71771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('3-(trimethoxysilyl)propyl dimethyl octadecyl ammonium chloride', 'V07AV', 0.11, '%', 70433);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valganciclovir (valganciclovir hydrochloride)', 'J05AB14', 450, 'mg', 69890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valganciclovir (valganciclovir hydrochloride)', 'J05AB14', 50, 'mg / ml', 79164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('palivizumab', 'J06BB16', 50, 'mg / vial', 70006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('palivizumab', 'J06BB16', 100, 'mg / vial', 70007);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moroctocog alfa', 'B02BD02', 250, 'unit / vial', 79508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moroctocog alfa', 'B02BD02', 500, 'unit / vial', 79509);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moroctocog alfa', 'B02BD02', 1000, 'unit / vial', 79510);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moroctocog alfa', 'B02BD02', 2000, 'unit / vial', 79511);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thyrotropin alfa', 'V04CJ01', 0.9, 'mg / ml', 70142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyethyl starch 130/0.4', 'B05AA07', 6, '%', 76364);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('betaine', 'A16AA06', 1, 'g / 1.7 cc', 61949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextran (dextran 70)', 'S01XA20', 0.1, '%', 13167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextran (dextran 70)', 'S01XA20', 0.1, '%', 10032);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextran', 'S01XA20', 0.1, '%', 2682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextran', 'S01XA20', 0.1, '%', 70567);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('palifermin', 'V03AF08', 6.25, 'mg / vial', 75968);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('darunavir (darunavir ethanolate)', 'J05AE10', 75, 'mg', 82408);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('darunavir (darunavir ethanolate)', 'J05AE10', 400, 'mg', 80949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('darunavir (darunavir ethanolate)', 'J05AE10', 600, 'mg', 80950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrazepam', 'N05CD02', 5, 'mg', 3991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrazepam', 'N05CD02', 10, 'mg', 3992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrazepam', 'N05CD02', 5, 'mg', 47629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrazepam', 'N05CD02', 10, 'mg', 47630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrazepam', 'N05CD02', 5, 'mg', 53893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrazepam', 'N05CD02', 10, 'mg', 53896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrazepam', 'N05CD02', 5, 'mg', 69245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitrazepam', 'N05CD02', 10, 'mg', 69246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n-isopropyl-n''-phenyl-para-phenylenediamine', 'V04CL', 0.01, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n-cyclohexyl-n''-phenyl-para-phenylenediamine', 'V04CL', 0.025, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n,n''-diphenyl-para-phenylenediamine', 'V04CL', 0.025, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mercaptobenzothiazole', 'V04CL', 0.061, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n-hydroxymethylsuccinimide', 'V04CL', 0.15, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('(morpholinothio)benzothiazole', 'V04CL', 0.02, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('n-cyclohexyl-2-benzothiazolesulfenamide', 'V04CL', 0.02, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dithiobis(benzothiazole)', 'V04CL', 0.02, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetramethylthiuram monosulfide', 'V04CL', 0.005, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiram', 'V04CL', 0.005, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bis(1-piperidylthiocarbonyl)disulfide', 'V04CL', 0.005, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium polycarbophil', 'A06AC08', 625, 'mg', 70837);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glucagon (recombinant dna origin)', 'H04AA01', 1, 'mg / vial', 67195);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glucagon (recombinant dna origin) (glucagon hydrochloride)', 'H04AA01', 1, 'mg / vial', 81923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('glucagon (recombinant dna origin) (glucagon hydrochloride)', 'H04AA01', 1, 'mg / vial', 81924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yohimbine hydrochloride', 'G04BE04', 6, 'mg', 13132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norfloxacin', 'J01MA06', 400, 'mg', 47429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yohimbine hydrochloride', 'G04BE04', 5.4, 'mg', 12016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('yohimbine hydrochloride', 'G04BE04', 2, 'mg', 12575);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysacc. serot. 18c conjug. to tetanus toxoid carrier prot.', 'J07AL02', 3, 'µg / 0.5 ml', 80596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharid serot. 19f conjug. to diphtheria toxoid carrier prot.', 'J07AL02', 3, 'µg / 0.5 ml', 80596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hetastarch', 'B05AA07', 6, 'g / 100 ml', 70150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('denosumab', 'M05BX04', 60, 'mg / ml', 82897);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('denosumab', 'M05BX04', 120, 'mg / 1.7 ml', 85304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tropicamide', 'S01FA06', 0.5, '%', 260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tropicamide', 'S01FA06', 1, '% / w/v', 18758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tropicamide', 'S01FA06', 1, '%', 16255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tropicamide', 'S01FA06', 0.5, '%', 16634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tropicamide', 'S01FA06', 1, '%', 6054);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tropicamide', 'S01FA06', 0.5, '%', 6056);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tropicamide', 'S01FA06', 1, '%', 780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lincomycin (lincomycin hydrochloride)', 'J01FF02', 300, 'mg / ml', 425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12', 10, 'mg', 15118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12', 100, 'mg', 15104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12', 150, 'mg', 15105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12', 25, 'mg', 15106);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12', 50, 'mg', 15107);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12', 75, 'mg', 15108);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12', 10, 'mg', 944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12', 25, 'mg', 945);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12', 50, 'mg', 946);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12', 75, 'mg', 2780);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12', 100, 'mg', 2049);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('quinidine sulfate', 'C01BA01', 190, 'mg / ml', 4516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iohexol', 'V08AB02', 388, 'mg / ml', 44184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iohexol', 'V08AB02', 518, 'mg / ml', 44185);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iohexol', 'V08AB02', 647, 'mg / ml', 44186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iohexol', 'V08AB02', 755, 'mg / ml', 44187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amantadine hydrochloride', 'N04BB01', 100, 'mg', 43886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amantadine hydrochloride', 'N04BB01', 100, 'mg', 17975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amantadine hydrochloride', 'N04BB01', 100, 'mg', 13464);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amantadine hydrochloride', 'N04BB01', 10, 'mg / ml', 14393);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amantadine hydrochloride', 'N04BB01', 10, 'mg / ml', 74802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('halobetasol propionate', 'D07AC21', 0.05, '%', 13917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('halobetasol propionate', 'D07AC21', 0.05, '%', 13909);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinolone acetonide', 'D07AC04', 0.025, '%', 20258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinolone acetonide', 'D07AC04', 0.01, '%', 20009);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinolone acetonide', 'D07AC04', 0.01, '%', 13875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinolone acetonide', 'D07AC04', 0.01, '%', 66546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinolone acetonide', 'S02BA08', 0.01, '% / w/v', 78584);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinolone acetonide', 'D07AC04', 0.01, '%', 9273);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinolone acetonide', 'D07AC04', 0.025, '%', 8975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinolone acetonide', 'D07AC04', 0.25, 'mg / g', 9447);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enoxaparin sodium', 'B01AB05', 100, 'mg / ml', 14049);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enoxaparin sodium', 'B01AB05', 100, 'mg / ml', 59932);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enoxaparin sodium', 'B01AB05', 100, 'mg / ml', 60174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enoxaparin sodium', 'B01AB05', 150, 'mg / ml', 66484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('asparaginase', 'L01XX02', 10000, 'unit / vial', 12995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('asparaginase', 'L01XX02', 10000, 'unit / vial', 61174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bicalutamide', 'L02BB03', 50, 'mg', 19647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bicalutamide', 'L02BB03', 50, 'mg', 76331);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bicalutamide', 'L02BB03', 50, 'mg', 76679);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bicalutamide', 'L02BB03', 50, 'mg', 76683);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bicalutamide', 'L02BB03', 50, 'mg', 75561);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bicalutamide', 'L02BB03', 50, 'mg', 75978);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bicalutamide', 'L02BB03', 50, 'mg', 76122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bicalutamide', 'L02BB03', 50, 'mg', 76175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bicalutamide', 'L02BB03', 50, 'mg', 78142);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bicalutamide', 'L02BB03', 50, 'mg', 81064);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bicalutamide', 'L02BB03', 50, 'mg', 79663);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bicalutamide', 'L02BB03', 50, 'mg', 81133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bicalutamide', 'L02BB03', 50, 'mg', 78772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bicalutamide', 'L02BB03', 50, 'mg', 84234);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dalteparin sodium', 'B01AB04', 5000, 'unit / 0.2 ml', 18306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dalteparin sodium', 'B01AB04', 2500, 'unit / 0.2 ml', 18307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dalteparin sodium', 'B01AB04', 10000, 'unit / ml', 18235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dalteparin sodium', 'B01AB04', 25000, 'unit / ml', 50478);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dalteparin sodium', 'B01AB04', 7500, 'unit / 0.3 ml', 83790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dalteparin sodium', 'B01AB04', 10000, 'unit / 0.4 ml', 83791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dalteparin sodium', 'B01AB04', 12500, 'unit / 0.5 ml', 83792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dalteparin sodium', 'B01AB04', 15000, 'unit / 0.6 ml', 83793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dalteparin sodium', 'B01AB04', 18000, 'unit / 0.72 ml', 83794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tinzaparin sodium', 'B01AB10', 10000, 'unit / ml', 19202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tinzaparin sodium', 'B01AB10', 20000, 'unit / ml', 47420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tinzaparin sodium', 'B01AB10', 10000, 'unit / ml', 47983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tinzaparin sodium', 'B01AB10', 20000, 'unit / ml', 50802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 10, 'unit / ml', 45892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 25000, 'unit / ml', 18721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gliclazide', 'A10BB09', 80, 'mg', 77250);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 1000, 'unit / ml', 10526);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 50, 'unit / ml', 12646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 40, 'unit / ml', 12647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 10, 'unit / ml', 9790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 100, 'unit / ml', 9791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 1000, 'unit / ml', 9470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 10000, 'unit / ml', 9471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 100, 'unit / ml', 9400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 25000, 'unit / ml', 8041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 100, 'unit / ml', 8042);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 10000, 'unit / ml', 8043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'V07AC', 10, 'unit / ml', 6627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 10000, 'unit / ml', 74973);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 1000, 'unit / ml', 74976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 1000, 'unit / ml', 78841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 10000, 'unit / ml', 78842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('heparin sodium', 'B01AB01', 10000, 'unit / ml', 78843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dronedarone (dronedarone hydrochloride)', 'C01BD07', 400, 'mg', 81672);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 5, 'mg', 63418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 10, 'mg', 63419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 25, 'mg', 63420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 50, 'mg', 63421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 10, 'mg', 50116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 5, 'mg', 50115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 25, 'mg', 50117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 50, 'mg', 50120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 5, 'mg', 60871);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 10, 'mg', 60872);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 25, 'mg', 60873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 50, 'mg', 60874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 5, 'mg', 60994);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 10, 'mg', 60995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 25, 'mg', 60996);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 50, 'mg', 60997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 5, 'mg', 60236);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 10, 'mg', 60237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 25, 'mg', 60238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 50, 'mg', 60239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 2.5, 'mg', 66699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 2.5, 'mg', 74061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine hydrochloride)', 'N05AH01', 50, 'mg / ml', 34560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine hydrochloride)', 'N05AH01', 25, 'mg / ml', 62556);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loxapine (loxapine hydrochloride)', 'N05AH01', 25, 'mg / ml', 74062);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('digoxin', 'C01AA05', 0.0625, 'mg', 66032);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('digoxin', 'C01AA05', 0.125, 'mg', 66033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('digoxin', 'C01AA05', 0.25, 'mg', 66034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('digoxin', 'C01AA05', 0.125, 'mg', 69479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('digoxin', 'C01AA05', 0.0625, 'mg', 69478);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('digoxin', 'C01AA05', 0.25, 'mg', 69480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('digoxin', 'C01AA05', 0.25, 'mg', 76686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('digoxin', 'C01AA05', 0.125, 'mg', 76687);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('digoxin', 'C01AA05', 0.0625, 'mg', 76688);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('digoxin', 'C01AA05', 0.0625, 'mg', 82129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('digoxin', 'C01AA05', 0.125, 'mg', 82130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('digoxin', 'C01AA05', 0.250, 'mg', 82131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('digoxin', 'C01AA05', 0.25, 'mg / ml', 15757);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('digoxin', 'C01AA05', 0.05, 'mg / ml', 15756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('digoxin', 'C01AA05', 0.05, 'mg / ml', 66031);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gliclazide', 'A10BB09', 80, 'mg', 44051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gliclazide', 'A10BB09', 80, 'mg', 10918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gliclazide', 'A10BB09', 80, 'mg', 47424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gliclazide', 'A10BB09', 80, 'mg', 61497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gliclazide', 'A10BB09', 30, 'mg', 66827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gliclazide', 'A10BB09', 80, 'mg', 69269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gliclazide', 'A10BB09', 80, 'mg', 72804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gliclazide', 'A10BB09', 80, 'mg', 77975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gliclazide', 'A10BB09', 30, 'mg', 78313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gliclazide', 'A10BB09', 60, 'mg', 84157);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 50, 'mg', 18999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 25, 'mg', 19000);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 10, 'mg', 19001);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 10, 'mg', 9126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 50, 'mg', 9347);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 25, 'mg', 9348);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 10, 'mg', 8057);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 25, 'mg', 8058);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 50, 'mg', 8059);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 10, 'mg', 7442);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 25, 'mg', 7443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 50, 'mg', 7444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 50, 'mg', 7391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 25, 'mg', 7392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 10, 'mg', 7393);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 10, 'mg', 64798);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 25, 'mg', 64799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 50, 'mg', 64800);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 50, 'mg / ml', 8118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 10, 'mg / 5 ml', 8566);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 2, 'mg / ml', 316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 50, 'mg / ml', 50516);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('deferasirox', 'V03AC03', 125.0, 'mg', 77283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('deferasirox', 'V03AC03', 250.0, 'mg', 77284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('deferasirox', 'V03AC03', 500.0, 'mg', 77285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dodicin', 'V07AV', 0.4, '%', 3884);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin', 'J01CA01', 500, 'mg', 11172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin', 'J01CA01', 250, 'mg', 11173);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin', 'J01CA01', 250, 'mg', 5595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin', 'J01CA01', 500, 'mg', 5596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin', 'J01CA01', 500, 'mg', 1124);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin', 'J01CA01', 250, 'mg', 1125);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin (ampicillin sodium)', 'J01CA01', 2, 'g / vial', 37491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin (ampicillin sodium)', 'J01CA01', 1, 'g / vial', 37492);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin (ampicillin sodium)', 'J01CA01', 1, 'g / vial', 12267);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin (ampicillin sodium)', 'J01CA01', 2, 'g / vial', 12268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin (ampicillin sodium)', 'J01CA01', 500, 'mg / vial', 37493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin (ampicillin sodium)', 'J01CA01', 250, 'mg / vial', 37494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin (ampicillin sodium)', 'J01CA01', 250, 'mg / vial', 16990);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin (ampicillin sodium)', 'J01CA01', 250, 'mg / vial', 12261);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin (ampicillin sodium)', 'J01CA01', 500, 'mg / vial', 12262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin', 'J01CA01', 250, 'mg / 5 ml', 11170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin', 'J01CA01', 125, 'mg / 5 ml', 11171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin', 'J01CA01', 125, 'mg / 5 ml', 5827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin', 'J01CA01', 250, 'mg / 5 ml', 5828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ampicillin', 'J01CA01', 500, 'mg / 5 ml', 1270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trifluridine', 'S01AD02', 1, '%', 8203);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trifluridine', 'S01AD02', 1, '%', 72882);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin hydrochloride', 'G04CA03', 1, 'mg', 43244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin hydrochloride', 'G04CA03', 2, 'mg', 43245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin hydrochloride', 'G04CA03', 5, 'mg', 43246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin hydrochloride', 'G04CA03', 10, 'mg', 43247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin hydrochloride', 'G04CA03', 10, 'mg', 12778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin hydrochloride', 'G04CA03', 1, 'mg', 9618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin hydrochloride', 'G04CA03', 2, 'mg', 9619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('terazosin hydrochloride', 'G04CA03', 5, 'mg', 9542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hexachlorophene', 'D08AE01', 3, '%', 16734);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norfloxacin', 'J01MA06', 400, 'mg', 61027);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norfloxacin', 'J01MA06', 400, 'mg', 65123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norfloxacin', 'J01MA06', 400, 'mg', 70783);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norfloxacin', 'J01MA06', 400, 'mg', 75498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('norfloxacin', 'J01MA06', 400, 'mg', 78683);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cloxacillin sodium', 'J01CF02', 250, 'mg', 5674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cloxacillin sodium', 'J01CF02', 500, 'mg', 5673);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cloxacillin sodium', 'J01CF02', 1, 'g / vial', 13134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cloxacillin sodium', 'J01CF02', 2, 'g / vial', 12434);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cloxacillin sodium', 'J01CF02', 500, 'mg / vial', 12435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cloxacillin sodium', 'J01CF02', 125, 'mg / 5 ml', 6424);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cloxacillin sodium', 'J01CF02', 125, 'mg / 5 ml', 3794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moclobemide', 'N06AG02', 300, 'mg', 18969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moclobemide', 'N06AG02', 150, 'mg', 13256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moclobemide', 'N06AG02', 100, 'mg', 51594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moclobemide', 'N06AG02', 150, 'mg', 51595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moclobemide', 'N06AG02', 150, 'mg', 60426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moclobemide', 'N06AG02', 100, 'mg', 60425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moclobemide', 'N06AG02', 300, 'mg', 64019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moclobemide', 'N06AG02', 100, 'mg', 63228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moclobemide', 'N06AG02', 150, 'mg', 63229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moclobemide', 'N06AG02', 300, 'mg', 63230);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moclobemide', 'N06AG02', 150, 'mg', 67255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moclobemide', 'N06AG02', 300, 'mg', 67256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moclobemide', 'N06AG02', 150, 'mg', 67101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('moclobemide', 'N06AG02', 300, 'mg', 67102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiopental sodium', 'N01AF03', 500, 'mg', 6770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiopental sodium', 'N01AF03', 1, 'g / vial', 224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiopental sodium', 'N01AF03', 250, 'mg / syr', 6771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiopental sodium', 'N01AF03', 25, 'mg / ml', 8600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thiopental sodium', 'N01AF03', 5, 'g / bottle', 2315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paliperidone', 'N05AX13', 9, 'mg', 78561);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftazidime (ceftazidime pentahydrate)', 'J01DD02', 1, 'g / vial', 43080);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftazidime (ceftazidime pentahydrate)', 'J01DD02', 2, 'g / vial', 43081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftazidime (ceftazidime pentahydrate)', 'J01DD02', 6, 'g / vial', 43082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftazidime', 'J01DD02', 6, 'g / vial', 11371);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftazidime', 'J01DD02', 2, 'g / vial', 11372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ceftazidime', 'J01DD02', 1, 'g / vial', 11370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('emtricitabine', 'J05AF09', 200, 'mg', 75762);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trospium chloride', 'G04BD09', 20, 'mg', 76057);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trospium chloride', 'G04BD09', 60, 'mg', 82529);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxaliplatin', 'L01XA03', 50, 'mg / vial', 78159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxaliplatin', 'L01XA03', 100, 'mg / vial', 78160);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxaliplatin', 'L01XA03', 5, 'mg / ml', 78161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lenalidomide', 'L04AX04', 5, 'mg', 79016);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lenalidomide', 'L04AX04', 10, 'mg', 79017);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lenalidomide', 'L04AX04', 15, 'mg', 80322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lenalidomide', 'L04AX04', 25, 'mg', 80324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('darifenacin (darifenacin hydrobromide)', 'G04BD10', 7.5, 'mg', 75871);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('darifenacin (darifenacin hydrobromide)', 'G04BD10', 15, 'mg', 75872);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etodolac', 'M01AB08', 200, 'mg', 51745);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etodolac', 'M01AB08', 300, 'mg', 51746);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etodolac', 'M01AB08', 200, 'mg', 66748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etodolac', 'M01AB08', 300, 'mg', 66749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyldopa', 'C02AB02', 250, 'mg', 11167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyldopa', 'C02AB02', 500, 'mg', 11168);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyldopa', 'C02AB02', 125, 'mg', 11169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyldopa', 'C02AB02', 125, 'mg', 2470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyldopa', 'C02AB02', 250, 'mg', 2471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyldopa', 'C02AB02', 500, 'mg', 2909);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyldopa', 'C02AB02', 500, 'mg', 2251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyldopa', 'C02AB02', 125, 'mg', 2232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyldopa', 'C02AB02', 250, 'mg', 2188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl (fentanyl citrate)', 'N02AB03', 200, 'µg', 83587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl (fentanyl citrate)', 'N02AB03', 400, 'µg', 83588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl (fentanyl citrate)', 'N02AB03', 600, 'µg', 83589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl (fentanyl citrate)', 'N02AB03', 800, 'µg', 83590);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl (fentanyl citrate)', 'N02AB03', 1200, 'µg', 83591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl (fentanyl citrate)', 'N02AB03', 100, 'µg', 84910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl (fentanyl citrate)', 'N02AB03', 200, 'µg', 84911);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl (fentanyl citrate)', 'N02AB03', 300, 'µg', 84912);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl (fentanyl citrate)', 'N02AB03', 400, 'µg', 84913);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl (fentanyl citrate)', 'N02AB03', 600, 'µg', 84914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl (fentanyl citrate)', 'N02AB03', 800, 'µg', 84915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 25, 'µg / hour', 76148);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 50, 'µg / hour', 76149);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 75, 'µg / hour', 76150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 25, 'µg / hour', 76857);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 50, 'µg / hour', 76858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 75, 'µg / hour', 76859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 100, 'µg / hour', 76860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 100, 'µg / hour', 76151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 12.0, 'µg / hour', 81986);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 12, 'µg / hour', 79746);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 12, 'µg / hour', 82689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 25, 'µg / hour', 82690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 50, 'µg / hour', 82691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 75, 'µg / hour', 82692);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 100, 'µg / hour', 82693);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 25, 'µg / hour', 80018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 50, 'µg / hour', 80019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 75, 'µg / hour', 80020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 100, 'µg / hour', 80021);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 12, 'µg / hour', 81586);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 25, 'µg / hour', 81587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 50, 'µg / hour', 81588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 75, 'µg / hour', 81589);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 100, 'µg / hour', 81590);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 12, 'µg / hour', 81243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 25, 'µg / hour', 81244);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 37, 'µg / hour', 81245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 50, 'µg / hour', 81246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 75, 'µg / hour', 81247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl', 'N02AB03', 100, 'µg / hour', 81248);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl (fentanyl citrate)', 'N01AH01', 50, 'µg / ml', 12664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fentanyl (fentanyl citrate)', 'N01AH01', 50, 'µg / ml', 63983);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxtriphylline', 'R03DA02', 100, 'mg', 4894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxtriphylline', 'R03DA02', 200, 'mg', 4895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxtriphylline', 'R03DA02', 300, 'mg', 4898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxtriphylline', 'R03DA02', 10, 'mg / ml', 20293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxtriphylline', 'R03DA02', 100, 'mg / 5 ml', 3966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 25, 'mg', 18005);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 100, 'mg', 13392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 50, 'mg', 12662);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 25, 'mg', 61676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 50, 'mg', 61677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 100, 'mg', 61678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 100, 'mg', 64051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 50, 'mg', 64054);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 25, 'mg', 64055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 25.0, 'mg', 64918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 50.0, 'mg', 64919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 100.0, 'mg', 64920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 25, 'mg', 66267);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 50, 'mg', 66268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 100, 'mg', 66269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 25, 'mg', 68828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 50, 'mg', 68829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 100, 'mg', 68830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 25, 'mg', 69170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 50, 'mg', 69172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 100, 'mg', 69174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 25, 'mg', 69940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 50, 'mg', 69941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 100, 'mg', 69942);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 25, 'mg', 69856);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 50, 'mg', 69857);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 100, 'mg', 69858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 25, 'mg', 69900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 50, 'mg', 69901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 100, 'mg', 69902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 25, 'mg', 71283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 50, 'mg', 71284);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 100, 'mg', 71285);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 25, 'mg', 72848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 50, 'mg', 72849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 100, 'mg', 72850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 50, 'mg', 75917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 100, 'mg', 75918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 25, 'mg', 77280);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 50, 'mg', 77281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 100, 'mg', 77282);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 25, 'mg', 78908);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 50, 'mg', 78910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 100, 'mg', 78911);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 25, 'mg', 83874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 50, 'mg', 83875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 100, 'mg', 83876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 25, 'mg / cap', 75916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', 'G03AD01', 0.75, 'mg', 65334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', 'G02BA03', 52, 'mg', 66845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', 'G03AD01', 0.75, 'mg', 77107);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('levonorgestrel', 'G03AD01', 0.75, 'mg', 84978);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 46718);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 16473);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 10947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 11337);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 63871);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 72122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 72123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 72126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 72128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 72129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 71463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 71464);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 71465);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 71466);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 70769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 70770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 70771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 70772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 71540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 71541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 71542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 71543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 71544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 70934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 71245);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 71246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 71247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 71248);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 71249);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 71302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 71303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 71304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 71305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 71306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 71307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 71310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 71311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 71312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 71313);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 73865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 73866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 73867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 73868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 73869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 73870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 73871);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 73872);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 73873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 75133);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 75134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 75135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 76721);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 76722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 76723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 76724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 76725);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 76728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 76729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 76730);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 76731);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 76732);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 75463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 75464);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 75465);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 75466);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 75467);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 72430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 72429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 72431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 72432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 72433);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 73495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 73496);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 73497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 73498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 73499);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 73750);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 73751);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 73752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 73753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 73754);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 73864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 77028);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 77029);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 77030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 77031);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 77032);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 78626);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 78627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 78628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 78630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 78632);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 82862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 82863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 82864);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 82861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 82865);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 81676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 81677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 81678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 81679);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 81680);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 5, 'mg', 81483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 10, 'mg', 81484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 20, 'mg', 81485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 40, 'mg', 81486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('simvastatin', 'C10AA01', 80, 'mg', 81487);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 78184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('solifenacin succinate', 'G04BD08', 5, 'mg', 76292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('solifenacin succinate', 'G04BD08', 10, 'mg', 76293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 46352);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.15, '%', 44478);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1, '%', 45490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 41219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 41220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 41221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 37812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.15, '%', 34197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 6.25, '%', 29437);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 29438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 29436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.1, '%', 25675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 21701);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 4.5, '%', 19411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.25, '%', 19346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 20341);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 19504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 18892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 3.15, '%', 17969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 18799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 18782);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 18771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.09, '%', 18329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 6.25, '%', 19113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.2, '%', 18900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 17241);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 17242);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 17243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.5, '%', 16773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.14, '%', 15830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 16719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 16720);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.125, '%', 16238);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.09, '%', 16184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 6.25, '%', 15690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 15557);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 15507);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.43, '%', 15508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 14705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.115, '%', 13705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.115, '%', 13656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 14632);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 14617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 13553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 6.25, '%', 13394);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 13373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 6.25, '%', 13352);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 13868);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 14321);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 14211);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 14213);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 4.5, '%', 14215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 10490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 10491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 10471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 10425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 6.25, '%', 10429);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.6, '%', 11066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.125, '%', 12289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.125, '%', 12255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 6.25, '%', 11453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 12556);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 11431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.08, '%', 9224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 9223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.28, '%', 8354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 8606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 10010);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 4.5, '%', 8044);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 8045);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 8046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 7139);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 7071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 6535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 7041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 7022);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 4.5, '%', 6466);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 6469);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 6464);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 6465);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 7457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.35, '%', 5699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 6268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 3.5, '%', 6263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.29, '%', 7322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 7320);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 3.5, '%', 6667);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 6666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 3824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.6, '%', 3826);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.75, '%', 4199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.35, '%', 4200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 3619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 3592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.85, '%', 3594);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.5, '%', 5240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 4612);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.6, '%', 3471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 3470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 5088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 3924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 4494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 3307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.75, '%', 2545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 2298);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 3.12, '%', 2932);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 2196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 48111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 49187);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 49430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 50061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.84, '%', 50646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 50866);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 6.25, '%', 51889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 4.5, '%', 53825);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.44, '%', 62048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 61358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1, '%', 61471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 60867);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 61030);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 62389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 62391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 63262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.25, '%', 64703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 62730);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%', 64461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.154, '%', 67128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 65738);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 67182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.106, '%', 65270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 65846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.125, '%', 66387);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 7.95, '%', 64771);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 7.95, '%', 64770);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.86, '%', 65998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 66666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 64939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 66126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.106, '%', 65628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 65645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 68306);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 6.25, '%', 68862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.05, '%', 68930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 6.25, '%', 68931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 67324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 67373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.125, '%', 67389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 67406);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 67435);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 67464);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%', 67597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.154, '%', 67640);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 69936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 4.5, '%', 70067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.05, '%', 70765);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 72292);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 72294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 72295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 70135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 70143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%', 70144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.1, '%', 70805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.1, '%', 70804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 71528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 71597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 71598);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.115, '%', 70165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.05, '%', 70197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.05, '%', 70199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 69698);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%', 69699);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.145, '%', 70392);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1, '%', 70410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.11, '%', 70433);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.14, '%', 70460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 4.5, '%', 71966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.6, '%', 71987);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.6, '%', 70599);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.024, '%', 75171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.14, '%', 76460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.0240, '%', 76479);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 76537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%', 72822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 72823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.11, '%', 72834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%', 72860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.74, '%', 75223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 75231);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 76592);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.5, '%', 72930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 72931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 6.25, '%', 74028);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.15, '%', 74065);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.15, '%', 74069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 74338);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 74344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%', 75554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 4.5, '%', 75555);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 72428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 75729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%', 72572);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 72493);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.5, '%', 72494);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.05, '%', 72496);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 72497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.05, '%', 72614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.11, '%', 72615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 73297);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.175, '%', 73358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.09, '%', 74753);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%', 74808);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 73631);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprostadil', 'G04BE01', 250, 'µg', 62021);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.125, '%', 73675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.11, '%', 76314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.11, '%', 76315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%', 73723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.1, '%', 73722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 73726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%', 73838);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 77369);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 77370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 78416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.1, '%', 78430);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 4.5, '%', 77307);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 77126);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 77546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 77547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 77801);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 77802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 77829);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.154, '%', 77845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 77869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 77870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 77871);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.00, '%', 77382);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 78183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 5.0, 'mg', 81685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 77175);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 78260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 77591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.37, '%', 77649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 78326);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 76819);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.1375, '%', 77965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 67, 'mg', 67060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.1375, '%', 77966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 81582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.6, '%', 82831);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 82279);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 78729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.6, '%', 78730);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 82833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%', 79876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.115, '%', 80991);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 81854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 83037);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.85, '%', 78563);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%', 79842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%', 79844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 80719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.37, '%', 78918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 80171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 82556);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 4.5, '%', 80303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.14, '%', 80305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.154, '%', 80458);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 79860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.025, '%', 81121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 81653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 81844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.59, '%', 81845);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.145, '%', 80495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.14, '%', 82428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 81305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 81992);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 4.5, '%', 81995);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.154, '%', 80336);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.14, '%', 82417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%', 80541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 80464);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%', 80630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 82544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 79832);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.05, '%', 82115);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.1, '%', 82120);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.14, '%', 83084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.14, '%', 83511);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.14, '%', 83623);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.14, '%', 83682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.125, '%', 83946);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.154, '%', 83957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.05, '%', 83962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 84220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%', 84223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%', 84358);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 7.95, '%', 84366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.14, '%', 84373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.6, '%', 84440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.154, '%', 84554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5, '%', 84566);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%', 84768);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%', 85170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '% / w/w', 14193);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '% / w/w', 81274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.05, '% / w/w', 81277);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.5, '% / w/w', 82413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '% / w/w', 82414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '% / w/w', 80990);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '% / w/w', 80403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '% / w/w', 79976);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '% / w/w', 79901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 10, 'mg', 81686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '% / w/w', 81013);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '% / w/w', 81014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '% / w/w', 81303);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.145, '% / w/w', 82416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '% / w/w', 80465);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '% / w/w', 82548);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.2, '% / w/w', 84145);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 4.5, '% / w/w', 85444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.154, '% / w/v', 80304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.154, '% / w/v', 83956);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'D08AJ51', 0.05, '%', 18082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloroquinaldol', 'V04CL', 0.08, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estropipate', 'G03CA07', 0.75, 'mg', 16824);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estropipate', 'G03CA07', 3.0, 'mg', 16827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estropipate', 'G03CA07', 1.5, 'mg', 16816);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoleucine', 'B05ZA', 85, 'mg / 100 ml', 50094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iopromide', 'V08AB05', 50, '%', 16178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iopromide', 'V08AB05', 62, '%', 16179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iopromide', 'V08AB05', 77, '%', 16180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 1, 'mg', 12455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 2, 'mg', 12456);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 4, 'mg', 12457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 1, 'mg', 64067);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 2, 'mg', 64068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 4, 'mg', 64069);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 1, 'mg', 64570);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 2, 'mg', 64571);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 4, 'mg', 64572);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 1, 'mg', 66535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 2, 'mg', 66536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 4, 'mg', 66537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 1, 'mg', 68508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 2, 'mg', 68509);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 4, 'mg', 68510);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 1, 'mg', 70496);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 2, 'mg', 70497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 4, 'mg', 70498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 1, 'mg / tab', 64159);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 2, 'mg / tab', 64160);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 4, 'mg / tab', 64161);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tositumomab', 'V10XA53', 14, 'mg / ml', 75584);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloramphenicol', 'S01AA01', 0.5, '%', 6363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloramphenicol (chloramphenicol sodium succinate)', 'J01BA01', 1, 'g / vial', 2789);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloramphenicol', 'S01AA01', 1, '%', 16628);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloramphenicol', 'S01AA01', 0.5, '%', 16630);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloramphenicol', 'S01AA01', 1, '%', 13141);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloramphenicol', 'S01AA01', 0.5, '%', 12644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloramphenicol', 'S01AA01', 5, 'mg / ml', 19243);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloramphenicol', 'S01AA01', 2.5, 'mg / ml', 13116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chloramphenicol', 'S01AA01', 10, 'mg / g', 13117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('duloxetine (duloxetine hydrochloride)', 'N06AX21', 30, 'mg', 78681);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('duloxetine (duloxetine hydrochloride)', 'N06AX21', 60, 'mg', 78682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('anidulafungin', 'J02AX06', 100, 'mg / vial', 78747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('anidulafungin', 'J02AX06', 100, 'mg / vial', 81644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('manganese (manganese sulfate)', 'A12CX', 0.5, 'mg / ml', 13489);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('manganese (manganese sulfate)', 'A12CX', 0.1, 'mg / ml', 13486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitric oxide', 'R07AX01', 100, 'ppm / cylr', 75618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nitric oxide', 'R07AX01', 800, 'ppm / cylr', 75619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bevacizumab', 'L01XC07', 25, 'mg / ml', 75642);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rabies vaccine inactivated (human diploid-cell culture)', 'J07BG01', 2.5, 'unit / vial', 46832);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 2, 'mg', 11136);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 4, 'mg', 8111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 8, 'mg', 8102);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 16, 'mg', 8103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 4, 'mg', 52490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 8, 'mg', 52491);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 16, 'mg', 52492);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 2.0, 'mg', 78601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 2.0, 'mg', 77724);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 4.0, 'mg', 77725);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 8.0, 'mg', 77726);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 16, 'mg', 77727);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 2.0, 'mg', 78528);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 4.0, 'mg', 78529);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 8.0, 'mg', 78530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 16, 'mg', 78531);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 2.0, 'mg', 78532);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 4.0, 'mg', 78533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 8.0, 'mg', 78534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 16, 'mg', 78535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 2.0, 'mg', 78614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 4.0, 'mg', 78615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 8.0, 'mg', 78616);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 500, 'µg / ml', 78485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 16, 'mg', 78617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 2.0, 'mg', 78536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 4, 'mg', 78537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 8, 'mg', 78538);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 16, 'mg', 78539);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 2.0, 'mg', 78540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 4, 'mg', 78541);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 8, 'mg', 78542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 16, 'mg', 78543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 2.0, 'mg', 78544);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 4, 'mg', 78545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 8, 'mg', 78546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 16, 'mg', 78547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 2.0, 'mg', 80898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 4.0, 'mg', 80899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 8.0, 'mg', 80900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 16, 'mg', 80901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 32, 'mg', 81632);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 2, 'mg', 83747);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 4, 'mg', 83748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 8, 'mg', 83749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalapril sodium', 'C09AA02', 16, 'mg', 83750);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('spiramycin', 'J01FA02', 750000, 'unit', 13090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('spiramycin', 'J01FA02', 1500000, 'unit', 12601);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ergoloid mesylates', 'C04AE01', 1, 'mg', 690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 10, 'mg / vial', 62792);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 20, 'mg / vial', 62793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 30, 'mg / vial', 62794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 200, 'µg / ml', 19627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 50, 'µg / ml', 9915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 100, 'µg / ml', 9916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 500, 'µg / ml', 9917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 50, 'µg / ml', 72996);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 100, 'µg / ml', 72997);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 500, 'µg / ml', 72998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 200, 'µg / ml', 72999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 100, 'µg / ml', 78483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 200, 'µg / ml', 78484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetirizine hydrochloride', 'R06AE07', 20, 'mg', 46803);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetirizine hydrochloride', 'R06AE07', 5, 'mg', 43369);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetirizine hydrochloride', 'R06AE07', 10, 'mg', 43370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetirizine hydrochloride', 'R06AE07', 10, 'mg', 50975);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetirizine hydrochloride', 'R06AE07', 10, 'mg', 63802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetirizine hydrochloride', 'R06AE07', 10, 'mg', 63803);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetirizine hydrochloride', 'R06AE07', 5, 'mg', 64501);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetirizine hydrochloride', 'R06AE07', 10, 'mg', 80148);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetirizine hydrochloride', 'R06AE07', 20, 'mg', 80149);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetirizine hydrochloride', 'R06AE07', 10, 'mg', 84957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cetirizine hydrochloride', 'R06AE07', 5, 'mg / 5 ml', 61744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mometasone furoate', 'D07AC13', 0.1, '%', 11196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mometasone furoate', 'D07AC13', 0.1, '%', 11444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mometasone furoate', 'D07AC13', 0.1, '%', 68758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mometasone furoate', 'D07AC13', 0.1, '%', 75622);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mometasone furoate', 'D07AC13', 0.1, '%', 72459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mometasone furoate', 'D07AC13', 0.1, '%', 75025);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mometasone furoate', 'D07AC13', 0.1, '% / w/w', 75180);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mometasone furoate', 'D07AC13', 0.1, '% / w/w', 85196);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mometasone furoate', 'R01AD09', 50, 'µg / spray', 61885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mometasone furoate', 'D07AC13', 1, 'mg / g', 11443);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 15, 'mg', 43438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 30, 'mg', 43439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 15, 'mg', 43372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 30, 'mg', 43373);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 15, 'mg', 5616);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 30, 'mg', 5618);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 15, 'mg', 48627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 30, 'mg', 48634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 15, 'mg', 47984);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 30, 'mg', 47986);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 15, 'mg', 47988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 30, 'mg', 47989);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 15, 'mg', 66885);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 30, 'mg', 66886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 30, 'mg', 68805);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 15, 'mg', 68804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 15, 'mg', 75853);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 30, 'mg', 75854);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 15, 'mg', 78328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temazepam', 'N05CD07', 30, 'mg', 78329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('orphenadrine citrate', 'M03BC01', 100, 'mg', 16522);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('orphenadrine citrate', 'M03BC01', 100, 'mg', 14325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('orphenadrine citrate', 'M03BC01', 100, 'mg', 67477);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('orphenadrine citrate', 'M03BC01', 30, 'mg / ml', 14003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('orphenadrine citrate', 'M03BC01', 30, 'mg / ml', 47910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('maraviroc', 'J05AX09', 150, 'mg', 78519);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('maraviroc', 'J05AX09', 300, 'mg', 78520);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sitagliptin (sitagliptin phosphate monohydrate)', 'A10BH01', 100, 'mg', 78924);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('silicone', 'D02AA', 20, '%', 27514);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc (zinc sulfate)', 'A12CB01', 1, 'mg / ml', 13451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc (zinc sulfate)', 'A12CB01', 5, 'mg / ml', 13416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paliperidone', 'N05AX13', 6, 'mg', 78560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprostadil', 'G04BE01', 500, 'µg', 62022);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprostadil', 'G04BE01', 1000, 'µg', 62023);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprostadil', 'G04BE01', 23.2, 'µg / vial', 43155);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprostadil', 'G04BE01', 23.2, 'µg / vial', 20353);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprostadil', 'C01EA01', 500, 'µg / ml', 4802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprostadil', 'C01EA01', 500, 'µg / ml', 65340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alprostadil', 'C01EA01', 500, 'µg / ml', 77079);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyquaternium-1', 'S01XA20', 0.001, '%', 60122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('polyquaternium-1', 'S01XA20', 0.001, '%', 78302);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodoform', 'D09AA13', 5, '%', 74399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('enalaprilat', 'C09AA02', 1.25, 'mg / ml', 12650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cobaltous chloride', 'V04CL', 0.016, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine', 'R05DA04', 50, 'mg', 19050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine (codeine sulfate)', 'R05DA04', 50, 'mg', 19050);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine (codeine monohydrate)', 'R05DA04', 25, 'mg', 49057);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine (codeine sulfate)', 'R05DA04', 25, 'mg', 49057);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine', 'R05DA04', 100, 'mg / srt', 19049);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine (codeine sulfate)', 'R05DA04', 100, 'mg / srt', 19049);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine', 'R05DA04', 75, 'mg / srt', 19051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('codeine (codeine sulfate)', 'R05DA04', 75, 'mg / srt', 19051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('botulinum toxin type a', 'M03AX01', 100, 'unit / vial', 13476);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('botulinum toxin type a', 'M03AX01', 100, 'unit / vial', 67653);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lanthanum (lanthanum carbonate hydrate)', 'V03AE03', 250, 'mg', 77258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lanthanum (lanthanum carbonate hydrate)', 'V03AE03', 500, 'mg', 77259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lanthanum (lanthanum carbonate hydrate)', 'V03AE03', 750, 'mg', 77260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lanthanum (lanthanum carbonate hydrate)', 'V03AE03', 1000, 'mg', 77261);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('idursulfase', 'A16AB09', 2, 'mg / ml', 78165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluticasone furoate', 'R01AD12', 27.5, 'µg / act', 78388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paliperidone', 'N05AX13', 3, 'mg', 78559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paliperidone (paliperidone palmitate)', 'N05AX13', 50, 'mg / 0.5 ml', 83941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paliperidone (paliperidone palmitate)', 'N05AX13', 75, 'mg / 0.75 ml', 83942);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paliperidone (paliperidone palmitate)', 'N05AX13', 100, 'mg / 1 ml', 83943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('paliperidone (paliperidone palmitate)', 'N05AX13', 150, 'mg / 1.5 ml', 83944);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('temsirolimus', 'L01XE09', 25, 'mg / ml', 78941);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylnaltrexone bromide', 'A06AH01', 20, 'mg / ml', 79388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('panitumumab', 'L01XC08', 100, 'mg / 5 ml', 79412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosphenytoin sodium', 'N03AB05', 75, 'mg / ml', 50269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodixanol', 'V08AB09', 550, 'mg / ml', 18685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iodixanol', 'V08AB09', 652, 'mg / ml', 18694);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpropamide', 'A10BB02', 250, 'mg', 2091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpropamide', 'A10BB02', 100, 'mg', 2658);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('folic acid', 'B03BB01', 5, 'mg', 3778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('folic acid', 'B03BB01', 5, 'mg', 578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('folic acid', 'B03BB01', 5, 'mg', 3002);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('folic acid', 'B03BB01', 25, 'mg', 2283);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('folic acid', 'B03BB01', 5, 'mg', 77118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('folic acid', 'B03BB01', 5, 'mg', 85094);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('folic acid', 'B03BB01', 5, 'mg / ml', 10312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b12 (cyanocobalamin)', 'B03BA01', 100, 'µg / ml', 4268);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b12', 'B03BA01', 100, 'µg / ml', 65140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b12', 'B03BA01', 1000, 'µg / ml', 71746);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b12', 'B03BA01', 1, 'mg / ml', 16909);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b12', 'B03BA01', 1, 'mg / ml', 13324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b12', 'B03BA01', 1, 'mg / ml', 6262);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b12', 'B03BA01', 1, 'mg / ml', 4432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b12 (cyanocobalamin)', 'B03BA01', 1, 'mg / ml', 4269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vitamin b12', 'B03BA01', 1, 'mg / ml', 3500);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aliskiren (aliskiren fumarate)', 'C09XA02', 150, 'mg', 78739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aliskiren (aliskiren fumarate)', 'C09XA02', 300, 'mg', 78740);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 100, 'mg', 43440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 100, 'mg', 43375);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 200, 'mg', 17849);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 200, 'mg', 51210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 200, 'mg', 63352);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 200, 'mg', 63736);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 200, 'mg', 63876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 200, 'mg', 63903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 100, 'mg', 65258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 160, 'mg', 65259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 67, 'mg', 67469);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 200, 'mg', 67470);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 200, 'mg', 71549);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 200, 'mg', 71739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 100, 'mg', 71082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 160, 'mg', 71083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 48, 'mg', 75447);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 145, 'mg', 75448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 200, 'mg', 75904);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 160, 'mg', 73482);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 200, 'mg', 73485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 100, 'mg', 77447);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 160, 'mg', 77448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 100, 'mg', 77343);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 160, 'mg', 77344);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 200, 'mg', 77156);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 100, 'mg', 79587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 160, 'mg', 79588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 100, 'mg', 84171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fenofibrate', 'C10AB05', 160, 'mg', 84172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 250, 'mg', 51068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', 'H02AB09', 10, 'mg', 432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', 'H02AB09', 20, 'mg', 433);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', 'D07AA02', 1, '%', 28281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', 'D07AA02', 2.5, '%', 10844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', 'D07AA02', 1, '%', 9928);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', 'D07AA02', 2.5, '%', 5472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', 'D07AA02', 2.5, '%', 5413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', 'D07AA02', 1, '%', 7035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', 'D07AA02', 2.5, '%', 6695);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', 'D07AA02', 1, '%', 3370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', 'D07AA02', 1, '%', 410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', 'D07AA02', 1, '%', 411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone (hydrocortisone sodium succinate)', 'H02AB09', 1, 'g / vial', 15605);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone (hydrocortisone sodium succinate)', 'H02AB09', 1, 'g / vial', 14755);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone (hydrocortisone sodium succinate)', 'H02AB09', 1, 'g / vial', 2222);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone (hydrocortisone sodium succinate)', 'H02AB09', 100, 'mg / vial', 15608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone (hydrocortisone sodium succinate)', 'H02AB09', 250, 'mg / vial', 15607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone (hydrocortisone sodium succinate)', 'H02AB09', 500, 'mg / vial', 15606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone (hydrocortisone sodium succinate)', 'H02AB09', 100, 'mg / vial', 12346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone (hydrocortisone sodium succinate)', 'H02AB09', 250, 'mg / vial', 12229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone (hydrocortisone sodium succinate)', 'H02AB09', 500, 'mg / vial', 12703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone (hydrocortisone sodium succinate)', 'H02AB09', 500, 'mg / vial', 2221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone (hydrocortisone sodium succinate)', 'H02AB09', 100, 'mg / vial', 2219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone (hydrocortisone sodium succinate)', 'H02AB09', 250, 'mg / vial', 2220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', 'A07EA02', 100, 'mg / 60 ml', 18968);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', 'A07EA02', 100, 'mg / 60 ml', 7265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', 'D07AA02', 10, 'mg / g', 9272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', 'D07AA02', 10, 'mg / g', 3880);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocortisone', 'D07AA02', 10, 'mg / g', 3881);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisolone (prednisolone sodium phosphate)', 'H02AB06', 5, 'mg / 5 ml', 49795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisolone (prednisolone sodium phosphate)', 'H02AB06', 5, 'mg / 5 ml', 69619);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefadroxil', 'J01DB05', 500, 'mg', 56852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefadroxil', 'J01DB05', 500, 'mg', 64363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefadroxil', 'J01DB05', 500, 'mg', 79666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydralazine hydrochloride', 'C02DB02', 50, 'mg', 13412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpromazine (chlorpromazine hydrochloride)', 'N05AA01', 50.0, 'mg', 1293);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpromazine (chlorpromazine hydrochloride)', 'N05AA01', 25.0, 'mg', 1294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpromazine (chlorpromazine hydrochloride)', 'N05AA01', 100, 'mg', 1295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vecuronium bromide', 'M03AC03', 10.00, 'mg / vial', 65176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vecuronium bromide', 'M03AC03', 20.00, 'mg / vial', 65177);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amcinonide', 'D07AC11', 0.1, '%', 35664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amcinonide', 'D07AC11', 0.1, '%', 35665);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amcinonide', 'D07AC11', 0.1, '%', 35663);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amcinonide', 'D07AC11', 0.1, '%', 71333);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amcinonide', 'D07AC11', 0.1, '%', 71334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amcinonide', 'D07AC11', 0.1, '%', 71335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amcinonide', 'D07AC11', 0.1, '%', 70909);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurbiprofen', 'M01AE09', 50, 'mg', 16514);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurbiprofen', 'M01AE09', 100, 'mg', 16515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurbiprofen', 'M01AE09', 50, 'mg', 14092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurbiprofen', 'M01AE09', 100, 'mg', 14093);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurbiprofen', 'M01AE09', 100, 'mg', 11465);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurbiprofen', 'M01AE09', 50, 'mg', 11466);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurbiprofen', 'M01AE09', 100, 'mg', 6276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flurbiprofen', 'M01AE09', 50, 'mg', 6167);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorouracil', 'L01BC02', 5, '%', 2138);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorouracil', 'L01BC02', 50, 'mg / ml', 42841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluorouracil', 'L01BC02', 50, 'mg / ml', 10015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorthalidone', 'C03BA04', 50, 'mg', 2467);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorthalidone', 'C03BA04', 100, 'mg', 2468);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('potassium dichromate', 'V04CL', 0.019, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('selenium (selenious acid)', 'A12CX', 40, 'µg / ml', 13559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorine (sodium dichloro-s-triazinetrione)', 'V07AV', 3.1, '%', 61485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefixime', 'J01DD08', 400, 'mg', 10525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefixime', 'J01DD08', 100, 'mg / 5 ml', 10523);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydralazine hydrochloride', 'C02DB02', 10, 'mg', 12959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydralazine hydrochloride', 'C02DB02', 25, 'mg', 13413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydralazine hydrochloride', 'C02DB02', 10, 'mg', 11047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydralazine hydrochloride', 'C02DB02', 25, 'mg', 11626);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydralazine hydrochloride', 'C02DB02', 50, 'mg', 11627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol', 'N05AD01', 5, 'mg / ml', 10026);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydralazine hydrochloride', 'C02DB02', 10, 'mg', 12691);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydralazine hydrochloride', 'C02DB02', 25, 'mg', 8475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydralazine hydrochloride', 'C02DB02', 50, 'mg', 8476);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydralazine hydrochloride', 'C02DB02', 20, 'mg / amp', 12237);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorambucil', 'L01AA02', 2, 'mg', 1193);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenolate sodium', 'V07AV', 0.06, '%', 36396);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenolate sodium', 'V07AV', 0.06, '% / w/w', 36398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate trihydrate', 'H01BA02', 0.1, 'mg', 78965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate trihydrate', 'H01BA02', 0.2, 'mg', 78966);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate trihydrate', 'H01BA02', 0.1, 'mg', 83219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin acetate trihydrate', 'H01BA02', 0.2, 'mg', 83220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemcitabine (gemcitabine hydrochloride)', 'L01BC05', 1, 'g / vial', 49070);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemcitabine (gemcitabine hydrochloride)', 'L01BC05', 1, 'g / vial', 78409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemcitabine (gemcitabine hydrochloride)', 'L01BC05', 1, 'g / vial', 79108);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemcitabine (gemcitabine hydrochloride)', 'L01BC05', 1, 'g / vial', 80969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemcitabine (gemcitabine hydrochloride)', 'L01BC05', 1, 'g / vial', 78742);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemcitabine (gemcitabine hydrochloride)', 'L01BC05', 2, 'g / vial', 80422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemcitabine (gemcitabine hydrochloride)', 'L01BC05', 200, 'mg / vial', 49068);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemcitabine (gemcitabine hydrochloride)', 'L01BC05', 200, 'mg / vial', 78408);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemcitabine (gemcitabine hydrochloride)', 'L01BC05', 200, 'mg / vial', 79107);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gemcitabine (gemcitabine hydrochloride)', 'L01BC05', 200, 'mg / vial', 78741);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 15, 'mg', 63399);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 25, 'mg', 63400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 25, 'mg', 76522);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 25, 'mg', 50171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 100, 'mg', 50172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 200, 'mg', 50174);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 100, 'mg', 76524);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 200, 'mg', 76525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 200, 'mg', 75324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 25, 'mg', 74206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 100, 'mg', 74207);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 200, 'mg', 74208);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 25, 'mg', 75663);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 100, 'mg', 75664);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 200, 'mg', 75665);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 25, 'mg', 75666);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 100, 'mg', 75667);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 200, 'mg', 75668);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 25, 'mg', 74529);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 100, 'mg', 74530);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 25, 'mg', 73232);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 100, 'mg', 73233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 200, 'mg', 73234);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 25, 'mg', 74840);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 100, 'mg', 74841);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 200, 'mg', 74842);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 25, 'mg', 74874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 100, 'mg', 74875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 200, 'mg', 74876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 25, 'mg', 77316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 100, 'mg', 77317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 200, 'mg', 77318);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 25, 'mg', 81053);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 100, 'mg', 81054);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 200, 'mg', 81055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 50, 'mg', 79760);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 25, 'mg', 80117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 100, 'mg', 80118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 200, 'mg', 80119);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 25, 'mg', 79915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 100, 'mg', 79916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 200, 'mg', 79917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 100, 'mg', 83087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 25, 'mg', 83085);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 200, 'mg', 83088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 25, 'mg', 84197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 100, 'mg', 84198);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('topiramate', 'N03AX11', 200, 'mg', 84199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('disulfiram', 'V04CL', 0.005, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('estradiol valerate', 'G03CA03', 10, 'mg / ml', 9615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('finasteride', 'G04CB01', 5, 'mg', 13370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('finasteride', 'D11AX10', 1, 'mg', 61606);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('finasteride', 'G04CB01', 5, 'mg', 79259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('finasteride', 'G04CB01', 5, 'mg', 79578);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('finasteride', 'D11AX10', 1, 'mg', 82509);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('finasteride', 'D11AX10', 1, 'mg', 80561);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('finasteride', 'G04CB01', 5, 'mg', 80802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('finasteride', 'G04CB01', 5, 'mg', 83386);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('finasteride', 'G04CB01', 5, 'mg', 83421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('finasteride', 'G04CB01', 5, 'mg', 83549);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('finasteride', 'G04CB01', 5, 'mg', 83963);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('finasteride', 'G04CB01', 5, 'mg', 84031);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('finasteride', 'G04CB01', 5, 'mg', 84122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('finasteride', 'G04CB01', 5, 'mg', 84235);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imiquimod', 'D06BB10', 3.75, '% / w/w', 82603);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imiquimod', 'D06BB10', 3.75, '% / w/w', 85046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('imiquimod', 'D06BB10', 50, 'mg / g', 62979);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nepafenac', 'S01BC10', 0.1, '% / w/v', 79459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lactic acid', 'V07AV', 0.18, '% / w/w', 79490);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lactic acid', 'V07AV', 0.18, '% / w/w', 80740);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lactic acid', 'B05ZA', 5.400, 'g / 1000 ml', 76308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lactic acid', 'B05ZA', 5.400, 'g / 1000 ml', 76310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('edrophonium chloride', 'V04CX', 10, 'mg / ml', 12181);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amiloride hydrochloride', 'C03DB01', 5.0, 'mg', 73433);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pegvisomant', 'H01AX01', 10, 'mg / vial', 75772);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pegvisomant', 'H01AX01', 15, 'mg / vial', 75774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pegvisomant', 'H01AX01', 20, 'mg / vial', 75775);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trypan blue', 'S01KX02', 0.06, '%', 76514);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fludrocortisone 21-acetate', 'H02AA02', 0.1, 'mg', 19460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naphazoline nitrate', 'S01GA01', 0.5, 'mg / ml', 7203);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homatropine hydrobromide', 'S01FA05', 5, '%', 258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('homatropine hydrobromide', 'S01FA05', 2, '%', 257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbachol', 'N07AB01', 2, 'mg', 19401);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbachol', 'S01EB02', 0.01, '%', 3906);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbachol', 'S01EB02', 1.5, '%', 575);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbachol', 'S01EB02', 3, '%', 255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbachol', 'N07AB01', 0.25, 'mg / ml', 17400);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethopropazine (ethopropazine hydrochloride)', 'N04AA05', 50, 'mg', 12549);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 30, 'mg', 8595);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 60, 'mg', 8596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 10, 'mg', 5846);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 20, 'mg', 5847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 10, 'mg', 6733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 20, 'mg', 6734);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 40, 'mg', 6735);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 60, 'mg', 6737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 30, 'mg', 6122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 5, 'mg / ml', 11597);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 10, 'mg / ml', 7123);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 1, 'mg / ml', 6539);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 5, 'mg / ml', 6540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 20, 'mg / ml', 6903);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 20, 'mg / ml', 6182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 10, 'mg / ml', 6183);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 1, 'mg / ml', 6171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 50, 'mg / ml', 6736);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 1, 'mg / ml', 3752);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('morphine hydrochloride', 'N02AA01', 5, 'mg / ml', 4297);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('permethrin', 'P03AC04', 5, '%', 37239);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('permethrin', 'P03AC04', 1, '%', 8964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('permethrin', 'P03AC04', 5, '%', 50657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('permethrin', 'P03AC04', 1, '%', 50804);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('d-penicillamine', 'M01CC01', 250, 'mg', 287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol', 'N05AD01', 2, 'mg', 8170);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol', 'N05AD01', 5, 'mg', 8171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol', 'N05AD01', 10, 'mg', 8172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol', 'N05AD01', 20, 'mg', 8477);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol', 'N05AD01', 0.5, 'mg', 7128);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol', 'N05AD01', 1, 'mg', 7129);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol', 'N05AD01', 2, 'mg', 7130);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol', 'N05AD01', 10, 'mg', 7131);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol', 'N05AD01', 5, 'mg', 5859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol', 'N05AD01', 0.5, 'mg', 3918);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol', 'N05AD01', 1, 'mg', 3919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol (haloperidol decanoate)', 'N05AD01', 50, 'mg / ml', 16901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol (haloperidol decanoate)', 'N05AD01', 100, 'mg / ml', 16902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol', 'N05AD01', 2, 'mg / ml', 8558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol', 'N05AD01', 2, 'mg / ml', 5197);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol (haloperidol decanoate)', 'N05AD01', 50, 'mg / ml', 49965);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol (haloperidol decanoate)', 'N05AD01', 100, 'mg / ml', 49967);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol (haloperidol decanoate)', 'N05AD01', 50, 'mg / ml', 63111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol (haloperidol decanoate)', 'N05AD01', 100, 'mg / ml', 63112);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol (haloperidol decanoate)', 'N05AD01', 50, 'mg / ml', 66072);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('haloperidol (haloperidol decanoate)', 'N05AD01', 100, 'mg / ml', 66074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisone', 'H02AB07', 5, 'mg', 44807);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisone', 'H02AB07', 50, 'mg', 17756);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisone', 'H02AB07', 50, 'mg', 14281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisone', 'H02AB07', 5, 'mg', 6402);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisone', 'H02AB07', 1, 'mg', 5826);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisone', 'H02AB07', 5, 'mg', 4732);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisone', 'H02AB07', 50, 'mg', 4736);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisone', 'H02AB07', 50, 'mg', 1286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisone', 'H02AB07', 1, 'mg', 3076);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisone', 'H02AB07', 5, 'mg', 733);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisone', 'H02AB07', 5, 'mg', 507);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prednisone', 'H02AB07', 1.0, 'mg', 66101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('anethole trithione', 'A16AX02', 25.0, 'mg', 63884);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pinaverium bromide', 'A03AX04', 50, 'mg', 15176);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pinaverium bromide', 'A03AX04', 100, 'mg', 49943);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone acetate', 'H02AB04', 20, 'mg / ml', 18988);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone acetate', 'H02AB04', 40, 'mg / ml', 16275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone acetate', 'H02AB04', 80, 'mg / ml', 16276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone acetate', 'H02AB04', 40, 'mg / ml', 1134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone acetate', 'H02AB04', 80, 'mg / ml', 789);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone acetate', 'H02AB04', 40, 'mg / ml', 69444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone acetate', 'H02AB04', 80, 'mg / ml', 69454);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone acetate', 'H02AB04', 40, 'mg / ml', 69455);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methylprednisolone acetate', 'H02AB04', 80, 'mg / ml', 69456);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flupentixol decanoate', 'N05AF01', 20, 'mg / ml', 18800);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flupentixol decanoate', 'N05AF01', 100, 'mg / ml', 18737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flupentixol decanoate', 'N05AF01', 100, 'mg / ml', 81742);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('mebendazole', 'P02CA01', 100, 'mg', 4743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('testosterone enanthate', 'G03BA03', 200, 'mg / ml', 11224);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('testosterone enanthate', 'G03BA03', 200, 'mg / ml', 1275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aminophylline', 'R03DA05', 100, 'mg', 14688);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aminophylline', 'R03DA05', 50, 'mg / ml', 5704);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aminophylline', 'R03DA05', 25, 'mg / ml', 5705);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aminophylline', 'R03DA05', 25, 'mg / ml', 4226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aminophylline', 'R03DA05', 50, 'mg / ml', 4227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('labetalol hydrochloride', 'C07AG01', 100, 'mg', 29542);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('labetalol hydrochloride', 'C07AG01', 200, 'mg', 29543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('labetalol hydrochloride', 'C07AG01', 100, 'mg', 67456);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('labetalol hydrochloride', 'C07AG01', 200, 'mg', 67457);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('labetalol hydrochloride', 'C07AG01', 5, 'mg / ml', 51066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epinephrine racemic', 'R03AA01', 22.5, 'mg / ml', 39484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tobramycin', 'J01GB01', 28, 'mg', 85000);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tobramycin', 'S01AA12', 0.3, '%', 65418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tobramycin', 'S01AA12', 0.3, '%', 69799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tobramycin (tobramycin sulfate)', 'J01GB01', 1.2, 'g / vial', 5402);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tobramycin (tobramycin sulfate)', 'J01GB01', 1.2, 'g / vial', 77066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tobramycin', 'S01AA12', 0.3, '%', 4571);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tobramycin (tobramycin sulfate)', 'J01GB01', 10, 'mg / ml', 49816);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 500, 'mg', 50749);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tobramycin (tobramycin sulfate)', 'J01GB01', 40, 'mg / ml', 49817);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tobramycin', 'S01AA12', 3, 'mg / ml', 63055);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tobramycin (tobramycin sulfate)', 'J01GB01', 300, 'mg / 5 ml', 63101);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tobramycin (tobramycin sulfate)', 'J01GB01', 10, 'mg / ml', 64815);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tobramycin (tobramycin sulfate)', 'J01GB01', 40, 'mg / ml', 64816);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tobramycin', 'S01AA12', 3, 'mg / g', 5707);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buspirone hydrochloride', 'N05BE01', 10, 'mg', 43349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buspirone hydrochloride', 'N05BE01', 10, 'mg', 19799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buspirone hydrochloride', 'N05BE01', 10, 'mg', 20011);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buspirone hydrochloride', 'N05BE01', 10, 'mg', 52040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buspirone hydrochloride', 'N05BE01', 5, 'mg', 50219);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buspirone hydrochloride', 'N05BE01', 10, 'mg', 50220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buspirone hydrochloride', 'N05BE01', 10, 'mg', 50822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buspirone hydrochloride', 'N05BE01', 5, 'mg', 50317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buspirone hydrochloride', 'N05BE01', 10, 'mg', 50318);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buspirone hydrochloride', 'N05BE01', 10, 'mg', 65827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('buspirone hydrochloride', 'N05BE01', 10, 'mg', 74832);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimebutine maleate', 'A03AA05', 200, 'mg', 11743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimebutine maleate', 'A03AA05', 100, 'mg', 69763);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trimebutine maleate', 'A03AA05', 200, 'mg', 69764);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocodone bitartrate', 'R05DA03', 5, 'mg', 13314);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocodone bitartrate', 'R05DA03', 1, 'mg / ml', 13315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydrocodone bitartrate', 'R05DA03', 1, 'mg / ml', 80973);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dobutamine (dobutamine hydrochloride)', 'C01CA07', 12.5, 'mg / ml', 43484);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dobutamine (dobutamine hydrochloride)', 'C01CA07', 12.5, 'mg / ml', 43041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dobutamine (dobutamine hydrochloride)', 'C01CA07', 12.5, 'mg / ml', 47337);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dobutamine (dobutamine hydrochloride)', 'C01CA07', 12.5, 'mg / ml', 65680);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 2, 'mg', 43485);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 2, 'mg', 43486);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 2, 'mg', 43419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 2, 'mg', 35201);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 2, 'mg', 20012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 2, 'mg', 18071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 2, 'mg', 47464);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 2, 'mg', 49614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 2, 'mg', 61436);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 2, 'mg', 61604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 2, 'mg', 63011);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 2, 'mg', 74169);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 2, 'mg', 74281);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 2, 'mg', 73379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 2, 'mg', 78349);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 0.2, 'mg / ml', 42934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 0.2, 'mg / ml', 19218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 0.2, 'mg / ml', 14567);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loperamide hydrochloride', 'A07DA03', 2, 'mg / 15 ml', 77716);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gadofosveset trisodium', 'V08CA11', 244, 'mg / ml', 81886);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('varicella-zoster virus vaccine live attenuated (oka/merck strain)', 'J07BK01', 2000, 'unit / 0.5 ml', 64641);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('varicella-zoster virus vaccine live attenuated (oka/merck strain)', 'J07BK01', 1350, 'unit / 0.5 ml', 70216);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('varicella-zoster virus vaccine live attenuated (oka/merck strain)', 'J07BK02', 19400, 'pfu / 0.65 ml', 80146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpromazine hydrochloride', 'N05AA01', 25, 'mg / ml', 17004);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('chlorpromazine hydrochloride', 'N05AA01', 27.9, 'mg / ml', 8488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cocaine hydrochloride', 'R02AD03', 40, 'mg / ml', 25828);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cocaine hydrochloride', 'R02AD03', 100, 'mg / ml', 18334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cocaine hydrochloride', 'R02AD03', 100, 'mg / ml', 13391);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cocaine hydrochloride', 'R02AD03', 40, 'mg / ml', 12625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenazopyridine hydrochloride', 'G04BX06', 100, 'mg', 4388);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenazopyridine hydrochloride', 'G04BX06', 200, 'mg', 4260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenazopyridine hydrochloride', 'G04BX06', 200, 'mg', 3329);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenazopyridine hydrochloride', 'G04BX06', 100, 'mg', 1695);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dodicin hydrochloride', 'V07AV', 10, '%', 5590);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dodicin hydrochloride', 'V07AV', 3.5, '%', 5132);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dodicin hydrochloride', 'V07AV', 3, '%', 2405);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epirubicin hydrochloride', 'L01DB03', 50, 'mg / vial', 78641);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epirubicin hydrochloride', 'L01DB03', 2, 'mg / ml', 18504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epirubicin hydrochloride', 'L01DB03', 2, 'mg / ml', 75043);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epirubicin hydrochloride', 'L01DB03', 2.0, 'mg / ml', 79761);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epirubicin hydrochloride', 'L01DB03', 2, 'mg / ml', 78921);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epirubicin hydrochloride', 'L01DB03', 2, 'mg / ml', 80958);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esmolol hydrochloride', 'C07AB09', 10, 'mg / ml', 42910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('esmolol hydrochloride', 'C07AB09', 10, 'mg / ml', 79483);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethambutol hydrochloride', 'J04AK02', 100, 'mg', 1471);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ethambutol hydrochloride', 'J04AK02', 400, 'mg', 1472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluphenazine hydrochloride', 'N05AB02', 1, 'mg', 12572);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluphenazine hydrochloride', 'N05AB02', 2, 'mg', 12573);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluphenazine hydrochloride', 'N05AB02', 5, 'mg', 12574);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluphenazine hydrochloride', 'N05AB02', 1, 'mg', 2858);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluphenazine hydrochloride', 'N05AB02', 2.5, 'mg', 2859);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluphenazine hydrochloride', 'N05AB02', 5, 'mg', 2860);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluphenazine hydrochloride', 'N05AB02', 2, 'mg', 2861);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 30, 'mg', 43838);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 1, 'mg', 35655);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 8, 'mg', 35658);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 12, 'mg', 20171);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 24, 'mg', 20172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 3, 'mg', 18556);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 6, 'mg', 18558);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 3, 'mg', 13113);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 3, 'mg', 11869);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 2, 'mg', 11428);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 4, 'mg', 11425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 1, 'mg', 11413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 8, 'mg', 11363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 8, 'mg', 9509);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 4, 'mg', 5940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 2, 'mg', 5939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 1, 'mg', 6889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 18, 'mg', 67480);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 2, 'mg', 69806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 4, 'mg', 69807);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 8, 'mg', 69808);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 2, 'mg', 73474);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 4, 'mg', 73475);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 4, 'mg', 82286);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 8, 'mg', 82287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 16, 'mg', 82288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 32, 'mg', 82289);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 4.5, 'mg', 84452);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 9.0, 'mg', 84453);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 250, 'mg / vial', 16679);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 20, 'mg / ml', 17822);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 50, 'mg / ml', 17823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 10, 'mg / ml', 18323);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 50, 'mg / ml', 18324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 20, 'mg / ml', 18325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 2, 'mg / ml', 18315);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 1, 'mg / ml', 11870);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 1, 'mg / ml', 10173);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 10, 'mg / ml', 5936);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 2, 'mg / ml', 5937);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydromorphone hydrochloride', 'N02AA03', 100, 'mg / ml', 68787);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lodoxamide (lodoxamide tromethamine)', 'S01GX05', 0.1, '%', 13591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 250, 'mg', 42872);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 500, 'mg', 42873);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 250, 'mg', 3728);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 500, 'mg', 3729);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 250, 'mg', 48998);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 500, 'mg', 48999);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 250, 'mg', 50748);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 500, 'mg', 51070);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 250, 'mg', 61083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 500, 'mg', 61084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 25, 'mg / ml', 42874);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 50, 'mg / ml', 42875);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 75, 'mg / ml', 42876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 375, 'mg / 5 ml', 10545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 125, 'mg / 5 ml', 3730);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 250, 'mg / 5 ml', 3731);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 125, 'mg / 5 ml', 60834);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 250, 'mg / 5 ml', 60835);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefaclor', 'J01DC04', 375, 'mg / 5 ml', 60836);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoclopramide hydrochloride', 'A03FA01', 5, 'mg', 18060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoclopramide hydrochloride', 'A03FA01', 10, 'mg', 18061);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoclopramide hydrochloride', 'A03FA01', 5, 'mg', 10495);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoclopramide hydrochloride', 'A03FA01', 10, 'mg', 10496);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoclopramide hydrochloride', 'A03FA01', 5, 'mg', 49332);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoclopramide hydrochloride', 'A03FA01', 10, 'mg', 49335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoclopramide hydrochloride', 'A03FA01', 5, 'mg / ml', 42950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoclopramide hydrochloride', 'A03FA01', 5, 'mg / ml', 19409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoclopramide hydrochloride', 'A03FA01', 1, 'mg / ml', 49340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('metoclopramide hydrochloride', 'A03FA01', 5, 'mg / ml', 67481);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 40, 'mg', 37370);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 500, 'mg', 37375);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 20, 'mg', 37369);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 80, 'mg', 19189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 80, 'mg', 9240);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 80, 'mg', 6827);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 20, 'mg', 3809);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 40, 'mg', 2472);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 40, 'mg', 2447);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 20, 'mg', 2333);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 40, 'mg', 2851);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 20, 'mg', 2798);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 20, 'mg', 62684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 40, 'mg', 62685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 20, 'mg', 71616);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 40, 'mg', 71617);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 20, 'mg', 71743);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 40, 'mg', 71744);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 20, 'mg', 72451);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 40, 'mg', 72452);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 20, 'mg', 83669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 40, 'mg', 83670);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 80, 'mg', 83671);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 10, 'mg / ml', 37372);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 10, 'mg / ml', 12218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 10, 'mg / ml', 4431);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 10, 'mg / ml', 4910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 10, 'mg / ml', 84533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('furosemide', 'C03CA01', 10, 'mg / ml', 84539);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 43365);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 43366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('etravirine', 'J05AG04', 100, 'mg', 79246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 20259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 20260);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 19961);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 19962);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 19916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 19895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 19064);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 19071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 19073);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 19074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 13723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 9703);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 61172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 61173);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 63304);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 63305);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 65801);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 65802);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 65856);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 65857);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 65003);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 65006);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 67397);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 67398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 77154);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 77155);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 79103);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 79104);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 80053);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 80054);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 78795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 78796);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10, 'mg', 82954);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg', 82955);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg / 5 ml', 43418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg / 5 ml', 44218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20, 'mg / 5 ml', 50635);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 75, 'mg', 8199);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 10, 'mg', 9417);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 50, 'mg', 9418);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 25, 'mg', 9346);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 50, 'mg', 3141);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 75, 'mg', 3413);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 25, 'mg', 1929);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 10, 'mg', 1878);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 50, 'mg', 1263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 25, 'mg', 1264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 10, 'mg', 1265);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 10, 'mg', 2426);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 25, 'mg', 2427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 50, 'mg', 1690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 10, 'mg', 2213);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 25, 'mg', 2214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 50, 'mg', 2215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 10, 'mg', 71408);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 25, 'mg', 71409);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 50, 'mg', 71411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 10, 'mg', 71545);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 25, 'mg', 71546);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 50, 'mg', 71547);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 10, 'mg', 72460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 25, 'mg', 72461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amitriptyline hydrochloride', 'N06AA09', 50, 'mg', 72462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefuroxime (cefuroxime axetil)', 'J01DC02', 250, 'mg', 43086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefuroxime (cefuroxime axetil)', 'J01DC02', 500, 'mg', 43087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefuroxime (cefuroxime axetil)', 'J01DC02', 250, 'mg', 66439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefuroxime (cefuroxime axetil)', 'J01DC02', 500, 'mg', 66440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefuroxime (cefuroxime axetil)', 'J01DC02', 250, 'mg', 68362);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefuroxime (cefuroxime axetil)', 'J01DC02', 500, 'mg', 68363);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefuroxime (cefuroxime axetil)', 'J01DC02', 500, 'mg', 79704);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefuroxime (cefuroxime sodium)', 'J01DC02', 1.5, 'g / vial', 65299);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefuroxime (cefuroxime sodium)', 'J01DC02', 7.5, 'g / vial', 65300);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefuroxime (cefuroxime sodium)', 'J01DC02', 750, 'mg / vial', 65298);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefuroxime (cefuroxime axetil)', 'J01DC02', 125, 'mg / 5 ml', 43089);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('valrubicin', 'L01DB09', 40, 'mg / ml', 66191);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('micafungin sodium', 'J02AX05', 50, 'mg / vial', 77957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('micafungin sodium', 'J02AX05', 100, 'mg / vial', 79665);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epoprostenol (epoprostenol sodium)', 'B01AC09', 0.5, 'mg / vial', 50121);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('epoprostenol (epoprostenol sodium)', 'B01AC09', 1.5, 'mg / vial', 50122);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinonide', 'D07AC08', 0.05, '%', 19312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinonide', 'D07AC08', 0.05, '%', 19317);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinonide', 'D07AC08', 0.05, '%', 20008);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinonide', 'D07AC08', 0.05, '%', 19203);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinonide', 'D07AC08', 0.05, '%', 9276);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinonide', 'D07AC08', 0.05, '%', 5439);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinonide', 'D07AC08', 0.05, '%', 60294);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinonide', 'D07AC08', 0.05, '%', 60295);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinonide', 'D07AC08', 0.05, '% / w/w', 11682);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fluocinonide', 'D07AC08', 0.5, 'mg / g', 63806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carboprost (carboprost tromethamine)', 'G02AD04', 250, 'µg / ml', 49287);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piroxicam', 'M01AC01', 20, 'mg', 20205);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piroxicam', 'M01AC01', 10, 'mg', 20206);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piroxicam', 'M01AC01', 10, 'mg', 19269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piroxicam', 'M01AC01', 20, 'mg', 19270);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piroxicam', 'M01AC01', 20, 'mg', 18333);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piroxicam', 'M01AC01', 10, 'mg', 18335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piroxicam', 'M01AC01', 20, 'mg', 11178);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piroxicam', 'M01AC01', 10, 'mg', 11179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piroxicam', 'M01AC01', 20, 'mg', 6812);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piroxicam', 'M01AC01', 10, 'mg', 6813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piroxicam', 'M01AC01', 10, 'mg', 6714);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piroxicam', 'M01AC01', 20, 'mg', 6715);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('piroxicam', 'M01AC01', 20, 'mg', 63012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dinoprostone', 'G02AD02', 0.5, 'mg', 2684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dinoprostone', 'G02AD02', 10, 'mg / insert', 50327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dinoprostone', 'G02AD02', 0.5, 'mg / 2.5 ml', 10492);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dinoprostone', 'G02AD02', 1, 'mg / 3 g', 11830);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dinoprostone', 'G02AD02', 2, 'mg / 3 g', 11831);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diazoxide', 'V03AH01', 100, 'mg', 6269);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flavoxate hydrochloride', 'G04BD02', 200, 'mg', 7520);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flavoxate hydrochloride', 'G04BD02', 200, 'mg', 60251);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flavoxate hydrochloride', 'G04BD02', 200, 'mg', 68832);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('flavoxate hydrochloride', 'G04BD02', 200, 'mg', 69540);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('disopyramide', 'C01BA03', 100, 'mg', 37379);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('disopyramide', 'C01BA03', 150, 'mg', 37380);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pipotiazine palmitate', 'N05AC04', 25, 'mg / ml', 13164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pipotiazine palmitate', 'N05AC04', 50, 'mg / ml', 12223);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('naltrexone hydrochloride', 'N07BB04', 50, 'mg', 43143);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dabigatran etexilate (dabigatran etexilate mesilate)', 'B01AE07', 110, 'mg', 79795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dabigatran etexilate (dabigatran etexilate mesilate)', 'B01AE07', 75, 'mg', 79794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dabigatran etexilate (dabigatran etexilate mesilate)', 'B01AE07', 150, 'mg', 84384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenobarbital sodium', 'N03AA02', 120, 'mg / ml', 4266);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenobarbital sodium', 'N03AA02', 30, 'mg / ml', 4515);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenobarbital sodium', 'N03AA02', 30, 'mg / ml', 78939);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenobarbital sodium', 'N03AA02', 120, 'mg / ml', 78940);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('probenecid', 'M04AB01', 500, 'mg', 1883);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('idarubicin hydrochloride', 'L01DB06', 10, 'mg / vial', 19258);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('idarubicin hydrochloride', 'L01DB06', 5, 'mg / vial', 19259);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('idarubicin hydrochloride', 'L01DB06', 1, 'mg / ml', 76813);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('idarubicin hydrochloride', 'L01DB06', 1, 'mg / ml', 82316);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfinpyrazone', 'M04AB02', 200, 'mg', 14931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sulfinpyrazone', 'M04AB02', 200, 'mg', 3425);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pyrimethamine', 'P01BD01', 25, 'mg', 1116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('testosterone', 'G03BA03', 12.2, 'mg', 63125);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('testosterone', 'G03BA03', 24.3, 'mg', 70098);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('testosterone', 'G03BA03', 1, '%', 69384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('testosterone', 'G03BA03', 1, '%', 69385);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('testosterone', 'G03BA03', 1, '%', 76591);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('testosterone', 'G03BA03', 1, '%', 73432);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine hydrochloride', 'N06AA01', 25, 'mg', 43354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine hydrochloride', 'N06AA01', 50, 'mg', 43355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine hydrochloride', 'N06AA01', 10, 'mg', 43356);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine hydrochloride', 'N06AA01', 75, 'mg', 43357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine hydrochloride', 'N06AA01', 100, 'mg', 43060);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine hydrochloride', 'N06AA01', 50, 'mg', 20084);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine hydrochloride', 'N06AA01', 25, 'mg', 20085);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine hydrochloride', 'N06AA01', 10, 'mg', 20031);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine hydrochloride', 'N06AA01', 50, 'mg', 20032);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine hydrochloride', 'N06AA01', 75, 'mg', 20033);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine hydrochloride', 'N06AA01', 25, 'mg', 20000);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine hydrochloride', 'N06AA01', 100, 'mg', 19220);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine hydrochloride', 'N06AA01', 50, 'mg', 14116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine hydrochloride', 'N06AA01', 10, 'mg', 14117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine hydrochloride', 'N06AA01', 25, 'mg', 14118);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desipramine hydrochloride', 'N06AA01', 75, 'mg', 14288);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dipyridamole', 'B01AC07', 25, 'mg', 11034);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dipyridamole', 'B01AC07', 50, 'mg', 11035);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dipyridamole', 'B01AC07', 75, 'mg', 11036);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dipyridamole', 'B01AC07', 75, 'mg', 5893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dipyridamole', 'B01AC07', 25, 'mg', 4915);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dipyridamole', 'B01AC07', 50, 'mg', 4916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dipyridamole', 'B01AC07', 5, 'mg / ml', 6720);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dipyridamole', 'B01AC07', 5, 'mg / ml', 68907);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dipyridamole', 'B01AC07', 5, 'mg / ml', 68448);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prochlorperazine (prochlorperazine maleate)', 'N05AB04', 10, 'mg', 45324);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prochlorperazine (prochlorperazine maleate)', 'N05AB04', 5, 'mg', 45325);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prochlorperazine (prochlorperazine maleate)', 'N05AB04', 5, 'mg', 13641);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prochlorperazine (prochlorperazine maleate)', 'N05AB04', 10, 'mg', 13642);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prochlorperazine (prochlorperazine maleate)', 'N05AB04', 10, 'mg', 9564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 20, 'mg', 77987);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prochlorperazine (prochlorperazine maleate)', 'N05AB04', 5, 'mg', 9565);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prochlorperazine', 'N05AB04', 10, 'mg', 9919);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prochlorperazine', 'N05AB04', 10, 'mg / sup', 9629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prochlorperazine (prochlorperazine mesylate)', 'N05AB04', 5, 'mg / ml', 9972);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prochlorperazine (prochlorperazine mesylate)', 'N05AB04', 5, 'mg / ml', 9920);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tetrabenazine', 'N07XX06', 25, 'mg', 42959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('orciprenaline sulfate', 'R03CB03', 2, 'mg / ml', 60071);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tripelennamine hydrochloride', 'D04AA04', 2, '%', 62807);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('proxymetacaine hydrochloride', 'S01HA04', 0.5, '%', 16629);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('proxymetacaine hydrochloride', 'S01HA04', 0.5, '%', 6105);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('proxymetacaine hydrochloride', 'S01HA04', 0.5, '%', 1172);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('idebenone', 'N06BX13', 150, 'mg', 79969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nilotinib (nilotinib hydrochloride monohydrate)', 'L01XE08', 200, 'mg', 80138);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nilotinib (nilotinib hydrochloride monohydrate)', 'L01XE08', 150, 'mg', 85322);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rivaroxaban', 'B01AX06', 10, 'mg', 80247);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bethanechol chloride', 'N07AB02', 50, 'mg', 12887);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bethanechol chloride', 'N07AB02', 25, 'mg', 12745);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bethanechol chloride', 'N07AB02', 10, 'mg', 12746);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bethanechol chloride', 'N07AB02', 25, 'mg', 10708);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bethanechol chloride', 'N07AB02', 10, 'mg', 10709);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bethanechol chloride', 'N07AB02', 50, 'mg', 10710);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bethanechol chloride', 'N07AB02', 50, 'mg', 60352);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bethanechol chloride', 'N07AB02', 10, 'mg', 60350);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('bethanechol chloride', 'N07AB02', 25, 'mg', 60351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atropine sulfate', 'S01FA01', 1, '%', 16476);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atropine sulfate', 'S01FA01', 1, '%', 12215);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atropine sulfate', 'S01FA01', 1, '%', 254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atropine sulfate', 'S01FA01', 1, '% / w/v', 18862);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atropine sulfate', 'A03BA01', 0.4, 'mg / ml', 17184);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atropine sulfate', 'A03BA01', 0.6, 'mg / ml', 17186);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atropine sulfate', 'A03BA01', 0.3, 'mg / ml', 4291);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atropine sulfate', 'A03BA01', 0.4, 'mg / ml', 4228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atropine sulfate', 'A03BA01', 0.6, 'mg / ml', 4229);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atropine sulfate', 'A03BA01', 0.6, 'mg / ml', 3553);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atropine sulfate', 'A03BA01', 0.4, 'mg / ml', 3554);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atropine sulfate', 'A03BA01', 1, 'mg / ml', 4440);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atropine sulfate', 'A03BA01', 0.1, 'mg / ml', 2390);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 200, 'mg', 43018);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 400, 'mg', 43019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 800, 'mg', 43020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 200, 'mg', 19814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 400, 'mg', 19815);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 800, 'mg', 19816);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 800, 'mg', 15894);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 400, 'mg', 15895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 200, 'mg', 15896);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 400, 'mg', 11420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 200, 'mg', 7063);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 200, 'mg', 66607);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 400, 'mg', 66188);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 800, 'mg', 66189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 200, 'mg', 77144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 400, 'mg', 77145);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 800, 'mg', 77146);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 200, 'mg', 77200);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 400, 'mg', 77201);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 800, 'mg', 77202);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'D06BB03', 5, '% / w/w', 15525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'D06BB03', 5, '% / w/w', 4959);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir (acyclovir sodium)', 'J05AB01', 500, 'mg / vial', 50497);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir', 'J05AB01', 200, 'mg / 5 ml', 11416);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir (acyclovir sodium)', 'J05AB01', 50, 'mg / ml', 60218);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acyclovir (acyclovir sodium)', 'J05AB01', 25, 'mg / ml', 60208);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('phenylephrine (phenylephrine hydrochloride)', 'C01CA06', 10, 'mg / ml', 12889);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 10.0, 'mg', 79616);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('testosterone undecanoate', 'G03BA03', 40, 'mg', 13411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('testosterone undecanoate', 'G03BA03', 40, 'mg', 80793);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dimercaprol', 'V03AB09', 100, 'mg / ml', 18814);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iopamidol', 'V08AB04', 61, '%', 43505);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iopamidol', 'V08AB04', 76, '%', 43506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iopamidol', 'V08AB04', 76, '%', 65799);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iopamidol', 'V08AB04', 61, '%', 65800);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('iopamidol', 'V08AB04', 41, '%', 43504);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 10, 'mg', 9562);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 15, 'mg', 9563);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 30, 'mg', 9353);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 10, 'mg', 5563);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 15, 'mg', 3807);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 30, 'mg', 3808);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 10, 'mg', 3806);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 15, 'mg', 4794);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 30, 'mg', 4795);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 10, 'mg', 4796);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 10, 'mg', 3656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 15, 'mg', 3657);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 30, 'mg', 3658);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 15, 'mg', 5213);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 30, 'mg', 5214);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 10, 'mg', 3463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 30, 'mg', 3464);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 15, 'mg', 3465);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 10, 'mg', 71419);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 15, 'mg', 71420);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oxazepam', 'N05BA04', 30, 'mg', 71421);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olsalazine sodium', 'A07EC03', 250, 'mg', 17893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclophosphamide', 'L01AA01', 25, 'mg', 65460);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclophosphamide', 'L01AA01', 50, 'mg', 65461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclophosphamide', 'L01AA01', 200, 'mg / vial', 65462);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclophosphamide', 'L01AA01', 500, 'mg / vial', 65463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclophosphamide', 'L01AA01', 1000, 'mg / vial', 65464);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cyclophosphamide', 'L01AA01', 2000, 'mg / vial', 65465);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 2, '%', 34463);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 2, '%', 31582);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 2.5, '%', 19488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 0.5, '%', 18014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'N01BB02', 2, '%', 17002);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'N01BB02', 2, '%', 16823);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'N01BB02', 2, '%', 10977);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 0.5, '%', 48182);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 2.25, '%', 64645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 0.70, '%', 65636);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 0.70, '%', 65637);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 2, '%', 68438);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 2, '%', 68947);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 2, '%', 68948);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 2, '%', 68949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 0.5, '%', 75376);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 5, '%', 74327);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 0.72, '%', 74760);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 1, '%', 73395);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'N01BB02', 2, '%', 78152);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 1.0, '%', 77330);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 0.50, '% / w/w', 69189);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 1, '% / w/w', 82759);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'D04AB01', 20, 'mg / ml', 31563);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'C01BB01', 20, 'mg / ml', 18012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'N01BB02', 10, 'mg / ml', 17964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'C01BB01', 2, 'mg / ml', 10518);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'C01BB01', 4, 'mg / ml', 10519);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'C01BB01', 8, 'mg / ml', 10520);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'C01BB01', 10, 'mg / ml', 12645);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'C01BB01', 20, 'mg / ml', 8351);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'N01BB02', 40, 'mg / ml', 5536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'C01BB01', 4, 'mg / ml', 5339);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'C01BB01', 2, 'mg / ml', 5340);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'C01BB01', 100, 'mg / 5 ml', 4478);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'N01BB02', 5, 'mg / ml', 584);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 10, 'mg', 78083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'N01BB02', 10, 'mg / ml', 585);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'N01BB02', 20, 'mg / ml', 587);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'N01BB02', 20, 'mg / ml', 2935);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'N01BB02', 20, 'mg / ml', 209);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'N01BB02', 40, 'mg / ml', 210);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'N01BB02', 20, 'mg / ml', 212);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'N01BB02', 10, 'mg / ml', 78153);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'N01BB02', 10, 'mg / ml', 78773);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'N01BB02', 20, 'mg / ml', 78774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lidocaine hydrochloride', 'N01BB02', 10, 'mg / ml', 83355);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 15, 'mg', 82934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sodium acetate trihydrate', 'V07AB', 0.39, '%', 6366);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('procainamide hydrochloride', 'C01BA02', 375, 'g', 7150);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('procainamide hydrochloride', 'C01BA02', 500, 'mg', 7149);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('procainamide hydrochloride', 'C01BA02', 250, 'mg', 7151);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('procainamide hydrochloride', 'C01BA02', 500, 'mg', 6086);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('procainamide hydrochloride', 'C01BA02', 750, 'mg', 6087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('procainamide hydrochloride', 'C01BA02', 250, 'mg', 6088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('procainamide hydrochloride', 'C01BA02', 100, 'mg / ml', 19357);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cloxacillin (cloxacillin sodium)', 'J01CF02', 500, 'mg', 17116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cloxacillin (cloxacillin sodium)', 'J01CF02', 500, 'mg', 11164);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cloxacillin (cloxacillin sodium)', 'J01CF02', 250, 'mg', 11165);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cloxacillin (cloxacillin sodium)', 'J01CF02', 250, 'mg', 2233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cloxacillin (cloxacillin sodium)', 'J01CF02', 500, 'mg', 2234);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cloxacillin (cloxacillin sodium)', 'J01CF02', 125, 'mg / 5 ml', 11163);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dihydroergotamine mesylate', 'N02CA01', 4, 'mg / ml', 43498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dihydroergotamine mesylate', 'N02CA01', 1, 'mg / ml', 415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dihydroergotamine mesylate', 'N02CA01', 1, 'mg / ml', 64769);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sunitinib (sunitinib malate)', 'L01XE04', 12.5, 'mg', 76647);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sunitinib (sunitinib malate)', 'L01XE04', 25, 'mg', 76648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sunitinib (sunitinib malate)', 'L01XE04', 50, 'mg', 76649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclesonide', 'R03BA08', 100, 'µg / act', 77111);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclesonide', 'R03BA08', 200, 'µg / act', 77112);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciclesonide', 'R03BA08', 50, 'µg / act', 78899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amikacin (amikacin sulfate)', 'J01GB06', 250, 'mg / ml', 66810);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hamamelis virginiana', 'C05AX03', 50, '%', 36788);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olmesartan  medoxomil', 'C09CA08', 40, 'mg', 80415);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('olmesartan  medoxomil', 'C09CA08', 20, 'mg', 80414);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 1 conjugated to protein d carrier protein', 'J07AL02', 1, 'µg / 0.5 ml', 80596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 4 conjugated to protein d carrier protein', 'J07AL02', 3, 'µg / 0.5 ml', 80596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 1.25, 'mg', 81683);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 5 conjugated to protein d carrier protein', 'J07AL02', 1, 'µg / 0.5 ml', 80596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 6b conjugated to protein d carrier protein', 'J07AL02', 1, 'µg / 0.5 ml', 80596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 7f conjugated to protein d carrier protein', 'J07AL02', 1, 'µg / 0.5 ml', 80596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 9v conjugated to protein d carrier protein', 'J07AL02', 1, 'µg / 0.5 ml', 80596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 14 conjugated to protein d carrier protein', 'J07AL02', 1, 'µg / 0.5 ml', 80596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 23f conjugated to protein d carrier protein', 'J07AL02', 1, 'µg / 0.5 ml', 80596);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ustekinumab', 'L04AC05', 45, 'mg / 0.5 ml', 80608);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loteprednol etabonate', 'S01BA14', 0.5, '% / w/v', 80652);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('loteprednol etabonate', 'S01BA14', 0.2, '% / w/v', 80634);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desvenlafaxine (desvenlafaxine succinate)', 'N06AX23', 50, 'mg', 80650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desvenlafaxine (desvenlafaxine succinate)', 'N06AX23', 100, 'mg', 80651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('histrelin acetate', 'H01CA03', 50, 'mg', 76398);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lanreotide (lanreotide acetate)', 'H01CB03', 60, 'mg / 0.3 ml', 76900);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lanreotide (lanreotide acetate)', 'H01CB03', 90, 'mg / 0.3 ml', 76901);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lanreotide (lanreotide acetate)', 'H01CB03', 120, 'mg / 0.5 ml', 76902);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rotavirus vaccine (rix4414 strain), live, oral, attenuated (human)', 'J07BH01', 1000000, 'ccid50 / ml', 78588);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('carbon monoxide', 'V03AN05', 0.3, '%', 13895);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefotaxime (cefotaxime sodium)', 'J01DD01', 1.0, 'g / vial', 74689);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefotaxime (cefotaxime sodium)', 'J01DD01', 2.0, 'g / vial', 74690);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cefotaxime (cefotaxime sodium)', 'J01DD01', 500, 'mg / vial', 74688);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('nilutamide', 'L02BB02', 50, 'mg', 43312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('acamprosate calcium', 'N07BB03', 333, 'mg', 77863);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eculizumab', 'L04AA25', 10, 'mg / ml', 80774);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aripiprazole', 'N05AX12', 2.0, 'mg', 80782);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aripiprazole', 'N05AX12', 5.0, 'mg', 80783);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aripiprazole', 'N05AX12', 10.0, 'mg', 80784);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aripiprazole', 'N05AX12', 15.0, 'mg', 80785);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aripiprazole', 'N05AX12', 20.0, 'mg', 80786);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aripiprazole', 'N05AX12', 30.0, 'mg', 80790);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('romiplostim', 'B02BX04', 250, 'µg / 0.5 ml', 80832);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('romiplostim', 'B02BX04', 500, 'µg / ml', 80833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisdexamfetamine dimesylate', 'N06BA12', 50, 'mg', 80844);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisdexamfetamine dimesylate', 'N06BA12', 30, 'mg', 80843);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisdexamfetamine dimesylate', 'N06BA12', 20, 'mg', 83254);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisdexamfetamine dimesylate', 'N06BA12', 40, 'mg', 83255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lisdexamfetamine dimesylate', 'N06BA12', 60, 'mg', 83256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eplerenone', 'C03DA04', 25, 'mg', 80855);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eplerenone', 'C03DA04', 50, 'mg', 80856);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('methyl aminolevulinate (methyl aminolevulinate hydrochloride)', 'L01XD03', 168, 'mg / g', 80876);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clostridium botulinum neurotoxin type a (150kd), free from complexing proteins', 'M03AX01', 100, 'unit / vial', 80952);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosaprepitant (fosaprepitant dimeglumine)', 'A04AD', 150, 'mg / vial', 84835);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('golimumab', 'L04AB06', 50, 'mg / 0.5 ml', 81020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('golimumab', 'L04AB06', 50, 'mg / 0.5 ml', 81021);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized sweet vernal grass pollen', 'V01AA02', 100000, 'unit / ml', 81089);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized sweet vernal grass pollen', 'V01AA02', 20000, 'unit / ml', 81092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized redtop grass pollen', 'V01AA02', 100000, 'unit / ml', 61909);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized redtop grass pollen', 'V01AA02', 10000, 'unit / ml', 61910);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized redtop grass pollen', 'V01AA02', 100000, 'unit / ml', 66459);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized redtop grass pollen', 'V01AA02', 100000, 'unit / ml', 81087);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized redtop grass pollen', 'V01AA02', 25000, 'unit / ml', 81091);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized redtop grass pollen', 'V01AA02', 20000, 'unit / ml', 81092);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 2.5, 'mg', 81684);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized meadow fescue grass pollen', 'V01AA02', 100000, 'unit / ml', 61892);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized meadow fescue grass pollen', 'V01AA02', 10000, 'unit / ml', 61893);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized meadow fescue grass pollen', 'V01AA02', 100000, 'unit / ml', 66461);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized meadow fescue grass pollen', 'V01AA02', 100000, 'unit / ml', 81090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized perennial rye grass pollen', 'V01AA02', 100000, 'unit / ml', 61922);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized perennial rye grass pollen', 'V01AA02', 10000, 'unit / ml', 61923);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized perennial rye grass pollen', 'V01AA02', 100000, 'unit / ml', 66465);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('standardized perennial rye grass pollen', 'V01AA02', 100000, 'unit / ml', 81088);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lapatinib (lapatinib ditosylate monohydrate)', 'L01XE07', 250, 'mg', 81179);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('vorinostat', 'L01XX38', 100, 'mg', 81300);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rasagiline (rasagiline mesylate)', 'N04BD02', 0.5, 'mg', 77019);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('rasagiline (rasagiline mesylate)', 'N04BD02', 1.0, 'mg', 77020);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desonide', 'D07AB08', 0.05, '%', 43536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desonide', 'D07AB08', 0.05, '%', 43537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desonide', 'D07AB08', 0.05, '%', 33930);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desonide', 'D07AB08', 0.05, '%', 33931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desonide', 'D07AB08', 0.05, '%', 17138);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desonide', 'D07AB08', 0.05, '%', 83384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desonide', 'D07AB08', 0.05, '%', 17137);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dipivefrin hydrochloride', 'S01EA02', 0.1, '%', 61228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dipivefrin hydrochloride', 'S01EA02', 0.1, '%', 65914);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tigecycline', 'J01AA12', 50, 'mg / vial', 77090);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dasatinib (dasatinib monohydrate)', 'L01XE06', 20, 'mg', 77850);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dasatinib (dasatinib monohydrate)', 'L01XE06', 50, 'mg', 77851);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dasatinib (dasatinib monohydrate)', 'L01XE06', 70, 'mg', 77852);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dasatinib (dasatinib monohydrate)', 'L01XE06', 100, 'mg', 80564);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ranibizumab', 'S01LA04', 10, 'mg / ml', 78217);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gadopentetate dimeglumine', 'V08CA01', 469, 'mg / ml', 13384);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ciprofloxacin hydrochloride', 'S01AX13', 0.3, '%', 42964);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('penicillin v (penicillin v potassium)', 'J01CE02', 300, 'mg', 11957);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 1.25, 'mg', 43308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 2.5, 'mg', 43309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 10, 'mg', 43311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 15, 'mg', 81078);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 2.5, 'mg', 72226);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 5, 'mg', 72227);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 10, 'mg', 72228);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 2.5, 'mg', 72255);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 5, 'mg', 72256);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 10, 'mg', 72257);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 2.5, 'mg', 74047);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 5, 'mg', 74048);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 10, 'mg', 74051);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 15.0, 'mg', 76678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 1.25, 'mg', 73644);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 2.5, 'mg', 73646);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 5, 'mg', 73648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 10, 'mg', 73650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 1.25, 'mg', 78066);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 1.25, 'mg', 78079);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 2.5, 'mg', 78081);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 5, 'mg', 78082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 1.25, 'mg', 78477);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 2.5, 'mg', 77332);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 5, 'mg', 77334);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 10, 'mg', 77335);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 2.5, 'mg', 77336);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 5, 'mg', 77337);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 10, 'mg', 77338);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 1.25, 'mg', 77676);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 2.5, 'mg', 77677);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 5, 'mg', 77678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 10, 'mg', 77679);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 1.25, 'mg', 77309);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 2.5, 'mg', 77310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 5.0, 'mg', 77311);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 10.0, 'mg', 77312);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 15, 'mg', 79678);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 1.25, 'mg', 78648);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 2.5, 'mg', 78649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 5.0, 'mg', 78650);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 10, 'mg', 78651);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 1.25, 'mg', 79402);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 1.25, 'mg', 79403);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 1.25, 'mg', 79613);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 2.5, 'mg', 79614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ramipril', 'C09AA05', 5.0, 'mg', 79615);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ioversol', 'V08AB07', 51, '%', 43427);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ioversol', 'V08AB07', 64, '%', 43599);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ioversol', 'V08AB07', 68, '%', 43604);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ioversol', 'V08AB07', 51, '%', 19898);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ioversol', 'V08AB07', 74, '%', 19899);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ioversol', 'V08AB07', 74, '%', 14389);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ioversol', 'V08AB07', 68, '%', 11328);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 10, 'mg', 12759);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 20, 'mg', 12760);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 10, 'mg', 72096);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 20, 'mg', 72097);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 10, 'mg', 75137);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 20, 'mg', 75138);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 10, 'mg', 75144);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 20, 'mg', 75145);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 20, 'mg', 74117);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 10, 'mg', 74116);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 10, 'mg', 74778);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 20, 'mg', 74779);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 10, 'mg', 77986);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 10, 'mg', 78832);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 20, 'mg', 78833);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 10, 'mg', 81674);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fosinopril sodium', 'C09AA09', 20, 'mg', 81675);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('clofarabine', 'L01BB06', 1, 'mg / ml', 81614);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('certolizumab pegol', 'L04AB05', 200, 'mg / ml', 81737);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('doripenem (doripenem monohydrate)', 'J01DH04', 500, 'mg / vial', 81855);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose anhydrous', 'B05ZA', 500, 'g / 1000 ml', 70916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose anhydrous', 'B05ZA', 500, 'g / 1000 ml', 70916);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose anhydrous', 'B05ZA', 500, 'g / 1000 ml', 70917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose anhydrous', 'B05ZA', 500, 'g / 1000 ml', 70917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose anhydrous', 'B05ZA', 22.00, 'g / 1000 ml', 76308);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose anhydrous', 'B05ZA', 22.00, 'g / 1000 ml', 76310);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose anhydrous (dextrose monohydrate)', 'B05ZA', 1.1, 'g / l', 49560);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose anhydrous (dextrose monohydrate)', 'B05ZA', 1.1, 'g / l', 49559);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextrose anhydrous', 'B05ZA', 1.33, 'g / l', 78012);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('inact.japanese encephal virus(attenuat. strain sa14-14-2 produced in vero cells)', 'J07BA02', 6, 'µg / 0.5 ml', 81890);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('saxagliptin (saxagliptin hydrochloride)', 'A10BH03', 5, 'mg', 81917);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 14', 'J07AL02', 2, 'µg / 0.5 ml', 68040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 14', 'J07AL02', 2.2, 'µg / 0.5 ml', 82074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 14', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 18c', 'J07AL02', 2, 'µg / 0.5 ml', 68040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 18c', 'J07AL02', 2.2, 'µg / 0.5 ml', 82074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 18c', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 19f', 'J07AL02', 2, 'µg / 0.5 ml', 68040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 19f', 'J07AL02', 2.2, 'µg / 0.5 ml', 82074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 19f', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 23f', 'J07AL02', 2, 'µg / 0.5 ml', 68040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 23f', 'J07AL02', 2.2, 'µg / 0.5 ml', 82074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 23f', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 4', 'J07AL02', 2, 'µg / 0.5 ml', 68040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 4', 'J07AL02', 2.2, 'µg / 0.5 ml', 82074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 4', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 6b', 'J07AL02', 4, 'µg / 0.5 ml', 68040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 6b', 'J07AL02', 4.4, 'µg / 0.5 ml', 82074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 6b', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 9v', 'J07AL02', 2, 'µg / 0.5 ml', 68040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 9v', 'J07AL02', 2.2, 'µg / 0.5 ml', 82074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 9v', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 3', 'J07AL02', 2.2, 'µg / 0.5 ml', 82074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 3', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 5', 'J07AL02', 2.2, 'µg / 0.5 ml', 82074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 5', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 6a', 'J07AL02', 2.2, 'µg / 0.5 ml', 82074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 7f', 'J07AL02', 2.2, 'µg / 0.5 ml', 82074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 7f', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('azacitidine', 'L01BC07', 100, 'mg / vial', 82233);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('alglucosidase alfa', 'A16AB07', 50, 'mg / vial', 77041);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin (desmopressin acetate)', 'H01BA02', 60, 'µg', 77052);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin (desmopressin acetate)', 'H01BA02', 120, 'µg', 77053);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('desmopressin (desmopressin acetate)', 'H01BA02', 240, 'µg', 77054);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('telbivudine', 'J05AF11', 600, 'mg', 77381);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atracurium besylate', 'M03AC04', 10, 'mg / ml', 59791);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('atracurium besylate', 'M03AC04', 10, 'mg / ml', 60046);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('altretamine', 'L01XX03', 50, 'mg', 18669);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menotropins', 'G03GA02', 75, 'unit / vial', 72083);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('menotropins', 'G03GA02', 75, 'unit / vial', 76872);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotyp 19a', 'J07AL02', 2.2, 'µg / 0.5 ml', 82074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('silver dihydrogen citrate', 'V07AV', 0.003, '% / w/w', 82082);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 1', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 1', 'J07AL02', 2.2, 'µg / 0.5 ml', 82074);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('besifloxacin', 'S01AX23', 0.6, '% / w/v', 82246);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('degarelix (degarelix acetate)', 'L02BX02', 80, 'mg / vial', 82263);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('degarelix (degarelix acetate)', 'L02BX02', 120, 'mg / vial', 82264);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('thrombin alfa', 'B02BD30', 6000, 'unit / vial', 82488);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexmedetomidine (dexmedetomidine hydrochloride)', 'N05CM18', 100, 'µg / ml', 82498);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('gadoxetate disodium', 'V08CA10', 181.43, 'mg / ml', 82625);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('canakinumab', 'L04AC08', 150, 'mg / vial', 83040);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin glulisine (recombinant dna origin)', 'A10AB06', 100, 'unit / ml', 76507);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin glulisine (recombinant dna origin)', 'A10AB06', 100, 'unit / ml', 76506);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('insulin glulisine (recombinant dna origin)', 'A10AB06', 100, 'unit / ml', 77968);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac diethylamine', 'M02AA15', 1.16, '%', 77569);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diclofenac diethylamine', 'M02AA15', 1.16, '% / w/w', 82423);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('posaconazole', 'J02AC04', 40, 'mg / ml', 77877);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aprepitant', 'A04AD12', 80, 'mg', 78410);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aprepitant', 'A04AD12', 125, 'mg', 78411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aprepitant', 'A04AD12', 125, 'mg', 78412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('aprepitant', 'A04AD12', 80, 'mg', 78412);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('daptomycin', 'J01XX09', 500, 'mg / vial', 78525);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('raltegravir (raltegravir potassium)', 'J05AX08', 400, 'mg', 78722);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('calcium polystyrene sulfonate', 'V03AE01', 999, 'mg / g', 17205);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15, 'mg', 20261);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15, 'mg', 73931);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 7.5, 'mg', 73934);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15, 'mg', 75767);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 10, 'mg', 75821);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15, 'mg', 73742);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 7.5, 'mg / 5 ml', 37038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15, 'mg / 5 ml', 26149);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 7.5, 'mg / 5 ml', 12950);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 3, 'mg / ml', 13517);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 30, 'mg / 5 ml', 15140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 3, 'mg / ml', 11847);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 3, 'mg / ml', 11848);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15, 'mg / 5 ml', 12411);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15, 'mg / 5 ml', 11649);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15, 'mg / 5 ml', 11027);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15, 'mg / 15 ml', 12720);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 30, 'mg / 15 ml', 12723);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 3, 'mg / ml', 12788);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15, 'mg / 5 ml', 12621);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15, 'mg / 5 ml', 9543);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15, 'mg / 5 ml', 10054);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 12.5, 'mg / 5 ml', 7354);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15, 'mg / 5 ml', 4590);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 3, 'mg / ml', 3422);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide (dextromethorphan polistirex)', 'R05DA09', 30, 'mg / 5 ml', 50620);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide (dextromethorphan polistirex)', 'R05DA09', 30, 'mg / 5 ml', 50719);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide (dextromethorphan polistirex)', 'R05DA09', 15, 'mg / 5 ml', 60760);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 7.5, 'mg / 5 ml', 60140);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 7.5, 'mg / 5 ml', 65134);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15, 'mg / 5 ml', 65135);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15, 'mg / 5 ml', 74668);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 7.5, 'mg / 5 ml', 76356);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 30, 'mg / 30 ml', 76949);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15, 'mg / 5 ml', 80467);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('amyl cinnamal', 'V04CL', 0.015, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('isoeugenol', 'V04CL', 0.015, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cinnamyl alcohol', 'V04CL', 0.054, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('hydroxycitronellal', 'V04CL', 0.054, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('oak moss', 'V04CL', 0.07, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('diphenylguanidine', 'V04CL', 0.068, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc diethyldithiocarbamate', 'V04CL', 0.068, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zinc dibutyldithiocarbamate', 'V04CL', 0.068, 'mg / patch', 75739);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('varenicline (varenicline tartrate)', 'N07BA03', 0.5, 'mg', 77655);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('varenicline (varenicline tartrate)', 'N07BA03', 1.0, 'mg', 77656);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('varenicline (varenicline tartrate)', 'N07BA03', 0.5, 'mg', 78360);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('varenicline (varenicline tartrate)', 'N07BA03', 1.0, 'mg', 78360);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('prasugrel (prasugrel hydrochloride)', 'B01AC22', 10, 'mg', 83444);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tocilizumab', 'L04AC07', 80, 'mg / 4 ml', 83533);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tocilizumab', 'L04AC07', 200, 'mg / 10 ml', 83534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tocilizumab', 'L04AC07', 400, 'mg / 20 ml', 83535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sapropterin dihydrochloride', 'A16AX07', 100, 'mg', 83577);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('liraglutide', 'A10BX07', 6, 'mg / ml', 83627);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('trabectedin', 'L01CX01', 1, 'mg / vial', 83679);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pazopanib (pazopanib hydrochloride)', 'L01XE11', 200, 'mg', 83758);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('human c1 esterase inhibitor', 'B02AB03', 500, 'unit / vial', 83783);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('sevelamer carbonate', 'V03AE02', 800, 'mg', 83974);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('zucapsaicin', 'M02AB02', 0.075, '% / w/w', 83993);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexlansoprazole', 'A02BC06', 30, 'mg', 84014);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('dexlansoprazole', 'A02BC06', 60, 'mg', 84015);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('velaglucerase alfa', 'A16AB10', 400, 'unit / vial', 84221);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lacosamide', 'N03AX18', 50, 'mg', 84272);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lacosamide', 'N03AX18', 100, 'mg', 84273);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lacosamide', 'N03AX18', 150, 'mg', 84274);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('lacosamide', 'N03AX18', 200, 'mg', 84275);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('roflumilast', 'R03DX07', 500, 'µg', 84447);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tapentadol (tapentadol hydrochloride)', 'N02AX06', 50, 'mg', 84534);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tapentadol (tapentadol hydrochloride)', 'N02AX06', 100, 'mg', 84535);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tapentadol (tapentadol hydrochloride)', 'N02AX06', 150, 'mg', 84536);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tapentadol (tapentadol hydrochloride)', 'N02AX06', 200, 'mg', 84537);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tapentadol (tapentadol hydrochloride)', 'N02AX06', 250, 'mg', 84538);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 2', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotyp 8', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 9n', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 10a', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 11a', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 12f', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 15b', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 17f', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 19a', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 20', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 22f', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('pneumococcal polysaccharide serotype 33f', 'J07AL02', 25, 'µg / 0.5 ml', 2969);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('exenatide', 'A10BX04', 250, 'µg / ml', 84685);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('exenatide', 'A10BX04', 250, 'µg / ml', 84686);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eltrombopag (eltrombopag olamine)', 'B02BX05', 25, 'mg', 84687);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('eltrombopag (eltrombopag olamine)', 'B02BX05', 50, 'mg', 84688);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('fingolimod (fingolimod hydrochloride)', 'L04AA27', 0.5, 'mg', 85038);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('ticagrelor', 'B01AC24', 90, 'mg', 85352);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('cabazitaxel', 'L01CD04', 40, 'mg / ml', 85445);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolterodine tartrate', 'G04BD07', 1, 'mg', 62518);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolterodine tartrate', 'G04BD07', 2, 'mg', 62519);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolterodine tartrate', 'G04BD07', 2, 'mg', 68599);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('tolterodine tartrate', 'G04BD07', 4, 'mg', 68600);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('belimumab', 'L04AA26', 120, 'mg / vial', 85508);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('belimumab', 'L04AA26', 400, 'mg / vial', 85509);
INSERT INTO staging.consumable_substance (description, atc_code, amount, unit, drug_code) VALUES ('abiraterone acetate', 'L02BX03', 250, 'mg', 85626);


--
-- PostgreSQL database dump complete
--

--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = staging, pg_catalog;

--
-- Data for Name: vaccine; Type: TABLE DATA; Schema: staging; Owner: gm-dbo
--

INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '00075124', 'INTRADERMAL');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '00428833', 'SUBCUTANEOUS');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '00431648', 'SUBCUTANEOUS');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '00466085', 'SUBCUTANEOUS');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '00514462', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '00588490', 'SUBCUTANEOUS');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '00615358', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '00885975', 'ORAL');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '01908286', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '01919431', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '01959018', 'SUBCUTANEOUS');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '01959034', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '01959042', 'SUBCUTANEOUS');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02015986', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02130955', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02187078', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02223929', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02224143', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02229702', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02230578', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02230946', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02231056', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02231259', 'SUBCUTANEOUS');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02231267', 'SUBCUTANEOUS');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02231343', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02231523', 'ORAL');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02235721', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02237548', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02237792', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02239208', 'SUBCUTANEOUS');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02239910', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02240255', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02241047', 'SUBCUTANEOUS');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02242727', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02243167', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02243676', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02243741', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02243820', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02244081', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02245057', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02245977', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02246081', 'SUBCUTANEOUS');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02247208', 'ORAL');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02247600', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02248361', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02248649', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02253852', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02264625', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02267667', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02269562', 'SUBCUTANEOUS');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02279924', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02283190', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02284413', 'ORAL');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02296454', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02297884', 'SUBCUTANEOUS');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02300591', 'ORAL');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02312557', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02315939', 'SUBCUTANEOUS');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02320541', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02333279', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02335204', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02336650', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02342227', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02346850', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02347393', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02348756', 'INTRADERMAL');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02352044', 'INTRAMUSCULAR');
INSERT INTO staging.vaccine (is_live, external_code, route) VALUES (NULL, '02352621', 'NASAL');


--
-- PostgreSQL database dump complete
--



-- ===========================================================
-- add to ref.branded_drug if does not already exist
-- ===========================================================

-- provide for linkage to FreeDiams if does not exist
INSERT INTO Ref.data_source (
  version,
  name_short,
  name_long,
  source
)
SELECT '0.54', 'FreeDiams', '"Free Diams" Drug Database Frontend', 'http://ericmaeker.fr/FreeMedForms/di-manual/index.html' FROM Ref.data_source
WHERE NOT EXISTS (SELECT 1 FROM Ref.data_source WHERE position('FreeDiams' in name_short) > 0)
LIMIT 1
;

-- update staging.branded_drug with in-database foreign key to fk_data_source
UPDATE staging.branded_drug
SET fk_data_source =
(SELECT pk from Ref.data_source WHERE position('FreeDiams' in name_short) > 0)
;

-- add to ref.branded_drug where does not already exist
INSERT INTO ref.branded_drug (	
	description,
	preparation,
	atc_code,
	is_fake,
	fk_data_source,
	external_code,
	external_code_type
) 
SELECT DISTINCT ON (s_bd.external_code) initcap(s_bd.description), lower(preparation), atc_code, FALSE, (SELECT pk from Ref.data_source WHERE position('FreeDiams' in name_short) > 0), s_bd.external_code, 'FreeDiams::CA_HCDPD::DIN'
	FROM staging.branded_drug AS s_bd
	WHERE s_bd.external_code NOT IN
		(
		SELECT r_bd.external_code
		FROM ref.branded_drug AS r_bd
		WHERE r_bd.external_code_type = s_bd.external_code_type
		)
;

-- previous worked:
-- SELECT DISTINCT ON (s_bd.external_code) initcap(s_bd.description), lower(preparation), FALSE, (SELECT pk from Ref.data_source WHERE position('FreeDiams' in name_short) > 0), s_bd.external_code, 'FreeDiams::CA_HCDPD::DIN'
-- 	FROM staging.branded_drug AS s_bd
-- 	WHERE s_bd.external_code NOT IN
-- 		(
-- 		SELECT r_bd.external_code
-- 		FROM ref.branded_drug AS r_bd
-- 		WHERE r_bd.fk_data_source IN (
-- 			SELECT pk from Ref.data_source WHERE position('FreeDiams' in name_short) > 0
-- 			)
-- 		)
-- ;


-- alternative to test... perhaps computationally faster:
-- SELECT DISTINCT ON (s_bd.external_code) initcap(s_bd.description), lower(preparation), FALSE, (SELECT pk from Ref.data_source WHERE position('FreeDiams' in name_short) > 0), s_bd.external_code, 'FreeDiams::CA_HCDPD::DIN'
-- 	FROM staging.branded_drug AS s_bd
-- 	WHERE NOT EXISTS
-- 		(
-- 		SELECT s_bd.external_code
-- 		FROM ref.branded_drug AS r_bd
-- 		WHERE r_bd.fk_data_source IN (
-- 			SELECT pk from Ref.data_source WHERE position('FreeDiams' in name_short) > 0
-- 			)
-- 		);


-- ===========================================================
-- add to ref.consumable_substance
-- where does not already exist, and provided amounts are >= 0
-- ===========================================================

INSERT INTO ref.consumable_substance (
	description,
	atc_code,
	amount,
	unit
)
SELECT DISTINCT ON (description, amount, unit)
		lower(description),
		atc_code,
		amount,
		lower(unit)
	FROM
		staging.consumable_substance s_cs
	WHERE
		NOT EXISTS (
			SELECT 1
			FROM
				ref.consumable_substance r_cs
			WHERE
				UPPER(r_cs.description) = UPPER(s_cs.description)
					AND
				r_cs.amount = s_cs.amount
					AND
				UPPER(r_cs.unit) = UPPER(s_cs.unit)
			LIMIT 1
		)
		AND s_cs.amount >= 0
;

-- ==================================================================
-- create links ref.branded_drug.pk <--> ref.consumable_substance.pk
-- ==================================================================

-- create ~ 21,500 links
INSERT INTO ref.lnk_substance2brand (
	fk_brand,
	fk_substance
)
SELECT DISTINCT r_bd.pk, r_cs.pk
FROM ref.branded_drug r_bd
  INNER JOIN staging.branded_drug s_bd
  ON (r_bd.external_code = s_bd.external_code AND r_bd.fk_data_source = s_bd.fk_data_source)
   INNER JOIN staging.consumable_substance s_cs
   ON s_bd.drug_code = s_cs.drug_code
     INNER JOIN ref.consumable_substance r_cs
     ON (
         UPPER(s_cs.description) = UPPER(r_cs.description)
         AND s_cs.amount = r_cs.amount 
         AND UPPER(s_cs.unit) = UPPER(r_cs.unit)
         )
	WHERE
		NOT EXISTS (
			SELECT 1
			FROM
				ref.lnk_substance2brand r_ls
			WHERE
				r_bd.pk = r_ls.fk_brand
					AND
				r_cs.pk = r_ls.fk_substance
			LIMIT 1
		)
;

-- ===================================================
-- VACCINE import & creation
-- ===================================================
-- working from staging vaccines, where the branded drug is not yet represented
-- among 'production' vaccines.
-- Error-free insertion depends on
-- 1) matching branded substance to route by which it is administered
--   e.g. intramuscular, intradermal
--    which must already exist in clin.vacc_route
-- 2) matching to at least one indication-per-ingredient
-- Owing to foreign key restraints, these require to be wrapped inside a transaction
-- Also, short of writing a function, the indications easier to stage than directly insert.
-- Result is
-- ~ 72 vaccines, 68 unique products ~ (17 live) of which 4 have 2 routes (IM, SC)
-- (these address ~ 283 indications).
-- 145 indications

-- ===================================================
-- Map ingredients to indications
-- ===================================================
-- For the 'vaccine import' transaction, we need two parts.
-- The first part is new branded vaccines --> into clin.vaccine
-- The second part is more-laborious:
-- ... needs one-to-many mappings of ingredients to indications
-- ... e.g. some single 'ingredients' immunize against e.g. meningococcal, diphtheria
-- ... whereas some (pertactin) are non-specific adjuvants
-- then will need to insert not-yet-existing link pairs
-- ... {vaccine pk, indication}


-- populate staging table with mapped indications
-- ~ 476 records (108 distinct ingredient codes)
--  note: e.g. a 23-valent vaccine aganist pneumonococcus only constitutes one distinct indication


INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('cholera' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('cholera' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('cholera' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('diphtheria' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('diphtheria' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('diphtheria' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('haemophilus' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('haemophilus influenzae' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('haemophilus' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('hepatitis a' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('hepatitis a' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('hepatitis a' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('hepatitis b' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('hepatitis b' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('hepatitis b' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('papillomavirus' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('papillomavirus' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('papillomavirus' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('h1n1' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('h1n1' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('h1n1' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('h3n2' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('h3n2' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('h3n2' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('influenza' in lower(s_i.description)) > 0 AND position('haemophilus' in lower(s_i.description)) = 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('influenza (seasonal' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('influenza' in lower(s_i.description)) > 0 AND position('haemophilus' in lower(s_i.description)) = 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('haemagglutinin-strain b' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('influenza (seasonal' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('haemagglutinin-strain b' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('japanese' in lower(s_i.description)) > 0 AND position('enceph' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('japanese b' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('japanese' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('measles' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('measles' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('measles' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('mening' in lower(s_i.description)) > 0
 	AND position(' gr' in lower(s_i.description)) > 0 AND position('p a' in lower(s_i.description)) > 0
 	THEN
		(SELECT id FROM clin.vacc_indication WHERE position('meningococcus a' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('mening' in lower(s_i.description)) > 0
 	AND position(' gr' in lower(s_i.description)) > 0 AND position('p a' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('mening' in lower(s_i.description)) > 0
 	AND position(' gr' in lower(s_i.description)) > 0 AND position('p c' in lower(s_i.description)) > 0
 	THEN
		(SELECT id FROM clin.vacc_indication WHERE position('meningococcus c' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('mening' in lower(s_i.description)) > 0
 	AND position(' gr' in lower(s_i.description)) > 0 AND position('p c' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('mening' in lower(s_i.description)) > 0
 	AND position(' gr' in lower(s_i.description)) > 0 AND position('p w' in lower(s_i.description)) > 0
 	THEN
		(SELECT id FROM clin.vacc_indication WHERE position('meningococcus w' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('mening' in lower(s_i.description)) > 0
 	AND position(' gr' in lower(s_i.description)) > 0 AND position('p w' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('mening' in lower(s_i.description)) > 0
 	AND position(' gr' in lower(s_i.description)) > 0 AND position('p y' in lower(s_i.description)) > 0
 	THEN
		(SELECT id FROM clin.vacc_indication WHERE position('meningococcus y' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('mening' in lower(s_i.description)) > 0
 	AND position(' gr' in lower(s_i.description)) > 0 AND position('p y' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('mumps' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('mumps' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('mumps' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('pertussis' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('pertussis' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('pertussis' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('pneumococc' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('pneumococcus' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('pneumococc' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('polio' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('polio' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('polio' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('rabies' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('rabies' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('rabies' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('rotavirus' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('rotavirus' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('rotavirus' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('rubella' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('rubella' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('rubella' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('salmonella typhi' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('salmonella typhi' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('salmonella typhi' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('tetanus' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('tetanus' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('tetanus' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('tick-borne' in lower(s_i.description)) > 0 AND position('enceph' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('tick-borne' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('tick-borne' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('bacillus calmette-guerin' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('tuberculosis' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('bacillus calmette-guerin' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('varicella' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('varicella' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('varicella' in lower(s_i.description)) > 0;

INSERT INTO staging.ingred2ind (ingred_code, fk_indication)
SELECT s_i.ingred_code,
	CASE WHEN position('yellow fever' in lower(s_i.description)) > 0 THEN
		(SELECT id FROM clin.vacc_indication WHERE position('yellow fever' in lower(clin.vacc_indication.description)) > 0)
	END
FROM staging.ingred s_i
WHERE position('yellow fever' in lower(s_i.description)) > 0;


-- ===================================================
-- Insert vaccines and then create to-indication links
-- ===================================================
-- NOTE column id_route has been pulled out of the insert
-- it had been represented, in the select, by c_vr.id
-- and
--	INNER JOIN clin.vacc_route c_vr
--	  ON UPPER(c_vr.description) = UPPER(s_v.route)



INSERT INTO clin.vaccine  (
  is_live,
  fk_brand
)
SELECT
	CASE WHEN EXISTS
    	(SELECT 1
    	FROM ref.branded_drug AS r_bd
    	INNER JOIN staging.vaccine s_v
    	   ON s_v.external_code = r_bd.external_code
    	INNER JOIN staging.branded_drug s_bd
    	  ON r_bd.external_code = s_bd.external_code AND r_bd.external_code_type = s_bd.external_code_type
    	INNER JOIN staging.ingred s_i
    	  ON s_bd.drug_code = s_i.drug_code
    	AND position(' live ' in lower(s_i.description)) > 0
    	LIMIT 1
    	) THEN TRUE ELSE NULL
	END,
	r_bd.pk
	FROM ref.branded_drug AS r_bd
	INNER JOIN staging.vaccine s_v
	   ON s_v.external_code = r_bd.external_code
	INNER JOIN staging.branded_drug s_bd
	  ON r_bd.external_code = s_bd.external_code AND r_bd.external_code_type = s_bd.external_code_type
	AND NOT EXISTS
			(SELECT 1
			FROM clin.vaccine c_v
			INNER JOIN ref.branded_drug as r_bd
			  ON c_v.fk_brand = r_bd.pk
			WHERE r_bd.external_code = s_bd.external_code AND r_bd.external_code_type = s_bd.external_code_type
			LIMIT 1
			)
;


-- 	AND NOT EXISTS
-- 			(SELECT 1
-- 			FROM clin.vaccine c_v
-- 			INNER JOIN ref.branded_drug as r_bd
-- 			  ON c_v.fk_brand = r_bd.pk
-- 			WHERE r_bd.fk_data_source = (SELECT pk from Ref.data_source WHERE position('FreeDiams' in name_short) > 0)
-- 			AND s_v.external_code = r_bd.external_code
-- 			LIMIT 1
-- 			)


-- 	  ON r_bd.external_code = s_bd.external_code AND r_bd.fk_data_source = s_bd.fk_data_source
--	WHERE r_bd.fk_data_source = (SELECT pk from Ref.data_source WHERE position('FreeDiams' in name_short) > 0)


-- ======================================================
-- Create the links
-- ======================================================

INSERT INTO clin.lnk_vaccine2inds (
  fk_indication,
  fk_vaccine
)
SELECT DISTINCT s_i2i.fk_indication, c_v.pk
FROM staging.ingred2ind s_i2i
INNER JOIN staging.ingred s_i
  ON s_i.ingred_code = s_i2i.ingred_code
INNER JOIN staging.branded_drug s_bd
  ON s_bd.drug_code = s_i.drug_code
INNER JOIN ref.branded_drug r_bd
  ON r_bd.external_code = s_bd.external_code AND r_bd.external_code_type = s_bd.external_code_type
INNER JOIN clin.vaccine c_v
  ON c_v.fk_brand = r_bd.pk
WHERE s_i2i.fk_indication > 0
AND NOT EXISTS
			(SELECT 1
			FROM clin.lnk_vaccine2inds c_lvi
			WHERE fk_indication = s_i2i.fk_indication
			AND fk_vaccine = c_v.pk
			LIMIT 1
			)
;

commit;

-- =================
-- cleanup and exit
-- =================

\unset ON_ERROR_STOP
DROP TABLE staging.branded_drug CASCADE;
DROP TABLE staging.consumable_substance CASCADE;
DROP TABLE staging.vaccine CASCADE;
DROP TABLE staging.ingred CASCADE;
DROP TABLE staging.ingred2ind CASCADE;
\set ON_ERROR_STOP 1

-- end